<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
<xsl:stylesheet xmlns:xs="http://www.w3.org/2001/XMLSchema"
                xmlns:xsd="http://www.w3.org/2001/XMLSchema"
                xmlns:saxon="http://saxon.sf.net/"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:schold="http://www.ascc.net/xml/schematron"
                xmlns:iso="http://purl.oclc.org/dsdl/schematron"
                xmlns:xhtml="http://www.w3.org/1999/xhtml"
                xmlns:hl7="urn:hl7-org:v3"
                xmlns:cda="urn:hl7-org:v3"
                xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
                xmlns:hl7v2="urn:hl7-org:v2xml"
                xmlns:lab="urn:oid:1.3.6.1.4.1.19376.1.3.2"
                xmlns:sdtc="urn:hl7-org:sdtc"
                xmlns:hl7nl="urn:hl7-nl:v3"
                xmlns:nfu="urn:urn:nictiz-nl:v3/nfu"
                xmlns:pharm="urn:ihe:pharm:medication"
                version="2.0"><!--Implementers: please note that overriding process-prolog or process-root is 
    the preferred method for meta-stylesheets to use where possible. -->
   <xsl:param name="archiveDirParameter"/>
   <xsl:param name="archiveNameParameter"/>
   <xsl:param name="fileNameParameter"/>
   <xsl:param name="fileDirParameter"/>
   <xsl:variable name="document-uri">
      <xsl:value-of select="document-uri(/)"/>
   </xsl:variable>

   <!--PHASES-->


   <!--PROLOG-->
   <xsl:output xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
               method="xml"
               omit-xml-declaration="no"
               standalone="yes"
               indent="yes"/>

   <!--XSD TYPES FOR XSLT2-->


   <!--KEYS AND FUNCTIONS-->


   <!--DEFAULT RULES-->


   <!--MODE: SCHEMATRON-SELECT-FULL-PATH-->
   <!--This mode can be used to generate an ugly though full XPath for locators-->
   <xsl:template match="*" mode="schematron-select-full-path">
      <xsl:apply-templates select="." mode="schematron-get-full-path"/>
   </xsl:template>

   <!--MODE: SCHEMATRON-FULL-PATH-->
   <!--This mode can be used to generate an ugly though full XPath for locators-->
   <xsl:template match="*" mode="schematron-get-full-path">
      <xsl:apply-templates select="parent::*" mode="schematron-get-full-path"/>
      <xsl:text>/</xsl:text>
      <xsl:choose>
         <xsl:when test="namespace-uri()=''">
            <xsl:value-of select="name()"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:text>*:</xsl:text>
            <xsl:value-of select="local-name()"/>
            <xsl:text>[namespace-uri()='</xsl:text>
            <xsl:value-of select="namespace-uri()"/>
            <xsl:text>']</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="preceding"
                    select="count(preceding-sibling::*[local-name()=local-name(current())                                   and namespace-uri() = namespace-uri(current())])"/>
      <xsl:text>[</xsl:text>
      <xsl:value-of select="1+ $preceding"/>
      <xsl:text>]</xsl:text>
   </xsl:template>
   <xsl:template match="@*" mode="schematron-get-full-path">
      <xsl:apply-templates select="parent::*" mode="schematron-get-full-path"/>
      <xsl:text>/</xsl:text>
      <xsl:choose>
         <xsl:when test="namespace-uri()=''">@<xsl:value-of select="name()"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:text>@*[local-name()='</xsl:text>
            <xsl:value-of select="local-name()"/>
            <xsl:text>' and namespace-uri()='</xsl:text>
            <xsl:value-of select="namespace-uri()"/>
            <xsl:text>']</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
   </xsl:template>

   <!--MODE: SCHEMATRON-FULL-PATH-2-->
   <!--This mode can be used to generate prefixed XPath for humans-->
   <xsl:template match="node() | @*" mode="schematron-get-full-path-2">
      <xsl:for-each select="ancestor-or-self::*">
         <xsl:text>/</xsl:text>
         <xsl:value-of select="name(.)"/>
         <xsl:if test="preceding-sibling::*[name(.)=name(current())]">
            <xsl:text>[</xsl:text>
            <xsl:value-of select="count(preceding-sibling::*[name(.)=name(current())])+1"/>
            <xsl:text>]</xsl:text>
         </xsl:if>
      </xsl:for-each>
      <xsl:if test="not(self::*)">
         <xsl:text/>/@<xsl:value-of select="name(.)"/>
      </xsl:if>
   </xsl:template>
   <!--MODE: SCHEMATRON-FULL-PATH-3-->
   <!--This mode can be used to generate prefixed XPath for humans 
	(Top-level element has index)-->
   <xsl:template match="node() | @*" mode="schematron-get-full-path-3">
      <xsl:for-each select="ancestor-or-self::*">
         <xsl:text>/</xsl:text>
         <xsl:value-of select="name(.)"/>
         <xsl:if test="parent::*">
            <xsl:text>[</xsl:text>
            <xsl:value-of select="count(preceding-sibling::*[name(.)=name(current())])+1"/>
            <xsl:text>]</xsl:text>
         </xsl:if>
      </xsl:for-each>
      <xsl:if test="not(self::*)">
         <xsl:text/>/@<xsl:value-of select="name(.)"/>
      </xsl:if>
   </xsl:template>

   <!--MODE: GENERATE-ID-FROM-PATH -->
   <xsl:template match="/" mode="generate-id-from-path"/>
   <xsl:template match="text()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.text-', 1+count(preceding-sibling::text()), '-')"/>
   </xsl:template>
   <xsl:template match="comment()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.comment-', 1+count(preceding-sibling::comment()), '-')"/>
   </xsl:template>
   <xsl:template match="processing-instruction()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.processing-instruction-', 1+count(preceding-sibling::processing-instruction()), '-')"/>
   </xsl:template>
   <xsl:template match="@*" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.@', name())"/>
   </xsl:template>
   <xsl:template match="*" mode="generate-id-from-path" priority="-0.5">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:text>.</xsl:text>
      <xsl:value-of select="concat('.',name(),'-',1+count(preceding-sibling::*[name()=name(current())]),'-')"/>
   </xsl:template>

   <!--MODE: GENERATE-ID-2 -->
   <xsl:template match="/" mode="generate-id-2">U</xsl:template>
   <xsl:template match="*" mode="generate-id-2" priority="2">
      <xsl:text>U</xsl:text>
      <xsl:number level="multiple" count="*"/>
   </xsl:template>
   <xsl:template match="node()" mode="generate-id-2">
      <xsl:text>U.</xsl:text>
      <xsl:number level="multiple" count="*"/>
      <xsl:text>n</xsl:text>
      <xsl:number count="node()"/>
   </xsl:template>
   <xsl:template match="@*" mode="generate-id-2">
      <xsl:text>U.</xsl:text>
      <xsl:number level="multiple" count="*"/>
      <xsl:text>_</xsl:text>
      <xsl:value-of select="string-length(local-name(.))"/>
      <xsl:text>_</xsl:text>
      <xsl:value-of select="translate(name(),':','.')"/>
   </xsl:template>
   <!--Strip characters-->
   <xsl:template match="text()" priority="-1"/>

   <!--SCHEMA SETUP-->
   <xsl:template match="/">
      <svrl:schematron-output xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                              title=" Schematron file for OUL_R22 - Notificatie resultaten "
                              schemaVersion="">
         <xsl:comment>
            <xsl:value-of select="$archiveDirParameter"/>   
		 <xsl:value-of select="$archiveNameParameter"/>  
		 <xsl:value-of select="$fileNameParameter"/>  
		 <xsl:value-of select="$fileDirParameter"/>
         </xsl:comment>
         <svrl:ns-prefix-in-attribute-values uri="urn:hl7-org:v3" prefix="hl7"/>
         <svrl:ns-prefix-in-attribute-values uri="urn:hl7-org:v3" prefix="cda"/>
         <svrl:ns-prefix-in-attribute-values uri="http://www.w3.org/2001/XMLSchema-instance" prefix="xsi"/>
         <svrl:ns-prefix-in-attribute-values uri="http://www.w3.org/2001/XMLSchema" prefix="xs"/>
         <svrl:ns-prefix-in-attribute-values uri="urn:hl7-org:v2xml" prefix="hl7v2"/>
         <svrl:ns-prefix-in-attribute-values uri="http://www.w3.org/XML/1998/namespace" prefix="xml"/>
         <svrl:ns-prefix-in-attribute-values uri="urn:oid:1.3.6.1.4.1.19376.1.3.2" prefix="lab"/>
         <svrl:ns-prefix-in-attribute-values uri="urn:hl7-org:sdtc" prefix="sdtc"/>
         <svrl:ns-prefix-in-attribute-values uri="urn:hl7-nl:v3" prefix="hl7nl"/>
         <svrl:ns-prefix-in-attribute-values uri="urn:urn:nictiz-nl:v3/nfu" prefix="nfu"/>
         <svrl:ns-prefix-in-attribute-values uri="urn:ihe:pharm:medication" prefix="pharm"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M12"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="name">OUL_R22_Lab2PublicHealth</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M13"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">template-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000</xsl:attribute>
            <xsl:attribute name="name">Lab2PublicHealth Resultaatbericht (OUL^R22)</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M14"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">template-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000-closed</xsl:attribute>
            <xsl:attribute name="name">Lab2PublicHealth Resultaatbericht (OUL^R22)</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M15"/>
      </svrl:schematron-output>
   </xsl:template>

   <!--SCHEMATRON PATTERNS-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl"> Schematron file for OUL_R22 - Notificatie resultaten </svrl:text>

   <!--PATTERN -->
   <xsl:template match="text()" priority="-1" mode="M12"/>
   <xsl:template match="@*|node()" priority="-2" mode="M12">
      <xsl:apply-templates select="*" mode="M12"/>
   </xsl:template>

   <!--PATTERN OUL_R22_Lab2PublicHealth-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">OUL_R22_Lab2PublicHealth</svrl:text>

	  <!--RULE -->
   <xsl:template match="/" priority="1000" mode="M13">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::hl7v2:MSH | descendant-or-self::hl7v2:NTE | descendant-or-self::hl7v2:OUL_R22.PATIENT | descendant-or-self::hl7v2:OUL_R22.VISIT | descendant-or-self::hl7v2:OUL_R22.SPECIMEN | descendant-or-self::hl7v2:DSC"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::hl7v2:MSH | descendant-or-self::hl7v2:NTE | descendant-or-self::hl7v2:OUL_R22.PATIENT | descendant-or-self::hl7v2:OUL_R22.VISIT | descendant-or-self::hl7v2:OUL_R22.SPECIMEN | descendant-or-self::hl7v2:DSC">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>In de instance werd tenminste één van de volgende elementen verwacht: descendant-or-self::hl7v2:MSH | descendant-or-self::hl7v2:NTE | descendant-or-self::hl7v2:OUL_R22.PATIENT | descendant-or-self::hl7v2:OUL_R22.VISIT | descendant-or-self::hl7v2:OUL_R22.SPECIMEN | descendant-or-self::hl7v2:DSC</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M13"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M13"/>
   <xsl:template match="@*|node()" priority="-2" mode="M13">
      <xsl:apply-templates select="*" mode="M13"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000Lab2PublicHealth Resultaatbericht (OUL^R22)-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">Lab2PublicHealth Resultaatbericht (OUL^R22)</svrl:text>

	  <!--RULE d20e13342-false-d746284e0-->
   <xsl:template match="/hl7v2:OUL_R22" priority="6391" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth): element hl7v2:MSH is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth): element hl7v2:MSH komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NTE) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth): element hl7v2:NTE komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OUL_R22.PATIENT) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7v2:OUL_R22.PATIENT) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth): element hl7v2:OUL_R22.PATIENT is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OUL_R22.PATIENT) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7v2:OUL_R22.PATIENT) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth): element hl7v2:OUL_R22.PATIENT komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OUL_R22.VISIT) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7v2:OUL_R22.VISIT) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth): element hl7v2:OUL_R22.VISIT is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OUL_R22.VISIT) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7v2:OUL_R22.VISIT) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth): element hl7v2:OUL_R22.VISIT komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OUL_R22.SPECIMEN) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7v2:OUL_R22.SPECIMEN) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth): element hl7v2:OUL_R22.SPECIMEN is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DSC) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DSC) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth): element hl7v2:DSC komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH" priority="6390" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.1) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.1) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.1 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.2) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.2) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.2 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.3) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.3) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.3 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.4) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.4) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.4 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.5) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.5) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.5 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.6) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.6) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.6 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.7) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.7) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.7 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.9) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.9) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.9 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.10) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.10) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.10 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.11) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.11) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.11 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.12) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.12) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.12 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.13) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.13) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.14) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.14) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.15) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.15) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.15 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.15) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.15) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.16) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.16) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.16 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.16) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.16) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.17) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.17) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.18) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.18) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.19) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.19) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.20) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.20) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.21) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.21) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.21 is mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.21) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.21) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.1"
                 priority="6389"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van Item MOET '1' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Field Separator') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Field Separator') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Field Separator' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.2"
                 priority="6388"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('2') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('2') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van Item MOET '2' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Encoding Characters') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Encoding Characters') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Encoding Characters' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.3"
                 priority="6387"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('3') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('3') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van Item MOET '3' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70361') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70361') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van Table MOET 'HL70361' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Sending Application') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Sending Application') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Sending Application' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.3/hl7v2:HD.1"
                 priority="6385"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.3/hl7v2:HD.2"
                 priority="6384"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.3/hl7v2:HD.3"
                 priority="6383"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.4"
                 priority="6381"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('4') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('4') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van Item MOET '4' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70362') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70362') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van Table MOET 'HL70362' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Sending Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Sending Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Sending Facility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.4/hl7v2:HD.1"
                 priority="6379"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.4/hl7v2:HD.2"
                 priority="6378"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.4/hl7v2:HD.3"
                 priority="6377"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.5"
                 priority="6375"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('5') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('5') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van Item MOET '5' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70361') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70361') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van Table MOET 'HL70361' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Receiving Application') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Receiving Application') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Receiving Application' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.5/hl7v2:HD.1"
                 priority="6373"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.5/hl7v2:HD.2"
                 priority="6372"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.5/hl7v2:HD.3"
                 priority="6371"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.6"
                 priority="6369"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('6') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('6') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van Item MOET '6' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70362') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70362') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van Table MOET 'HL70362' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Receiving Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Receiving Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Receiving Facility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.6/hl7v2:HD.1"
                 priority="6367"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.6/hl7v2:HD.2"
                 priority="6366"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.6/hl7v2:HD.3"
                 priority="6365"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.7"
                 priority="6363"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('7') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('7') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van Item MOET '7' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Date/Time Of Message') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Date/Time Of Message') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Date/Time Of Message' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.7/hl7v2:TS.1"
                 priority="6361"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.7/hl7v2:TS.2"
                 priority="6360"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.8"
                 priority="6358"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('8') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('8') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van Item MOET '8' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Security') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Security') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Security' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.9"
                 priority="6357"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='OUL^R22^OUL_R22'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="text()='OUL^R22^OUL_R22'">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSG_datatype): de elementinhoud van hl7v2:MSH.9 MOET ''OUL^R22^OUL_R22'' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSG.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSG.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSG_datatype): element hl7v2:MSG.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSG.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSG.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSG_datatype): element hl7v2:MSG.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSG.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSG.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSG_datatype): element hl7v2:MSG.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('9') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('9') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van Item MOET '9' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('MSG') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('MSG') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van Type MOET 'MSG' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Message Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Message Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Message Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.9/hl7v2:MSG.1"
                 priority="6355"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSG_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70076') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70076') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSG_datatype): de waarde van Table MOET 'HL70076' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Message Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Message Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSG_datatype): de waarde van LongName MOET 'Message Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.9/hl7v2:MSG.2"
                 priority="6353"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSG_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70003') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70003') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSG_datatype): de waarde van Table MOET 'HL70003' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Trigger Event') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Trigger Event') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSG_datatype): de waarde van LongName MOET 'Trigger Event' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.9/hl7v2:MSG.3"
                 priority="6351"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSG_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70354') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70354') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSG_datatype): de waarde van Table MOET 'HL70354' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Message Structure') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Message Structure') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSG_datatype): de waarde van LongName MOET 'Message Structure' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.10"
                 priority="6349"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('10') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('10') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van Item MOET '10' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Message Control ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Message Control ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Message Control ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.11"
                 priority="6348"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PT.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PT.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.48-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PT_datatype): element hl7v2:PT.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PT.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PT.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.48-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PT_datatype): element hl7v2:PT.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('11') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('11') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van Item MOET '11' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('PT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('PT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van Type MOET 'PT' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Processing ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Processing ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Processing ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.11/hl7v2:PT.1"
                 priority="6346"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.48-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PT_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70103') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70103') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.48-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PT_datatype): de waarde van Table MOET 'HL70103' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Processing ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Processing ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.48-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PT_datatype): de waarde van LongName MOET 'Processing ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.11/hl7v2:PT.2"
                 priority="6344"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.48-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PT_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70207') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70207') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.48-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PT_datatype): de waarde van Table MOET 'HL70207' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Processing Mode') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Processing Mode') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.48-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PT_datatype): de waarde van LongName MOET 'Processing Mode' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.12"
                 priority="6342"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='2.5'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="text()='2.5'">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(VID_datatype): de elementinhoud van hl7v2:MSH.12 MOET ''2.5'' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:VID.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:VID.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(VID_datatype): element hl7v2:VID.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:VID.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:VID.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(VID_datatype): element hl7v2:VID.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:VID.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:VID.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(VID_datatype): element hl7v2:VID.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('12') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('12') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van Item MOET '12' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('VID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('VID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van Type MOET 'VID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.1"
                 priority="6340"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(VID_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70104') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70104') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(VID_datatype): de waarde van Table MOET 'HL70104' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(VID_datatype): de waarde van LongName MOET 'Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.2"
                 priority="6338"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(VID_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70399') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70399') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(VID_datatype): de waarde van Table MOET 'HL70399' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Internationalization Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Internationalization Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(VID_datatype): de waarde van LongName MOET 'Internationalization Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.2/hl7v2:CE.1"
                 priority="6336"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.2/hl7v2:CE.2"
                 priority="6335"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.2/hl7v2:CE.3"
                 priority="6334"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.2/hl7v2:CE.4"
                 priority="6332"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.2/hl7v2:CE.5"
                 priority="6331"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.2/hl7v2:CE.6"
                 priority="6330"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.3"
                 priority="6328"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(VID_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('International Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('International Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(VID_datatype): de waarde van LongName MOET 'International Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.3/hl7v2:CE.1"
                 priority="6326"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.3/hl7v2:CE.2"
                 priority="6325"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.3/hl7v2:CE.3"
                 priority="6324"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.3/hl7v2:CE.4"
                 priority="6322"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.3/hl7v2:CE.5"
                 priority="6321"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.3/hl7v2:CE.6"
                 priority="6320"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.13"
                 priority="6318"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('13') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('13') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van Item MOET '13' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Sequence Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Sequence Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Sequence Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.14"
                 priority="6317"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('14') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('14') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van Item MOET '14' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Continuation Pointer') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Continuation Pointer') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Continuation Pointer' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.15"
                 priority="6316"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('15') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('15') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van Item MOET '15' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70155') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70155') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van Table MOET 'HL70155' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Accept Acknowledgment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Accept Acknowledgment Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Accept Acknowledgment Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.16"
                 priority="6314"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='NE'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="text()='NE'">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de elementinhoud van hl7v2:MSH.16 MOET ''NE'' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('16') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('16') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van Item MOET '16' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70155') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70155') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van Table MOET 'HL70155' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Application Acknowledgment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Application Acknowledgment Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Application Acknowledgment Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.17"
                 priority="6312"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='NLD'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="text()='NLD'">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de elementinhoud van hl7v2:MSH.17 MOET ''NLD'' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('17') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('17') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van Item MOET '17' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70399') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70399') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van Table MOET 'HL70399' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Country Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Country Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.18"
                 priority="6310"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('692') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('692') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van Item MOET '692' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70211') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70211') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van Table MOET 'HL70211' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Character Set') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Character Set') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Character Set' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.19"
                 priority="6308"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('693') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('693') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van Item MOET '693' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Principal Language Of Message') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Principal Language Of Message') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Principal Language Of Message' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.19/hl7v2:CE.1"
                 priority="6306"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.19/hl7v2:CE.2"
                 priority="6305"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.19/hl7v2:CE.3"
                 priority="6304"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.19/hl7v2:CE.4"
                 priority="6302"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.19/hl7v2:CE.5"
                 priority="6301"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.19/hl7v2:CE.6"
                 priority="6300"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.20"
                 priority="6298"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1317') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1317') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van Item MOET '1317' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70356') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70356') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van Table MOET 'HL70356' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Character Set Handling Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Character Set Handling Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Alternate Character Set Handling Scheme' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.21"
                 priority="6296"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1598') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1598') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van Item MOET '1598' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Message Profile Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Message Profile Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Message Profile Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.21/hl7v2:EI.1"
                 priority="6294"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.21/hl7v2:EI.2"
                 priority="6293"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.21/hl7v2:EI.3"
                 priority="6292"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.21/hl7v2:EI.4"
                 priority="6291"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:NTE" priority="6289" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NTE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): element hl7v2:NTE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NTE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): element hl7v2:NTE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.3) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NTE.3) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): element hl7v2:NTE.3 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NTE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): element hl7v2:NTE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:NTE/hl7v2:NTE.1"
                 priority="6288"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('96') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('96') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van Item MOET '96' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('SI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van Type MOET 'SI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Set ID - NTE') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Set ID - NTE') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van LongName MOET 'Set ID - NTE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:NTE/hl7v2:NTE.2"
                 priority="6287"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('97') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('97') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van Item MOET '97' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70105') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70105') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van Table MOET 'HL70105' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source of Comment') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Source of Comment') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van LongName MOET 'Source of Comment' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:NTE/hl7v2:NTE.3"
                 priority="6285"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('98') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('98') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van Item MOET '98' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('FT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van Type MOET 'FT' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Comment') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Comment') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van LongName MOET 'Comment' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape"
                 priority="6284"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.27-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FT_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/hl7v2:escape"
                 priority="6283"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="6282"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:NTE/hl7v2:NTE.4"
                 priority="6281"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1318') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1318') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van Item MOET '1318' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70364') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70364') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van Table MOET 'HL70364' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Comment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Comment Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van LongName MOET 'Comment Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.1"
                 priority="6279"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.2"
                 priority="6278"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.3"
                 priority="6277"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.4"
                 priority="6275"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.5"
                 priority="6274"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.6"
                 priority="6273"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE d20e13492-false-d748977e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT"
                 priority="6271"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth): element hl7v2:PID is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth): element hl7v2:PID komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PD1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth): element hl7v2:PD1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID"
                 priority="6270"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): element hl7v2:PID.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): element hl7v2:PID.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.3) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.3) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): element hl7v2:PID.3 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.5) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.5) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): element hl7v2:PID.5 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.7) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.7) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): element hl7v2:PID.7 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): element hl7v2:PID.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.8) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.8) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): element hl7v2:PID.8 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): element hl7v2:PID.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.11) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.11) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): element hl7v2:PID.11 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): element hl7v2:PID.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): element hl7v2:PID.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.12) = 0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.12) = 0">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): element hl7v2:PID.12 MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.13) = 0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.13) = 0">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): element hl7v2:PID.13 MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.14) = 0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.14) = 0">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): element hl7v2:PID.14 MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.15) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.15) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): element hl7v2:PID.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.15) = 0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.15) = 0">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): element hl7v2:PID.15 MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.16) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.16) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): element hl7v2:PID.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.16) = 0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.16) = 0">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): element hl7v2:PID.16 MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.17) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.17) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): element hl7v2:PID.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.17) = 0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.17) = 0">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): element hl7v2:PID.17 MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.18) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.18) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): element hl7v2:PID.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.18) = 0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.18) = 0">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): element hl7v2:PID.18 MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.19) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.19) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): element hl7v2:PID.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.19) = 0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.19) = 0">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): element hl7v2:PID.19 MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.20) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.20) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): element hl7v2:PID.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.20) = 0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.20) = 0">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): element hl7v2:PID.20 MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.21) = 0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.21) = 0">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): element hl7v2:PID.21 MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.22) = 0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.22) = 0">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): element hl7v2:PID.22 MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.23) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.23) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): element hl7v2:PID.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.23) = 0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.23) = 0">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): element hl7v2:PID.23 MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.24) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.24) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): element hl7v2:PID.24 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.24) = 0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.24) = 0">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): element hl7v2:PID.24 MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.25) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.25) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): element hl7v2:PID.25 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.25) = 0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.25) = 0">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): element hl7v2:PID.25 MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.26) = 0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.26) = 0">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): element hl7v2:PID.26 MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.27) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.27) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): element hl7v2:PID.27 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.27) = 0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.27) = 0">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): element hl7v2:PID.27 MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.28) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.28) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): element hl7v2:PID.28 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.28) = 0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.28) = 0">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): element hl7v2:PID.28 MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.29) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.29) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): element hl7v2:PID.29 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.29) = 0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.29) = 0">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): element hl7v2:PID.29 MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.30) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.30) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): element hl7v2:PID.30 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.30) = 0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.30) = 0">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): element hl7v2:PID.30 MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.31) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.31) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): element hl7v2:PID.31 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.31) = 0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.31) = 0">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): element hl7v2:PID.31 MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.32) = 0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.32) = 0">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): element hl7v2:PID.32 MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.33) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.33) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): element hl7v2:PID.33 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.33) = 0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.33) = 0">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): element hl7v2:PID.33 MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.34) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.34) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): element hl7v2:PID.34 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.34) = 0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.34) = 0">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): element hl7v2:PID.34 MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.35) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.35) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): element hl7v2:PID.35 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.35) = 0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.35) = 0">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): element hl7v2:PID.35 MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.36) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.36) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): element hl7v2:PID.36 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.36) = 0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.36) = 0">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): element hl7v2:PID.36 MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.37) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.37) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): element hl7v2:PID.37 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.37) = 0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.37) = 0">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): element hl7v2:PID.37 MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.38) &lt;= 2"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.38) &lt;= 2">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): element hl7v2:PID.38 komt te vaak voor [max 2x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.38) = 0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.38) = 0">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): element hl7v2:PID.38 MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.39) = 0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.39) = 0">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): element hl7v2:PID.39 MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.1"
                 priority="6269"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('104') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('104') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Item MOET '104' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('SI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Type MOET 'SI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Set ID - PID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Set ID - PID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van LongName MOET 'Set ID - PID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2"
                 priority="6268"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('105') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('105') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Item MOET '105' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CX') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CX') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Type MOET 'CX' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Patient ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van LongName MOET 'Patient ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.1"
                 priority="6266"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.2"
                 priority="6265"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.3"
                 priority="6264"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.4"
                 priority="6262"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.4/hl7v2:HD.1"
                 priority="6260"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.4/hl7v2:HD.2"
                 priority="6259"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.4/hl7v2:HD.3"
                 priority="6258"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.5"
                 priority="6256"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.6"
                 priority="6254"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.6/hl7v2:HD.1"
                 priority="6252"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.6/hl7v2:HD.2"
                 priority="6251"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.6/hl7v2:HD.3"
                 priority="6250"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.7"
                 priority="6248"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.8"
                 priority="6247"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9"
                 priority="6246"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="6244"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="6243"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="6242"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="6240"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="6239"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="6238"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="6236"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="6235"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="6234"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10"
                 priority="6233"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="6231"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="6230"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="6229"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="6227"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="6226"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="6225"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="6223"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="6222"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="6221"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3"
                 priority="6220"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('106') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('106') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Item MOET '106' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CX') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CX') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Type MOET 'CX' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Identifier List') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Patient Identifier List') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van LongName MOET 'Patient Identifier List' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.1"
                 priority="6218"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.2"
                 priority="6217"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.3"
                 priority="6216"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.4"
                 priority="6214"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.4/hl7v2:HD.1"
                 priority="6212"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.4/hl7v2:HD.2"
                 priority="6211"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.4/hl7v2:HD.3"
                 priority="6210"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.5"
                 priority="6208"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.6"
                 priority="6206"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.6/hl7v2:HD.1"
                 priority="6204"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.6/hl7v2:HD.2"
                 priority="6203"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.6/hl7v2:HD.3"
                 priority="6202"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.7"
                 priority="6200"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.8"
                 priority="6199"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9"
                 priority="6198"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="6196"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="6195"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="6194"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="6192"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="6191"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="6190"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="6188"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="6187"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="6186"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10"
                 priority="6185"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="6183"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="6182"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="6181"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="6179"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="6178"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="6177"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="6175"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="6174"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="6173"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4"
                 priority="6172"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('107') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('107') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Item MOET '107' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CX') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CX') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Type MOET 'CX' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Patient ID - PID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Patient ID - PID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van LongName MOET 'Alternate Patient ID - PID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.1"
                 priority="6170"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.2"
                 priority="6169"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.3"
                 priority="6168"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.4"
                 priority="6166"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.4/hl7v2:HD.1"
                 priority="6164"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.4/hl7v2:HD.2"
                 priority="6163"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.4/hl7v2:HD.3"
                 priority="6162"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.5"
                 priority="6160"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.6"
                 priority="6158"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.6/hl7v2:HD.1"
                 priority="6156"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.6/hl7v2:HD.2"
                 priority="6155"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.6/hl7v2:HD.3"
                 priority="6154"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.7"
                 priority="6152"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.8"
                 priority="6151"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9"
                 priority="6150"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="6148"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="6147"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="6146"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="6144"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="6143"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="6142"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="6140"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="6139"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="6138"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10"
                 priority="6137"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="6135"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="6134"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="6133"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="6131"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="6130"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="6129"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="6127"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="6126"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="6125"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5"
                 priority="6124"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.13) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.13) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.14) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.14) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('108') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('108') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Item MOET '108' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XPN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('XPN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Type MOET 'XPN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Patient Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van LongName MOET 'Patient Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.1"
                 priority="6122"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('FN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.1/hl7v2:FN.1"
                 priority="6120"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.1/hl7v2:FN.2"
                 priority="6119"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.1/hl7v2:FN.3"
                 priority="6118"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Own Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.1/hl7v2:FN.4"
                 priority="6117"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.1/hl7v2:FN.5"
                 priority="6116"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.2"
                 priority="6115"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.3"
                 priority="6114"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.4"
                 priority="6113"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.5"
                 priority="6112"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.6"
                 priority="6111"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.7"
                 priority="6110"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70200') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.8"
                 priority="6108"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.9"
                 priority="6106"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70448') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Context') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.9/hl7v2:CE.1"
                 priority="6104"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.9/hl7v2:CE.2"
                 priority="6103"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.9/hl7v2:CE.3"
                 priority="6102"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.9/hl7v2:CE.4"
                 priority="6100"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.9/hl7v2:CE.5"
                 priority="6099"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.9/hl7v2:CE.6"
                 priority="6098"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.10"
                 priority="6096"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.10/hl7v2:DR.1"
                 priority="6094"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.1"
                 priority="6092"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.2"
                 priority="6091"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.10/hl7v2:DR.2"
                 priority="6089"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.1"
                 priority="6087"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.2"
                 priority="6086"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.11"
                 priority="6084"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70444') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Assembly Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.12"
                 priority="6082"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.12/hl7v2:TS.1"
                 priority="6080"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.12/hl7v2:TS.2"
                 priority="6079"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.13"
                 priority="6077"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.13/hl7v2:TS.1"
                 priority="6075"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.13/hl7v2:TS.2"
                 priority="6074"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.14"
                 priority="6072"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Professional Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6"
                 priority="6071"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.13) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.13) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.14) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.14) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('109') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('109') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Item MOET '109' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XPN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('XPN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Type MOET 'XPN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Mother''s Maiden Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Mother''s Maiden Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van LongName MOET 'Mother''s Maiden Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.1"
                 priority="6069"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('FN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.1/hl7v2:FN.1"
                 priority="6067"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.1/hl7v2:FN.2"
                 priority="6066"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.1/hl7v2:FN.3"
                 priority="6065"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Own Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.1/hl7v2:FN.4"
                 priority="6064"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.1/hl7v2:FN.5"
                 priority="6063"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.2"
                 priority="6062"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.3"
                 priority="6061"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.4"
                 priority="6060"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.5"
                 priority="6059"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.6"
                 priority="6058"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.7"
                 priority="6057"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70200') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.8"
                 priority="6055"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.9"
                 priority="6053"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70448') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Context') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.9/hl7v2:CE.1"
                 priority="6051"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.9/hl7v2:CE.2"
                 priority="6050"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.9/hl7v2:CE.3"
                 priority="6049"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.9/hl7v2:CE.4"
                 priority="6047"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.9/hl7v2:CE.5"
                 priority="6046"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.9/hl7v2:CE.6"
                 priority="6045"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.10"
                 priority="6043"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.10/hl7v2:DR.1"
                 priority="6041"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.1"
                 priority="6039"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.2"
                 priority="6038"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.10/hl7v2:DR.2"
                 priority="6036"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.1"
                 priority="6034"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.2"
                 priority="6033"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.11"
                 priority="6031"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70444') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Assembly Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.12"
                 priority="6029"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.12/hl7v2:TS.1"
                 priority="6027"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.12/hl7v2:TS.2"
                 priority="6026"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.13"
                 priority="6024"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.13/hl7v2:TS.1"
                 priority="6022"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.13/hl7v2:TS.2"
                 priority="6021"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.14"
                 priority="6019"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Professional Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.7"
                 priority="6018"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('110') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('110') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Item MOET '110' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Date/Time of Birth') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Date/Time of Birth') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van LongName MOET 'Date/Time of Birth' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.7/hl7v2:TS.1"
                 priority="6016"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.7/hl7v2:TS.2"
                 priority="6015"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.8"
                 priority="6013"
                 mode="M14">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.3.1937.777.10.11.1-2013-02-10T000000.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.3.1937.777.10.11.1-2013-02-10T000000.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.84-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(IS_datatype): de elementwaarde MOET een zijn van '2.16.840.1.113883.3.1937.777.10.11.1 Administrative Sex (2013-02-10T00:00:00)'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('111') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('111') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Item MOET '111' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70001') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70001') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70001' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Administrative Sex') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Administrative Sex') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van LongName MOET 'Administrative Sex' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9"
                 priority="6011"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.13) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.13) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.14) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.14) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('112') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('112') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Item MOET '112' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XPN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('XPN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Type MOET 'XPN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Alias') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Patient Alias') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van LongName MOET 'Patient Alias' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.1"
                 priority="6009"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('FN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.1/hl7v2:FN.1"
                 priority="6007"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.1/hl7v2:FN.2"
                 priority="6006"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.1/hl7v2:FN.3"
                 priority="6005"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Own Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.1/hl7v2:FN.4"
                 priority="6004"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.1/hl7v2:FN.5"
                 priority="6003"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.2"
                 priority="6002"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.3"
                 priority="6001"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.4"
                 priority="6000"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.5"
                 priority="5999"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.6"
                 priority="5998"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.7"
                 priority="5997"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70200') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.8"
                 priority="5995"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.9"
                 priority="5993"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70448') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Context') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.9/hl7v2:CE.1"
                 priority="5991"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.9/hl7v2:CE.2"
                 priority="5990"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.9/hl7v2:CE.3"
                 priority="5989"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.9/hl7v2:CE.4"
                 priority="5987"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.9/hl7v2:CE.5"
                 priority="5986"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.9/hl7v2:CE.6"
                 priority="5985"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.10"
                 priority="5983"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.10/hl7v2:DR.1"
                 priority="5981"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.1"
                 priority="5979"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.2"
                 priority="5978"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.10/hl7v2:DR.2"
                 priority="5976"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.1"
                 priority="5974"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.2"
                 priority="5973"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.11"
                 priority="5971"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70444') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Assembly Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.12"
                 priority="5969"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.12/hl7v2:TS.1"
                 priority="5967"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.12/hl7v2:TS.2"
                 priority="5966"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.13"
                 priority="5964"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.13/hl7v2:TS.1"
                 priority="5962"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.13/hl7v2:TS.2"
                 priority="5961"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.14"
                 priority="5959"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Professional Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.10"
                 priority="5958"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('113') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('113') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Item MOET '113' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70005') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70005') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70005' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Race') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Race') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van LongName MOET 'Race' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.10/hl7v2:CE.1"
                 priority="5956"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.10/hl7v2:CE.2"
                 priority="5955"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.10/hl7v2:CE.3"
                 priority="5954"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.10/hl7v2:CE.4"
                 priority="5952"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.10/hl7v2:CE.5"
                 priority="5951"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.10/hl7v2:CE.6"
                 priority="5950"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11"
                 priority="5948"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.13) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.13) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.14) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.14) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('114') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('114') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Item MOET '114' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XAD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('XAD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Type MOET 'XAD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Address') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Patient Address') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van LongName MOET 'Patient Address' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.1"
                 priority="5946"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): element hl7v2:SAD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): element hl7v2:SAD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): element hl7v2:SAD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SAD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('SAD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'SAD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Street Address') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Street Address') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'Street Address' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.1/hl7v2:SAD.1"
                 priority="5944"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Street or Mailing Address') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Street or Mailing Address') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): de waarde van LongName MOET 'Street or Mailing Address' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.1/hl7v2:SAD.2"
                 priority="5943"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Street Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Street Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): de waarde van LongName MOET 'Street Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.1/hl7v2:SAD.3"
                 priority="5942"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Dwelling Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Dwelling Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): de waarde van LongName MOET 'Dwelling Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.2"
                 priority="5941"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Other Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Other Designation') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'Other Designation' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.3"
                 priority="5940"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('City') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('City') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'City' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.4"
                 priority="5939"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('State or Province') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('State or Province') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'State or Province' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.5"
                 priority="5938"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Zip or Postal Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Zip or Postal Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'Zip or Postal Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.6"
                 priority="5937"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70399') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70399') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Table MOET 'HL70399' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Country') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Country') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'Country' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.7"
                 priority="5935"
                 mode="M14">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.25.11.409 Adrestype HL7v2 NL (DYNAMISCH)'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70190') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70190') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Table MOET 'HL70190' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Address Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Address Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'Address Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.8"
                 priority="5933"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Other Geographic Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Other Geographic Designation') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'Other Geographic Designation' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.9"
                 priority="5932"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70289') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70289') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Table MOET 'HL70289' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('County/Parish Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('County/Parish Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'County/Parish Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.10"
                 priority="5931"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70288') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70288') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Table MOET 'HL70288' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Census Tract') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Census Tract') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'Census Tract' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.11"
                 priority="5930"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Address Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Address Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'Address Representation Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.12"
                 priority="5928"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Address Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Address Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'Address Validity Range' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.12/hl7v2:DR.1"
                 priority="5926"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.1"
                 priority="5924"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.2"
                 priority="5923"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.12/hl7v2:DR.2"
                 priority="5921"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.1"
                 priority="5919"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.2"
                 priority="5918"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.13"
                 priority="5916"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.13/hl7v2:TS.1"
                 priority="5914"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.13/hl7v2:TS.2"
                 priority="5913"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.14"
                 priority="5911"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.14/hl7v2:TS.1"
                 priority="5909"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.14/hl7v2:TS.2"
                 priority="5908"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.12"
                 priority="5906"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('115') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('115') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Item MOET '115' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70289') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70289') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70289' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('County Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('County Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van LongName MOET 'County Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.13"
                 priority="5905"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('116') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('116') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Item MOET '116' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('XTN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Type MOET 'XTN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Phone Number - Home') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Phone Number - Home') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van LongName MOET 'Phone Number - Home' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.1"
                 priority="5903"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Telephone Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Telephone Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.2"
                 priority="5902"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70201') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Table MOET 'HL70201' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Telecommunication Use Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Use Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.3"
                 priority="5900"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70202') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Table MOET 'HL70202' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Equipment Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.4"
                 priority="5898"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Email Address') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Email Address' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.5"
                 priority="5897"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Country Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Country Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.6"
                 priority="5896"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Area/City Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Area/City Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.7"
                 priority="5895"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Local Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Local Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.8"
                 priority="5894"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Extension') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Extension' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.9"
                 priority="5893"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Any Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Any Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.10"
                 priority="5892"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Extension Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Extension Prefix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.11"
                 priority="5891"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Speed Dial Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Speed Dial Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.12"
                 priority="5890"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Unformatted Telephone number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Unformatted Telephone number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.14"
                 priority="5889"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('117') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('117') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Item MOET '117' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('XTN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Type MOET 'XTN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Phone Number - Business') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Phone Number - Business') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van LongName MOET 'Phone Number - Business' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.1"
                 priority="5887"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Telephone Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Telephone Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.2"
                 priority="5886"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70201') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Table MOET 'HL70201' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Telecommunication Use Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Use Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.3"
                 priority="5884"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70202') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Table MOET 'HL70202' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Equipment Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.4"
                 priority="5882"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Email Address') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Email Address' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.5"
                 priority="5881"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Country Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Country Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.6"
                 priority="5880"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Area/City Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Area/City Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.7"
                 priority="5879"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Local Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Local Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.8"
                 priority="5878"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Extension') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Extension' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.9"
                 priority="5877"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Any Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Any Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.10"
                 priority="5876"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Extension Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Extension Prefix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.11"
                 priority="5875"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Speed Dial Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Speed Dial Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.12"
                 priority="5874"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Unformatted Telephone number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Unformatted Telephone number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.15"
                 priority="5873"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('118') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('118') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Item MOET '118' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70296') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70296') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70296' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Primary Language') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Primary Language') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van LongName MOET 'Primary Language' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.15/hl7v2:CE.1"
                 priority="5871"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.15/hl7v2:CE.2"
                 priority="5870"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.15/hl7v2:CE.3"
                 priority="5869"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.15/hl7v2:CE.4"
                 priority="5867"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.15/hl7v2:CE.5"
                 priority="5866"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.15/hl7v2:CE.6"
                 priority="5865"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.16"
                 priority="5863"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('119') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('119') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Item MOET '119' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70002') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70002') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70002' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Marital Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Marital Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van LongName MOET 'Marital Status' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.16/hl7v2:CE.1"
                 priority="5861"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.16/hl7v2:CE.2"
                 priority="5860"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.16/hl7v2:CE.3"
                 priority="5859"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.16/hl7v2:CE.4"
                 priority="5857"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.16/hl7v2:CE.5"
                 priority="5856"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.16/hl7v2:CE.6"
                 priority="5855"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.17"
                 priority="5853"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('120') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('120') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Item MOET '120' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70006') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70006') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70006' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Religion') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Religion') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van LongName MOET 'Religion' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.17/hl7v2:CE.1"
                 priority="5851"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.17/hl7v2:CE.2"
                 priority="5850"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.17/hl7v2:CE.3"
                 priority="5849"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.17/hl7v2:CE.4"
                 priority="5847"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.17/hl7v2:CE.5"
                 priority="5846"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.17/hl7v2:CE.6"
                 priority="5845"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18"
                 priority="5843"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('121') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('121') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Item MOET '121' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CX') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CX') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Type MOET 'CX' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Account Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Patient Account Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van LongName MOET 'Patient Account Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.1"
                 priority="5841"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.2"
                 priority="5840"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.3"
                 priority="5839"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.4"
                 priority="5837"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.4/hl7v2:HD.1"
                 priority="5835"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.4/hl7v2:HD.2"
                 priority="5834"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.4/hl7v2:HD.3"
                 priority="5833"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.5"
                 priority="5831"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.6"
                 priority="5829"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.6/hl7v2:HD.1"
                 priority="5827"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.6/hl7v2:HD.2"
                 priority="5826"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.6/hl7v2:HD.3"
                 priority="5825"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.7"
                 priority="5823"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.8"
                 priority="5822"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9"
                 priority="5821"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="5819"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="5818"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="5817"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="5815"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="5814"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="5813"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="5811"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="5810"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="5809"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10"
                 priority="5808"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="5806"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="5805"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="5804"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="5802"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="5801"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="5800"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="5798"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="5797"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="5796"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.19"
                 priority="5795"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('122') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('122') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Item MOET '122' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('SSN Number - Patient') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('SSN Number - Patient') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van LongName MOET 'SSN Number - Patient' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.20"
                 priority="5794"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DLN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DLN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DLN_datatype): element hl7v2:DLN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DLN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DLN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DLN_datatype): element hl7v2:DLN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DLN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DLN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DLN_datatype): element hl7v2:DLN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('123') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('123') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Item MOET '123' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DLN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DLN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Type MOET 'DLN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Driver''s License Number - Patient') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Driver''s License Number - Patient') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van LongName MOET 'Driver''s License Number - Patient' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.20/hl7v2:DLN.1"
                 priority="5792"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DLN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('License Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('License Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DLN_datatype): de waarde van LongName MOET 'License Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.20/hl7v2:DLN.2"
                 priority="5791"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DLN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70333') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70333') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DLN_datatype): de waarde van Table MOET 'HL70333' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Issuing State, Province, Country') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Issuing State, Province, Country') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DLN_datatype): de waarde van LongName MOET 'Issuing State, Province, Country' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.20/hl7v2:DLN.3"
                 priority="5790"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DLN_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DLN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21"
                 priority="5789"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('124') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('124') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Item MOET '124' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CX') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CX') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Type MOET 'CX' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Mother''s Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Mother''s Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van LongName MOET 'Mother''s Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.1"
                 priority="5787"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.2"
                 priority="5786"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.3"
                 priority="5785"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.4"
                 priority="5783"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.4/hl7v2:HD.1"
                 priority="5781"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.4/hl7v2:HD.2"
                 priority="5780"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.4/hl7v2:HD.3"
                 priority="5779"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.5"
                 priority="5777"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.6"
                 priority="5775"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.6/hl7v2:HD.1"
                 priority="5773"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.6/hl7v2:HD.2"
                 priority="5772"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.6/hl7v2:HD.3"
                 priority="5771"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.7"
                 priority="5769"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.8"
                 priority="5768"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9"
                 priority="5767"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="5765"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="5764"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="5763"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="5761"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="5760"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="5759"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="5757"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="5756"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="5755"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10"
                 priority="5754"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="5752"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="5751"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="5750"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="5748"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="5747"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="5746"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="5744"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="5743"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="5742"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.22"
                 priority="5741"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('125') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('125') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Item MOET '125' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70189') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70189') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70189' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Ethnic Group') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Ethnic Group') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van LongName MOET 'Ethnic Group' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.22/hl7v2:CE.1"
                 priority="5739"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.22/hl7v2:CE.2"
                 priority="5738"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.22/hl7v2:CE.3"
                 priority="5737"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.22/hl7v2:CE.4"
                 priority="5735"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.22/hl7v2:CE.5"
                 priority="5734"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.22/hl7v2:CE.6"
                 priority="5733"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.23"
                 priority="5731"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('126') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('126') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Item MOET '126' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Birth Place') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Birth Place') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van LongName MOET 'Birth Place' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.24"
                 priority="5730"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('127') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('127') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Item MOET '127' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70136') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Multiple Birth Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Multiple Birth Indicator') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van LongName MOET 'Multiple Birth Indicator' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.25"
                 priority="5728"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('128') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('128') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Item MOET '128' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Birth Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Birth Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van LongName MOET 'Birth Order' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.26"
                 priority="5727"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('129') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('129') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Item MOET '129' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70171') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70171') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70171' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Citizenship') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Citizenship') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van LongName MOET 'Citizenship' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.26/hl7v2:CE.1"
                 priority="5725"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.26/hl7v2:CE.2"
                 priority="5724"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.26/hl7v2:CE.3"
                 priority="5723"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.26/hl7v2:CE.4"
                 priority="5721"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.26/hl7v2:CE.5"
                 priority="5720"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.26/hl7v2:CE.6"
                 priority="5719"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.27"
                 priority="5717"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('130') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('130') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Item MOET '130' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70172') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70172') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70172' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Veterans Military Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Veterans Military Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van LongName MOET 'Veterans Military Status' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.27/hl7v2:CE.1"
                 priority="5715"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.27/hl7v2:CE.2"
                 priority="5714"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.27/hl7v2:CE.3"
                 priority="5713"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.27/hl7v2:CE.4"
                 priority="5711"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.27/hl7v2:CE.5"
                 priority="5710"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.27/hl7v2:CE.6"
                 priority="5709"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.28"
                 priority="5707"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('739') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('739') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Item MOET '739' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70212') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70212') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70212' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Nationality') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Nationality') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van LongName MOET 'Nationality' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.28/hl7v2:CE.1"
                 priority="5705"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.28/hl7v2:CE.2"
                 priority="5704"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.28/hl7v2:CE.3"
                 priority="5703"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.28/hl7v2:CE.4"
                 priority="5701"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.28/hl7v2:CE.5"
                 priority="5700"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.28/hl7v2:CE.6"
                 priority="5699"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.29"
                 priority="5697"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('740') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('740') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Item MOET '740' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Death Date and Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Patient Death Date and Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van LongName MOET 'Patient Death Date and Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.29/hl7v2:TS.1"
                 priority="5695"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.29/hl7v2:TS.2"
                 priority="5694"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.30"
                 priority="5692"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('741') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('741') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Item MOET '741' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70136') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Death Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Patient Death Indicator') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van LongName MOET 'Patient Death Indicator' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.31"
                 priority="5690"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1535') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1535') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Item MOET '1535' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70136') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identity Unknown Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identity Unknown Indicator') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van LongName MOET 'Identity Unknown Indicator' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.32"
                 priority="5688"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1536') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1536') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Item MOET '1536' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70445') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70445') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70445' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identity Reliability Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identity Reliability Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van LongName MOET 'Identity Reliability Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.33"
                 priority="5687"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1537') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1537') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Item MOET '1537' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Last Update Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Last Update Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van LongName MOET 'Last Update Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.33/hl7v2:TS.1"
                 priority="5685"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.33/hl7v2:TS.2"
                 priority="5684"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.34"
                 priority="5682"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1538') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1538') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Item MOET '1538' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Last Update Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Last Update Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van LongName MOET 'Last Update Facility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.34/hl7v2:HD.1"
                 priority="5680"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.34/hl7v2:HD.2"
                 priority="5679"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.34/hl7v2:HD.3"
                 priority="5678"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.35"
                 priority="5676"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1539') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1539') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Item MOET '1539' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70446') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70446') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70446' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Species Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Species Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van LongName MOET 'Species Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.35/hl7v2:CE.1"
                 priority="5674"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.35/hl7v2:CE.2"
                 priority="5673"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.35/hl7v2:CE.3"
                 priority="5672"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.35/hl7v2:CE.4"
                 priority="5670"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.35/hl7v2:CE.5"
                 priority="5669"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.35/hl7v2:CE.6"
                 priority="5668"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.36"
                 priority="5666"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1540') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1540') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Item MOET '1540' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70447') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70447') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70447' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Breed Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Breed Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van LongName MOET 'Breed Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.36/hl7v2:CE.1"
                 priority="5664"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.36/hl7v2:CE.2"
                 priority="5663"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.36/hl7v2:CE.3"
                 priority="5662"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.36/hl7v2:CE.4"
                 priority="5660"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.36/hl7v2:CE.5"
                 priority="5659"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.36/hl7v2:CE.6"
                 priority="5658"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.37"
                 priority="5656"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1541') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1541') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Item MOET '1541' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Strain') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Strain') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van LongName MOET 'Strain' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.38"
                 priority="5655"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1542') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1542') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Item MOET '1542' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70429') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70429') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70429' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Production Class Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Production Class Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van LongName MOET 'Production Class Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.38/hl7v2:CE.1"
                 priority="5653"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.38/hl7v2:CE.2"
                 priority="5652"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.38/hl7v2:CE.3"
                 priority="5651"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.38/hl7v2:CE.4"
                 priority="5649"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.38/hl7v2:CE.5"
                 priority="5648"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.38/hl7v2:CE.6"
                 priority="5647"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.39"
                 priority="5645"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1840') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1840') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Item MOET '1840' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70171') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70171') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70171' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Tribal Citizenship') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Tribal Citizenship') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2PublicHealth): de waarde van LongName MOET 'Tribal Citizenship' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.1"
                 priority="5643"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.2"
                 priority="5642"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.3"
                 priority="5641"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.4"
                 priority="5639"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.5"
                 priority="5638"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.6"
                 priority="5637"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.7"
                 priority="5635"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.8"
                 priority="5634"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.9"
                 priority="5633"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1"
                 priority="5632"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PD1.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): element hl7v2:PD1.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PD1.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): element hl7v2:PD1.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PD1.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): element hl7v2:PD1.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PD1.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): element hl7v2:PD1.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PD1.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): element hl7v2:PD1.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PD1.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): element hl7v2:PD1.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PD1.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): element hl7v2:PD1.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PD1.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): element hl7v2:PD1.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.13) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PD1.13) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): element hl7v2:PD1.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.16) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PD1.16) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): element hl7v2:PD1.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.17) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PD1.17) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): element hl7v2:PD1.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.18) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PD1.18) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): element hl7v2:PD1.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.19) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PD1.19) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): element hl7v2:PD1.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.20) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PD1.20) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): element hl7v2:PD1.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.21) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PD1.21) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): element hl7v2:PD1.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.1"
                 priority="5631"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('755') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('755') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van Item MOET '755' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70223') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70223') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van Table MOET 'HL70223' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Living Dependency') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Living Dependency') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van LongName MOET 'Living Dependency' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.2"
                 priority="5630"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('742') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('742') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van Item MOET '742' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70220') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70220') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van Table MOET 'HL70220' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Living Arrangement') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Living Arrangement') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van LongName MOET 'Living Arrangement' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.3"
                 priority="5629"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('756') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('756') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van Item MOET '756' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XON') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('XON') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van Type MOET 'XON' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Primary Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Patient Primary Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van LongName MOET 'Patient Primary Facility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.1"
                 priority="5627"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Organization Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van LongName MOET 'Organization Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.2"
                 priority="5626"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70204') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70204') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Table MOET 'HL70204' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Organization Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van LongName MOET 'Organization Name Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.3"
                 priority="5625"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.4"
                 priority="5624"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.5"
                 priority="5623"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.6"
                 priority="5621"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.6/hl7v2:HD.1"
                 priority="5619"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.6/hl7v2:HD.2"
                 priority="5618"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.6/hl7v2:HD.3"
                 priority="5617"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.7"
                 priority="5615"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.8"
                 priority="5613"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.8/hl7v2:HD.1"
                 priority="5611"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.8/hl7v2:HD.2"
                 priority="5610"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.8/hl7v2:HD.3"
                 priority="5609"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.9"
                 priority="5607"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.10"
                 priority="5605"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Organization Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van LongName MOET 'Organization Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4"
                 priority="5604"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.13) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.14) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.15) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.16) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.17) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.18) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.19) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.20) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.21) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.22) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.23) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('757') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('757') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van Item MOET '757' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('XCN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Primary Care Provider Name &amp; ID No.') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Patient Primary Care Provider Name &amp; ID No.') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van LongName MOET 'Patient Primary Care Provider Name &amp; ID No.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.1"
                 priority="5602"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.2"
                 priority="5601"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('FN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="5599"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="5598"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="5597"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Own Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="5596"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="5595"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.3"
                 priority="5594"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.4"
                 priority="5593"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.5"
                 priority="5592"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.6"
                 priority="5591"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.7"
                 priority="5590"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.8"
                 priority="5589"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.9"
                 priority="5588"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="5586"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="5585"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="5584"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.10"
                 priority="5582"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70200') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.11"
                 priority="5580"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.12"
                 priority="5579"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.13"
                 priority="5577"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.14"
                 priority="5575"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="5573"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="5572"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="5571"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.15"
                 priority="5569"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.16"
                 priority="5567"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70448') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Context') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="5565"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="5564"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="5563"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="5561"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="5560"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="5559"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.17"
                 priority="5557"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="5555"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="5553"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="5552"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="5550"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="5548"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="5547"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.18"
                 priority="5545"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70444') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Assembly Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.19"
                 priority="5543"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="5541"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="5540"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.20"
                 priority="5538"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="5536"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="5535"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.21"
                 priority="5533"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Professional Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22"
                 priority="5532"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="5530"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="5529"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="5528"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="5526"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="5525"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="5524"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="5522"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="5521"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="5520"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23"
                 priority="5519"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="5517"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="5516"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="5515"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="5513"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="5512"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="5511"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="5509"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="5508"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="5507"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.5"
                 priority="5506"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('745') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('745') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van Item MOET '745' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70231') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70231') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van Table MOET 'HL70231' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Student Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Student Indicator') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van LongName MOET 'Student Indicator' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.6"
                 priority="5505"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('753') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('753') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van Item MOET '753' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70295') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70295') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van Table MOET 'HL70295' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Handicap') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Handicap') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van LongName MOET 'Handicap' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.7"
                 priority="5504"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('759') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('759') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van Item MOET '759' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70315') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70315') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van Table MOET 'HL70315' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Living Will Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Living Will Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van LongName MOET 'Living Will Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.8"
                 priority="5503"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('760') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('760') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van Item MOET '760' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70316') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70316') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van Table MOET 'HL70316' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organ Donor Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Organ Donor Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van LongName MOET 'Organ Donor Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.9"
                 priority="5502"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('761') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('761') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van Item MOET '761' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70136') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Separate Bill') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Separate Bill') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van LongName MOET 'Separate Bill' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10"
                 priority="5500"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('762') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('762') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van Item MOET '762' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CX') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CX') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van Type MOET 'CX' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Duplicate Patient') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Duplicate Patient') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van LongName MOET 'Duplicate Patient' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.1"
                 priority="5498"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.2"
                 priority="5497"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.3"
                 priority="5496"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.4"
                 priority="5494"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.4/hl7v2:HD.1"
                 priority="5492"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.4/hl7v2:HD.2"
                 priority="5491"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.4/hl7v2:HD.3"
                 priority="5490"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.5"
                 priority="5488"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.6"
                 priority="5486"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.6/hl7v2:HD.1"
                 priority="5484"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.6/hl7v2:HD.2"
                 priority="5483"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.6/hl7v2:HD.3"
                 priority="5482"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.7"
                 priority="5480"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.8"
                 priority="5479"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9"
                 priority="5478"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="5476"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="5475"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="5474"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="5472"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="5471"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="5470"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="5468"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="5467"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="5466"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10"
                 priority="5465"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="5463"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="5462"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="5461"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="5459"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="5458"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="5457"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="5455"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="5454"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="5453"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.11"
                 priority="5452"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('743') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('743') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van Item MOET '743' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70215') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70215') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van Table MOET 'HL70215' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Publicity Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Publicity Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van LongName MOET 'Publicity Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.11/hl7v2:CE.1"
                 priority="5450"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.11/hl7v2:CE.2"
                 priority="5449"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.11/hl7v2:CE.3"
                 priority="5448"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.11/hl7v2:CE.4"
                 priority="5446"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.11/hl7v2:CE.5"
                 priority="5445"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.11/hl7v2:CE.6"
                 priority="5444"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.12"
                 priority="5442"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('744') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('744') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van Item MOET '744' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70136') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Protection Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Protection Indicator') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van LongName MOET 'Protection Indicator' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.13"
                 priority="5440"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1566') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1566') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van Item MOET '1566' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Protection Indicator Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Protection Indicator Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van LongName MOET 'Protection Indicator Effective Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.14"
                 priority="5439"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1567') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1567') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van Item MOET '1567' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XON') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('XON') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van Type MOET 'XON' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Place of Worship') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Place of Worship') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van LongName MOET 'Place of Worship' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.1"
                 priority="5437"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Organization Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van LongName MOET 'Organization Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.2"
                 priority="5436"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70204') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70204') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Table MOET 'HL70204' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Organization Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van LongName MOET 'Organization Name Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.3"
                 priority="5435"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.4"
                 priority="5434"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.5"
                 priority="5433"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.6"
                 priority="5431"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.6/hl7v2:HD.1"
                 priority="5429"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.6/hl7v2:HD.2"
                 priority="5428"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.6/hl7v2:HD.3"
                 priority="5427"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.7"
                 priority="5425"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.8"
                 priority="5423"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.8/hl7v2:HD.1"
                 priority="5421"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.8/hl7v2:HD.2"
                 priority="5420"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.8/hl7v2:HD.3"
                 priority="5419"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.9"
                 priority="5417"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.10"
                 priority="5415"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Organization Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van LongName MOET 'Organization Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.15"
                 priority="5414"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1568') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1568') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van Item MOET '1568' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70435') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70435') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van Table MOET 'HL70435' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Advance Directive Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Advance Directive Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van LongName MOET 'Advance Directive Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.15/hl7v2:CE.1"
                 priority="5412"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.15/hl7v2:CE.2"
                 priority="5411"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.15/hl7v2:CE.3"
                 priority="5410"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.15/hl7v2:CE.4"
                 priority="5408"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.15/hl7v2:CE.5"
                 priority="5407"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.15/hl7v2:CE.6"
                 priority="5406"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.16"
                 priority="5404"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1569') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1569') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van Item MOET '1569' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70441') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70441') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van Table MOET 'HL70441' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Immunization Registry Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Immunization Registry Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van LongName MOET 'Immunization Registry Status' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.17"
                 priority="5403"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1570') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1570') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van Item MOET '1570' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Immunization Registry Status Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Immunization Registry Status Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van LongName MOET 'Immunization Registry Status Effective Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.18"
                 priority="5402"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1571') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1571') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van Item MOET '1571' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Publicity Code Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Publicity Code Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van LongName MOET 'Publicity Code Effective Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.19"
                 priority="5401"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1572') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1572') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van Item MOET '1572' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70140') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70140') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van Table MOET 'HL70140' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Military Branch') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Military Branch') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van LongName MOET 'Military Branch' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.20"
                 priority="5400"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('486') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('486') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van Item MOET '486' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70141') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70141') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van Table MOET 'HL70141' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Military Rank/Grade') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Military Rank/Grade') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van LongName MOET 'Military Rank/Grade' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.21"
                 priority="5399"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1573') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1573') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van Item MOET '1573' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70142') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70142') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van Table MOET 'HL70142' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Military Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Military Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van LongName MOET 'Military Status' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:NTE"
                 priority="5398"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NTE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): element hl7v2:NTE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NTE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): element hl7v2:NTE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.3) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NTE.3) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): element hl7v2:NTE.3 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NTE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): element hl7v2:NTE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:NTE/hl7v2:NTE.1"
                 priority="5397"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('96') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('96') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van Item MOET '96' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('SI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van Type MOET 'SI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Set ID - NTE') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Set ID - NTE') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van LongName MOET 'Set ID - NTE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:NTE/hl7v2:NTE.2"
                 priority="5396"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('97') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('97') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van Item MOET '97' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70105') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70105') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van Table MOET 'HL70105' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source of Comment') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Source of Comment') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van LongName MOET 'Source of Comment' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:NTE/hl7v2:NTE.3"
                 priority="5394"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('98') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('98') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van Item MOET '98' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('FT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van Type MOET 'FT' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Comment') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Comment') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van LongName MOET 'Comment' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape"
                 priority="5393"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.27-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FT_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/hl7v2:escape"
                 priority="5392"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="5391"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:NTE/hl7v2:NTE.4"
                 priority="5390"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1318') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1318') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van Item MOET '1318' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70364') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70364') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van Table MOET 'HL70364' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Comment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Comment Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van LongName MOET 'Comment Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.1"
                 priority="5388"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.2"
                 priority="5387"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.3"
                 priority="5386"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.4"
                 priority="5384"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.5"
                 priority="5383"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.6"
                 priority="5382"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE d20e13501-false-d768844e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT"
                 priority="5380"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth): element hl7v2:PV1 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth): element hl7v2:PV1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth): element hl7v2:PV2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1"
                 priority="5379"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.2) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.2) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.2 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.3) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.3) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.3 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.10) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.10) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.10 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.13) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.13) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.14) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.14) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.16) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.16) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.18) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.18) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.19) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.19) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.21) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.21) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.22) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.22) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.23) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.23) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.28) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.28) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.28 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.29) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.29) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.29 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.30) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.30) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.30 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.31) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.31) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.31 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.32) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.32) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.32 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.33) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.33) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.33 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.34) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.34) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.34 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.35) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.35) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.35 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.36) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.36) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.36 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.37) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.37) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.37 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.38) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.38) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.38 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.39) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.39) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.39 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.39) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.39) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.39 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.40) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.40) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.40 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.41) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.41) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.41 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.42) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.42) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.42 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.43) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.43) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.43 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.44) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.44) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.44 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.46) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.46) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.46 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.47) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.47) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.47 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.48) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.48) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.48 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.49) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.49) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.49 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.50) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.50) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.50 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.51) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.51) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.51 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.1"
                 priority="5378"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('131') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('131') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Item MOET '131' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('SI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Type MOET 'SI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Set ID - PV1') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Set ID - PV1') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van LongName MOET 'Set ID - PV1' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.2"
                 priority="5377"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('132') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('132') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Item MOET '132' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70004') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70004') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70004' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Class') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Patient Class') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van LongName MOET 'Patient Class' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3"
                 priority="5376"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): element hl7v2:PL.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): element hl7v2:PL.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): element hl7v2:PL.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): element hl7v2:PL.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): element hl7v2:PL.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.6) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.6) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): element hl7v2:PL.6 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): element hl7v2:PL.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): element hl7v2:PL.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): element hl7v2:PL.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): element hl7v2:PL.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): element hl7v2:PL.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): element hl7v2:PL.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('133') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('133') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Item MOET '133' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('PL') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('PL') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Type MOET 'PL' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigned Patient Location') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigned Patient Location') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van LongName MOET 'Assigned Patient Location' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.1"
                 priority="5374"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70302') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): de waarde van Table MOET 'HL70302' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Point of Care') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): de waarde van LongName MOET 'Point of Care' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.2"
                 priority="5373"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70303') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): de waarde van Table MOET 'HL70303' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Room') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): de waarde van LongName MOET 'Room' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.3"
                 priority="5372"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70304') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): de waarde van Table MOET 'HL70304' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Bed') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): de waarde van LongName MOET 'Bed' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.4"
                 priority="5371"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): de waarde van LongName MOET 'Facility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.4/hl7v2:HD.1"
                 priority="5369"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.4/hl7v2:HD.2"
                 priority="5368"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.4/hl7v2:HD.3"
                 priority="5367"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.5"
                 priority="5365"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70306') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): de waarde van Table MOET 'HL70306' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Location Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): de waarde van LongName MOET 'Location Status' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.6"
                 priority="5364"
                 mode="M14">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.411-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.411-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.84-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(IS_datatype): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.25.11.411 RIVM ISIS-AR Type Afdeling (DYNAMISCH)'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70305') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): de waarde van Table MOET 'HL70305' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Person Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Person Location Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): de waarde van LongName MOET 'Person Location Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.7"
                 priority="5362"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70307') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): de waarde van Table MOET 'HL70307' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Building') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): de waarde van LongName MOET 'Building' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.8"
                 priority="5361"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70308') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): de waarde van Table MOET 'HL70308' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Floor') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): de waarde van LongName MOET 'Floor' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.9"
                 priority="5360"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Location Description') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Location Description') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): de waarde van LongName MOET 'Location Description' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.10"
                 priority="5359"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Comprehensive Location Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Comprehensive Location Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): de waarde van LongName MOET 'Comprehensive Location Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.10/hl7v2:EI.1"
                 priority="5357"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.10/hl7v2:EI.2"
                 priority="5356"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.10/hl7v2:EI.3"
                 priority="5355"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.10/hl7v2:EI.4"
                 priority="5354"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.11"
                 priority="5352"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority for Location') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority for Location') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): de waarde van LongName MOET 'Assigning Authority for Location' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.11/hl7v2:HD.1"
                 priority="5350"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.11/hl7v2:HD.2"
                 priority="5349"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.11/hl7v2:HD.3"
                 priority="5348"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.4"
                 priority="5346"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('134') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('134') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Item MOET '134' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70007') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70007') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70007' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Admission Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Admission Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van LongName MOET 'Admission Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5"
                 priority="5345"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('135') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('135') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Item MOET '135' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CX') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CX') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Type MOET 'CX' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Preadmit Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Preadmit Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van LongName MOET 'Preadmit Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.1"
                 priority="5343"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.2"
                 priority="5342"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.3"
                 priority="5341"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.4"
                 priority="5339"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.4/hl7v2:HD.1"
                 priority="5337"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.4/hl7v2:HD.2"
                 priority="5336"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.4/hl7v2:HD.3"
                 priority="5335"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.5"
                 priority="5333"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.6"
                 priority="5331"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.6/hl7v2:HD.1"
                 priority="5329"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.6/hl7v2:HD.2"
                 priority="5328"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.6/hl7v2:HD.3"
                 priority="5327"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.7"
                 priority="5325"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.8"
                 priority="5324"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9"
                 priority="5323"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="5321"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="5320"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="5319"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="5317"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="5316"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="5315"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="5313"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="5312"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="5311"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10"
                 priority="5310"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="5308"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="5307"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="5306"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="5304"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="5303"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="5302"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="5300"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="5299"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="5298"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6"
                 priority="5297"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('136') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('136') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Item MOET '136' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('PL') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('PL') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Type MOET 'PL' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prior Patient Location') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Prior Patient Location') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van LongName MOET 'Prior Patient Location' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.1"
                 priority="5295"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70302') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Table MOET 'HL70302' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Point of Care') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Point of Care' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.2"
                 priority="5294"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70303') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Table MOET 'HL70303' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Room') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Room' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.3"
                 priority="5293"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70304') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Table MOET 'HL70304' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Bed') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Bed' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.4"
                 priority="5292"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Facility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.4/hl7v2:HD.1"
                 priority="5290"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.4/hl7v2:HD.2"
                 priority="5289"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.4/hl7v2:HD.3"
                 priority="5288"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.5"
                 priority="5286"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70306') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Table MOET 'HL70306' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Location Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Location Status' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.6"
                 priority="5285"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70305') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Table MOET 'HL70305' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Person Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Person Location Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Person Location Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.7"
                 priority="5284"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70307') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Table MOET 'HL70307' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Building') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Building' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.8"
                 priority="5283"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70308') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Table MOET 'HL70308' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Floor') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Floor' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.9"
                 priority="5282"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Location Description') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Location Description') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Location Description' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.10"
                 priority="5281"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Comprehensive Location Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Comprehensive Location Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Comprehensive Location Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.10/hl7v2:EI.1"
                 priority="5279"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.10/hl7v2:EI.2"
                 priority="5278"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.10/hl7v2:EI.3"
                 priority="5277"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.10/hl7v2:EI.4"
                 priority="5276"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.11"
                 priority="5274"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority for Location') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority for Location') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Assigning Authority for Location' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.11/hl7v2:HD.1"
                 priority="5272"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.11/hl7v2:HD.2"
                 priority="5271"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.11/hl7v2:HD.3"
                 priority="5270"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7"
                 priority="5268"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.13) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.14) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.15) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.16) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.17) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.18) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.19) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.20) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.21) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.22) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.23) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('137') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('137') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Item MOET '137' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('XCN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70010') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70010') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70010' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Attending Doctor') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Attending Doctor') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van LongName MOET 'Attending Doctor' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.1"
                 priority="5266"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.2"
                 priority="5265"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('FN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="5263"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="5262"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="5261"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Own Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="5260"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="5259"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.3"
                 priority="5258"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.4"
                 priority="5257"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.5"
                 priority="5256"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.6"
                 priority="5255"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.7"
                 priority="5254"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.8"
                 priority="5253"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.9"
                 priority="5252"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="5250"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="5249"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="5248"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.10"
                 priority="5246"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70200') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.11"
                 priority="5244"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.12"
                 priority="5243"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.13"
                 priority="5241"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.14"
                 priority="5239"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="5237"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="5236"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="5235"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.15"
                 priority="5233"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.16"
                 priority="5231"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70448') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Context') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="5229"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="5228"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="5227"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="5225"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="5224"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="5223"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.17"
                 priority="5221"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="5219"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="5217"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="5216"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="5214"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="5212"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="5211"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.18"
                 priority="5209"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70444') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Assembly Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.19"
                 priority="5207"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="5205"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="5204"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.20"
                 priority="5202"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="5200"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="5199"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.21"
                 priority="5197"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Professional Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22"
                 priority="5196"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="5194"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="5193"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="5192"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="5190"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="5189"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="5188"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="5186"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="5185"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="5184"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23"
                 priority="5183"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="5181"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="5180"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="5179"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="5177"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="5176"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="5175"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="5173"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="5172"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="5171"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8"
                 priority="5170"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.13) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.14) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.15) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.16) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.17) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.18) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.19) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.20) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.21) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.22) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.23) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('138') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('138') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Item MOET '138' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('XCN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70010') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70010') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70010' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Referring Doctor') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Referring Doctor') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van LongName MOET 'Referring Doctor' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.1"
                 priority="5168"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.2"
                 priority="5167"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('FN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="5165"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="5164"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="5163"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Own Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="5162"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="5161"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.3"
                 priority="5160"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.4"
                 priority="5159"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.5"
                 priority="5158"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.6"
                 priority="5157"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.7"
                 priority="5156"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.8"
                 priority="5155"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.9"
                 priority="5154"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="5152"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="5151"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="5150"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.10"
                 priority="5148"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70200') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.11"
                 priority="5146"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.12"
                 priority="5145"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.13"
                 priority="5143"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.14"
                 priority="5141"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="5139"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="5138"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="5137"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.15"
                 priority="5135"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.16"
                 priority="5133"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70448') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Context') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="5131"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="5130"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="5129"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="5127"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="5126"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="5125"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.17"
                 priority="5123"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="5121"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="5119"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="5118"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="5116"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="5114"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="5113"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.18"
                 priority="5111"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70444') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Assembly Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.19"
                 priority="5109"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="5107"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="5106"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.20"
                 priority="5104"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="5102"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="5101"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.21"
                 priority="5099"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Professional Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22"
                 priority="5098"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="5096"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="5095"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="5094"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="5092"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="5091"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="5090"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="5088"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="5087"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="5086"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23"
                 priority="5085"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="5083"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="5082"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="5081"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="5079"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="5078"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="5077"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="5075"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="5074"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="5073"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9"
                 priority="5072"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.13) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.14) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.15) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.16) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.17) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.18) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.19) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.20) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.21) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.22) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.23) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('139') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('139') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Item MOET '139' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('XCN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70010') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70010') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70010' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Consulting Doctor') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Consulting Doctor') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van LongName MOET 'Consulting Doctor' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.1"
                 priority="5070"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.2"
                 priority="5069"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('FN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="5067"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="5066"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="5065"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Own Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="5064"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="5063"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.3"
                 priority="5062"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.4"
                 priority="5061"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.5"
                 priority="5060"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.6"
                 priority="5059"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.7"
                 priority="5058"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.8"
                 priority="5057"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.9"
                 priority="5056"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="5054"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="5053"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="5052"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.10"
                 priority="5050"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70200') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.11"
                 priority="5048"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.12"
                 priority="5047"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.13"
                 priority="5045"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.14"
                 priority="5043"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="5041"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="5040"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="5039"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.15"
                 priority="5037"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.16"
                 priority="5035"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70448') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Context') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="5033"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="5032"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="5031"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="5029"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="5028"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="5027"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.17"
                 priority="5025"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="5023"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="5021"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="5020"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="5018"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="5016"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="5015"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.18"
                 priority="5013"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70444') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Assembly Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.19"
                 priority="5011"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="5009"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="5008"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.20"
                 priority="5006"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="5004"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="5003"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.21"
                 priority="5001"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Professional Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22"
                 priority="5000"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="4998"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="4997"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="4996"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="4994"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="4993"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="4992"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="4990"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="4989"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="4988"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23"
                 priority="4987"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="4985"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="4984"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="4983"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="4981"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="4980"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="4979"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="4977"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="4976"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="4975"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.10"
                 priority="4974"
                 mode="M14">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.1.11.2-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.1.11.2-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.84-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(IS_datatype): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.1.11.2 RoleCodeNL - zorgverlenertype (personen) (DYNAMISCH)'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('140') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('140') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Item MOET '140' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70069') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70069') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70069' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Hospital Service') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Hospital Service') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van LongName MOET 'Hospital Service' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11"
                 priority="4972"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('141') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('141') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Item MOET '141' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('PL') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('PL') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Type MOET 'PL' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Temporary Location') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Temporary Location') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van LongName MOET 'Temporary Location' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.1"
                 priority="4970"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70302') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Table MOET 'HL70302' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Point of Care') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Point of Care' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.2"
                 priority="4969"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70303') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Table MOET 'HL70303' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Room') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Room' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.3"
                 priority="4968"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70304') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Table MOET 'HL70304' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Bed') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Bed' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.4"
                 priority="4967"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Facility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.4/hl7v2:HD.1"
                 priority="4965"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.4/hl7v2:HD.2"
                 priority="4964"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.4/hl7v2:HD.3"
                 priority="4963"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.5"
                 priority="4961"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70306') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Table MOET 'HL70306' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Location Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Location Status' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.6"
                 priority="4960"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70305') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Table MOET 'HL70305' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Person Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Person Location Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Person Location Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.7"
                 priority="4959"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70307') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Table MOET 'HL70307' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Building') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Building' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.8"
                 priority="4958"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70308') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Table MOET 'HL70308' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Floor') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Floor' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.9"
                 priority="4957"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Location Description') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Location Description') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Location Description' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.10"
                 priority="4956"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Comprehensive Location Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Comprehensive Location Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Comprehensive Location Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.10/hl7v2:EI.1"
                 priority="4954"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.10/hl7v2:EI.2"
                 priority="4953"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.10/hl7v2:EI.3"
                 priority="4952"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.10/hl7v2:EI.4"
                 priority="4951"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.11"
                 priority="4949"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority for Location') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority for Location') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Assigning Authority for Location' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.11/hl7v2:HD.1"
                 priority="4947"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.11/hl7v2:HD.2"
                 priority="4946"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.11/hl7v2:HD.3"
                 priority="4945"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.12"
                 priority="4943"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('142') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('142') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Item MOET '142' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70087') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70087') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70087' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Preadmit Test Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Preadmit Test Indicator') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van LongName MOET 'Preadmit Test Indicator' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.13"
                 priority="4942"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('143') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('143') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Item MOET '143' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70092') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70092') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70092' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Re-admission Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Re-admission Indicator') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van LongName MOET 'Re-admission Indicator' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.14"
                 priority="4941"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('144') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('144') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Item MOET '144' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70023') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70023') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70023' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Admit Source') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Admit Source') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van LongName MOET 'Admit Source' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.15"
                 priority="4940"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('145') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('145') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Item MOET '145' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70009') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70009') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70009' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Ambulatory Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Ambulatory Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van LongName MOET 'Ambulatory Status' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.16"
                 priority="4939"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('146') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('146') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Item MOET '146' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70099') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70099') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70099' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('VIP Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('VIP Indicator') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van LongName MOET 'VIP Indicator' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17"
                 priority="4938"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.13) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.14) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.15) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.16) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.17) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.18) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.19) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.20) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.21) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.22) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.23) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('147') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('147') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Item MOET '147' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('XCN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70010') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70010') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70010' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Admitting Doctor') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Admitting Doctor') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van LongName MOET 'Admitting Doctor' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.1"
                 priority="4936"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.2"
                 priority="4935"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('FN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="4933"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="4932"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="4931"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Own Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="4930"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="4929"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.3"
                 priority="4928"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.4"
                 priority="4927"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.5"
                 priority="4926"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.6"
                 priority="4925"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.7"
                 priority="4924"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.8"
                 priority="4923"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.9"
                 priority="4922"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="4920"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="4919"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="4918"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.10"
                 priority="4916"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70200') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.11"
                 priority="4914"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.12"
                 priority="4913"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.13"
                 priority="4911"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.14"
                 priority="4909"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="4907"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="4906"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="4905"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.15"
                 priority="4903"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.16"
                 priority="4901"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70448') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Context') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="4899"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="4898"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="4897"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="4895"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="4894"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="4893"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.17"
                 priority="4891"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="4889"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="4887"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="4886"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="4884"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="4882"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="4881"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.18"
                 priority="4879"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70444') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Assembly Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.19"
                 priority="4877"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="4875"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="4874"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.20"
                 priority="4872"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="4870"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="4869"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.21"
                 priority="4867"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Professional Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22"
                 priority="4866"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="4864"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="4863"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="4862"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="4860"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="4859"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="4858"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="4856"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="4855"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="4854"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23"
                 priority="4853"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="4851"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="4850"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="4849"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="4847"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="4846"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="4845"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="4843"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="4842"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="4841"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.18"
                 priority="4840"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('148') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('148') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Item MOET '148' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70018') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70018') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70018' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Patient Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van LongName MOET 'Patient Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19"
                 priority="4839"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('149') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('149') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Item MOET '149' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CX') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CX') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Type MOET 'CX' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Visit Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Visit Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van LongName MOET 'Visit Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.1"
                 priority="4837"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.2"
                 priority="4836"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.3"
                 priority="4835"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.4"
                 priority="4833"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.4/hl7v2:HD.1"
                 priority="4831"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.4/hl7v2:HD.2"
                 priority="4830"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.4/hl7v2:HD.3"
                 priority="4829"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.5"
                 priority="4827"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.6"
                 priority="4825"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.6/hl7v2:HD.1"
                 priority="4823"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.6/hl7v2:HD.2"
                 priority="4822"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.6/hl7v2:HD.3"
                 priority="4821"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.7"
                 priority="4819"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.8"
                 priority="4818"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9"
                 priority="4817"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="4815"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="4814"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="4813"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="4811"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="4810"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="4809"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="4807"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="4806"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="4805"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10"
                 priority="4804"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="4802"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="4801"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="4800"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="4798"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="4797"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="4796"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="4794"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="4793"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="4792"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.20"
                 priority="4791"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FC.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FC.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.25-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FC_datatype): element hl7v2:FC.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FC.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FC.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.25-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FC_datatype): element hl7v2:FC.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('150') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('150') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Item MOET '150' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FC') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('FC') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Type MOET 'FC' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70064') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70064') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70064' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Financial Class') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Financial Class') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van LongName MOET 'Financial Class' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.20/hl7v2:FC.1"
                 priority="4789"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.25-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FC_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70064') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70064') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.25-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FC_datatype): de waarde van Table MOET 'HL70064' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Financial Class Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Financial Class Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.25-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FC_datatype): de waarde van LongName MOET 'Financial Class Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.20/hl7v2:FC.2"
                 priority="4788"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.25-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FC_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.25-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FC_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.20/hl7v2:FC.2/hl7v2:TS.1"
                 priority="4786"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.20/hl7v2:FC.2/hl7v2:TS.2"
                 priority="4785"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.21"
                 priority="4783"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('151') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('151') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Item MOET '151' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70032') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70032') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70032' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Charge Price Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Charge Price Indicator') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van LongName MOET 'Charge Price Indicator' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.22"
                 priority="4782"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('152') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('152') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Item MOET '152' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70045') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70045') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70045' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Courtesy Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Courtesy Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van LongName MOET 'Courtesy Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.23"
                 priority="4781"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('153') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('153') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Item MOET '153' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70046') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70046') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70046' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Credit Rating') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Credit Rating') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van LongName MOET 'Credit Rating' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.24"
                 priority="4780"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('154') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('154') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Item MOET '154' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70044') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70044') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70044' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Contract Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Contract Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van LongName MOET 'Contract Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.25"
                 priority="4779"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('155') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('155') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Item MOET '155' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Contract Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Contract Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van LongName MOET 'Contract Effective Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.26"
                 priority="4778"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('156') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('156') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Item MOET '156' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Contract Amount') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Contract Amount') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van LongName MOET 'Contract Amount' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.27"
                 priority="4777"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('157') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('157') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Item MOET '157' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Contract Period') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Contract Period') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van LongName MOET 'Contract Period' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.28"
                 priority="4776"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('158') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('158') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Item MOET '158' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70073') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70073') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70073' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Interest Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Interest Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van LongName MOET 'Interest Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.29"
                 priority="4775"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('159') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('159') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Item MOET '159' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70110') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70110') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70110' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Transfer to Bad Debt Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Transfer to Bad Debt Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van LongName MOET 'Transfer to Bad Debt Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.30"
                 priority="4774"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('160') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('160') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Item MOET '160' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Transfer to Bad Debt Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Transfer to Bad Debt Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van LongName MOET 'Transfer to Bad Debt Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.31"
                 priority="4773"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('161') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('161') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Item MOET '161' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70021') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70021') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70021' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Bad Debt Agency Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Bad Debt Agency Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van LongName MOET 'Bad Debt Agency Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.32"
                 priority="4772"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('162') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('162') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Item MOET '162' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Bad Debt Transfer Amount') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Bad Debt Transfer Amount') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van LongName MOET 'Bad Debt Transfer Amount' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.33"
                 priority="4771"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('163') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('163') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Item MOET '163' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Bad Debt Recovery Amount') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Bad Debt Recovery Amount') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van LongName MOET 'Bad Debt Recovery Amount' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.34"
                 priority="4770"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('164') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('164') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Item MOET '164' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70111') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70111') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70111' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Delete Account Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Delete Account Indicator') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van LongName MOET 'Delete Account Indicator' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.35"
                 priority="4769"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('165') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('165') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Item MOET '165' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Delete Account Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Delete Account Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van LongName MOET 'Delete Account Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.36"
                 priority="4768"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('166') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('166') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Item MOET '166' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70112') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70112') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70112' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Discharge Disposition') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Discharge Disposition') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van LongName MOET 'Discharge Disposition' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.37"
                 priority="4767"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DLD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DLD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.15-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DLD_datatype): element hl7v2:DLD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DLD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DLD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.15-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DLD_datatype): element hl7v2:DLD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('167') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('167') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Item MOET '167' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DLD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DLD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Type MOET 'DLD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70113') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70113') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70113' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Discharged to Location') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Discharged to Location') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van LongName MOET 'Discharged to Location' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.37/hl7v2:DLD.1"
                 priority="4765"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.15-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DLD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70113') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70113') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.15-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DLD_datatype): de waarde van Table MOET 'HL70113' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Discharge Location') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Discharge Location') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.15-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DLD_datatype): de waarde van LongName MOET 'Discharge Location' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.37/hl7v2:DLD.2"
                 priority="4764"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.15-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DLD_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.15-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DLD_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.37/hl7v2:DLD.2/hl7v2:TS.1"
                 priority="4762"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.37/hl7v2:DLD.2/hl7v2:TS.2"
                 priority="4761"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.38"
                 priority="4759"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('168') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('168') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Item MOET '168' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70114') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70114') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70114' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Diet Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Diet Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van LongName MOET 'Diet Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.38/hl7v2:CE.1"
                 priority="4757"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.38/hl7v2:CE.2"
                 priority="4756"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.38/hl7v2:CE.3"
                 priority="4755"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.38/hl7v2:CE.4"
                 priority="4753"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.38/hl7v2:CE.5"
                 priority="4752"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.38/hl7v2:CE.6"
                 priority="4751"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.39"
                 priority="4749"
                 mode="M14">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.412-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.412-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.84-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(IS_datatype): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.25.11.412 RIVM ISIS-AR Instellingstypen (DYNAMISCH)'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('169') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('169') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Item MOET '169' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70115') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70115') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70115' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Servicing Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Servicing Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van LongName MOET 'Servicing Facility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.40"
                 priority="4747"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('170') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('170') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Item MOET '170' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70116') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70116') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70116' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Bed Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Bed Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van LongName MOET 'Bed Status' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.41"
                 priority="4746"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('171') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('171') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Item MOET '171' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70117') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70117') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70117' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Account Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Account Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van LongName MOET 'Account Status' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42"
                 priority="4745"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('172') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('172') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Item MOET '172' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('PL') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('PL') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Type MOET 'PL' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Pending Location') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Pending Location') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van LongName MOET 'Pending Location' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.1"
                 priority="4743"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70302') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Table MOET 'HL70302' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Point of Care') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Point of Care' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.2"
                 priority="4742"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70303') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Table MOET 'HL70303' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Room') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Room' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.3"
                 priority="4741"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70304') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Table MOET 'HL70304' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Bed') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Bed' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.4"
                 priority="4740"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Facility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.4/hl7v2:HD.1"
                 priority="4738"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.4/hl7v2:HD.2"
                 priority="4737"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.4/hl7v2:HD.3"
                 priority="4736"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.5"
                 priority="4734"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70306') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Table MOET 'HL70306' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Location Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Location Status' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.6"
                 priority="4733"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70305') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Table MOET 'HL70305' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Person Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Person Location Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Person Location Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.7"
                 priority="4732"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70307') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Table MOET 'HL70307' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Building') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Building' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.8"
                 priority="4731"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70308') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Table MOET 'HL70308' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Floor') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Floor' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.9"
                 priority="4730"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Location Description') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Location Description') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Location Description' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.10"
                 priority="4729"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Comprehensive Location Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Comprehensive Location Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Comprehensive Location Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.10/hl7v2:EI.1"
                 priority="4727"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.10/hl7v2:EI.2"
                 priority="4726"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.10/hl7v2:EI.3"
                 priority="4725"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.10/hl7v2:EI.4"
                 priority="4724"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.11"
                 priority="4722"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority for Location') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority for Location') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Assigning Authority for Location' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.11/hl7v2:HD.1"
                 priority="4720"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.11/hl7v2:HD.2"
                 priority="4719"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.11/hl7v2:HD.3"
                 priority="4718"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43"
                 priority="4716"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('173') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('173') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Item MOET '173' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('PL') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('PL') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Type MOET 'PL' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prior Temporary Location') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Prior Temporary Location') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van LongName MOET 'Prior Temporary Location' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.1"
                 priority="4714"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70302') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Table MOET 'HL70302' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Point of Care') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Point of Care' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.2"
                 priority="4713"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70303') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Table MOET 'HL70303' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Room') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Room' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.3"
                 priority="4712"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70304') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Table MOET 'HL70304' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Bed') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Bed' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.4"
                 priority="4711"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Facility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.4/hl7v2:HD.1"
                 priority="4709"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.4/hl7v2:HD.2"
                 priority="4708"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.4/hl7v2:HD.3"
                 priority="4707"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.5"
                 priority="4705"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70306') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Table MOET 'HL70306' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Location Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Location Status' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.6"
                 priority="4704"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70305') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Table MOET 'HL70305' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Person Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Person Location Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Person Location Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.7"
                 priority="4703"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70307') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Table MOET 'HL70307' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Building') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Building' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.8"
                 priority="4702"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70308') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Table MOET 'HL70308' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Floor') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Floor' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.9"
                 priority="4701"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Location Description') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Location Description') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Location Description' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.10"
                 priority="4700"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Comprehensive Location Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Comprehensive Location Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Comprehensive Location Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.10/hl7v2:EI.1"
                 priority="4698"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.10/hl7v2:EI.2"
                 priority="4697"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.10/hl7v2:EI.3"
                 priority="4696"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.10/hl7v2:EI.4"
                 priority="4695"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.11"
                 priority="4693"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority for Location') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority for Location') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Assigning Authority for Location' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.11/hl7v2:HD.1"
                 priority="4691"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.11/hl7v2:HD.2"
                 priority="4690"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.11/hl7v2:HD.3"
                 priority="4689"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.44"
                 priority="4687"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('174') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('174') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Item MOET '174' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Admit Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Admit Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van LongName MOET 'Admit Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.44/hl7v2:TS.1"
                 priority="4685"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.44/hl7v2:TS.2"
                 priority="4684"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.45"
                 priority="4682"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('175') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('175') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Item MOET '175' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Discharge Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Discharge Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van LongName MOET 'Discharge Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.45/hl7v2:TS.1"
                 priority="4680"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.45/hl7v2:TS.2"
                 priority="4679"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.46"
                 priority="4677"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('176') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('176') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Item MOET '176' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Current Patient Balance') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Current Patient Balance') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van LongName MOET 'Current Patient Balance' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.47"
                 priority="4676"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('177') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('177') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Item MOET '177' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Total Charges') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Total Charges') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van LongName MOET 'Total Charges' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.48"
                 priority="4675"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('178') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('178') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Item MOET '178' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Total Adjustments') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Total Adjustments') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van LongName MOET 'Total Adjustments' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.49"
                 priority="4674"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('179') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('179') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Item MOET '179' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Total Payments') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Total Payments') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van LongName MOET 'Total Payments' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50"
                 priority="4673"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('180') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('180') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Item MOET '180' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CX') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CX') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Type MOET 'CX' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Visit ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Visit ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van LongName MOET 'Alternate Visit ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.1"
                 priority="4671"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.2"
                 priority="4670"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.3"
                 priority="4669"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.4"
                 priority="4667"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.4/hl7v2:HD.1"
                 priority="4665"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.4/hl7v2:HD.2"
                 priority="4664"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.4/hl7v2:HD.3"
                 priority="4663"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.5"
                 priority="4661"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.6"
                 priority="4659"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.6/hl7v2:HD.1"
                 priority="4657"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.6/hl7v2:HD.2"
                 priority="4656"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.6/hl7v2:HD.3"
                 priority="4655"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.7"
                 priority="4653"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.8"
                 priority="4652"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9"
                 priority="4651"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="4649"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="4648"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="4647"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="4645"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="4644"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="4643"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="4641"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="4640"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="4639"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10"
                 priority="4638"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="4636"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="4635"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="4634"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="4632"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="4631"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="4630"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="4628"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="4627"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="4626"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.51"
                 priority="4625"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1226') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1226') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Item MOET '1226' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70326') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70326') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70326' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Visit Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Visit Indicator') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van LongName MOET 'Visit Indicator' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52"
                 priority="4624"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.13) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.14) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.15) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.16) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.17) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.18) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.19) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.20) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.21) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.22) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.23) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1274') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1274') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Item MOET '1274' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('XCN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70010') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70010') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70010' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Other Healthcare Provider') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Other Healthcare Provider') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2PublicHealth): de waarde van LongName MOET 'Other Healthcare Provider' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.1"
                 priority="4622"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.2"
                 priority="4621"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('FN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="4619"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="4618"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="4617"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Own Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="4616"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="4615"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.3"
                 priority="4614"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.4"
                 priority="4613"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.5"
                 priority="4612"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.6"
                 priority="4611"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.7"
                 priority="4610"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.8"
                 priority="4609"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.9"
                 priority="4608"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="4606"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="4605"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="4604"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.10"
                 priority="4602"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70200') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.11"
                 priority="4600"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.12"
                 priority="4599"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.13"
                 priority="4597"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.14"
                 priority="4595"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="4593"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="4592"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="4591"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.15"
                 priority="4589"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.16"
                 priority="4587"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70448') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Context') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="4585"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="4584"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="4583"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="4581"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="4580"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="4579"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.17"
                 priority="4577"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="4575"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="4573"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="4572"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="4570"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="4568"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="4567"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.18"
                 priority="4565"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70444') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Assembly Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.19"
                 priority="4563"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="4561"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="4560"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.20"
                 priority="4558"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="4556"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="4555"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.21"
                 priority="4553"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Professional Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22"
                 priority="4552"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="4550"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="4549"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="4548"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="4546"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="4545"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="4544"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="4542"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="4541"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="4540"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23"
                 priority="4539"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="4537"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="4536"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="4535"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="4533"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="4532"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="4531"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="4529"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="4528"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="4527"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2"
                 priority="4526"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.14) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.14) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.15) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.15) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.16) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.16) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.17) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.17) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.18) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.18) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.19) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.19) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.20) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.20) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.21) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.21) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.22) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.22) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.24) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.24) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.24 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.25) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.25) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.25 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.26) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.26) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.26 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.27) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.27) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.27 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.28) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.28) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.28 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.29) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.29) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.29 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.30) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.30) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.30 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.31) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.31) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.31 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.32) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.32) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.32 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.33) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.33) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.33 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.34) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.34) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.34 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.35) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.35) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.35 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.36) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.36) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.36 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.37) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.37) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.37 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.38) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.38) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.38 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.40) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.40) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.40 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.42) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.42) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.42 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.43) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.43) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.43 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.44) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.44) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.44 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.46) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.46) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.46 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.47) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.47) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.47 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.48) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.48) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.48 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1"
                 priority="4525"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('181') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('181') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Item MOET '181' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('PL') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('PL') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Type MOET 'PL' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prior Pending Location') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Prior Pending Location') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van LongName MOET 'Prior Pending Location' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.1"
                 priority="4523"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70302') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Table MOET 'HL70302' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Point of Care') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Point of Care' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.2"
                 priority="4522"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70303') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Table MOET 'HL70303' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Room') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Room' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.3"
                 priority="4521"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70304') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Table MOET 'HL70304' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Bed') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Bed' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.4"
                 priority="4520"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Facility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.4/hl7v2:HD.1"
                 priority="4518"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.4/hl7v2:HD.2"
                 priority="4517"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.4/hl7v2:HD.3"
                 priority="4516"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.5"
                 priority="4514"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70306') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Table MOET 'HL70306' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Location Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Location Status' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.6"
                 priority="4513"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70305') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Table MOET 'HL70305' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Person Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Person Location Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Person Location Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.7"
                 priority="4512"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70307') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Table MOET 'HL70307' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Building') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Building' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.8"
                 priority="4511"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70308') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Table MOET 'HL70308' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Floor') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Floor' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.9"
                 priority="4510"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Location Description') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Location Description') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Location Description' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.10"
                 priority="4509"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Comprehensive Location Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Comprehensive Location Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Comprehensive Location Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.10/hl7v2:EI.1"
                 priority="4507"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.10/hl7v2:EI.2"
                 priority="4506"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.10/hl7v2:EI.3"
                 priority="4505"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.10/hl7v2:EI.4"
                 priority="4504"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.11"
                 priority="4502"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority for Location') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority for Location') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Assigning Authority for Location' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.11/hl7v2:HD.1"
                 priority="4500"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.11/hl7v2:HD.2"
                 priority="4499"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.11/hl7v2:HD.3"
                 priority="4498"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.2"
                 priority="4496"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('182') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('182') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Item MOET '182' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70129') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70129') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Table MOET 'HL70129' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Accommodation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Accommodation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van LongName MOET 'Accommodation Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.2/hl7v2:CE.1"
                 priority="4494"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.2/hl7v2:CE.2"
                 priority="4493"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.2/hl7v2:CE.3"
                 priority="4492"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.2/hl7v2:CE.4"
                 priority="4490"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.2/hl7v2:CE.5"
                 priority="4489"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.2/hl7v2:CE.6"
                 priority="4488"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.3"
                 priority="4486"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('183') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('183') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Item MOET '183' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Admit Reason') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Admit Reason') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van LongName MOET 'Admit Reason' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.3/hl7v2:CE.1"
                 priority="4484"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.3/hl7v2:CE.2"
                 priority="4483"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.3/hl7v2:CE.3"
                 priority="4482"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.3/hl7v2:CE.4"
                 priority="4480"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.3/hl7v2:CE.5"
                 priority="4479"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.3/hl7v2:CE.6"
                 priority="4478"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.4"
                 priority="4476"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('184') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('184') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Item MOET '184' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Transfer Reason') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Transfer Reason') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van LongName MOET 'Transfer Reason' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.4/hl7v2:CE.1"
                 priority="4474"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.4/hl7v2:CE.2"
                 priority="4473"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.4/hl7v2:CE.3"
                 priority="4472"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.4/hl7v2:CE.4"
                 priority="4470"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.4/hl7v2:CE.5"
                 priority="4469"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.4/hl7v2:CE.6"
                 priority="4468"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.5"
                 priority="4466"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('185') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('185') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Item MOET '185' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Valuables') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Patient Valuables') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van LongName MOET 'Patient Valuables' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.6"
                 priority="4465"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('186') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('186') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Item MOET '186' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Valuables Location') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Patient Valuables Location') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van LongName MOET 'Patient Valuables Location' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.7"
                 priority="4464"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('187') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('187') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Item MOET '187' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70130') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70130') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Table MOET 'HL70130' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Visit User Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Visit User Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van LongName MOET 'Visit User Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.8"
                 priority="4463"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('188') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('188') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Item MOET '188' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expected Admit Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Expected Admit Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van LongName MOET 'Expected Admit Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.8/hl7v2:TS.1"
                 priority="4461"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.8/hl7v2:TS.2"
                 priority="4460"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.9"
                 priority="4458"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('189') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('189') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Item MOET '189' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expected Discharge Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Expected Discharge Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van LongName MOET 'Expected Discharge Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.9/hl7v2:TS.1"
                 priority="4456"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.9/hl7v2:TS.2"
                 priority="4455"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.10"
                 priority="4453"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('711') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('711') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Item MOET '711' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Estimated Length of Inpatient Stay') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Estimated Length of Inpatient Stay') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van LongName MOET 'Estimated Length of Inpatient Stay' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.11"
                 priority="4452"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('712') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('712') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Item MOET '712' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Actual Length of Inpatient Stay') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Actual Length of Inpatient Stay') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van LongName MOET 'Actual Length of Inpatient Stay' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.12"
                 priority="4451"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('713') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('713') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Item MOET '713' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Visit Description') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Visit Description') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van LongName MOET 'Visit Description' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13"
                 priority="4450"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.13) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.14) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.15) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.16) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.17) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.18) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.19) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.20) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.21) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.22) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.23) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('714') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('714') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Item MOET '714' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('XCN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Referral Source Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Referral Source Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van LongName MOET 'Referral Source Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.1"
                 priority="4448"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.2"
                 priority="4447"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('FN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="4445"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="4444"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="4443"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Own Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="4442"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="4441"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.3"
                 priority="4440"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.4"
                 priority="4439"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.5"
                 priority="4438"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.6"
                 priority="4437"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.7"
                 priority="4436"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.8"
                 priority="4435"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.9"
                 priority="4434"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="4432"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="4431"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="4430"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.10"
                 priority="4428"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70200') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.11"
                 priority="4426"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.12"
                 priority="4425"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.13"
                 priority="4423"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.14"
                 priority="4421"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="4419"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="4418"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="4417"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.15"
                 priority="4415"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.16"
                 priority="4413"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70448') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Context') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="4411"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="4410"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="4409"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="4407"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="4406"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="4405"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.17"
                 priority="4403"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="4401"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="4399"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="4398"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="4396"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="4394"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="4393"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.18"
                 priority="4391"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70444') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Assembly Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.19"
                 priority="4389"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="4387"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="4386"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.20"
                 priority="4384"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="4382"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="4381"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.21"
                 priority="4379"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Professional Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22"
                 priority="4378"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="4376"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="4375"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="4374"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="4372"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="4371"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="4370"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="4368"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="4367"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="4366"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23"
                 priority="4365"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="4363"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="4362"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="4361"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="4359"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="4358"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="4357"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="4355"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="4354"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="4353"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.14"
                 priority="4352"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('715') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('715') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Item MOET '715' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Previous Service Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Previous Service Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van LongName MOET 'Previous Service Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.15"
                 priority="4351"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('716') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('716') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Item MOET '716' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70136') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Employment Illness Related Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Employment Illness Related Indicator') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van LongName MOET 'Employment Illness Related Indicator' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.16"
                 priority="4349"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('717') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('717') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Item MOET '717' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70213') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70213') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Table MOET 'HL70213' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Purge Status Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Purge Status Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van LongName MOET 'Purge Status Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.17"
                 priority="4348"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('718') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('718') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Item MOET '718' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Purge Status Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Purge Status Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van LongName MOET 'Purge Status Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.18"
                 priority="4347"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('719') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('719') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Item MOET '719' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70214') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70214') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Table MOET 'HL70214' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Special Program Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Special Program Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van LongName MOET 'Special Program Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.19"
                 priority="4346"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('720') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('720') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Item MOET '720' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70136') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Retention Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Retention Indicator') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van LongName MOET 'Retention Indicator' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.20"
                 priority="4344"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('721') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('721') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Item MOET '721' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expected Number of Insurance Plans') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Expected Number of Insurance Plans') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van LongName MOET 'Expected Number of Insurance Plans' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.21"
                 priority="4343"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('722') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('722') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Item MOET '722' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70215') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70215') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Table MOET 'HL70215' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Visit Publicity Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Visit Publicity Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van LongName MOET 'Visit Publicity Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.22"
                 priority="4342"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('723') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('723') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Item MOET '723' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70136') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Visit Protection Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Visit Protection Indicator') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van LongName MOET 'Visit Protection Indicator' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.23"
                 priority="4340"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('724') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('724') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Item MOET '724' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XON') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('XON') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Type MOET 'XON' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Clinic Organization Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Clinic Organization Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van LongName MOET 'Clinic Organization Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.1"
                 priority="4338"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Organization Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van LongName MOET 'Organization Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.2"
                 priority="4337"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70204') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70204') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Table MOET 'HL70204' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Organization Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van LongName MOET 'Organization Name Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.3"
                 priority="4336"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.4"
                 priority="4335"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.5"
                 priority="4334"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.6"
                 priority="4332"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.6/hl7v2:HD.1"
                 priority="4330"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.6/hl7v2:HD.2"
                 priority="4329"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.6/hl7v2:HD.3"
                 priority="4328"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.7"
                 priority="4326"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.8"
                 priority="4324"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.8/hl7v2:HD.1"
                 priority="4322"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.8/hl7v2:HD.2"
                 priority="4321"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.8/hl7v2:HD.3"
                 priority="4320"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.9"
                 priority="4318"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.10"
                 priority="4316"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Organization Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van LongName MOET 'Organization Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.24"
                 priority="4315"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('725') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('725') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Item MOET '725' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70216') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70216') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Table MOET 'HL70216' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Status Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Patient Status Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van LongName MOET 'Patient Status Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.25"
                 priority="4314"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('726') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('726') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Item MOET '726' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70217') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70217') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Table MOET 'HL70217' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Visit Priority Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Visit Priority Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van LongName MOET 'Visit Priority Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.26"
                 priority="4313"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('727') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('727') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Item MOET '727' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Previous Treatment Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Previous Treatment Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van LongName MOET 'Previous Treatment Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.27"
                 priority="4312"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('728') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('728') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Item MOET '728' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70112') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70112') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Table MOET 'HL70112' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expected Discharge Disposition') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Expected Discharge Disposition') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van LongName MOET 'Expected Discharge Disposition' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.28"
                 priority="4311"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('729') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('729') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Item MOET '729' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Signature on File Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Signature on File Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van LongName MOET 'Signature on File Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.29"
                 priority="4310"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('730') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('730') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Item MOET '730' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('First Similar Illness Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('First Similar Illness Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van LongName MOET 'First Similar Illness Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.30"
                 priority="4309"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('731') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('731') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Item MOET '731' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70218') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70218') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Table MOET 'HL70218' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Charge Adjustment Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Patient Charge Adjustment Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van LongName MOET 'Patient Charge Adjustment Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.30/hl7v2:CE.1"
                 priority="4307"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.30/hl7v2:CE.2"
                 priority="4306"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.30/hl7v2:CE.3"
                 priority="4305"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.30/hl7v2:CE.4"
                 priority="4303"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.30/hl7v2:CE.5"
                 priority="4302"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.30/hl7v2:CE.6"
                 priority="4301"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.31"
                 priority="4299"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('732') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('732') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Item MOET '732' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70219') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70219') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Table MOET 'HL70219' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Recurring Service Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Recurring Service Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van LongName MOET 'Recurring Service Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.32"
                 priority="4298"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('733') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('733') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Item MOET '733' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70136') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Billing Media Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Billing Media Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van LongName MOET 'Billing Media Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.33"
                 priority="4296"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('734') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('734') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Item MOET '734' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expected Surgery Date and Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Expected Surgery Date and Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van LongName MOET 'Expected Surgery Date and Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.33/hl7v2:TS.1"
                 priority="4294"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.33/hl7v2:TS.2"
                 priority="4293"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.34"
                 priority="4291"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('735') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('735') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Item MOET '735' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70136') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Military Partnership Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Military Partnership Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van LongName MOET 'Military Partnership Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.35"
                 priority="4289"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('736') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('736') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Item MOET '736' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70136') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Military Non-Availability Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Military Non-Availability Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van LongName MOET 'Military Non-Availability Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.36"
                 priority="4287"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('737') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('737') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Item MOET '737' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70136') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Newborn Baby Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Newborn Baby Indicator') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van LongName MOET 'Newborn Baby Indicator' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.37"
                 priority="4285"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('738') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('738') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Item MOET '738' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70136') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Baby Detained Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Baby Detained Indicator') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van LongName MOET 'Baby Detained Indicator' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.38"
                 priority="4283"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1543') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1543') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Item MOET '1543' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70430') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70430') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Table MOET 'HL70430' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Mode of Arrival Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Mode of Arrival Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van LongName MOET 'Mode of Arrival Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.38/hl7v2:CE.1"
                 priority="4281"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.38/hl7v2:CE.2"
                 priority="4280"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.38/hl7v2:CE.3"
                 priority="4279"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.38/hl7v2:CE.4"
                 priority="4277"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.38/hl7v2:CE.5"
                 priority="4276"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.38/hl7v2:CE.6"
                 priority="4275"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.39"
                 priority="4273"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1544') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1544') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Item MOET '1544' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70431') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70431') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Table MOET 'HL70431' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Recreational Drug Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Recreational Drug Use Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van LongName MOET 'Recreational Drug Use Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.39/hl7v2:CE.1"
                 priority="4271"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.39/hl7v2:CE.2"
                 priority="4270"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.39/hl7v2:CE.3"
                 priority="4269"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.39/hl7v2:CE.4"
                 priority="4267"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.39/hl7v2:CE.5"
                 priority="4266"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.39/hl7v2:CE.6"
                 priority="4265"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.40"
                 priority="4263"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1545') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1545') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Item MOET '1545' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70432') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70432') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Table MOET 'HL70432' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Admission Level of Care Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Admission Level of Care Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van LongName MOET 'Admission Level of Care Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.40/hl7v2:CE.1"
                 priority="4261"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.40/hl7v2:CE.2"
                 priority="4260"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.40/hl7v2:CE.3"
                 priority="4259"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.40/hl7v2:CE.4"
                 priority="4257"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.40/hl7v2:CE.5"
                 priority="4256"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.40/hl7v2:CE.6"
                 priority="4255"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.41"
                 priority="4253"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1546') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1546') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Item MOET '1546' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70433') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70433') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Table MOET 'HL70433' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Precaution Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Precaution Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van LongName MOET 'Precaution Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.41/hl7v2:CE.1"
                 priority="4251"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.41/hl7v2:CE.2"
                 priority="4250"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.41/hl7v2:CE.3"
                 priority="4249"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.41/hl7v2:CE.4"
                 priority="4247"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.41/hl7v2:CE.5"
                 priority="4246"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.41/hl7v2:CE.6"
                 priority="4245"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.42"
                 priority="4243"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1547') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1547') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Item MOET '1547' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70434') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70434') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Table MOET 'HL70434' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Condition Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Patient Condition Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van LongName MOET 'Patient Condition Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.42/hl7v2:CE.1"
                 priority="4241"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.42/hl7v2:CE.2"
                 priority="4240"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.42/hl7v2:CE.3"
                 priority="4239"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.42/hl7v2:CE.4"
                 priority="4237"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.42/hl7v2:CE.5"
                 priority="4236"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.42/hl7v2:CE.6"
                 priority="4235"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.43"
                 priority="4233"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('759') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('759') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Item MOET '759' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70315') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70315') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Table MOET 'HL70315' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Living Will Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Living Will Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van LongName MOET 'Living Will Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.44"
                 priority="4232"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('760') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('760') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Item MOET '760' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70316') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70316') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Table MOET 'HL70316' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organ Donor Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Organ Donor Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van LongName MOET 'Organ Donor Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.45"
                 priority="4231"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1548') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1548') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Item MOET '1548' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70435') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70435') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Table MOET 'HL70435' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Advance Directive Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Advance Directive Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van LongName MOET 'Advance Directive Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.45/hl7v2:CE.1"
                 priority="4229"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.45/hl7v2:CE.2"
                 priority="4228"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.45/hl7v2:CE.3"
                 priority="4227"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.45/hl7v2:CE.4"
                 priority="4225"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.45/hl7v2:CE.5"
                 priority="4224"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.45/hl7v2:CE.6"
                 priority="4223"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.46"
                 priority="4221"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1549') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1549') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Item MOET '1549' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Status Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Patient Status Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van LongName MOET 'Patient Status Effective Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.47"
                 priority="4220"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1550') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1550') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Item MOET '1550' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expected LOA Return Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Expected LOA Return Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van LongName MOET 'Expected LOA Return Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.47/hl7v2:TS.1"
                 priority="4218"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.47/hl7v2:TS.2"
                 priority="4217"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.48"
                 priority="4215"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1841') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1841') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Item MOET '1841' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expected Pre-admission Testing Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Expected Pre-admission Testing Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van LongName MOET 'Expected Pre-admission Testing Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.48/hl7v2:TS.1"
                 priority="4213"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.48/hl7v2:TS.2"
                 priority="4212"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.49"
                 priority="4210"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1842') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1842') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Item MOET '1842' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70534') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70534') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van Table MOET 'HL70534' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Notify Clergy Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Notify Clergy Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van LongName MOET 'Notify Clergy Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE d20e13508-false-d795394e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN"
                 priority="4209"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPM) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth): element hl7v2:SPM is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPM) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth): element hl7v2:SPM komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OUL_R22.ORDER) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7v2:OUL_R22.ORDER) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth): element hl7v2:OUL_R22.ORDER is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM"
                 priority="4208"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPM.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): element hl7v2:SPM.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.2) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPM.2) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): element hl7v2:SPM.2 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPM.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): element hl7v2:SPM.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.4) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPM.4) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): element hl7v2:SPM.4 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPM.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): element hl7v2:SPM.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPM.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): element hl7v2:SPM.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPM.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): element hl7v2:SPM.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPM.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): element hl7v2:SPM.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPM.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): element hl7v2:SPM.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.13) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPM.13) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): element hl7v2:SPM.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.17) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPM.17) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): element hl7v2:SPM.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.18) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPM.18) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): element hl7v2:SPM.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.19) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPM.19) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): element hl7v2:SPM.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.20) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPM.20) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): element hl7v2:SPM.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.22) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPM.22) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): element hl7v2:SPM.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.23) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPM.23) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): element hl7v2:SPM.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.25) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPM.25) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): element hl7v2:SPM.25 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.26) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPM.26) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): element hl7v2:SPM.26 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.27) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPM.27) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): element hl7v2:SPM.27 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.28) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPM.28) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): element hl7v2:SPM.28 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.29) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPM.29) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): element hl7v2:SPM.29 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.1"
                 priority="4207"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1754') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1754') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Item MOET '1754' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('SI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Type MOET 'SI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Set ID _ SPM') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Set ID _ SPM') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van LongName MOET 'Set ID _ SPM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2"
                 priority="4206"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EIP.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EIP.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): element hl7v2:EIP.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EIP.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EIP.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): element hl7v2:EIP.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1755') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1755') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Item MOET '1755' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EIP') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('EIP') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Type MOET 'EIP' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van LongName MOET 'Specimen ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2/hl7v2:EIP.1"
                 priority="4204"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Assigned Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Placer Assigned Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): de waarde van LongName MOET 'Placer Assigned Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2/hl7v2:EIP.1/hl7v2:EI.1"
                 priority="4202"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2/hl7v2:EIP.1/hl7v2:EI.2"
                 priority="4201"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2/hl7v2:EIP.1/hl7v2:EI.3"
                 priority="4200"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2/hl7v2:EIP.1/hl7v2:EI.4"
                 priority="4199"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2/hl7v2:EIP.2"
                 priority="4197"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Assigned Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Filler Assigned Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): de waarde van LongName MOET 'Filler Assigned Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2/hl7v2:EIP.2/hl7v2:EI.1"
                 priority="4195"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2/hl7v2:EIP.2/hl7v2:EI.2"
                 priority="4194"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2/hl7v2:EIP.2/hl7v2:EI.3"
                 priority="4193"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2/hl7v2:EIP.2/hl7v2:EI.4"
                 priority="4192"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3"
                 priority="4190"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EIP.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EIP.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): element hl7v2:EIP.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EIP.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EIP.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): element hl7v2:EIP.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1756') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1756') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Item MOET '1756' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EIP') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('EIP') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Type MOET 'EIP' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Parent IDs') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen Parent IDs') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van LongName MOET 'Specimen Parent IDs' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3/hl7v2:EIP.1"
                 priority="4188"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Assigned Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Placer Assigned Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): de waarde van LongName MOET 'Placer Assigned Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3/hl7v2:EIP.1/hl7v2:EI.1"
                 priority="4186"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3/hl7v2:EIP.1/hl7v2:EI.2"
                 priority="4185"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3/hl7v2:EIP.1/hl7v2:EI.3"
                 priority="4184"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3/hl7v2:EIP.1/hl7v2:EI.4"
                 priority="4183"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3/hl7v2:EIP.2"
                 priority="4181"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Assigned Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Filler Assigned Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): de waarde van LongName MOET 'Filler Assigned Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3/hl7v2:EIP.2/hl7v2:EI.1"
                 priority="4179"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3/hl7v2:EIP.2/hl7v2:EI.2"
                 priority="4178"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3/hl7v2:EIP.2/hl7v2:EI.3"
                 priority="4177"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3/hl7v2:EIP.2/hl7v2:EI.4"
                 priority="4176"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.4"
                 priority="4174"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1900') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1900') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Item MOET '1900' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70487') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70487') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70487' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van LongName MOET 'Specimen Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.4/hl7v2:CWE.1"
                 priority="4172"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.4/hl7v2:CWE.2"
                 priority="4171"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.4/hl7v2:CWE.3"
                 priority="4170"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.4/hl7v2:CWE.4"
                 priority="4168"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.4/hl7v2:CWE.5"
                 priority="4167"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.4/hl7v2:CWE.6"
                 priority="4166"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.4/hl7v2:CWE.7"
                 priority="4164"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.4/hl7v2:CWE.8"
                 priority="4163"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.4/hl7v2:CWE.9"
                 priority="4162"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.5"
                 priority="4161"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1757') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1757') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Item MOET '1757' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70541') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70541') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70541' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Type Modifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen Type Modifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van LongName MOET 'Specimen Type Modifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.5/hl7v2:CWE.1"
                 priority="4159"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.5/hl7v2:CWE.2"
                 priority="4158"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.5/hl7v2:CWE.3"
                 priority="4157"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.5/hl7v2:CWE.4"
                 priority="4155"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.5/hl7v2:CWE.5"
                 priority="4154"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.5/hl7v2:CWE.6"
                 priority="4153"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.5/hl7v2:CWE.7"
                 priority="4151"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.5/hl7v2:CWE.8"
                 priority="4150"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.5/hl7v2:CWE.9"
                 priority="4149"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.6"
                 priority="4148"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1758') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1758') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Item MOET '1758' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70371') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70371') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70371' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Additives') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen Additives') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van LongName MOET 'Specimen Additives' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.6/hl7v2:CWE.1"
                 priority="4146"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.6/hl7v2:CWE.2"
                 priority="4145"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.6/hl7v2:CWE.3"
                 priority="4144"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.6/hl7v2:CWE.4"
                 priority="4142"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.6/hl7v2:CWE.5"
                 priority="4141"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.6/hl7v2:CWE.6"
                 priority="4140"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.6/hl7v2:CWE.7"
                 priority="4138"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.6/hl7v2:CWE.8"
                 priority="4137"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.6/hl7v2:CWE.9"
                 priority="4136"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.7"
                 priority="4135"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1759') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1759') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Item MOET '1759' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70488') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70488') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70488' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Collection Method') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen Collection Method') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van LongName MOET 'Specimen Collection Method' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.7/hl7v2:CWE.1"
                 priority="4133"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.7/hl7v2:CWE.2"
                 priority="4132"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.7/hl7v2:CWE.3"
                 priority="4131"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.7/hl7v2:CWE.4"
                 priority="4129"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.7/hl7v2:CWE.5"
                 priority="4128"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.7/hl7v2:CWE.6"
                 priority="4127"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.7/hl7v2:CWE.7"
                 priority="4125"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.7/hl7v2:CWE.8"
                 priority="4124"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.7/hl7v2:CWE.9"
                 priority="4123"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.8"
                 priority="4122"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1901') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1901') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Item MOET '1901' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Source Site') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen Source Site') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van LongName MOET 'Specimen Source Site' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.8/hl7v2:CWE.1"
                 priority="4120"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.8/hl7v2:CWE.2"
                 priority="4119"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.8/hl7v2:CWE.3"
                 priority="4118"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.8/hl7v2:CWE.4"
                 priority="4116"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.8/hl7v2:CWE.5"
                 priority="4115"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.8/hl7v2:CWE.6"
                 priority="4114"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.8/hl7v2:CWE.7"
                 priority="4112"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.8/hl7v2:CWE.8"
                 priority="4111"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.8/hl7v2:CWE.9"
                 priority="4110"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.9"
                 priority="4109"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1760') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1760') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Item MOET '1760' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70542') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70542') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70542' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Source Site Modifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen Source Site Modifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van LongName MOET 'Specimen Source Site Modifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.9/hl7v2:CWE.1"
                 priority="4107"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.9/hl7v2:CWE.2"
                 priority="4106"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.9/hl7v2:CWE.3"
                 priority="4105"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.9/hl7v2:CWE.4"
                 priority="4103"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.9/hl7v2:CWE.5"
                 priority="4102"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.9/hl7v2:CWE.6"
                 priority="4101"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.9/hl7v2:CWE.7"
                 priority="4099"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.9/hl7v2:CWE.8"
                 priority="4098"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.9/hl7v2:CWE.9"
                 priority="4097"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.10"
                 priority="4096"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1761') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1761') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Item MOET '1761' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70543') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70543') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70543' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Collection Site') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen Collection Site') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van LongName MOET 'Specimen Collection Site' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.10/hl7v2:CWE.1"
                 priority="4094"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.10/hl7v2:CWE.2"
                 priority="4093"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.10/hl7v2:CWE.3"
                 priority="4092"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.10/hl7v2:CWE.4"
                 priority="4090"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.10/hl7v2:CWE.5"
                 priority="4089"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.10/hl7v2:CWE.6"
                 priority="4088"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.10/hl7v2:CWE.7"
                 priority="4086"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.10/hl7v2:CWE.8"
                 priority="4085"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.10/hl7v2:CWE.9"
                 priority="4084"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.11"
                 priority="4083"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1762') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1762') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Item MOET '1762' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70369') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70369') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70369' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Role') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen Role') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van LongName MOET 'Specimen Role' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.11/hl7v2:CWE.1"
                 priority="4081"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.11/hl7v2:CWE.2"
                 priority="4080"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.11/hl7v2:CWE.3"
                 priority="4079"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.11/hl7v2:CWE.4"
                 priority="4077"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.11/hl7v2:CWE.5"
                 priority="4076"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.11/hl7v2:CWE.6"
                 priority="4075"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.11/hl7v2:CWE.7"
                 priority="4073"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.11/hl7v2:CWE.8"
                 priority="4072"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.11/hl7v2:CWE.9"
                 priority="4071"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.12"
                 priority="4070"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1902') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1902') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Item MOET '1902' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CQ') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Type MOET 'CQ' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Collection Amount') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen Collection Amount') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van LongName MOET 'Specimen Collection Amount' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.12/hl7v2:CQ.1"
                 priority="4068"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Quantity') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van LongName MOET 'Quantity' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.12/hl7v2:CQ.2"
                 priority="4067"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van LongName MOET 'Units' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.12/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="4065"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.12/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="4064"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.12/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="4063"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.12/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="4061"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.12/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="4060"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.12/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="4059"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.13"
                 priority="4057"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1763') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1763') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Item MOET '1763' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Grouped Specimen Count') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Grouped Specimen Count') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van LongName MOET 'Grouped Specimen Count' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.14"
                 priority="4056"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1764') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1764') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Item MOET '1764' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Description') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen Description') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van LongName MOET 'Specimen Description' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.15"
                 priority="4055"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1908') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1908') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Item MOET '1908' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70376') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70376') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70376' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Handling Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen Handling Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van LongName MOET 'Specimen Handling Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.15/hl7v2:CWE.1"
                 priority="4053"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.15/hl7v2:CWE.2"
                 priority="4052"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.15/hl7v2:CWE.3"
                 priority="4051"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.15/hl7v2:CWE.4"
                 priority="4049"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.15/hl7v2:CWE.5"
                 priority="4048"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.15/hl7v2:CWE.6"
                 priority="4047"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.15/hl7v2:CWE.7"
                 priority="4045"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.15/hl7v2:CWE.8"
                 priority="4044"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.15/hl7v2:CWE.9"
                 priority="4043"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.16"
                 priority="4042"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1903') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1903') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Item MOET '1903' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70489') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70489') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70489' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Risk Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen Risk Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van LongName MOET 'Specimen Risk Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.16/hl7v2:CWE.1"
                 priority="4040"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.16/hl7v2:CWE.2"
                 priority="4039"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.16/hl7v2:CWE.3"
                 priority="4038"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.16/hl7v2:CWE.4"
                 priority="4036"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.16/hl7v2:CWE.5"
                 priority="4035"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.16/hl7v2:CWE.6"
                 priority="4034"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.16/hl7v2:CWE.7"
                 priority="4032"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.16/hl7v2:CWE.8"
                 priority="4031"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.16/hl7v2:CWE.9"
                 priority="4030"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.17"
                 priority="4029"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1765') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1765') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Item MOET '1765' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Collection Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen Collection Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van LongName MOET 'Specimen Collection Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.17/hl7v2:DR.1"
                 priority="4027"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="4025"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="4024"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.17/hl7v2:DR.2"
                 priority="4022"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="4020"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="4019"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.18"
                 priority="4017"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('248') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('248') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Item MOET '248' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Received Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen Received Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van LongName MOET 'Specimen Received Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.18/hl7v2:TS.1"
                 priority="4015"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.18/hl7v2:TS.2"
                 priority="4014"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.19"
                 priority="4012"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1904') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1904') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Item MOET '1904' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Expiration Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen Expiration Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van LongName MOET 'Specimen Expiration Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.19/hl7v2:TS.1"
                 priority="4010"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.19/hl7v2:TS.2"
                 priority="4009"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.20"
                 priority="4007"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1766') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1766') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Item MOET '1766' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70136') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Availability') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen Availability') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van LongName MOET 'Specimen Availability' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.21"
                 priority="4005"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1767') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1767') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Item MOET '1767' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70490') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70490') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70490' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Reject Reason') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen Reject Reason') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van LongName MOET 'Specimen Reject Reason' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.21/hl7v2:CWE.1"
                 priority="4003"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.21/hl7v2:CWE.2"
                 priority="4002"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.21/hl7v2:CWE.3"
                 priority="4001"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.21/hl7v2:CWE.4"
                 priority="3999"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.21/hl7v2:CWE.5"
                 priority="3998"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.21/hl7v2:CWE.6"
                 priority="3997"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.21/hl7v2:CWE.7"
                 priority="3995"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.21/hl7v2:CWE.8"
                 priority="3994"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.21/hl7v2:CWE.9"
                 priority="3993"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.22"
                 priority="3992"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1768') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1768') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Item MOET '1768' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70491') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70491') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70491' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Quality') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen Quality') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van LongName MOET 'Specimen Quality' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.22/hl7v2:CWE.1"
                 priority="3990"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.22/hl7v2:CWE.2"
                 priority="3989"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.22/hl7v2:CWE.3"
                 priority="3988"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.22/hl7v2:CWE.4"
                 priority="3986"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.22/hl7v2:CWE.5"
                 priority="3985"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.22/hl7v2:CWE.6"
                 priority="3984"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.22/hl7v2:CWE.7"
                 priority="3982"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.22/hl7v2:CWE.8"
                 priority="3981"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.22/hl7v2:CWE.9"
                 priority="3980"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.23"
                 priority="3979"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1769') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1769') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Item MOET '1769' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70492') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70492') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70492' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Appropriateness') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen Appropriateness') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van LongName MOET 'Specimen Appropriateness' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.23/hl7v2:CWE.1"
                 priority="3977"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.23/hl7v2:CWE.2"
                 priority="3976"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.23/hl7v2:CWE.3"
                 priority="3975"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.23/hl7v2:CWE.4"
                 priority="3973"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.23/hl7v2:CWE.5"
                 priority="3972"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.23/hl7v2:CWE.6"
                 priority="3971"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.23/hl7v2:CWE.7"
                 priority="3969"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.23/hl7v2:CWE.8"
                 priority="3968"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.23/hl7v2:CWE.9"
                 priority="3967"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.24"
                 priority="3966"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1770') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1770') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Item MOET '1770' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70493') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70493') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70493' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Condition') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen Condition') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van LongName MOET 'Specimen Condition' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.24/hl7v2:CWE.1"
                 priority="3964"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.24/hl7v2:CWE.2"
                 priority="3963"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.24/hl7v2:CWE.3"
                 priority="3962"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.24/hl7v2:CWE.4"
                 priority="3960"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.24/hl7v2:CWE.5"
                 priority="3959"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.24/hl7v2:CWE.6"
                 priority="3958"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.24/hl7v2:CWE.7"
                 priority="3956"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.24/hl7v2:CWE.8"
                 priority="3955"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.24/hl7v2:CWE.9"
                 priority="3954"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.25"
                 priority="3953"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1771') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1771') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Item MOET '1771' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CQ') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Type MOET 'CQ' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Current Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen Current Quantity') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van LongName MOET 'Specimen Current Quantity' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.25/hl7v2:CQ.1"
                 priority="3951"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Quantity') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van LongName MOET 'Quantity' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.25/hl7v2:CQ.2"
                 priority="3950"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van LongName MOET 'Units' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.25/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="3948"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.25/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="3947"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.25/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="3946"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.25/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="3944"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.25/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="3943"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.25/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="3942"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.26"
                 priority="3940"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1772') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1772') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Item MOET '1772' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Number of Specimen Containers') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Number of Specimen Containers') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van LongName MOET 'Number of Specimen Containers' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.27"
                 priority="3939"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1773') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1773') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Item MOET '1773' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Container Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Container Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van LongName MOET 'Container Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.27/hl7v2:CWE.1"
                 priority="3937"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.27/hl7v2:CWE.2"
                 priority="3936"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.27/hl7v2:CWE.3"
                 priority="3935"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.27/hl7v2:CWE.4"
                 priority="3933"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.27/hl7v2:CWE.5"
                 priority="3932"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.27/hl7v2:CWE.6"
                 priority="3931"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.27/hl7v2:CWE.7"
                 priority="3929"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.27/hl7v2:CWE.8"
                 priority="3928"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.27/hl7v2:CWE.9"
                 priority="3927"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.28"
                 priority="3926"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1774') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1774') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Item MOET '1774' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70544') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70544') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70544' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Container Condition') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Container Condition') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van LongName MOET 'Container Condition' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.28/hl7v2:CWE.1"
                 priority="3924"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.28/hl7v2:CWE.2"
                 priority="3923"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.28/hl7v2:CWE.3"
                 priority="3922"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.28/hl7v2:CWE.4"
                 priority="3920"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.28/hl7v2:CWE.5"
                 priority="3919"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.28/hl7v2:CWE.6"
                 priority="3918"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.28/hl7v2:CWE.7"
                 priority="3916"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.28/hl7v2:CWE.8"
                 priority="3915"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.28/hl7v2:CWE.9"
                 priority="3914"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.29"
                 priority="3913"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1775') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1775') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Item MOET '1775' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70494') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70494') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70494' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Child Role') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen Child Role') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van LongName MOET 'Specimen Child Role' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.29/hl7v2:CWE.1"
                 priority="3911"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.29/hl7v2:CWE.2"
                 priority="3910"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.29/hl7v2:CWE.3"
                 priority="3909"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.29/hl7v2:CWE.4"
                 priority="3907"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.29/hl7v2:CWE.5"
                 priority="3906"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.29/hl7v2:CWE.6"
                 priority="3905"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.29/hl7v2:CWE.7"
                 priority="3903"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.29/hl7v2:CWE.8"
                 priority="3902"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.29/hl7v2:CWE.9"
                 priority="3901"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX"
                 priority="3900"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.3) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.3 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.11) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.11 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.13) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.14) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.15) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.19) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.1"
                 priority="3899"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('569') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('569') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van Item MOET '569' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('SI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van Type MOET 'SI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Set ID - OBX') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van LongName MOET 'Set ID - OBX' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.2"
                 priority="3898"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='ST'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="text()='ST'">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de elementinhoud van hl7v2:OBX.2 MOET ''ST'' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('570') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('570') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van Item MOET '570' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70125') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van Table MOET 'HL70125' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Value Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van LongName MOET 'Value Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.3"
                 priority="3896"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('571') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('571') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van Item MOET '571' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Observation Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van LongName MOET 'Observation Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="3894"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="3893"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="3892"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="3890"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="3889"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="3888"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.4"
                 priority="3886"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('572') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('572') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van Item MOET '572' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Observation Sub-ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van LongName MOET 'Observation Sub-ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.5"
                 priority="3885"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('573') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('573') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van Item MOET '573' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('varies') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('varies') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van Type MOET 'varies' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Observation Value') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van LongName MOET 'Observation Value' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.6"
                 priority="3884"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('574') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('574') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van Item MOET '574' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van LongName MOET 'Units' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="3882"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="3881"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="3880"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="3878"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="3877"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="3876"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.7"
                 priority="3874"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('575') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('575') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van Item MOET '575' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('References Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van LongName MOET 'References Range' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.8"
                 priority="3873"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('576') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('576') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van Item MOET '576' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70078') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van Table MOET 'HL70078' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Abnormal Flags') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van LongName MOET 'Abnormal Flags' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.9"
                 priority="3872"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('577') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('577') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van Item MOET '577' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Probability') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van LongName MOET 'Probability' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.10"
                 priority="3871"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('578') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('578') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van Item MOET '578' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70080') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van Table MOET 'HL70080' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Nature of Abnormal Test') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van LongName MOET 'Nature of Abnormal Test' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.11"
                 priority="3869"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('579') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('579') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van Item MOET '579' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70085') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van Table MOET 'HL70085' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Observation Result Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van LongName MOET 'Observation Result Status' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.12"
                 priority="3867"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('580') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('580') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van Item MOET '580' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Effective Date of Reference Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van LongName MOET 'Effective Date of Reference Range' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="3865"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="3864"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.13"
                 priority="3862"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('581') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('581') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van Item MOET '581' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('User Defined Access Checks') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van LongName MOET 'User Defined Access Checks' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.14"
                 priority="3861"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('582') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('582') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van Item MOET '582' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Date/Time of the Observation') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van LongName MOET 'Date/Time of the Observation' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="3859"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="3858"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.15"
                 priority="3856"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('583') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('583') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van Item MOET '583' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Producer''s ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van LongName MOET 'Producer''s ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="3854"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="3853"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="3852"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="3850"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="3849"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="3848"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16"
                 priority="3846"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.13) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.14) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.15) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.16) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.17) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.18) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.19) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.20) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.21) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.22) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.23) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('584') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('584') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van Item MOET '584' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('XCN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Responsible Observer') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van LongName MOET 'Responsible Observer' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="3844"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="3843"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('FN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="3841"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="3840"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="3839"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Own Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="3838"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="3837"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="3836"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="3835"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="3834"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="3833"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="3832"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="3831"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="3830"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="3828"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="3827"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="3826"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="3824"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70200') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="3822"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="3821"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="3819"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="3817"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="3815"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="3814"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="3813"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="3811"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="3809"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70448') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Context') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="3807"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="3806"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="3805"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="3803"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="3802"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="3801"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="3799"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="3797"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="3795"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="3794"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="3792"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="3790"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="3789"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="3787"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70444') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Assembly Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="3785"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="3783"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="3782"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="3780"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="3778"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="3777"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="3775"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Professional Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="3774"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="3772"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="3771"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="3770"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="3768"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="3767"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="3766"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="3764"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="3763"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="3762"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="3761"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="3759"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="3758"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="3757"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="3755"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="3754"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="3753"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="3751"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="3750"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="3749"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.17"
                 priority="3748"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('936') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('936') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van Item MOET '936' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Observation Method') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van LongName MOET 'Observation Method' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="3746"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="3745"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="3744"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="3742"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="3741"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="3740"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.18"
                 priority="3738"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1479') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1479') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van Item MOET '1479' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Equipment Instance Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van LongName MOET 'Equipment Instance Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="3736"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="3735"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="3734"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="3733"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.19"
                 priority="3731"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1480') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1480') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van Item MOET '1480' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Date/Time of the Analysis') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van LongName MOET 'Date/Time of the Analysis' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="3729"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="3728"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE d20e13520-false-d806294e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER"
                 priority="3726"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth): element hl7v2:SAC is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth): element hl7v2:SAC komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:INV) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:INV) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth): element hl7v2:INV komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC"
                 priority="3725"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.13) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.13) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.14) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.14) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.16) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.16) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.17) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.17) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.18) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.18) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.19) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.19) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.20) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.20) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.21) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.21) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.22) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.22) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.23) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.23) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.24) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.24) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.24 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.25) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.25) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.25 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.26) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.26) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.26 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.28) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.28) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.28 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.29) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.29) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.29 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.30) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.30) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.30 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.31) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.31) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.31 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.32) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.32) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.32 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.33) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.33) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.33 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.34) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.34) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.34 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.35) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.35) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.35 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.36) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.36) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.36 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.37) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.37) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.37 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.38) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.38) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.38 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.39) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.39) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.39 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.42) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.42) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.42 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.1"
                 priority="3724"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1329') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1329') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1329' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('External Accession Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('External Accession Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'External Accession Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.1/hl7v2:EI.1"
                 priority="3722"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.1/hl7v2:EI.2"
                 priority="3721"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.1/hl7v2:EI.3"
                 priority="3720"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.1/hl7v2:EI.4"
                 priority="3719"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.2"
                 priority="3717"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1330') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1330') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1330' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Accession Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Accession Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Accession Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.2/hl7v2:EI.1"
                 priority="3715"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.2/hl7v2:EI.2"
                 priority="3714"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.2/hl7v2:EI.3"
                 priority="3713"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.2/hl7v2:EI.4"
                 priority="3712"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.3"
                 priority="3710"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1331') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1331') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1331' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Container Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Container Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Container Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.3/hl7v2:EI.1"
                 priority="3708"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.3/hl7v2:EI.2"
                 priority="3707"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.3/hl7v2:EI.3"
                 priority="3706"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.3/hl7v2:EI.4"
                 priority="3705"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.4"
                 priority="3703"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1332') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1332') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1332' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Primary (parent) Container Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Primary (parent) Container Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Primary (parent) Container Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.4/hl7v2:EI.1"
                 priority="3701"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.4/hl7v2:EI.2"
                 priority="3700"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.4/hl7v2:EI.3"
                 priority="3699"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.4/hl7v2:EI.4"
                 priority="3698"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.5"
                 priority="3696"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1333') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1333') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1333' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Equipment Container Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Equipment Container Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Equipment Container Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.5/hl7v2:EI.1"
                 priority="3694"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.5/hl7v2:EI.2"
                 priority="3693"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.5/hl7v2:EI.3"
                 priority="3692"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.5/hl7v2:EI.4"
                 priority="3691"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6"
                 priority="3689"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): element hl7v2:SPS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): element hl7v2:SPS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPS.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): element hl7v2:SPS.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPS.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): element hl7v2:SPS.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPS.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): element hl7v2:SPS.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPS.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): element hl7v2:SPS.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPS.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): element hl7v2:SPS.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('249') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('249') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '249' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SPS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('SPS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'SPS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Source') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen Source') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Specimen Source' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.1"
                 priority="3687"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Source Name or Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen Source Name or Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van LongName MOET 'Specimen Source Name or Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.1/hl7v2:CWE.1"
                 priority="3685"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.1/hl7v2:CWE.2"
                 priority="3684"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.1/hl7v2:CWE.3"
                 priority="3683"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.1/hl7v2:CWE.4"
                 priority="3681"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.1/hl7v2:CWE.5"
                 priority="3680"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.1/hl7v2:CWE.6"
                 priority="3679"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.1/hl7v2:CWE.7"
                 priority="3677"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.1/hl7v2:CWE.8"
                 priority="3676"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.1/hl7v2:CWE.9"
                 priority="3675"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.2"
                 priority="3674"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70371') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70371') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van Table MOET 'HL70371' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Additives') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Additives') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van LongName MOET 'Additives' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.2/hl7v2:CWE.1"
                 priority="3672"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.2/hl7v2:CWE.2"
                 priority="3671"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.2/hl7v2:CWE.3"
                 priority="3670"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.2/hl7v2:CWE.4"
                 priority="3668"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.2/hl7v2:CWE.5"
                 priority="3667"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.2/hl7v2:CWE.6"
                 priority="3666"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.2/hl7v2:CWE.7"
                 priority="3664"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.2/hl7v2:CWE.8"
                 priority="3663"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.2/hl7v2:CWE.9"
                 priority="3662"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.3"
                 priority="3661"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TX') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TX') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van Type MOET 'TX' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Collection Method') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen Collection Method') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van LongName MOET 'Specimen Collection Method' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.3/hl7v2:escape"
                 priority="3660"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TX_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.3/hl7v2:escape/hl7v2:escape"
                 priority="3659"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.3/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="3658"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.4"
                 priority="3657"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70163') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70163') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van Table MOET 'HL70163' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Body Site') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Body Site') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van LongName MOET 'Body Site' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.4/hl7v2:CWE.1"
                 priority="3655"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.4/hl7v2:CWE.2"
                 priority="3654"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.4/hl7v2:CWE.3"
                 priority="3653"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.4/hl7v2:CWE.4"
                 priority="3651"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.4/hl7v2:CWE.5"
                 priority="3650"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.4/hl7v2:CWE.6"
                 priority="3649"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.4/hl7v2:CWE.7"
                 priority="3647"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.4/hl7v2:CWE.8"
                 priority="3646"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.4/hl7v2:CWE.9"
                 priority="3645"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.5"
                 priority="3644"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70495') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70495') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van Table MOET 'HL70495' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Site Modifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Site Modifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van LongName MOET 'Site Modifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.5/hl7v2:CWE.1"
                 priority="3642"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.5/hl7v2:CWE.2"
                 priority="3641"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.5/hl7v2:CWE.3"
                 priority="3640"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.5/hl7v2:CWE.4"
                 priority="3638"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.5/hl7v2:CWE.5"
                 priority="3637"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.5/hl7v2:CWE.6"
                 priority="3636"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.5/hl7v2:CWE.7"
                 priority="3634"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.5/hl7v2:CWE.8"
                 priority="3633"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.5/hl7v2:CWE.9"
                 priority="3632"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.6"
                 priority="3631"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Collection Method Modifier Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Collection Method Modifier Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van LongName MOET 'Collection Method Modifier Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.6/hl7v2:CWE.1"
                 priority="3629"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.6/hl7v2:CWE.2"
                 priority="3628"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.6/hl7v2:CWE.3"
                 priority="3627"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.6/hl7v2:CWE.4"
                 priority="3625"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.6/hl7v2:CWE.5"
                 priority="3624"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.6/hl7v2:CWE.6"
                 priority="3623"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.6/hl7v2:CWE.7"
                 priority="3621"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.6/hl7v2:CWE.8"
                 priority="3620"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.6/hl7v2:CWE.9"
                 priority="3619"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.7"
                 priority="3618"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70369') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70369') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van Table MOET 'HL70369' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Role') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen Role') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van LongName MOET 'Specimen Role' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.7/hl7v2:CWE.1"
                 priority="3616"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.7/hl7v2:CWE.2"
                 priority="3615"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.7/hl7v2:CWE.3"
                 priority="3614"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.7/hl7v2:CWE.4"
                 priority="3612"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.7/hl7v2:CWE.5"
                 priority="3611"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.7/hl7v2:CWE.6"
                 priority="3610"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.7/hl7v2:CWE.7"
                 priority="3608"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.7/hl7v2:CWE.8"
                 priority="3607"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.7/hl7v2:CWE.9"
                 priority="3606"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.7"
                 priority="3605"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1334') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1334') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1334' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Registration Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Registration Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Registration Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.7/hl7v2:TS.1"
                 priority="3603"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.7/hl7v2:TS.2"
                 priority="3602"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.8"
                 priority="3600"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1335') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1335') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1335' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70370') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70370') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Table MOET 'HL70370' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Container Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Container Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Container Status' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.8/hl7v2:CE.1"
                 priority="3598"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.8/hl7v2:CE.2"
                 priority="3597"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.8/hl7v2:CE.3"
                 priority="3596"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.8/hl7v2:CE.4"
                 priority="3594"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.8/hl7v2:CE.5"
                 priority="3593"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.8/hl7v2:CE.6"
                 priority="3592"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.9"
                 priority="3590"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1336') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1336') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1336' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70378') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70378') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Table MOET 'HL70378' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Carrier Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Carrier Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Carrier Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.9/hl7v2:CE.1"
                 priority="3588"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.9/hl7v2:CE.2"
                 priority="3587"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.9/hl7v2:CE.3"
                 priority="3586"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.9/hl7v2:CE.4"
                 priority="3584"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.9/hl7v2:CE.5"
                 priority="3583"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.9/hl7v2:CE.6"
                 priority="3582"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.10"
                 priority="3580"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1337') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1337') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1337' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Carrier Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Carrier Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Carrier Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.10/hl7v2:EI.1"
                 priority="3578"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.10/hl7v2:EI.2"
                 priority="3577"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.10/hl7v2:EI.3"
                 priority="3576"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.10/hl7v2:EI.4"
                 priority="3575"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.11"
                 priority="3573"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="*[matches(local-name(),'^NA\.\d+$')]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="*[matches(local-name(),'^NA\.\d+$')]">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): Element names in the datatype NA SHALL conform to pattern 'NA.n' where n is an integer</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="*[. castable as xs:decimal]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="*[. castable as xs:decimal]">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): Element values in the datatype NA SHALL be a valid NM - Numeric</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NA.1) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NA.1) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): element hl7v2:NA.1 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NA.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NA.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): element hl7v2:NA.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NA.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NA.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): element hl7v2:NA.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NA.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NA.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): element hl7v2:NA.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NA.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NA.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): element hl7v2:NA.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1338') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1338') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1338' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NA') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NA') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'NA' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Position in Carrier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Position in Carrier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Position in Carrier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.11/hl7v2:NA.1"
                 priority="3571"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Value1') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Value1') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): de waarde van LongName MOET 'Value1' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.11/hl7v2:NA.2"
                 priority="3570"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Value2') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Value2') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): de waarde van LongName MOET 'Value2' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.11/hl7v2:NA.3"
                 priority="3569"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Value3') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Value3') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): de waarde van LongName MOET 'Value3' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.11/hl7v2:NA.4"
                 priority="3568"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Value4') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Value4') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): de waarde van LongName MOET 'Value4' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.12"
                 priority="3567"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1339') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1339') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1339' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70379') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70379') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Table MOET 'HL70379' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Tray Type - SAC') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Tray Type - SAC') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Tray Type - SAC' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.12/hl7v2:CE.1"
                 priority="3565"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.12/hl7v2:CE.2"
                 priority="3564"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.12/hl7v2:CE.3"
                 priority="3563"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.12/hl7v2:CE.4"
                 priority="3561"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.12/hl7v2:CE.5"
                 priority="3560"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.12/hl7v2:CE.6"
                 priority="3559"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.13"
                 priority="3557"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1340') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1340') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1340' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Tray Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Tray Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Tray Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.13/hl7v2:EI.1"
                 priority="3555"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.13/hl7v2:EI.2"
                 priority="3554"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.13/hl7v2:EI.3"
                 priority="3553"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.13/hl7v2:EI.4"
                 priority="3552"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.14"
                 priority="3550"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="*[matches(local-name(),'^NA\.\d+$')]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="*[matches(local-name(),'^NA\.\d+$')]">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): Element names in the datatype NA SHALL conform to pattern 'NA.n' where n is an integer</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="*[. castable as xs:decimal]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="*[. castable as xs:decimal]">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): Element values in the datatype NA SHALL be a valid NM - Numeric</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NA.1) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NA.1) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): element hl7v2:NA.1 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NA.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NA.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): element hl7v2:NA.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NA.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NA.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): element hl7v2:NA.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NA.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NA.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): element hl7v2:NA.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NA.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NA.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): element hl7v2:NA.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1341') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1341') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1341' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NA') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NA') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'NA' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Position in Tray') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Position in Tray') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Position in Tray' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.14/hl7v2:NA.1"
                 priority="3548"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Value1') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Value1') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): de waarde van LongName MOET 'Value1' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.14/hl7v2:NA.2"
                 priority="3547"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Value2') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Value2') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): de waarde van LongName MOET 'Value2' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.14/hl7v2:NA.3"
                 priority="3546"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Value3') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Value3') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): de waarde van LongName MOET 'Value3' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.14/hl7v2:NA.4"
                 priority="3545"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Value4') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Value4') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): de waarde van LongName MOET 'Value4' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.15"
                 priority="3544"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1342') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1342') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1342' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Location') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Location') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Location' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.15/hl7v2:CE.1"
                 priority="3542"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.15/hl7v2:CE.2"
                 priority="3541"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.15/hl7v2:CE.3"
                 priority="3540"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.15/hl7v2:CE.4"
                 priority="3538"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.15/hl7v2:CE.5"
                 priority="3537"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.15/hl7v2:CE.6"
                 priority="3536"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.16"
                 priority="3534"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1343') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1343') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1343' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Container Height') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Container Height') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Container Height' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.17"
                 priority="3533"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1344') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1344') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1344' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Container Diameter') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Container Diameter') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Container Diameter' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.18"
                 priority="3532"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1345') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1345') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1345' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Barrier Delta') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Barrier Delta') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Barrier Delta' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.19"
                 priority="3531"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1346') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1346') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1346' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Bottom Delta') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Bottom Delta') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Bottom Delta' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.20"
                 priority="3530"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1347') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1347') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1347' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Container Height/Diameter/Delta Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Container Height/Diameter/Delta Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Container Height/Diameter/Delta Units' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.20/hl7v2:CE.1"
                 priority="3528"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.20/hl7v2:CE.2"
                 priority="3527"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.20/hl7v2:CE.3"
                 priority="3526"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.20/hl7v2:CE.4"
                 priority="3524"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.20/hl7v2:CE.5"
                 priority="3523"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.20/hl7v2:CE.6"
                 priority="3522"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.21"
                 priority="3520"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('644') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('644') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '644' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Container Volume') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Container Volume') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Container Volume' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.22"
                 priority="3519"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1349') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1349') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1349' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Available Specimen Volume') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Available Specimen Volume') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Available Specimen Volume' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.23"
                 priority="3518"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1350') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1350') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1350' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Initial Specimen Volume') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Initial Specimen Volume') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Initial Specimen Volume' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.24"
                 priority="3517"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1351') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1351') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1351' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Volume Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Volume Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Volume Units' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.24/hl7v2:CE.1"
                 priority="3515"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.24/hl7v2:CE.2"
                 priority="3514"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.24/hl7v2:CE.3"
                 priority="3513"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.24/hl7v2:CE.4"
                 priority="3511"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.24/hl7v2:CE.5"
                 priority="3510"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.24/hl7v2:CE.6"
                 priority="3509"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.25"
                 priority="3507"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1352') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1352') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1352' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70380') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70380') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Table MOET 'HL70380' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Separator Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Separator Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Separator Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.25/hl7v2:CE.1"
                 priority="3505"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.25/hl7v2:CE.2"
                 priority="3504"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.25/hl7v2:CE.3"
                 priority="3503"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.25/hl7v2:CE.4"
                 priority="3501"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.25/hl7v2:CE.5"
                 priority="3500"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.25/hl7v2:CE.6"
                 priority="3499"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.26"
                 priority="3497"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1353') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1353') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1353' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70381') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70381') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Table MOET 'HL70381' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Cap Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Cap Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Cap Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.26/hl7v2:CE.1"
                 priority="3495"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.26/hl7v2:CE.2"
                 priority="3494"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.26/hl7v2:CE.3"
                 priority="3493"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.26/hl7v2:CE.4"
                 priority="3491"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.26/hl7v2:CE.5"
                 priority="3490"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.26/hl7v2:CE.6"
                 priority="3489"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.27"
                 priority="3487"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('647') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('647') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '647' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70371') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70371') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Table MOET 'HL70371' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Additive') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Additive') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Additive' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.27/hl7v2:CWE.1"
                 priority="3485"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.27/hl7v2:CWE.2"
                 priority="3484"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.27/hl7v2:CWE.3"
                 priority="3483"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.27/hl7v2:CWE.4"
                 priority="3481"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.27/hl7v2:CWE.5"
                 priority="3480"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.27/hl7v2:CWE.6"
                 priority="3479"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.27/hl7v2:CWE.7"
                 priority="3477"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.27/hl7v2:CWE.8"
                 priority="3476"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.27/hl7v2:CWE.9"
                 priority="3475"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.28"
                 priority="3474"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1355') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1355') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1355' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Component') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen Component') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Specimen Component' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.28/hl7v2:CE.1"
                 priority="3472"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.28/hl7v2:CE.2"
                 priority="3471"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.28/hl7v2:CE.3"
                 priority="3470"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.28/hl7v2:CE.4"
                 priority="3468"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.28/hl7v2:CE.5"
                 priority="3467"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.28/hl7v2:CE.6"
                 priority="3466"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.29"
                 priority="3464"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): element hl7v2:SN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): element hl7v2:SN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): element hl7v2:SN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): element hl7v2:SN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1356') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1356') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1356' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('SN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'SN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Dilution Factor') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Dilution Factor') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Dilution Factor' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.29/hl7v2:SN.1"
                 priority="3462"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Comparator') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Comparator') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van LongName MOET 'Comparator' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.29/hl7v2:SN.2"
                 priority="3461"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Num1') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Num1') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van LongName MOET 'Num1' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.29/hl7v2:SN.3"
                 priority="3460"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Separator/Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Separator/Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van LongName MOET 'Separator/Suffix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.29/hl7v2:SN.4"
                 priority="3459"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Num2') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Num2') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van LongName MOET 'Num2' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.30"
                 priority="3458"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1357') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1357') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1357' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70373') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70373') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Table MOET 'HL70373' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Treatment') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Treatment') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Treatment' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.30/hl7v2:CE.1"
                 priority="3456"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.30/hl7v2:CE.2"
                 priority="3455"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.30/hl7v2:CE.3"
                 priority="3454"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.30/hl7v2:CE.4"
                 priority="3452"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.30/hl7v2:CE.5"
                 priority="3451"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.30/hl7v2:CE.6"
                 priority="3450"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.31"
                 priority="3448"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): element hl7v2:SN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): element hl7v2:SN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): element hl7v2:SN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): element hl7v2:SN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1358') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1358') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1358' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('SN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'SN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Temperature') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Temperature') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Temperature' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.31/hl7v2:SN.1"
                 priority="3446"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Comparator') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Comparator') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van LongName MOET 'Comparator' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.31/hl7v2:SN.2"
                 priority="3445"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Num1') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Num1') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van LongName MOET 'Num1' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.31/hl7v2:SN.3"
                 priority="3444"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Separator/Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Separator/Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van LongName MOET 'Separator/Suffix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.31/hl7v2:SN.4"
                 priority="3443"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Num2') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Num2') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van LongName MOET 'Num2' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.32"
                 priority="3442"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1359') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1359') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1359' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Hemolysis Index') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Hemolysis Index') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Hemolysis Index' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.33"
                 priority="3441"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1360') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1360') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1360' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Hemolysis Index Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Hemolysis Index Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Hemolysis Index Units' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.33/hl7v2:CE.1"
                 priority="3439"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.33/hl7v2:CE.2"
                 priority="3438"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.33/hl7v2:CE.3"
                 priority="3437"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.33/hl7v2:CE.4"
                 priority="3435"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.33/hl7v2:CE.5"
                 priority="3434"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.33/hl7v2:CE.6"
                 priority="3433"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.34"
                 priority="3431"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1361') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1361') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1361' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Lipemia Index') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Lipemia Index') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Lipemia Index' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.35"
                 priority="3430"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1362') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1362') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1362' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Lipemia Index Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Lipemia Index Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Lipemia Index Units' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.35/hl7v2:CE.1"
                 priority="3428"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.35/hl7v2:CE.2"
                 priority="3427"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.35/hl7v2:CE.3"
                 priority="3426"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.35/hl7v2:CE.4"
                 priority="3424"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.35/hl7v2:CE.5"
                 priority="3423"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.35/hl7v2:CE.6"
                 priority="3422"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.36"
                 priority="3420"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1363') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1363') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Icterus Index') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Icterus Index') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Icterus Index' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.37"
                 priority="3419"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1364') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1364') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1364' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Icterus Index Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Icterus Index Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Icterus Index Units' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.37/hl7v2:CE.1"
                 priority="3417"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.37/hl7v2:CE.2"
                 priority="3416"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.37/hl7v2:CE.3"
                 priority="3415"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.37/hl7v2:CE.4"
                 priority="3413"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.37/hl7v2:CE.5"
                 priority="3412"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.37/hl7v2:CE.6"
                 priority="3411"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.38"
                 priority="3409"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1365') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1365') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1365' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Fibrin Index') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Fibrin Index') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Fibrin Index' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.39"
                 priority="3408"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1366') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1366') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1366' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Fibrin Index Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Fibrin Index Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Fibrin Index Units' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.39/hl7v2:CE.1"
                 priority="3406"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.39/hl7v2:CE.2"
                 priority="3405"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.39/hl7v2:CE.3"
                 priority="3404"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.39/hl7v2:CE.4"
                 priority="3402"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.39/hl7v2:CE.5"
                 priority="3401"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.39/hl7v2:CE.6"
                 priority="3400"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.40"
                 priority="3398"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1367') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1367') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1367' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70374') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70374') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Table MOET 'HL70374' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('System Induced Contaminants') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('System Induced Contaminants') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'System Induced Contaminants' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.40/hl7v2:CE.1"
                 priority="3396"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.40/hl7v2:CE.2"
                 priority="3395"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.40/hl7v2:CE.3"
                 priority="3394"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.40/hl7v2:CE.4"
                 priority="3392"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.40/hl7v2:CE.5"
                 priority="3391"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.40/hl7v2:CE.6"
                 priority="3390"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.41"
                 priority="3388"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1368') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1368') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1368' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70382') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70382') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Table MOET 'HL70382' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Drug Interference') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Drug Interference') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Drug Interference' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.41/hl7v2:CE.1"
                 priority="3386"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.41/hl7v2:CE.2"
                 priority="3385"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.41/hl7v2:CE.3"
                 priority="3384"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.41/hl7v2:CE.4"
                 priority="3382"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.41/hl7v2:CE.5"
                 priority="3381"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.41/hl7v2:CE.6"
                 priority="3380"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.42"
                 priority="3378"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1369') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1369') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1369' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70375') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70375') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Table MOET 'HL70375' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Artificial Blood') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Artificial Blood') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Artificial Blood' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.42/hl7v2:CE.1"
                 priority="3376"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.42/hl7v2:CE.2"
                 priority="3375"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.42/hl7v2:CE.3"
                 priority="3374"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.42/hl7v2:CE.4"
                 priority="3372"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.42/hl7v2:CE.5"
                 priority="3371"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.42/hl7v2:CE.6"
                 priority="3370"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.43"
                 priority="3368"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1370') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1370') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1370' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70376') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70376') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Table MOET 'HL70376' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Special Handling Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Special Handling Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Special Handling Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.43/hl7v2:CWE.1"
                 priority="3366"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.43/hl7v2:CWE.2"
                 priority="3365"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.43/hl7v2:CWE.3"
                 priority="3364"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.43/hl7v2:CWE.4"
                 priority="3362"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.43/hl7v2:CWE.5"
                 priority="3361"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.43/hl7v2:CWE.6"
                 priority="3360"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.43/hl7v2:CWE.7"
                 priority="3358"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.43/hl7v2:CWE.8"
                 priority="3357"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.43/hl7v2:CWE.9"
                 priority="3356"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.44"
                 priority="3355"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1371') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1371') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1371' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70377') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70377') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Table MOET 'HL70377' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Other Environmental Factors') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Other Environmental Factors') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Other Environmental Factors' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.44/hl7v2:CE.1"
                 priority="3353"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.44/hl7v2:CE.2"
                 priority="3352"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.44/hl7v2:CE.3"
                 priority="3351"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.44/hl7v2:CE.4"
                 priority="3349"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.44/hl7v2:CE.5"
                 priority="3348"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.44/hl7v2:CE.6"
                 priority="3347"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV"
                 priority="3345"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:INV.1) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:INV.1) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): element hl7v2:INV.1 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:INV.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:INV.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): element hl7v2:INV.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:INV.2) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:INV.2) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): element hl7v2:INV.2 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:INV.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:INV.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): element hl7v2:INV.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:INV.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:INV.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): element hl7v2:INV.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:INV.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:INV.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): element hl7v2:INV.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:INV.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:INV.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): element hl7v2:INV.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:INV.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:INV.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): element hl7v2:INV.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:INV.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:INV.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): element hl7v2:INV.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:INV.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:INV.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): element hl7v2:INV.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:INV.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:INV.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): element hl7v2:INV.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:INV.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:INV.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): element hl7v2:INV.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:INV.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:INV.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): element hl7v2:INV.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:INV.13) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:INV.13) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): element hl7v2:INV.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:INV.14) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:INV.14) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): element hl7v2:INV.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:INV.16) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:INV.16) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): element hl7v2:INV.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:INV.17) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:INV.17) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): element hl7v2:INV.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:INV.18) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:INV.18) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): element hl7v2:INV.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:INV.19) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:INV.19) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): element hl7v2:INV.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:INV.20) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:INV.20) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): element hl7v2:INV.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.1"
                 priority="3344"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1372') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1372') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van Item MOET '1372' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70451') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70451') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van Table MOET 'HL70451' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Substance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Substance Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van LongName MOET 'Substance Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.1/hl7v2:CE.1"
                 priority="3342"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.1/hl7v2:CE.2"
                 priority="3341"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.1/hl7v2:CE.3"
                 priority="3340"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.1/hl7v2:CE.4"
                 priority="3338"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.1/hl7v2:CE.5"
                 priority="3337"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.1/hl7v2:CE.6"
                 priority="3336"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.2"
                 priority="3334"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1373') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1373') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van Item MOET '1373' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70383') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70383') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van Table MOET 'HL70383' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Substance Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Substance Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van LongName MOET 'Substance Status' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.2/hl7v2:CE.1"
                 priority="3332"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.2/hl7v2:CE.2"
                 priority="3331"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.2/hl7v2:CE.3"
                 priority="3330"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.2/hl7v2:CE.4"
                 priority="3328"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.2/hl7v2:CE.5"
                 priority="3327"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.2/hl7v2:CE.6"
                 priority="3326"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.3"
                 priority="3324"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1374') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1374') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van Item MOET '1374' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70384') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70384') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van Table MOET 'HL70384' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Substance Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Substance Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van LongName MOET 'Substance Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.3/hl7v2:CE.1"
                 priority="3322"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.3/hl7v2:CE.2"
                 priority="3321"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.3/hl7v2:CE.3"
                 priority="3320"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.3/hl7v2:CE.4"
                 priority="3318"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.3/hl7v2:CE.5"
                 priority="3317"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.3/hl7v2:CE.6"
                 priority="3316"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.4"
                 priority="3314"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1532') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1532') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van Item MOET '1532' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Inventory Container Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Inventory Container Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van LongName MOET 'Inventory Container Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.4/hl7v2:CE.1"
                 priority="3312"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.4/hl7v2:CE.2"
                 priority="3311"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.4/hl7v2:CE.3"
                 priority="3310"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.4/hl7v2:CE.4"
                 priority="3308"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.4/hl7v2:CE.5"
                 priority="3307"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.4/hl7v2:CE.6"
                 priority="3306"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.5"
                 priority="3304"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1376') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1376') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van Item MOET '1376' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Container Carrier Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Container Carrier Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van LongName MOET 'Container Carrier Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.5/hl7v2:CE.1"
                 priority="3302"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.5/hl7v2:CE.2"
                 priority="3301"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.5/hl7v2:CE.3"
                 priority="3300"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.5/hl7v2:CE.4"
                 priority="3298"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.5/hl7v2:CE.5"
                 priority="3297"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.5/hl7v2:CE.6"
                 priority="3296"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.6"
                 priority="3294"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1377') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1377') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van Item MOET '1377' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Position on Carrier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Position on Carrier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van LongName MOET 'Position on Carrier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.6/hl7v2:CE.1"
                 priority="3292"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.6/hl7v2:CE.2"
                 priority="3291"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.6/hl7v2:CE.3"
                 priority="3290"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.6/hl7v2:CE.4"
                 priority="3288"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.6/hl7v2:CE.5"
                 priority="3287"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.6/hl7v2:CE.6"
                 priority="3286"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.7"
                 priority="3284"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1378') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1378') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van Item MOET '1378' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Initial Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Initial Quantity') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van LongName MOET 'Initial Quantity' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.8"
                 priority="3283"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1379') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1379') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van Item MOET '1379' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Current Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Current Quantity') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van LongName MOET 'Current Quantity' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.9"
                 priority="3282"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1380') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1380') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van Item MOET '1380' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Available Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Available Quantity') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van LongName MOET 'Available Quantity' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.10"
                 priority="3281"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1381') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1381') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van Item MOET '1381' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Consumption Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Consumption Quantity') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van LongName MOET 'Consumption Quantity' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.11"
                 priority="3280"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1382') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1382') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van Item MOET '1382' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Quantity Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van LongName MOET 'Quantity Units' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.11/hl7v2:CE.1"
                 priority="3278"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.11/hl7v2:CE.2"
                 priority="3277"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.11/hl7v2:CE.3"
                 priority="3276"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.11/hl7v2:CE.4"
                 priority="3274"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.11/hl7v2:CE.5"
                 priority="3273"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.11/hl7v2:CE.6"
                 priority="3272"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.12"
                 priority="3270"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1383') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1383') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van Item MOET '1383' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Expiration Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van LongName MOET 'Expiration Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.12/hl7v2:TS.1"
                 priority="3268"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.12/hl7v2:TS.2"
                 priority="3267"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.13"
                 priority="3265"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1384') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1384') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van Item MOET '1384' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('First Used Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('First Used Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van LongName MOET 'First Used Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.13/hl7v2:TS.1"
                 priority="3263"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.13/hl7v2:TS.2"
                 priority="3262"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14"
                 priority="3260"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1385') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1385') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van Item MOET '1385' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TQ') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TQ') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van Type MOET 'TQ' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('On Board Stability Duration') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('On Board Stability Duration') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van LongName MOET 'On Board Stability Duration' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.1"
                 priority="3258"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CQ') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van Type MOET 'CQ' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Quantity') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van LongName MOET 'Quantity' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.1/hl7v2:CQ.1"
                 priority="3256"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Quantity') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van LongName MOET 'Quantity' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.1/hl7v2:CQ.2"
                 priority="3255"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van LongName MOET 'Units' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="3253"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="3252"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="3251"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="3249"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="3248"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="3247"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.2"
                 priority="3245"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RI.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:RI.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RI_datatype): element hl7v2:RI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RI.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:RI.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RI_datatype): element hl7v2:RI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('RI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('RI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van Type MOET 'RI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Interval') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Interval') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van LongName MOET 'Interval' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.2/hl7v2:RI.1"
                 priority="3243"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70335') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70335') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RI_datatype): de waarde van Table MOET 'HL70335' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Repeat Pattern') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Repeat Pattern') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RI_datatype): de waarde van LongName MOET 'Repeat Pattern' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.2/hl7v2:RI.2"
                 priority="3242"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Explicit Time Interval') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Explicit Time Interval') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RI_datatype): de waarde van LongName MOET 'Explicit Time Interval' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.3"
                 priority="3241"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Duration') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Duration') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van LongName MOET 'Duration' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.4"
                 priority="3240"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van LongName MOET 'Start Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.4/hl7v2:TS.1"
                 priority="3238"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.4/hl7v2:TS.2"
                 priority="3237"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.5"
                 priority="3235"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van LongName MOET 'End Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.5/hl7v2:TS.1"
                 priority="3233"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.5/hl7v2:TS.2"
                 priority="3232"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.6"
                 priority="3230"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Priority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Priority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van LongName MOET 'Priority' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.7"
                 priority="3229"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Condition') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Condition') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van LongName MOET 'Condition' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.8"
                 priority="3228"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TX') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TX') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van Type MOET 'TX' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.8/hl7v2:escape"
                 priority="3227"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TX_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.8/hl7v2:escape/hl7v2:escape"
                 priority="3226"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.8/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="3225"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.9"
                 priority="3224"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70472') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70472') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van Table MOET 'HL70472' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Conjunction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Conjunction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van LongName MOET 'Conjunction' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.10"
                 priority="3222"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('OSD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('OSD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van Type MOET 'OSD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Order Sequencing') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Order Sequencing') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van LongName MOET 'Order Sequencing' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.10/hl7v2:OSD.1"
                 priority="3220"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70524') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70524') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Table MOET 'HL70524' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Sequence/Results Flag') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Sequence/Results Flag') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van LongName MOET 'Sequence/Results Flag' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.10/hl7v2:OSD.2"
                 priority="3218"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Order Number: Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Placer Order Number: Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van LongName MOET 'Placer Order Number: Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.10/hl7v2:OSD.3"
                 priority="3217"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Order Number: Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Placer Order Number: Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van LongName MOET 'Placer Order Number: Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.10/hl7v2:OSD.4"
                 priority="3216"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Order Number: Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Filler Order Number: Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van LongName MOET 'Filler Order Number: Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.10/hl7v2:OSD.5"
                 priority="3215"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Order Number: Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Filler Order Number: Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van LongName MOET 'Filler Order Number: Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.10/hl7v2:OSD.6"
                 priority="3214"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Sequence Condition Value') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Sequence Condition Value') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van LongName MOET 'Sequence Condition Value' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.10/hl7v2:OSD.7"
                 priority="3213"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Maximum Number of Repeats') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Maximum Number of Repeats') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van LongName MOET 'Maximum Number of Repeats' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.10/hl7v2:OSD.8"
                 priority="3212"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Order Number: Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Placer Order Number: Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van LongName MOET 'Placer Order Number: Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.10/hl7v2:OSD.9"
                 priority="3211"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Order Number: Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Placer Order Number: Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van LongName MOET 'Placer Order Number: Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.10/hl7v2:OSD.10"
                 priority="3209"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Order Number: Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Filler Order Number: Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van LongName MOET 'Filler Order Number: Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.10/hl7v2:OSD.11"
                 priority="3208"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Order Number: Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Filler Order Number: Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van LongName MOET 'Filler Order Number: Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.11"
                 priority="3206"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Occurrence Duration') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Occurrence Duration') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van LongName MOET 'Occurrence Duration' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.11/hl7v2:CE.1"
                 priority="3204"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.11/hl7v2:CE.2"
                 priority="3203"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.11/hl7v2:CE.3"
                 priority="3202"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.11/hl7v2:CE.4"
                 priority="3200"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.11/hl7v2:CE.5"
                 priority="3199"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.11/hl7v2:CE.6"
                 priority="3198"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.12"
                 priority="3196"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Total Occurrences') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Total Occurrences') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van LongName MOET 'Total Occurrences' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.15"
                 priority="3195"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1386') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1386') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van Item MOET '1386' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Test/Fluid Identifier(s)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Test/Fluid Identifier(s)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van LongName MOET 'Test/Fluid Identifier(s)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.15/hl7v2:CE.1"
                 priority="3193"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.15/hl7v2:CE.2"
                 priority="3192"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.15/hl7v2:CE.3"
                 priority="3191"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.15/hl7v2:CE.4"
                 priority="3189"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.15/hl7v2:CE.5"
                 priority="3188"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.15/hl7v2:CE.6"
                 priority="3187"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.16"
                 priority="3185"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1387') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1387') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van Item MOET '1387' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Manufacturer Lot Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Manufacturer Lot Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van LongName MOET 'Manufacturer Lot Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.17"
                 priority="3184"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('286') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('286') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van Item MOET '286' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70385') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70385') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van Table MOET 'HL70385' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Manufacturer Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Manufacturer Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van LongName MOET 'Manufacturer Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.17/hl7v2:CE.1"
                 priority="3182"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.17/hl7v2:CE.2"
                 priority="3181"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.17/hl7v2:CE.3"
                 priority="3180"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.17/hl7v2:CE.4"
                 priority="3178"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.17/hl7v2:CE.5"
                 priority="3177"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.17/hl7v2:CE.6"
                 priority="3176"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.18"
                 priority="3174"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1389') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1389') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van Item MOET '1389' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70386') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70386') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van Table MOET 'HL70386' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Supplier Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Supplier Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van LongName MOET 'Supplier Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.18/hl7v2:CE.1"
                 priority="3172"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.18/hl7v2:CE.2"
                 priority="3171"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.18/hl7v2:CE.3"
                 priority="3170"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.18/hl7v2:CE.4"
                 priority="3168"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.18/hl7v2:CE.5"
                 priority="3167"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.18/hl7v2:CE.6"
                 priority="3166"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.19"
                 priority="3164"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1626') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1626') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van Item MOET '1626' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CQ') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van Type MOET 'CQ' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('On Board Stability Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('On Board Stability Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van LongName MOET 'On Board Stability Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.19/hl7v2:CQ.1"
                 priority="3162"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Quantity') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van LongName MOET 'Quantity' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.19/hl7v2:CQ.2"
                 priority="3161"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van LongName MOET 'Units' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.19/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="3159"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.19/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="3158"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.19/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="3157"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.19/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="3155"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.19/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="3154"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.19/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="3153"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.20"
                 priority="3151"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1896') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1896') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van Item MOET '1896' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CQ') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van Type MOET 'CQ' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Target Value') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Target Value') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van LongName MOET 'Target Value' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.20/hl7v2:CQ.1"
                 priority="3149"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Quantity') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van LongName MOET 'Quantity' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.20/hl7v2:CQ.2"
                 priority="3148"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van LongName MOET 'Units' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.20/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="3146"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.20/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="3145"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.20/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="3144"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.20/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="3142"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.20/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="3141"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.20/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="3140"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE d20e13527-false-d819556e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER"
                 priority="3138"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth): element hl7v2:OBR is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth): element hl7v2:OBR komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth): element hl7v2:ORC is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth): element hl7v2:ORC komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OUL_R22.RESULT) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7v2:OUL_R22.RESULT) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth): element hl7v2:OUL_R22.RESULT is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR"
                 priority="3137"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.3) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.3) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.3 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.4) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.4) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.4 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.13) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.13) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.14) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.14) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.15) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.15) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.18) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.18) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.19) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.19) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.20) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.20) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.21) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.21) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.22) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.22) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.23) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.23) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.24) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.24) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.24 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.25) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.25) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.25 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.26) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.26) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.26 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.29) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.29) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.29 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.30) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.30) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.30 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.32) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.32) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.32 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.36) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.36) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.36 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.37) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.37) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.37 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.40) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.40) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.40 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.41) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.41) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.41 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.42) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.42) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.42 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.44) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.44) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.44 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.48) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.48) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.48 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.49) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.49) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.49 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.1"
                 priority="3136"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('237') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('237') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Item MOET '237' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('SI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Type MOET 'SI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Set ID - OBR') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Set ID - OBR') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van LongName MOET 'Set ID - OBR' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.2"
                 priority="3135"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('216') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('216') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Item MOET '216' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Order Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Placer Order Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van LongName MOET 'Placer Order Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.2/hl7v2:EI.1"
                 priority="3133"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.2/hl7v2:EI.2"
                 priority="3132"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.2/hl7v2:EI.3"
                 priority="3131"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.2/hl7v2:EI.4"
                 priority="3130"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.3"
                 priority="3128"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('217') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('217') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Item MOET '217' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Order Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Filler Order Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van LongName MOET 'Filler Order Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.3/hl7v2:EI.1"
                 priority="3126"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.3/hl7v2:EI.2"
                 priority="3125"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.3/hl7v2:EI.3"
                 priority="3124"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.3/hl7v2:EI.4"
                 priority="3123"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.4"
                 priority="3121"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('238') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('238') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Item MOET '238' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal Service Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal Service Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van LongName MOET 'Universal Service Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.4/hl7v2:CE.1"
                 priority="3119"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.4/hl7v2:CE.2"
                 priority="3118"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.4/hl7v2:CE.3"
                 priority="3117"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.4/hl7v2:CE.4"
                 priority="3115"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.4/hl7v2:CE.5"
                 priority="3114"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.4/hl7v2:CE.6"
                 priority="3113"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.5"
                 priority="3111"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('239') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('239') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Item MOET '239' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Priority _ OBR') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Priority _ OBR') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van LongName MOET 'Priority _ OBR' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.6"
                 priority="3109"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('240') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('240') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Item MOET '240' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Requested Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Requested Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van LongName MOET 'Requested Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.6/hl7v2:TS.1"
                 priority="3107"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.6/hl7v2:TS.2"
                 priority="3106"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.7"
                 priority="3104"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('241') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('241') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Item MOET '241' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Observation Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van LongName MOET 'Observation Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.7/hl7v2:TS.1"
                 priority="3102"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.7/hl7v2:TS.2"
                 priority="3101"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.8"
                 priority="3099"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('242') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('242') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Item MOET '242' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Observation End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van LongName MOET 'Observation End Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.8/hl7v2:TS.1"
                 priority="3097"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.8/hl7v2:TS.2"
                 priority="3096"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.9"
                 priority="3094"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('243') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('243') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Item MOET '243' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CQ') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Type MOET 'CQ' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Collection Volume') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Collection Volume') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van LongName MOET 'Collection Volume' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.9/hl7v2:CQ.1"
                 priority="3092"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Quantity') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van LongName MOET 'Quantity' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.9/hl7v2:CQ.2"
                 priority="3091"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van LongName MOET 'Units' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.9/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="3089"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.9/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="3088"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.9/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="3087"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.9/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="3085"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.9/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="3084"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.9/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="3083"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10"
                 priority="3081"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.13) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.14) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.15) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.16) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.17) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.18) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.19) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.20) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.21) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.22) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.23) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('244') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('244') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Item MOET '244' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('XCN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Collector Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Collector Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van LongName MOET 'Collector Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.1"
                 priority="3079"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.2"
                 priority="3078"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('FN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="3076"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="3075"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="3074"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Own Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="3073"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="3072"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.3"
                 priority="3071"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.4"
                 priority="3070"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.5"
                 priority="3069"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.6"
                 priority="3068"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.7"
                 priority="3067"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.8"
                 priority="3066"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.9"
                 priority="3065"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="3063"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="3062"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="3061"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.10"
                 priority="3059"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70200') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.11"
                 priority="3057"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.12"
                 priority="3056"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.13"
                 priority="3054"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.14"
                 priority="3052"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="3050"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="3049"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="3048"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.15"
                 priority="3046"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.16"
                 priority="3044"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70448') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Context') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="3042"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="3041"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="3040"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="3038"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="3037"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="3036"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.17"
                 priority="3034"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="3032"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="3030"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="3029"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="3027"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="3025"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="3024"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.18"
                 priority="3022"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70444') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Assembly Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.19"
                 priority="3020"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="3018"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="3017"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.20"
                 priority="3015"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="3013"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="3012"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.21"
                 priority="3010"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Professional Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22"
                 priority="3009"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="3007"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="3006"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="3005"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="3003"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="3002"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="3001"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="2999"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="2998"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="2997"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23"
                 priority="2996"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="2994"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="2993"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="2992"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="2990"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="2989"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="2988"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="2986"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="2985"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="2984"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.11"
                 priority="2983"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('245') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('245') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Item MOET '245' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70065') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70065') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70065' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Action Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen Action Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van LongName MOET 'Specimen Action Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.12"
                 priority="2981"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('246') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('246') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Item MOET '246' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Danger Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Danger Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van LongName MOET 'Danger Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.12/hl7v2:CE.1"
                 priority="2979"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.12/hl7v2:CE.2"
                 priority="2978"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.12/hl7v2:CE.3"
                 priority="2977"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.12/hl7v2:CE.4"
                 priority="2975"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.12/hl7v2:CE.5"
                 priority="2974"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.12/hl7v2:CE.6"
                 priority="2973"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.13"
                 priority="2971"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('247') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('247') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Item MOET '247' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Relevant Clinical Information') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Relevant Clinical Information') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van LongName MOET 'Relevant Clinical Information' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.14"
                 priority="2970"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('248') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('248') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Item MOET '248' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Received Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen Received Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van LongName MOET 'Specimen Received Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.14/hl7v2:TS.1"
                 priority="2968"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.14/hl7v2:TS.2"
                 priority="2967"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15"
                 priority="2965"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): element hl7v2:SPS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): element hl7v2:SPS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPS.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): element hl7v2:SPS.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPS.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): element hl7v2:SPS.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPS.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): element hl7v2:SPS.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPS.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): element hl7v2:SPS.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPS.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): element hl7v2:SPS.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('249') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('249') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Item MOET '249' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SPS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('SPS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Type MOET 'SPS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Source') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen Source') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van LongName MOET 'Specimen Source' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1"
                 priority="2963"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Source Name or Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen Source Name or Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van LongName MOET 'Specimen Source Name or Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.1"
                 priority="2961"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.2"
                 priority="2960"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.3"
                 priority="2959"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.4"
                 priority="2957"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.5"
                 priority="2956"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.6"
                 priority="2955"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.7"
                 priority="2953"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.8"
                 priority="2952"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.9"
                 priority="2951"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2"
                 priority="2950"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70371') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70371') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van Table MOET 'HL70371' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Additives') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Additives') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van LongName MOET 'Additives' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.1"
                 priority="2948"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.2"
                 priority="2947"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.3"
                 priority="2946"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.4"
                 priority="2944"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.5"
                 priority="2943"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.6"
                 priority="2942"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.7"
                 priority="2940"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.8"
                 priority="2939"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.9"
                 priority="2938"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.3"
                 priority="2937"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TX') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TX') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van Type MOET 'TX' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Collection Method') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen Collection Method') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van LongName MOET 'Specimen Collection Method' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.3/hl7v2:escape"
                 priority="2936"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TX_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.3/hl7v2:escape/hl7v2:escape"
                 priority="2935"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.3/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="2934"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4"
                 priority="2933"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70163') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70163') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van Table MOET 'HL70163' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Body Site') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Body Site') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van LongName MOET 'Body Site' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.1"
                 priority="2931"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.2"
                 priority="2930"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.3"
                 priority="2929"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.4"
                 priority="2927"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.5"
                 priority="2926"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.6"
                 priority="2925"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.7"
                 priority="2923"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.8"
                 priority="2922"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.9"
                 priority="2921"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5"
                 priority="2920"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70495') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70495') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van Table MOET 'HL70495' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Site Modifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Site Modifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van LongName MOET 'Site Modifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.1"
                 priority="2918"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.2"
                 priority="2917"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.3"
                 priority="2916"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.4"
                 priority="2914"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.5"
                 priority="2913"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.6"
                 priority="2912"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.7"
                 priority="2910"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.8"
                 priority="2909"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.9"
                 priority="2908"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6"
                 priority="2907"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Collection Method Modifier Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Collection Method Modifier Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van LongName MOET 'Collection Method Modifier Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.1"
                 priority="2905"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.2"
                 priority="2904"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.3"
                 priority="2903"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.4"
                 priority="2901"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.5"
                 priority="2900"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.6"
                 priority="2899"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.7"
                 priority="2897"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.8"
                 priority="2896"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.9"
                 priority="2895"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7"
                 priority="2894"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70369') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70369') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van Table MOET 'HL70369' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Role') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen Role') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van LongName MOET 'Specimen Role' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.1"
                 priority="2892"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.2"
                 priority="2891"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.3"
                 priority="2890"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.4"
                 priority="2888"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.5"
                 priority="2887"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.6"
                 priority="2886"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.7"
                 priority="2884"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.8"
                 priority="2883"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.9"
                 priority="2882"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16"
                 priority="2881"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.13) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.14) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.15) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.16) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.17) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.18) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.19) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.20) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.21) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.22) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.23) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('226') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('226') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Item MOET '226' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('XCN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Ordering Provider') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Ordering Provider') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van LongName MOET 'Ordering Provider' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.1"
                 priority="2879"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.2"
                 priority="2878"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('FN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="2876"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="2875"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="2874"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Own Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="2873"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="2872"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.3"
                 priority="2871"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.4"
                 priority="2870"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.5"
                 priority="2869"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.6"
                 priority="2868"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.7"
                 priority="2867"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.8"
                 priority="2866"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.9"
                 priority="2865"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="2863"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="2862"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="2861"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.10"
                 priority="2859"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70200') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.11"
                 priority="2857"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.12"
                 priority="2856"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.13"
                 priority="2854"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.14"
                 priority="2852"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="2850"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="2849"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="2848"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.15"
                 priority="2846"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.16"
                 priority="2844"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70448') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Context') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="2842"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="2841"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="2840"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="2838"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="2837"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="2836"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.17"
                 priority="2834"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="2832"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="2830"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="2829"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="2827"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="2825"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="2824"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.18"
                 priority="2822"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70444') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Assembly Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.19"
                 priority="2820"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="2818"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="2817"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.20"
                 priority="2815"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="2813"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="2812"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.21"
                 priority="2810"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Professional Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22"
                 priority="2809"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="2807"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="2806"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="2805"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="2803"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="2802"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="2801"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="2799"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="2798"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="2797"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23"
                 priority="2796"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="2794"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="2793"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="2792"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="2790"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="2789"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="2788"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="2786"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="2785"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="2784"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.17"
                 priority="2783"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('250') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('250') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Item MOET '250' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('XTN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Type MOET 'XTN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Order Callback Phone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Order Callback Phone Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van LongName MOET 'Order Callback Phone Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.1"
                 priority="2781"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Telephone Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Telephone Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.2"
                 priority="2780"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70201') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Table MOET 'HL70201' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Telecommunication Use Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Use Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.3"
                 priority="2778"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70202') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Table MOET 'HL70202' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Equipment Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.4"
                 priority="2776"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Email Address') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Email Address' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.5"
                 priority="2775"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Country Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Country Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.6"
                 priority="2774"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Area/City Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Area/City Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.7"
                 priority="2773"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Local Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Local Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.8"
                 priority="2772"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Extension') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Extension' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.9"
                 priority="2771"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Any Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Any Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.10"
                 priority="2770"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Extension Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Extension Prefix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.11"
                 priority="2769"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Speed Dial Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Speed Dial Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.12"
                 priority="2768"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Unformatted Telephone number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Unformatted Telephone number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.18"
                 priority="2767"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('251') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('251') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Item MOET '251' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Field 1') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Placer Field 1') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van LongName MOET 'Placer Field 1' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.19"
                 priority="2766"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('252') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('252') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Item MOET '252' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Field 2') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Placer Field 2') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van LongName MOET 'Placer Field 2' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.20"
                 priority="2765"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('253') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('253') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Item MOET '253' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Field 1') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Filler Field 1') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van LongName MOET 'Filler Field 1' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.21"
                 priority="2764"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('254') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('254') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Item MOET '254' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Field 2') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Filler Field 2') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van LongName MOET 'Filler Field 2' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.22"
                 priority="2763"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('255') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('255') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Item MOET '255' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Results Rpt/Status Chng - Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Results Rpt/Status Chng - Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van LongName MOET 'Results Rpt/Status Chng - Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.22/hl7v2:TS.1"
                 priority="2761"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.22/hl7v2:TS.2"
                 priority="2760"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.23"
                 priority="2758"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MOC.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MOC.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.34-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MOC_datatype): element hl7v2:MOC.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MOC.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MOC.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.34-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MOC_datatype): element hl7v2:MOC.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('256') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('256') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Item MOET '256' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('MOC') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('MOC') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Type MOET 'MOC' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Charge to Practice') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Charge to Practice') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van LongName MOET 'Charge to Practice' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.1"
                 priority="2756"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MO.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MO.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MO_datatype): element hl7v2:MO.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MO.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MO.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MO_datatype): element hl7v2:MO.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('MO') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('MO') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.34-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MOC_datatype): de waarde van Type MOET 'MO' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Monetary Amount') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Monetary Amount') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.34-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MOC_datatype): de waarde van LongName MOET 'Monetary Amount' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.1/hl7v2:MO.1"
                 priority="2754"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MO_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Quantity') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MO_datatype): de waarde van LongName MOET 'Quantity' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.1/hl7v2:MO.2"
                 priority="2753"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MO_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Denomination') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Denomination') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MO_datatype): de waarde van LongName MOET 'Denomination' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.2"
                 priority="2751"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.34-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MOC_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Charge Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Charge Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.34-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MOC_datatype): de waarde van LongName MOET 'Charge Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.2/hl7v2:CE.1"
                 priority="2749"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.2/hl7v2:CE.2"
                 priority="2748"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.2/hl7v2:CE.3"
                 priority="2747"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.2/hl7v2:CE.4"
                 priority="2745"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.2/hl7v2:CE.5"
                 priority="2744"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.2/hl7v2:CE.6"
                 priority="2743"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.24"
                 priority="2741"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('257') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('257') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Item MOET '257' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70074') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70074') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70074' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Diagnostic Serv Sect ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Diagnostic Serv Sect ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van LongName MOET 'Diagnostic Serv Sect ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.25"
                 priority="2739"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='F'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="text()='F'">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de elementinhoud van hl7v2:OBR.25 MOET ''F'' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('258') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('258') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Item MOET '258' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70123') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70123') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70123' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Result Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van LongName MOET 'Result Status' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.26"
                 priority="2737"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PRL.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PRL.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PRL_datatype): element hl7v2:PRL.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PRL.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PRL.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PRL_datatype): element hl7v2:PRL.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PRL.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PRL.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PRL_datatype): element hl7v2:PRL.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('259') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('259') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Item MOET '259' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('PRL') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('PRL') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Type MOET 'PRL' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Parent Result') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Parent Result') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van LongName MOET 'Parent Result' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.1"
                 priority="2735"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PRL_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Parent Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Parent Observation Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PRL_datatype): de waarde van LongName MOET 'Parent Observation Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.1/hl7v2:CE.1"
                 priority="2733"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.1/hl7v2:CE.2"
                 priority="2732"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.1/hl7v2:CE.3"
                 priority="2731"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.1/hl7v2:CE.4"
                 priority="2729"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.1/hl7v2:CE.5"
                 priority="2728"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.1/hl7v2:CE.6"
                 priority="2727"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.2"
                 priority="2725"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PRL_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Parent Observation Sub-identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Parent Observation Sub-identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PRL_datatype): de waarde van LongName MOET 'Parent Observation Sub-identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.3"
                 priority="2724"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TX') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TX') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PRL_datatype): de waarde van Type MOET 'TX' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Parent Observation Value Descriptor') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Parent Observation Value Descriptor') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PRL_datatype): de waarde van LongName MOET 'Parent Observation Value Descriptor' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.3/hl7v2:escape"
                 priority="2723"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TX_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.3/hl7v2:escape/hl7v2:escape"
                 priority="2722"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.3/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="2721"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27"
                 priority="2720"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('221') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('221') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Item MOET '221' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TQ') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TQ') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Type MOET 'TQ' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity/Timing') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Quantity/Timing') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van LongName MOET 'Quantity/Timing' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1"
                 priority="2718"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CQ') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van Type MOET 'CQ' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Quantity') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van LongName MOET 'Quantity' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/hl7v2:CQ.1"
                 priority="2716"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Quantity') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van LongName MOET 'Quantity' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/hl7v2:CQ.2"
                 priority="2715"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van LongName MOET 'Units' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="2713"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="2712"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="2711"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="2709"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="2708"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="2707"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.2"
                 priority="2705"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RI.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:RI.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RI_datatype): element hl7v2:RI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RI.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:RI.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RI_datatype): element hl7v2:RI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('RI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('RI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van Type MOET 'RI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Interval') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Interval') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van LongName MOET 'Interval' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.2/hl7v2:RI.1"
                 priority="2703"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70335') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70335') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RI_datatype): de waarde van Table MOET 'HL70335' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Repeat Pattern') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Repeat Pattern') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RI_datatype): de waarde van LongName MOET 'Repeat Pattern' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.2/hl7v2:RI.2"
                 priority="2702"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Explicit Time Interval') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Explicit Time Interval') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RI_datatype): de waarde van LongName MOET 'Explicit Time Interval' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.3"
                 priority="2701"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Duration') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Duration') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van LongName MOET 'Duration' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.4"
                 priority="2700"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van LongName MOET 'Start Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.4/hl7v2:TS.1"
                 priority="2698"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.4/hl7v2:TS.2"
                 priority="2697"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.5"
                 priority="2695"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van LongName MOET 'End Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.5/hl7v2:TS.1"
                 priority="2693"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.5/hl7v2:TS.2"
                 priority="2692"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.6"
                 priority="2690"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Priority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Priority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van LongName MOET 'Priority' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.7"
                 priority="2689"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Condition') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Condition') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van LongName MOET 'Condition' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.8"
                 priority="2688"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TX') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TX') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van Type MOET 'TX' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.8/hl7v2:escape"
                 priority="2687"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TX_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.8/hl7v2:escape/hl7v2:escape"
                 priority="2686"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.8/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="2685"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.9"
                 priority="2684"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70472') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70472') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van Table MOET 'HL70472' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Conjunction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Conjunction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van LongName MOET 'Conjunction' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10"
                 priority="2682"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('OSD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('OSD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van Type MOET 'OSD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Order Sequencing') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Order Sequencing') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van LongName MOET 'Order Sequencing' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.1"
                 priority="2680"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70524') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70524') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Table MOET 'HL70524' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Sequence/Results Flag') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Sequence/Results Flag') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van LongName MOET 'Sequence/Results Flag' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.2"
                 priority="2678"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Order Number: Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Placer Order Number: Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van LongName MOET 'Placer Order Number: Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.3"
                 priority="2677"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Order Number: Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Placer Order Number: Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van LongName MOET 'Placer Order Number: Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.4"
                 priority="2676"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Order Number: Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Filler Order Number: Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van LongName MOET 'Filler Order Number: Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.5"
                 priority="2675"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Order Number: Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Filler Order Number: Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van LongName MOET 'Filler Order Number: Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.6"
                 priority="2674"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Sequence Condition Value') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Sequence Condition Value') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van LongName MOET 'Sequence Condition Value' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.7"
                 priority="2673"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Maximum Number of Repeats') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Maximum Number of Repeats') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van LongName MOET 'Maximum Number of Repeats' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.8"
                 priority="2672"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Order Number: Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Placer Order Number: Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van LongName MOET 'Placer Order Number: Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.9"
                 priority="2671"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Order Number: Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Placer Order Number: Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van LongName MOET 'Placer Order Number: Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.10"
                 priority="2669"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Order Number: Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Filler Order Number: Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van LongName MOET 'Filler Order Number: Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.11"
                 priority="2668"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Order Number: Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Filler Order Number: Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van LongName MOET 'Filler Order Number: Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.11"
                 priority="2666"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Occurrence Duration') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Occurrence Duration') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van LongName MOET 'Occurrence Duration' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.11/hl7v2:CE.1"
                 priority="2664"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.11/hl7v2:CE.2"
                 priority="2663"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.11/hl7v2:CE.3"
                 priority="2662"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.11/hl7v2:CE.4"
                 priority="2660"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.11/hl7v2:CE.5"
                 priority="2659"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.11/hl7v2:CE.6"
                 priority="2658"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.12"
                 priority="2656"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Total Occurrences') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Total Occurrences') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van LongName MOET 'Total Occurrences' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28"
                 priority="2655"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.13) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.14) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.15) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.16) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.17) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.18) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.19) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.20) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.21) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.22) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.23) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('260') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('260') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Item MOET '260' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('XCN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Result Copies To') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Result Copies To') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van LongName MOET 'Result Copies To' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.1"
                 priority="2653"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.2"
                 priority="2652"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('FN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="2650"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="2649"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="2648"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Own Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="2647"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="2646"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.3"
                 priority="2645"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.4"
                 priority="2644"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.5"
                 priority="2643"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.6"
                 priority="2642"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.7"
                 priority="2641"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.8"
                 priority="2640"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.9"
                 priority="2639"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="2637"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="2636"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="2635"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.10"
                 priority="2633"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70200') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.11"
                 priority="2631"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.12"
                 priority="2630"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.13"
                 priority="2628"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.14"
                 priority="2626"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="2624"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="2623"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="2622"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.15"
                 priority="2620"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.16"
                 priority="2618"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70448') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Context') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="2616"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="2615"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="2614"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="2612"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="2611"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="2610"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.17"
                 priority="2608"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="2606"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="2604"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="2603"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="2601"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="2599"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="2598"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.18"
                 priority="2596"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70444') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Assembly Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.19"
                 priority="2594"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="2592"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="2591"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.20"
                 priority="2589"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="2587"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="2586"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.21"
                 priority="2584"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Professional Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22"
                 priority="2583"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="2581"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="2580"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="2579"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="2577"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="2576"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="2575"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="2573"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="2572"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="2571"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23"
                 priority="2570"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="2568"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="2567"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="2566"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="2564"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="2563"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="2562"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="2560"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="2559"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="2558"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.29"
                 priority="2557"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EIP.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EIP.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): element hl7v2:EIP.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EIP.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EIP.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): element hl7v2:EIP.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('261') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('261') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Item MOET '261' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EIP') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('EIP') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Type MOET 'EIP' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Parent') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Parent') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van LongName MOET 'Parent' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.1"
                 priority="2555"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Assigned Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Placer Assigned Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): de waarde van LongName MOET 'Placer Assigned Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.1/hl7v2:EI.1"
                 priority="2553"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.1/hl7v2:EI.2"
                 priority="2552"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.1/hl7v2:EI.3"
                 priority="2551"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.1/hl7v2:EI.4"
                 priority="2550"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.2"
                 priority="2548"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Assigned Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Filler Assigned Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): de waarde van LongName MOET 'Filler Assigned Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.2/hl7v2:EI.1"
                 priority="2546"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.2/hl7v2:EI.2"
                 priority="2545"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.2/hl7v2:EI.3"
                 priority="2544"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.2/hl7v2:EI.4"
                 priority="2543"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.30"
                 priority="2541"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('262') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('262') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Item MOET '262' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70124') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70124') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70124' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Transportation Mode') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Transportation Mode') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van LongName MOET 'Transportation Mode' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.31"
                 priority="2539"
                 mode="M14">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.413-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.413-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.25.11.413 RIVM ISIS-AR Reden aanvraag (DYNAMISCH)'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('263') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('263') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Item MOET '263' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Reason for Study') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Reason for Study') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van LongName MOET 'Reason for Study' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.31/hl7v2:CE.1"
                 priority="2537"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.31/hl7v2:CE.2"
                 priority="2536"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.31/hl7v2:CE.3"
                 priority="2535"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.31/hl7v2:CE.4"
                 priority="2533"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.31/hl7v2:CE.5"
                 priority="2532"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.31/hl7v2:CE.6"
                 priority="2531"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32"
                 priority="2529"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('264') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('264') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Item MOET '264' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NDL') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NDL') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Type MOET 'NDL' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Principal Result Interpreter') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Principal Result Interpreter') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van LongName MOET 'Principal Result Interpreter' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1"
                 priority="2527"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CNN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CNN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'CNN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.1"
                 priority="2525"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.2"
                 priority="2524"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.3"
                 priority="2523"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.4"
                 priority="2522"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.5"
                 priority="2521"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.6"
                 priority="2520"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.7"
                 priority="2519"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree (e.g., MD') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Degree (e.g., MD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.8"
                 priority="2518"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.9"
                 priority="2517"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority - Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority - Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Assigning Authority - Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.10"
                 priority="2516"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority - Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority - Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Assigning Authority - Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.11"
                 priority="2515"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority - Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority - Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Assigning Authority - Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.2"
                 priority="2513"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Start Date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Start Date/time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Start Date/time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.2/hl7v2:TS.1"
                 priority="2511"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.2/hl7v2:TS.2"
                 priority="2510"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.3"
                 priority="2508"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('End Date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('End Date/time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'End Date/time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.3/hl7v2:TS.1"
                 priority="2506"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.3/hl7v2:TS.2"
                 priority="2505"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.4"
                 priority="2503"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70302') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Table MOET 'HL70302' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Point of Care') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Point of Care' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.5"
                 priority="2502"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70303') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Table MOET 'HL70303' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Room') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Room' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.6"
                 priority="2501"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70304') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Table MOET 'HL70304' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Bed') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Bed' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.7"
                 priority="2500"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Facility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.7/hl7v2:HD.1"
                 priority="2498"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.7/hl7v2:HD.2"
                 priority="2497"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.7/hl7v2:HD.3"
                 priority="2496"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.8"
                 priority="2494"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70306') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Table MOET 'HL70306' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Location Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Location Status' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.9"
                 priority="2493"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70305') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Table MOET 'HL70305' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Patient Location Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Patient Location Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.10"
                 priority="2492"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70307') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Table MOET 'HL70307' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Building') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Building' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.11"
                 priority="2491"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70308') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Table MOET 'HL70308' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Floor') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Floor' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33"
                 priority="2490"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('265') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('265') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Item MOET '265' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NDL') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NDL') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Type MOET 'NDL' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assistant Result Interpreter') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assistant Result Interpreter') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van LongName MOET 'Assistant Result Interpreter' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1"
                 priority="2488"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CNN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CNN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'CNN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.1"
                 priority="2486"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.2"
                 priority="2485"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.3"
                 priority="2484"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.4"
                 priority="2483"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.5"
                 priority="2482"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.6"
                 priority="2481"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.7"
                 priority="2480"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree (e.g., MD') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Degree (e.g., MD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.8"
                 priority="2479"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.9"
                 priority="2478"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority - Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority - Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Assigning Authority - Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.10"
                 priority="2477"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority - Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority - Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Assigning Authority - Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.11"
                 priority="2476"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority - Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority - Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Assigning Authority - Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.2"
                 priority="2474"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Start Date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Start Date/time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Start Date/time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.2/hl7v2:TS.1"
                 priority="2472"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.2/hl7v2:TS.2"
                 priority="2471"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.3"
                 priority="2469"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('End Date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('End Date/time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'End Date/time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.3/hl7v2:TS.1"
                 priority="2467"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.3/hl7v2:TS.2"
                 priority="2466"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.4"
                 priority="2464"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70302') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Table MOET 'HL70302' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Point of Care') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Point of Care' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.5"
                 priority="2463"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70303') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Table MOET 'HL70303' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Room') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Room' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.6"
                 priority="2462"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70304') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Table MOET 'HL70304' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Bed') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Bed' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.7"
                 priority="2461"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Facility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.7/hl7v2:HD.1"
                 priority="2459"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.7/hl7v2:HD.2"
                 priority="2458"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.7/hl7v2:HD.3"
                 priority="2457"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.8"
                 priority="2455"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70306') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Table MOET 'HL70306' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Location Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Location Status' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.9"
                 priority="2454"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70305') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Table MOET 'HL70305' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Patient Location Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Patient Location Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.10"
                 priority="2453"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70307') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Table MOET 'HL70307' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Building') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Building' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.11"
                 priority="2452"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70308') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Table MOET 'HL70308' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Floor') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Floor' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34"
                 priority="2451"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('266') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('266') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Item MOET '266' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NDL') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NDL') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Type MOET 'NDL' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Technician') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Technician') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van LongName MOET 'Technician' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1"
                 priority="2449"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CNN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CNN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'CNN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.1"
                 priority="2447"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.2"
                 priority="2446"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.3"
                 priority="2445"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.4"
                 priority="2444"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.5"
                 priority="2443"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.6"
                 priority="2442"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.7"
                 priority="2441"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree (e.g., MD') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Degree (e.g., MD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.8"
                 priority="2440"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.9"
                 priority="2439"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority - Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority - Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Assigning Authority - Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.10"
                 priority="2438"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority - Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority - Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Assigning Authority - Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.11"
                 priority="2437"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority - Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority - Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Assigning Authority - Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.2"
                 priority="2435"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Start Date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Start Date/time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Start Date/time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.2/hl7v2:TS.1"
                 priority="2433"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.2/hl7v2:TS.2"
                 priority="2432"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.3"
                 priority="2430"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('End Date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('End Date/time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'End Date/time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.3/hl7v2:TS.1"
                 priority="2428"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.3/hl7v2:TS.2"
                 priority="2427"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.4"
                 priority="2425"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70302') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Table MOET 'HL70302' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Point of Care') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Point of Care' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.5"
                 priority="2424"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70303') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Table MOET 'HL70303' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Room') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Room' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.6"
                 priority="2423"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70304') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Table MOET 'HL70304' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Bed') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Bed' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.7"
                 priority="2422"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Facility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.7/hl7v2:HD.1"
                 priority="2420"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.7/hl7v2:HD.2"
                 priority="2419"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.7/hl7v2:HD.3"
                 priority="2418"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.8"
                 priority="2416"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70306') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Table MOET 'HL70306' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Location Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Location Status' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.9"
                 priority="2415"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70305') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Table MOET 'HL70305' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Patient Location Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Patient Location Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.10"
                 priority="2414"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70307') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Table MOET 'HL70307' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Building') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Building' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.11"
                 priority="2413"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70308') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Table MOET 'HL70308' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Floor') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Floor' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35"
                 priority="2412"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('267') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('267') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Item MOET '267' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NDL') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NDL') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Type MOET 'NDL' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Transcriptionist') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Transcriptionist') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van LongName MOET 'Transcriptionist' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1"
                 priority="2410"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CNN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CNN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'CNN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.1"
                 priority="2408"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.2"
                 priority="2407"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.3"
                 priority="2406"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.4"
                 priority="2405"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.5"
                 priority="2404"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.6"
                 priority="2403"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.7"
                 priority="2402"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree (e.g., MD') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Degree (e.g., MD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.8"
                 priority="2401"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.9"
                 priority="2400"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority - Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority - Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Assigning Authority - Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.10"
                 priority="2399"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority - Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority - Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Assigning Authority - Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.11"
                 priority="2398"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority - Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority - Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Assigning Authority - Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.2"
                 priority="2396"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Start Date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Start Date/time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Start Date/time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.2/hl7v2:TS.1"
                 priority="2394"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.2/hl7v2:TS.2"
                 priority="2393"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.3"
                 priority="2391"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('End Date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('End Date/time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'End Date/time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.3/hl7v2:TS.1"
                 priority="2389"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.3/hl7v2:TS.2"
                 priority="2388"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.4"
                 priority="2386"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70302') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Table MOET 'HL70302' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Point of Care') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Point of Care' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.5"
                 priority="2385"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70303') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Table MOET 'HL70303' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Room') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Room' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.6"
                 priority="2384"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70304') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Table MOET 'HL70304' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Bed') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Bed' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.7"
                 priority="2383"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Facility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.7/hl7v2:HD.1"
                 priority="2381"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.7/hl7v2:HD.2"
                 priority="2380"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.7/hl7v2:HD.3"
                 priority="2379"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.8"
                 priority="2377"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70306') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Table MOET 'HL70306' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Location Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Location Status' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.9"
                 priority="2376"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70305') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Table MOET 'HL70305' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Patient Location Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Patient Location Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.10"
                 priority="2375"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70307') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Table MOET 'HL70307' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Building') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Building' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.11"
                 priority="2374"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70308') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Table MOET 'HL70308' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Floor') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Floor' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.36"
                 priority="2373"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('268') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('268') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Item MOET '268' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Scheduled Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Scheduled Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van LongName MOET 'Scheduled Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.36/hl7v2:TS.1"
                 priority="2371"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.36/hl7v2:TS.2"
                 priority="2370"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.37"
                 priority="2368"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1028') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1028') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Item MOET '1028' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Number of Sample Containers *') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Number of Sample Containers *') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van LongName MOET 'Number of Sample Containers *' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.38"
                 priority="2367"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1029') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1029') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Item MOET '1029' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Transport Logistics of Collected Sample') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Transport Logistics of Collected Sample') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van LongName MOET 'Transport Logistics of Collected Sample' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.38/hl7v2:CE.1"
                 priority="2365"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.38/hl7v2:CE.2"
                 priority="2364"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.38/hl7v2:CE.3"
                 priority="2363"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.38/hl7v2:CE.4"
                 priority="2361"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.38/hl7v2:CE.5"
                 priority="2360"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.38/hl7v2:CE.6"
                 priority="2359"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.39"
                 priority="2357"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1030') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1030') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Item MOET '1030' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Collector''s Comment *') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Collector''s Comment *') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van LongName MOET 'Collector''s Comment *' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.39/hl7v2:CE.1"
                 priority="2355"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.39/hl7v2:CE.2"
                 priority="2354"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.39/hl7v2:CE.3"
                 priority="2353"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.39/hl7v2:CE.4"
                 priority="2351"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.39/hl7v2:CE.5"
                 priority="2350"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.39/hl7v2:CE.6"
                 priority="2349"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.40"
                 priority="2347"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1031') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1031') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Item MOET '1031' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Transport Arrangement Responsibility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Transport Arrangement Responsibility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van LongName MOET 'Transport Arrangement Responsibility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.40/hl7v2:CE.1"
                 priority="2345"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.40/hl7v2:CE.2"
                 priority="2344"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.40/hl7v2:CE.3"
                 priority="2343"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.40/hl7v2:CE.4"
                 priority="2341"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.40/hl7v2:CE.5"
                 priority="2340"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.40/hl7v2:CE.6"
                 priority="2339"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.41"
                 priority="2337"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1032') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1032') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Item MOET '1032' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70224') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70224') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70224' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Transport Arranged') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Transport Arranged') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van LongName MOET 'Transport Arranged' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.42"
                 priority="2335"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1033') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1033') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Item MOET '1033' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70225') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70225') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70225' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Escort Required') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Escort Required') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van LongName MOET 'Escort Required' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.43"
                 priority="2333"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1034') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1034') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Item MOET '1034' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Planned Patient Transport Comment') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Planned Patient Transport Comment') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van LongName MOET 'Planned Patient Transport Comment' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.43/hl7v2:CE.1"
                 priority="2331"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.43/hl7v2:CE.2"
                 priority="2330"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.43/hl7v2:CE.3"
                 priority="2329"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.43/hl7v2:CE.4"
                 priority="2327"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.43/hl7v2:CE.5"
                 priority="2326"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.43/hl7v2:CE.6"
                 priority="2325"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.44"
                 priority="2323"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('393') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('393') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Item MOET '393' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70088') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70088') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70088' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Procedure Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Procedure Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van LongName MOET 'Procedure Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.44/hl7v2:CE.1"
                 priority="2321"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.44/hl7v2:CE.2"
                 priority="2320"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.44/hl7v2:CE.3"
                 priority="2319"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.44/hl7v2:CE.4"
                 priority="2317"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.44/hl7v2:CE.5"
                 priority="2316"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.44/hl7v2:CE.6"
                 priority="2315"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.45"
                 priority="2313"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1316') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1316') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Item MOET '1316' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70340') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70340') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70340' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Procedure Code Modifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Procedure Code Modifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van LongName MOET 'Procedure Code Modifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.45/hl7v2:CE.1"
                 priority="2311"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.45/hl7v2:CE.2"
                 priority="2310"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.45/hl7v2:CE.3"
                 priority="2309"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.45/hl7v2:CE.4"
                 priority="2307"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.45/hl7v2:CE.5"
                 priority="2306"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.45/hl7v2:CE.6"
                 priority="2305"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.46"
                 priority="2303"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1474') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1474') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Item MOET '1474' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70411') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70411') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70411' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Supplemental Service Information') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Placer Supplemental Service Information') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van LongName MOET 'Placer Supplemental Service Information' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.46/hl7v2:CE.1"
                 priority="2301"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.46/hl7v2:CE.2"
                 priority="2300"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.46/hl7v2:CE.3"
                 priority="2299"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.46/hl7v2:CE.4"
                 priority="2297"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.46/hl7v2:CE.5"
                 priority="2296"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.46/hl7v2:CE.6"
                 priority="2295"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.47"
                 priority="2293"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1475') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1475') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Item MOET '1475' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70411') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70411') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70411' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Supplemental Service Information') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Filler Supplemental Service Information') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van LongName MOET 'Filler Supplemental Service Information' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.47/hl7v2:CE.1"
                 priority="2291"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.47/hl7v2:CE.2"
                 priority="2290"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.47/hl7v2:CE.3"
                 priority="2289"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.47/hl7v2:CE.4"
                 priority="2287"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.47/hl7v2:CE.5"
                 priority="2286"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.47/hl7v2:CE.6"
                 priority="2285"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.48"
                 priority="2283"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1646') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1646') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Item MOET '1646' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70476') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70476') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70476' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Medically Necessary Duplicate Procedure Reason.') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Medically Necessary Duplicate Procedure Reason.') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van LongName MOET 'Medically Necessary Duplicate Procedure Reason.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.1"
                 priority="2281"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.2"
                 priority="2280"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.3"
                 priority="2279"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.4"
                 priority="2277"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.5"
                 priority="2276"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.6"
                 priority="2275"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.7"
                 priority="2273"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.8"
                 priority="2272"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.9"
                 priority="2271"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.49"
                 priority="2270"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1647') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1647') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Item MOET '1647' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70507') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70507') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70507' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Result Handling') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Result Handling') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2PublicHealth): de waarde van LongName MOET 'Result Handling' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC"
                 priority="2269"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.1) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC.1) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): element hl7v2:ORC.1 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): element hl7v2:ORC.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.2) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC.2) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): element hl7v2:ORC.2 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): element hl7v2:ORC.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.3) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC.3) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): element hl7v2:ORC.3 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): element hl7v2:ORC.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): element hl7v2:ORC.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): element hl7v2:ORC.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): element hl7v2:ORC.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): element hl7v2:ORC.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): element hl7v2:ORC.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.13) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC.13) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): element hl7v2:ORC.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.15) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC.15) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): element hl7v2:ORC.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.16) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC.16) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): element hl7v2:ORC.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.17) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC.17) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): element hl7v2:ORC.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.18) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC.18) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): element hl7v2:ORC.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.20) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC.20) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): element hl7v2:ORC.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.25) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC.25) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): element hl7v2:ORC.25 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.26) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC.26) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): element hl7v2:ORC.26 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.27) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC.27) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): element hl7v2:ORC.27 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.28) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC.28) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): element hl7v2:ORC.28 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.29) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC.29) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): element hl7v2:ORC.29 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.30) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC.30) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): element hl7v2:ORC.30 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.1"
                 priority="2268"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('215') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('215') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van Item MOET '215' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70119') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70119') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van Table MOET 'HL70119' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Order Control') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Order Control') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Order Control' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.2"
                 priority="2266"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('216') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('216') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van Item MOET '216' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Order Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Placer Order Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Placer Order Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.2/hl7v2:EI.1"
                 priority="2264"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.2/hl7v2:EI.2"
                 priority="2263"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.2/hl7v2:EI.3"
                 priority="2262"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.2/hl7v2:EI.4"
                 priority="2261"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.3"
                 priority="2259"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('217') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('217') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van Item MOET '217' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Order Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Filler Order Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Filler Order Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.3/hl7v2:EI.1"
                 priority="2257"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.3/hl7v2:EI.2"
                 priority="2256"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.3/hl7v2:EI.3"
                 priority="2255"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.3/hl7v2:EI.4"
                 priority="2254"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.4"
                 priority="2252"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('218') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('218') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van Item MOET '218' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Group Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Placer Group Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Placer Group Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.4/hl7v2:EI.1"
                 priority="2250"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.4/hl7v2:EI.2"
                 priority="2249"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.4/hl7v2:EI.3"
                 priority="2248"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.4/hl7v2:EI.4"
                 priority="2247"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.5"
                 priority="2245"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('219') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('219') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van Item MOET '219' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70038') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70038') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van Table MOET 'HL70038' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Order Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Order Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Order Status' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.6"
                 priority="2243"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('220') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('220') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van Item MOET '220' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70121') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70121') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van Table MOET 'HL70121' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Response Flag') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Response Flag') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Response Flag' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7"
                 priority="2241"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('221') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('221') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van Item MOET '221' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TQ') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TQ') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van Type MOET 'TQ' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity/Timing') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Quantity/Timing') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Quantity/Timing' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1"
                 priority="2239"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CQ') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van Type MOET 'CQ' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Quantity') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van LongName MOET 'Quantity' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/hl7v2:CQ.1"
                 priority="2237"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Quantity') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van LongName MOET 'Quantity' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/hl7v2:CQ.2"
                 priority="2236"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van LongName MOET 'Units' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="2234"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="2233"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="2232"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="2230"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="2229"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="2228"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.2"
                 priority="2226"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RI.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:RI.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RI_datatype): element hl7v2:RI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RI.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:RI.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RI_datatype): element hl7v2:RI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('RI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('RI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van Type MOET 'RI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Interval') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Interval') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van LongName MOET 'Interval' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.2/hl7v2:RI.1"
                 priority="2224"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70335') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70335') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RI_datatype): de waarde van Table MOET 'HL70335' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Repeat Pattern') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Repeat Pattern') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RI_datatype): de waarde van LongName MOET 'Repeat Pattern' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.2/hl7v2:RI.2"
                 priority="2223"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Explicit Time Interval') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Explicit Time Interval') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RI_datatype): de waarde van LongName MOET 'Explicit Time Interval' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.3"
                 priority="2222"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Duration') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Duration') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van LongName MOET 'Duration' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.4"
                 priority="2221"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van LongName MOET 'Start Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.4/hl7v2:TS.1"
                 priority="2219"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.4/hl7v2:TS.2"
                 priority="2218"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.5"
                 priority="2216"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van LongName MOET 'End Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.5/hl7v2:TS.1"
                 priority="2214"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.5/hl7v2:TS.2"
                 priority="2213"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.6"
                 priority="2211"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Priority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Priority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van LongName MOET 'Priority' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.7"
                 priority="2210"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Condition') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Condition') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van LongName MOET 'Condition' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.8"
                 priority="2209"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TX') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TX') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van Type MOET 'TX' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.8/hl7v2:escape"
                 priority="2208"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TX_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.8/hl7v2:escape/hl7v2:escape"
                 priority="2207"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.8/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="2206"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.9"
                 priority="2205"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70472') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70472') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van Table MOET 'HL70472' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Conjunction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Conjunction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van LongName MOET 'Conjunction' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10"
                 priority="2203"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('OSD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('OSD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van Type MOET 'OSD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Order Sequencing') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Order Sequencing') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van LongName MOET 'Order Sequencing' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.1"
                 priority="2201"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70524') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70524') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Table MOET 'HL70524' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Sequence/Results Flag') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Sequence/Results Flag') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van LongName MOET 'Sequence/Results Flag' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.2"
                 priority="2199"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Order Number: Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Placer Order Number: Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van LongName MOET 'Placer Order Number: Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.3"
                 priority="2198"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Order Number: Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Placer Order Number: Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van LongName MOET 'Placer Order Number: Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.4"
                 priority="2197"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Order Number: Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Filler Order Number: Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van LongName MOET 'Filler Order Number: Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.5"
                 priority="2196"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Order Number: Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Filler Order Number: Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van LongName MOET 'Filler Order Number: Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.6"
                 priority="2195"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Sequence Condition Value') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Sequence Condition Value') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van LongName MOET 'Sequence Condition Value' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.7"
                 priority="2194"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Maximum Number of Repeats') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Maximum Number of Repeats') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van LongName MOET 'Maximum Number of Repeats' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.8"
                 priority="2193"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Order Number: Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Placer Order Number: Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van LongName MOET 'Placer Order Number: Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.9"
                 priority="2192"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Order Number: Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Placer Order Number: Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van LongName MOET 'Placer Order Number: Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.10"
                 priority="2190"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Order Number: Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Filler Order Number: Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van LongName MOET 'Filler Order Number: Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.11"
                 priority="2189"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Order Number: Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Filler Order Number: Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van LongName MOET 'Filler Order Number: Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.11"
                 priority="2187"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Occurrence Duration') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Occurrence Duration') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van LongName MOET 'Occurrence Duration' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.11/hl7v2:CE.1"
                 priority="2185"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.11/hl7v2:CE.2"
                 priority="2184"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.11/hl7v2:CE.3"
                 priority="2183"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.11/hl7v2:CE.4"
                 priority="2181"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.11/hl7v2:CE.5"
                 priority="2180"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.11/hl7v2:CE.6"
                 priority="2179"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.12"
                 priority="2177"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Total Occurrences') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Total Occurrences') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van LongName MOET 'Total Occurrences' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.8"
                 priority="2176"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EIP.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EIP.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): element hl7v2:EIP.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EIP.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EIP.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): element hl7v2:EIP.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('222') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('222') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van Item MOET '222' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EIP') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('EIP') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van Type MOET 'EIP' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Parent') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Parent') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Parent' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.1"
                 priority="2174"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Assigned Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Placer Assigned Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): de waarde van LongName MOET 'Placer Assigned Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.1/hl7v2:EI.1"
                 priority="2172"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.1/hl7v2:EI.2"
                 priority="2171"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.1/hl7v2:EI.3"
                 priority="2170"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.1/hl7v2:EI.4"
                 priority="2169"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.2"
                 priority="2167"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Assigned Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Filler Assigned Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): de waarde van LongName MOET 'Filler Assigned Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.2/hl7v2:EI.1"
                 priority="2165"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.2/hl7v2:EI.2"
                 priority="2164"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.2/hl7v2:EI.3"
                 priority="2163"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.2/hl7v2:EI.4"
                 priority="2162"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.9"
                 priority="2160"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('223') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('223') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van Item MOET '223' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Date/Time of Transaction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Date/Time of Transaction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Date/Time of Transaction' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.9/hl7v2:TS.1"
                 priority="2158"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.9/hl7v2:TS.2"
                 priority="2157"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10"
                 priority="2155"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.13) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.14) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.15) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.16) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.17) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.18) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.19) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.20) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.21) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.22) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.23) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('224') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('224') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van Item MOET '224' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('XCN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entered By') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Entered By') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Entered By' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.1"
                 priority="2153"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.2"
                 priority="2152"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('FN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="2150"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="2149"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="2148"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Own Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="2147"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="2146"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.3"
                 priority="2145"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.4"
                 priority="2144"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.5"
                 priority="2143"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.6"
                 priority="2142"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.7"
                 priority="2141"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.8"
                 priority="2140"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.9"
                 priority="2139"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="2137"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="2136"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="2135"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.10"
                 priority="2133"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70200') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.11"
                 priority="2131"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.12"
                 priority="2130"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.13"
                 priority="2128"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.14"
                 priority="2126"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="2124"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="2123"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="2122"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.15"
                 priority="2120"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.16"
                 priority="2118"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70448') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Context') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="2116"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="2115"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="2114"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="2112"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="2111"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="2110"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.17"
                 priority="2108"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="2106"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="2104"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="2103"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="2101"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="2099"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="2098"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.18"
                 priority="2096"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70444') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Assembly Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.19"
                 priority="2094"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="2092"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="2091"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.20"
                 priority="2089"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="2087"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="2086"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.21"
                 priority="2084"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Professional Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22"
                 priority="2083"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="2081"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="2080"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="2079"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="2077"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="2076"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="2075"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="2073"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="2072"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="2071"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23"
                 priority="2070"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="2068"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="2067"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="2066"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="2064"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="2063"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="2062"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="2060"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="2059"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="2058"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11"
                 priority="2057"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.13) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.14) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.15) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.16) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.17) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.18) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.19) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.20) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.21) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.22) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.23) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('225') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('225') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van Item MOET '225' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('XCN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Verified By') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Verified By') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Verified By' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.1"
                 priority="2055"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.2"
                 priority="2054"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('FN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="2052"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="2051"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="2050"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Own Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="2049"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="2048"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.3"
                 priority="2047"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.4"
                 priority="2046"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.5"
                 priority="2045"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.6"
                 priority="2044"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.7"
                 priority="2043"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.8"
                 priority="2042"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.9"
                 priority="2041"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="2039"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="2038"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="2037"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.10"
                 priority="2035"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70200') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.11"
                 priority="2033"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.12"
                 priority="2032"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.13"
                 priority="2030"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.14"
                 priority="2028"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="2026"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="2025"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="2024"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.15"
                 priority="2022"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.16"
                 priority="2020"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70448') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Context') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="2018"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="2017"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="2016"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="2014"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="2013"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="2012"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.17"
                 priority="2010"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="2008"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="2006"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="2005"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="2003"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="2001"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="2000"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.18"
                 priority="1998"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70444') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Assembly Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.19"
                 priority="1996"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="1994"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="1993"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.20"
                 priority="1991"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="1989"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="1988"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.21"
                 priority="1986"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Professional Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22"
                 priority="1985"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="1983"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="1982"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="1981"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="1979"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="1978"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="1977"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="1975"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="1974"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="1973"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23"
                 priority="1972"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="1970"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="1969"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="1968"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="1966"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="1965"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="1964"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="1962"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="1961"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="1960"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12"
                 priority="1959"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.13) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.14) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.15) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.16) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.17) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.18) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.19) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.20) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.21) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.22) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.23) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('226') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('226') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van Item MOET '226' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('XCN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Ordering Provider') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Ordering Provider') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Ordering Provider' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.1"
                 priority="1957"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.2"
                 priority="1956"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('FN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="1954"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="1953"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="1952"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Own Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="1951"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="1950"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.3"
                 priority="1949"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.4"
                 priority="1948"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.5"
                 priority="1947"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.6"
                 priority="1946"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.7"
                 priority="1945"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.8"
                 priority="1944"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.9"
                 priority="1943"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="1941"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="1940"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="1939"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.10"
                 priority="1937"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70200') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.11"
                 priority="1935"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.12"
                 priority="1934"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.13"
                 priority="1932"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.14"
                 priority="1930"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="1928"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="1927"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="1926"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.15"
                 priority="1924"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.16"
                 priority="1922"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70448') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Context') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="1920"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="1919"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="1918"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="1916"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="1915"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="1914"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.17"
                 priority="1912"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="1910"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="1908"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="1907"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="1905"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="1903"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="1902"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.18"
                 priority="1900"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70444') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Assembly Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.19"
                 priority="1898"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="1896"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="1895"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.20"
                 priority="1893"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="1891"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="1890"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.21"
                 priority="1888"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Professional Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22"
                 priority="1887"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="1885"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="1884"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="1883"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="1881"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="1880"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="1879"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="1877"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="1876"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="1875"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23"
                 priority="1874"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="1872"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="1871"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="1870"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="1868"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="1867"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="1866"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="1864"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="1863"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="1862"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13"
                 priority="1861"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('227') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('227') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van Item MOET '227' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('PL') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('PL') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van Type MOET 'PL' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Enterer''s Location') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Enterer''s Location') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Enterer''s Location' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.1"
                 priority="1859"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70302') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Table MOET 'HL70302' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Point of Care') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Point of Care' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.2"
                 priority="1858"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70303') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Table MOET 'HL70303' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Room') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Room' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.3"
                 priority="1857"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70304') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Table MOET 'HL70304' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Bed') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Bed' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.4"
                 priority="1856"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Facility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.4/hl7v2:HD.1"
                 priority="1854"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.4/hl7v2:HD.2"
                 priority="1853"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.4/hl7v2:HD.3"
                 priority="1852"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.5"
                 priority="1850"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70306') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Table MOET 'HL70306' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Location Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Location Status' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.6"
                 priority="1849"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70305') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Table MOET 'HL70305' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Person Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Person Location Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Person Location Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.7"
                 priority="1848"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70307') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Table MOET 'HL70307' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Building') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Building' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.8"
                 priority="1847"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70308') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Table MOET 'HL70308' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Floor') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Floor' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.9"
                 priority="1846"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Location Description') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Location Description') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Location Description' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.10"
                 priority="1845"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Comprehensive Location Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Comprehensive Location Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Comprehensive Location Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.10/hl7v2:EI.1"
                 priority="1843"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.10/hl7v2:EI.2"
                 priority="1842"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.10/hl7v2:EI.3"
                 priority="1841"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.10/hl7v2:EI.4"
                 priority="1840"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.11"
                 priority="1838"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority for Location') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority for Location') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Assigning Authority for Location' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.11/hl7v2:HD.1"
                 priority="1836"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.11/hl7v2:HD.2"
                 priority="1835"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.11/hl7v2:HD.3"
                 priority="1834"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.14"
                 priority="1832"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('228') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('228') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van Item MOET '228' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('XTN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van Type MOET 'XTN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Call Back Phone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Call Back Phone Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Call Back Phone Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.1"
                 priority="1830"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Telephone Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Telephone Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.2"
                 priority="1829"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70201') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Table MOET 'HL70201' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Telecommunication Use Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Use Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.3"
                 priority="1827"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70202') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Table MOET 'HL70202' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Equipment Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.4"
                 priority="1825"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Email Address') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Email Address' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.5"
                 priority="1824"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Country Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Country Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.6"
                 priority="1823"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Area/City Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Area/City Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.7"
                 priority="1822"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Local Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Local Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.8"
                 priority="1821"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Extension') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Extension' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.9"
                 priority="1820"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Any Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Any Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.10"
                 priority="1819"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Extension Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Extension Prefix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.11"
                 priority="1818"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Speed Dial Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Speed Dial Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.12"
                 priority="1817"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Unformatted Telephone number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Unformatted Telephone number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.15"
                 priority="1816"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('229') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('229') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van Item MOET '229' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Order Effective Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Order Effective Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Order Effective Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.15/hl7v2:TS.1"
                 priority="1814"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.15/hl7v2:TS.2"
                 priority="1813"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.16"
                 priority="1811"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('230') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('230') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van Item MOET '230' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Order Control Code Reason') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Order Control Code Reason') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Order Control Code Reason' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.16/hl7v2:CE.1"
                 priority="1809"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.16/hl7v2:CE.2"
                 priority="1808"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.16/hl7v2:CE.3"
                 priority="1807"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.16/hl7v2:CE.4"
                 priority="1805"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.16/hl7v2:CE.5"
                 priority="1804"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.16/hl7v2:CE.6"
                 priority="1803"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.17"
                 priority="1801"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('231') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('231') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van Item MOET '231' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entering Organization') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Entering Organization') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Entering Organization' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.17/hl7v2:CE.1"
                 priority="1799"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.17/hl7v2:CE.2"
                 priority="1798"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.17/hl7v2:CE.3"
                 priority="1797"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.17/hl7v2:CE.4"
                 priority="1795"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.17/hl7v2:CE.5"
                 priority="1794"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.17/hl7v2:CE.6"
                 priority="1793"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.18"
                 priority="1791"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('232') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('232') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van Item MOET '232' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entering Device') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Entering Device') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Entering Device' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.18/hl7v2:CE.1"
                 priority="1789"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.18/hl7v2:CE.2"
                 priority="1788"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.18/hl7v2:CE.3"
                 priority="1787"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.18/hl7v2:CE.4"
                 priority="1785"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.18/hl7v2:CE.5"
                 priority="1784"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.18/hl7v2:CE.6"
                 priority="1783"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19"
                 priority="1781"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.13) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.14) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.15) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.16) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.17) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.18) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.19) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.20) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.21) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.22) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.23) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('233') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('233') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van Item MOET '233' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('XCN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Action By') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Action By') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Action By' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.1"
                 priority="1779"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.2"
                 priority="1778"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('FN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="1776"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="1775"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="1774"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Own Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="1773"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="1772"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.3"
                 priority="1771"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.4"
                 priority="1770"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.5"
                 priority="1769"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.6"
                 priority="1768"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.7"
                 priority="1767"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.8"
                 priority="1766"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.9"
                 priority="1765"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="1763"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="1762"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="1761"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.10"
                 priority="1759"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70200') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.11"
                 priority="1757"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.12"
                 priority="1756"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.13"
                 priority="1754"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.14"
                 priority="1752"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="1750"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="1749"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="1748"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.15"
                 priority="1746"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.16"
                 priority="1744"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70448') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Context') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="1742"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="1741"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="1740"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="1738"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="1737"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="1736"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.17"
                 priority="1734"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="1732"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="1730"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="1729"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="1727"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="1725"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="1724"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.18"
                 priority="1722"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70444') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Assembly Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.19"
                 priority="1720"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="1718"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="1717"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.20"
                 priority="1715"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="1713"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="1712"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.21"
                 priority="1710"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Professional Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22"
                 priority="1709"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="1707"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="1706"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="1705"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="1703"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="1702"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="1701"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="1699"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="1698"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="1697"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23"
                 priority="1696"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="1694"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="1693"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="1692"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="1690"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="1689"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="1688"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="1686"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="1685"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="1684"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.20"
                 priority="1683"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1310') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1310') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van Item MOET '1310' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70339') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70339') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van Table MOET 'HL70339' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Advanced Beneficiary Notice Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Advanced Beneficiary Notice Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Advanced Beneficiary Notice Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.20/hl7v2:CE.1"
                 priority="1681"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.20/hl7v2:CE.2"
                 priority="1680"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.20/hl7v2:CE.3"
                 priority="1679"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.20/hl7v2:CE.4"
                 priority="1677"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.20/hl7v2:CE.5"
                 priority="1676"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.20/hl7v2:CE.6"
                 priority="1675"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.21"
                 priority="1673"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1311') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1311') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van Item MOET '1311' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XON') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('XON') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van Type MOET 'XON' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Ordering Facility Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Ordering Facility Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Ordering Facility Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.1"
                 priority="1671"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Organization Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van LongName MOET 'Organization Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.2"
                 priority="1670"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70204') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70204') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Table MOET 'HL70204' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Organization Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van LongName MOET 'Organization Name Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.3"
                 priority="1669"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.4"
                 priority="1668"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.5"
                 priority="1667"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.6"
                 priority="1665"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.6/hl7v2:HD.1"
                 priority="1663"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.6/hl7v2:HD.2"
                 priority="1662"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.6/hl7v2:HD.3"
                 priority="1661"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.7"
                 priority="1659"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.8"
                 priority="1657"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.8/hl7v2:HD.1"
                 priority="1655"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.8/hl7v2:HD.2"
                 priority="1654"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.8/hl7v2:HD.3"
                 priority="1653"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.9"
                 priority="1651"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.10"
                 priority="1649"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Organization Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van LongName MOET 'Organization Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22"
                 priority="1648"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.13) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.13) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.14) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.14) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1312') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1312') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van Item MOET '1312' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XAD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('XAD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van Type MOET 'XAD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Ordering Facility Address') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Ordering Facility Address') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Ordering Facility Address' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.1"
                 priority="1646"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): element hl7v2:SAD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): element hl7v2:SAD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): element hl7v2:SAD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SAD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('SAD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'SAD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Street Address') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Street Address') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'Street Address' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.1/hl7v2:SAD.1"
                 priority="1644"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Street or Mailing Address') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Street or Mailing Address') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): de waarde van LongName MOET 'Street or Mailing Address' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.1/hl7v2:SAD.2"
                 priority="1643"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Street Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Street Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): de waarde van LongName MOET 'Street Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.1/hl7v2:SAD.3"
                 priority="1642"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Dwelling Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Dwelling Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): de waarde van LongName MOET 'Dwelling Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.2"
                 priority="1641"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Other Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Other Designation') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'Other Designation' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.3"
                 priority="1640"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('City') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('City') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'City' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.4"
                 priority="1639"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('State or Province') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('State or Province') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'State or Province' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.5"
                 priority="1638"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Zip or Postal Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Zip or Postal Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'Zip or Postal Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.6"
                 priority="1637"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70399') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70399') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Table MOET 'HL70399' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Country') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Country') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'Country' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.7"
                 priority="1635"
                 mode="M14">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.25.11.409 Adrestype HL7v2 NL (DYNAMISCH)'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70190') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70190') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Table MOET 'HL70190' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Address Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Address Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'Address Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.8"
                 priority="1633"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Other Geographic Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Other Geographic Designation') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'Other Geographic Designation' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.9"
                 priority="1632"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70289') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70289') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Table MOET 'HL70289' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('County/Parish Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('County/Parish Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'County/Parish Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.10"
                 priority="1631"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70288') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70288') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Table MOET 'HL70288' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Census Tract') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Census Tract') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'Census Tract' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.11"
                 priority="1630"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Address Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Address Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'Address Representation Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.12"
                 priority="1628"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Address Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Address Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'Address Validity Range' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.12/hl7v2:DR.1"
                 priority="1626"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.1"
                 priority="1624"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.2"
                 priority="1623"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.12/hl7v2:DR.2"
                 priority="1621"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.1"
                 priority="1619"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.2"
                 priority="1618"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.13"
                 priority="1616"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.13/hl7v2:TS.1"
                 priority="1614"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.13/hl7v2:TS.2"
                 priority="1613"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.14"
                 priority="1611"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.14/hl7v2:TS.1"
                 priority="1609"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.14/hl7v2:TS.2"
                 priority="1608"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.23"
                 priority="1606"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1313') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1313') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van Item MOET '1313' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('XTN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van Type MOET 'XTN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Ordering Facility Phone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Ordering Facility Phone Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Ordering Facility Phone Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.1"
                 priority="1604"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Telephone Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Telephone Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.2"
                 priority="1603"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70201') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Table MOET 'HL70201' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Telecommunication Use Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Use Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.3"
                 priority="1601"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70202') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Table MOET 'HL70202' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Equipment Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.4"
                 priority="1599"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Email Address') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Email Address' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.5"
                 priority="1598"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Country Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Country Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.6"
                 priority="1597"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Area/City Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Area/City Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.7"
                 priority="1596"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Local Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Local Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.8"
                 priority="1595"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Extension') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Extension' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.9"
                 priority="1594"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Any Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Any Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.10"
                 priority="1593"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Extension Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Extension Prefix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.11"
                 priority="1592"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Speed Dial Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Speed Dial Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.12"
                 priority="1591"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Unformatted Telephone number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Unformatted Telephone number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24"
                 priority="1590"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.13) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.13) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.14) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.14) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1314') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1314') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van Item MOET '1314' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XAD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('XAD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van Type MOET 'XAD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Ordering Provider Address') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Ordering Provider Address') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Ordering Provider Address' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.1"
                 priority="1588"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): element hl7v2:SAD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): element hl7v2:SAD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): element hl7v2:SAD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SAD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('SAD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'SAD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Street Address') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Street Address') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'Street Address' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.1/hl7v2:SAD.1"
                 priority="1586"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Street or Mailing Address') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Street or Mailing Address') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): de waarde van LongName MOET 'Street or Mailing Address' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.1/hl7v2:SAD.2"
                 priority="1585"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Street Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Street Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): de waarde van LongName MOET 'Street Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.1/hl7v2:SAD.3"
                 priority="1584"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Dwelling Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Dwelling Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): de waarde van LongName MOET 'Dwelling Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.2"
                 priority="1583"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Other Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Other Designation') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'Other Designation' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.3"
                 priority="1582"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('City') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('City') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'City' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.4"
                 priority="1581"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('State or Province') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('State or Province') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'State or Province' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.5"
                 priority="1580"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Zip or Postal Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Zip or Postal Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'Zip or Postal Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.6"
                 priority="1579"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70399') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70399') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Table MOET 'HL70399' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Country') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Country') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'Country' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.7"
                 priority="1577"
                 mode="M14">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.25.11.409 Adrestype HL7v2 NL (DYNAMISCH)'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70190') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70190') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Table MOET 'HL70190' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Address Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Address Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'Address Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.8"
                 priority="1575"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Other Geographic Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Other Geographic Designation') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'Other Geographic Designation' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.9"
                 priority="1574"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70289') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70289') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Table MOET 'HL70289' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('County/Parish Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('County/Parish Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'County/Parish Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.10"
                 priority="1573"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70288') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70288') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Table MOET 'HL70288' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Census Tract') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Census Tract') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'Census Tract' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.11"
                 priority="1572"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Address Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Address Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'Address Representation Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.12"
                 priority="1570"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Address Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Address Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'Address Validity Range' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.12/hl7v2:DR.1"
                 priority="1568"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.1"
                 priority="1566"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.2"
                 priority="1565"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.12/hl7v2:DR.2"
                 priority="1563"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.1"
                 priority="1561"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.2"
                 priority="1560"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.13"
                 priority="1558"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.13/hl7v2:TS.1"
                 priority="1556"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.13/hl7v2:TS.2"
                 priority="1555"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.14"
                 priority="1553"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.14/hl7v2:TS.1"
                 priority="1551"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.14/hl7v2:TS.2"
                 priority="1550"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.25"
                 priority="1548"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1473') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1473') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van Item MOET '1473' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Order Status Modifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Order Status Modifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Order Status Modifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.1"
                 priority="1546"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.2"
                 priority="1545"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.3"
                 priority="1544"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.4"
                 priority="1542"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.5"
                 priority="1541"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.6"
                 priority="1540"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.7"
                 priority="1538"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.8"
                 priority="1537"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.9"
                 priority="1536"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.26"
                 priority="1535"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1641') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1641') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van Item MOET '1641' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70552') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70552') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van Table MOET 'HL70552' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Advanced Beneficiary Notice Override Reason') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Advanced Beneficiary Notice Override Reason') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Advanced Beneficiary Notice Override Reason' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.1"
                 priority="1533"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.2"
                 priority="1532"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.3"
                 priority="1531"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.4"
                 priority="1529"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.5"
                 priority="1528"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.6"
                 priority="1527"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.7"
                 priority="1525"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.8"
                 priority="1524"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.9"
                 priority="1523"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.27"
                 priority="1522"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1642') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1642') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van Item MOET '1642' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler''s Expected Availability Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Filler''s Expected Availability Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Filler''s Expected Availability Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.27/hl7v2:TS.1"
                 priority="1520"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.27/hl7v2:TS.2"
                 priority="1519"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.28"
                 priority="1517"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('615') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('615') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van Item MOET '615' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70177') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70177') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van Table MOET 'HL70177' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Confidentiality Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Confidentiality Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Confidentiality Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.1"
                 priority="1515"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.2"
                 priority="1514"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.3"
                 priority="1513"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.4"
                 priority="1511"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.5"
                 priority="1510"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.6"
                 priority="1509"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.7"
                 priority="1507"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.8"
                 priority="1506"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.9"
                 priority="1505"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.29"
                 priority="1504"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1643') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1643') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van Item MOET '1643' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70482') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70482') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van Table MOET 'HL70482' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Order Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Order Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Order Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.1"
                 priority="1502"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.2"
                 priority="1501"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.3"
                 priority="1500"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.4"
                 priority="1498"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.5"
                 priority="1497"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.6"
                 priority="1496"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.7"
                 priority="1494"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.8"
                 priority="1493"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.9"
                 priority="1492"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.30"
                 priority="1491"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): element hl7v2:CNE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): element hl7v2:CNE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): element hl7v2:CNE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): element hl7v2:CNE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): element hl7v2:CNE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): element hl7v2:CNE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): element hl7v2:CNE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): element hl7v2:CNE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): element hl7v2:CNE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1644') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1644') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van Item MOET '1644' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CNE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CNE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van Type MOET 'CNE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70483') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70483') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van Table MOET 'HL70483' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Enterer Authorization Mode') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Enterer Authorization Mode') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Enterer Authorization Mode' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.1"
                 priority="1489"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.2"
                 priority="1488"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.3"
                 priority="1487"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.4"
                 priority="1485"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.5"
                 priority="1484"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.6"
                 priority="1483"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.7"
                 priority="1481"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.8"
                 priority="1480"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.9"
                 priority="1479"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:NTE"
                 priority="1478"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NTE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): element hl7v2:NTE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NTE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): element hl7v2:NTE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.3) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NTE.3) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): element hl7v2:NTE.3 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NTE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): element hl7v2:NTE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:NTE/hl7v2:NTE.1"
                 priority="1477"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('96') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('96') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van Item MOET '96' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('SI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van Type MOET 'SI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Set ID - NTE') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Set ID - NTE') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van LongName MOET 'Set ID - NTE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:NTE/hl7v2:NTE.2"
                 priority="1476"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('97') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('97') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van Item MOET '97' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70105') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70105') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van Table MOET 'HL70105' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source of Comment') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Source of Comment') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van LongName MOET 'Source of Comment' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:NTE/hl7v2:NTE.3"
                 priority="1474"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('98') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('98') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van Item MOET '98' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('FT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van Type MOET 'FT' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Comment') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Comment') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van LongName MOET 'Comment' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape"
                 priority="1473"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.27-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FT_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/hl7v2:escape"
                 priority="1472"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="1471"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:NTE/hl7v2:NTE.4"
                 priority="1470"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1318') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1318') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van Item MOET '1318' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70364') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70364') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van Table MOET 'HL70364' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Comment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Comment Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van LongName MOET 'Comment Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.1"
                 priority="1468"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.2"
                 priority="1467"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.3"
                 priority="1466"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.4"
                 priority="1464"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.5"
                 priority="1463"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.6"
                 priority="1462"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE d20e13539-false-d856723e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY"
                 priority="1460"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ1) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth): element hl7v2:TQ1 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth): element hl7v2:TQ1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1"
                 priority="1459"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ1.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ1.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ1.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ1.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ1.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ1.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ1.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ1.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.13) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ1.13) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.14) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ1.14) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.1"
                 priority="1458"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1627') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1627') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1627' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('SI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'SI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Set ID - TQ1') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Set ID - TQ1') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Set ID - TQ1' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.2"
                 priority="1457"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1628') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1628') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1628' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CQ') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'CQ' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Quantity') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Quantity' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.2/hl7v2:CQ.1"
                 priority="1455"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Quantity') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van LongName MOET 'Quantity' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.2/hl7v2:CQ.2"
                 priority="1454"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van LongName MOET 'Units' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.2/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="1452"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.2/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="1451"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.2/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="1450"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.2/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="1448"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.2/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="1447"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.2/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="1446"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.3"
                 priority="1444"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:RPT.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): element hl7v2:RPT.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:RPT.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): element hl7v2:RPT.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:RPT.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): element hl7v2:RPT.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:RPT.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): element hl7v2:RPT.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:RPT.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): element hl7v2:RPT.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:RPT.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): element hl7v2:RPT.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:RPT.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): element hl7v2:RPT.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:RPT.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): element hl7v2:RPT.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:RPT.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): element hl7v2:RPT.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:RPT.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): element hl7v2:RPT.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:RPT.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): element hl7v2:RPT.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1629') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1629') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1629' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('RPT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('RPT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'RPT' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70335') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70335') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Table MOET 'HL70335' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Repeat Pattern') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Repeat Pattern') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Repeat Pattern' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1"
                 priority="1442"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70335') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70335') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van Table MOET 'HL70335' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Repeat Pattern Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Repeat Pattern Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van LongName MOET 'Repeat Pattern Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.1"
                 priority="1440"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.2"
                 priority="1439"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.3"
                 priority="1438"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.4"
                 priority="1436"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.5"
                 priority="1435"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.6"
                 priority="1434"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.7"
                 priority="1432"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.8"
                 priority="1431"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.9"
                 priority="1430"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.2"
                 priority="1429"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70527') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70527') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van Table MOET 'HL70527' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Calendar Alignment') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Calendar Alignment') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van LongName MOET 'Calendar Alignment' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.3"
                 priority="1427"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Phase Range Begin Value') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Phase Range Begin Value') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van LongName MOET 'Phase Range Begin Value' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.4"
                 priority="1426"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Phase Range End Value') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Phase Range End Value') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van LongName MOET 'Phase Range End Value' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.5"
                 priority="1425"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Period Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Period Quantity') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van LongName MOET 'Period Quantity' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.6"
                 priority="1424"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Period Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Period Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van LongName MOET 'Period Units' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.7"
                 priority="1423"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70136') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Institution Specified Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Institution Specified Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van LongName MOET 'Institution Specified Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.8"
                 priority="1421"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70528') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70528') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van Table MOET 'HL70528' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Event') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Event') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van LongName MOET 'Event' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.9"
                 priority="1419"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Event Offset Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Event Offset Quantity') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van LongName MOET 'Event Offset Quantity' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.10"
                 priority="1418"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Event Offset Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Event Offset Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van LongName MOET 'Event Offset Units' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.11"
                 priority="1417"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('GTS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('GTS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van Type MOET 'GTS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('General Timing Specification') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('General Timing Specification') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van LongName MOET 'General Timing Specification' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.4"
                 priority="1416"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1630') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1630') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1630' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'TM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Explicit Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Explicit Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Explicit Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.5"
                 priority="1415"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1631') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1631') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1631' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CQ') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'CQ' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Relative Time and Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Relative Time and Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Relative Time and Units' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.5/hl7v2:CQ.1"
                 priority="1413"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Quantity') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van LongName MOET 'Quantity' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.5/hl7v2:CQ.2"
                 priority="1412"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van LongName MOET 'Units' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.5/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="1410"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.5/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="1409"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.5/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="1408"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.5/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="1406"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.5/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="1405"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.5/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="1404"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.6"
                 priority="1402"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1632') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1632') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1632' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CQ') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'CQ' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Service Duration') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Service Duration') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Service Duration' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.6/hl7v2:CQ.1"
                 priority="1400"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Quantity') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van LongName MOET 'Quantity' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.6/hl7v2:CQ.2"
                 priority="1399"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van LongName MOET 'Units' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.6/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="1397"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.6/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="1396"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.6/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="1395"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.6/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="1393"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.6/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="1392"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.6/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="1391"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.7"
                 priority="1389"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1633') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1633') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1633' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Start date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Start date/time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Start date/time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.7/hl7v2:TS.1"
                 priority="1387"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.7/hl7v2:TS.2"
                 priority="1386"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.8"
                 priority="1384"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1634') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1634') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1634' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('End date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('End date/time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'End date/time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.8/hl7v2:TS.1"
                 priority="1382"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.8/hl7v2:TS.2"
                 priority="1381"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.9"
                 priority="1379"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1635') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1635') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1635' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70485') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70485') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Table MOET 'HL70485' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Priority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Priority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Priority' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.1"
                 priority="1377"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.2"
                 priority="1376"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.3"
                 priority="1375"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.4"
                 priority="1373"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.5"
                 priority="1372"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.6"
                 priority="1371"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.7"
                 priority="1369"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.8"
                 priority="1368"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.9"
                 priority="1367"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.10"
                 priority="1366"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1636') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1636') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1636' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TX') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TX') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'TX' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Condition text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Condition text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Condition text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.10/hl7v2:escape"
                 priority="1365"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TX_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.10/hl7v2:escape/hl7v2:escape"
                 priority="1364"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.10/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="1363"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.11"
                 priority="1362"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1637') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1637') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1637' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TX') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TX') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'TX' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text instruction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text instruction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Text instruction' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.11/hl7v2:escape"
                 priority="1361"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TX_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.11/hl7v2:escape/hl7v2:escape"
                 priority="1360"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.11/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="1359"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.12"
                 priority="1358"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1638') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1638') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1638' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70427') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70427') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Table MOET 'HL70427' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Conjunction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Conjunction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Conjunction' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.13"
                 priority="1356"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1639') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1639') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1639' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CQ') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'CQ' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Occurrence duration') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Occurrence duration') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Occurrence duration' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.13/hl7v2:CQ.1"
                 priority="1354"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Quantity') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van LongName MOET 'Quantity' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.13/hl7v2:CQ.2"
                 priority="1353"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van LongName MOET 'Units' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.13/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="1351"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.13/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="1350"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.13/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="1349"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.13/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="1347"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.13/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="1346"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.13/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="1345"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.14"
                 priority="1343"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1640') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1640') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1640' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Total occurrence''s') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Total occurrence''s') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Total occurrence''s' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2"
                 priority="1342"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ2.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ2.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): element hl7v2:TQ2.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ2.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ2.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): element hl7v2:TQ2.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ2.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ2.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): element hl7v2:TQ2.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ2.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ2.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): element hl7v2:TQ2.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ2.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ2.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): element hl7v2:TQ2.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ2.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ2.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): element hl7v2:TQ2.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ2.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ2.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): element hl7v2:TQ2.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.1"
                 priority="1341"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1648') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1648') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van Item MOET '1648' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('SI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van Type MOET 'SI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Set ID - TQ2') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Set ID - TQ2') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van LongName MOET 'Set ID - TQ2' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.2"
                 priority="1340"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1649') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1649') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van Item MOET '1649' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70503') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70503') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van Table MOET 'HL70503' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Sequence/Results Flag') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Sequence/Results Flag') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van LongName MOET 'Sequence/Results Flag' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.3"
                 priority="1338"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1650') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1650') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van Item MOET '1650' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Related Placer Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Related Placer Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van LongName MOET 'Related Placer Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.3/hl7v2:EI.1"
                 priority="1336"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.3/hl7v2:EI.2"
                 priority="1335"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.3/hl7v2:EI.3"
                 priority="1334"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.3/hl7v2:EI.4"
                 priority="1333"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.4"
                 priority="1331"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1651') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1651') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van Item MOET '1651' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Related Filler Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Related Filler Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van LongName MOET 'Related Filler Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.4/hl7v2:EI.1"
                 priority="1329"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.4/hl7v2:EI.2"
                 priority="1328"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.4/hl7v2:EI.3"
                 priority="1327"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.4/hl7v2:EI.4"
                 priority="1326"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.5"
                 priority="1324"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1652') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1652') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van Item MOET '1652' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Related Placer Group Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Related Placer Group Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van LongName MOET 'Related Placer Group Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.5/hl7v2:EI.1"
                 priority="1322"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.5/hl7v2:EI.2"
                 priority="1321"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.5/hl7v2:EI.3"
                 priority="1320"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.5/hl7v2:EI.4"
                 priority="1319"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.6"
                 priority="1317"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1653') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1653') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van Item MOET '1653' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70504') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70504') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van Table MOET 'HL70504' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Sequence Condition Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Sequence Condition Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van LongName MOET 'Sequence Condition Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.7"
                 priority="1315"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1654') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1654') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van Item MOET '1654' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70505') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70505') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van Table MOET 'HL70505' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Cyclic Entry/Exit Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Cyclic Entry/Exit Indicator') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van LongName MOET 'Cyclic Entry/Exit Indicator' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.8"
                 priority="1313"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1655') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1655') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van Item MOET '1655' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CQ') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van Type MOET 'CQ' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Sequence Condition Time Interval') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Sequence Condition Time Interval') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van LongName MOET 'Sequence Condition Time Interval' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.8/hl7v2:CQ.1"
                 priority="1311"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Quantity') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van LongName MOET 'Quantity' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.8/hl7v2:CQ.2"
                 priority="1310"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van LongName MOET 'Units' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.8/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="1308"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.8/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="1307"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.8/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="1306"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.8/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="1304"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.8/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="1303"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.8/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="1302"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.9"
                 priority="1300"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1656') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1656') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van Item MOET '1656' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Cyclic Group Maximum Number of Repeats') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Cyclic Group Maximum Number of Repeats') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van LongName MOET 'Cyclic Group Maximum Number of Repeats' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.10"
                 priority="1299"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1657') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1657') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van Item MOET '1657' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70506') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70506') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van Table MOET 'HL70506' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Special Service Request Relationship') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Special Service Request Relationship') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van LongName MOET 'Special Service Request Relationship' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE d20e13549-false-d860319e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT"
                 priority="1297"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth): element hl7v2:OBX is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth): element hl7v2:OBX komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TCD) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth): element hl7v2:TCD komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX"
                 priority="1296"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): element hl7v2:OBX.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): element hl7v2:OBX.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.3) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): element hl7v2:OBX.3 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): element hl7v2:OBX.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): element hl7v2:OBX.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): element hl7v2:OBX.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): element hl7v2:OBX.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): element hl7v2:OBX.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): element hl7v2:OBX.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.11) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): element hl7v2:OBX.11 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): element hl7v2:OBX.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): element hl7v2:OBX.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.13) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): element hl7v2:OBX.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.14) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): element hl7v2:OBX.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.15) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): element hl7v2:OBX.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.19) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): element hl7v2:OBX.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.1"
                 priority="1295"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('569') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('569') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): de waarde van Item MOET '569' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('SI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): de waarde van Type MOET 'SI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Set ID - OBX') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): de waarde van LongName MOET 'Set ID - OBX' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.2"
                 priority="1294"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='CNE' or text()='NM' or text()='SN' or text()='TM'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="text()='CNE' or text()='NM' or text()='SN' or text()='TM'">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de elementinhoud van hl7v2:OBX.2 MOET ''CNE' of 'NM' of 'SN' of 'TM'' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('570') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('570') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): de waarde van Item MOET '570' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70125') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70125' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Value Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): de waarde van LongName MOET 'Value Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3"
                 priority="1292"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('571') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('571') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): de waarde van Item MOET '571' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Observation Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): de waarde van LongName MOET 'Observation Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="1290"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="1289"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="1288"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="1286"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="1285"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="1284"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.4"
                 priority="1282"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('572') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('572') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): de waarde van Item MOET '572' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Observation Sub-ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): de waarde van LongName MOET 'Observation Sub-ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.5"
                 priority="1281"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('573') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('573') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): de waarde van Item MOET '573' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('varies') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('varies') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): de waarde van Type MOET 'varies' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Observation Value') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): de waarde van LongName MOET 'Observation Value' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6"
                 priority="1280"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('574') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('574') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): de waarde van Item MOET '574' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): de waarde van LongName MOET 'Units' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="1278"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="1277"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="1276"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="1274"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="1273"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="1272"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.7"
                 priority="1270"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('575') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('575') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): de waarde van Item MOET '575' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('References Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): de waarde van LongName MOET 'References Range' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.8"
                 priority="1269"
                 mode="M14">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.3.1937.777.10.11.78-2015-09-04T000000.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.3.1937.777.10.11.78-2015-09-04T000000.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.84-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(IS_datatype): de elementwaarde MOET een zijn van '2.16.840.1.113883.3.1937.777.10.11.78 Abnormal flags (2015-09-04T00:00:00)'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('576') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('576') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): de waarde van Item MOET '576' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70078') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70078' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Abnormal Flags') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): de waarde van LongName MOET 'Abnormal Flags' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.9"
                 priority="1267"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('577') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('577') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): de waarde van Item MOET '577' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Probability') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): de waarde van LongName MOET 'Probability' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.10"
                 priority="1266"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('578') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('578') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): de waarde van Item MOET '578' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70080') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70080' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Nature of Abnormal Test') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): de waarde van LongName MOET 'Nature of Abnormal Test' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.11"
                 priority="1264"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='F'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="text()='F'">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de elementinhoud van hl7v2:OBX.11 MOET ''F'' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('579') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('579') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): de waarde van Item MOET '579' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70085') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): de waarde van Table MOET 'HL70085' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Observation Result Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): de waarde van LongName MOET 'Observation Result Status' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.12"
                 priority="1262"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('580') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('580') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): de waarde van Item MOET '580' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Effective Date of Reference Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): de waarde van LongName MOET 'Effective Date of Reference Range' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="1260"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="1259"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.13"
                 priority="1257"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('581') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('581') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): de waarde van Item MOET '581' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('User Defined Access Checks') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): de waarde van LongName MOET 'User Defined Access Checks' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.14"
                 priority="1256"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('582') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('582') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): de waarde van Item MOET '582' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Date/Time of the Observation') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): de waarde van LongName MOET 'Date/Time of the Observation' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="1254"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="1253"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15"
                 priority="1251"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('583') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('583') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): de waarde van Item MOET '583' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Producer''s ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): de waarde van LongName MOET 'Producer''s ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="1249"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="1248"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="1247"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="1245"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="1244"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="1243"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16"
                 priority="1241"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.13) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.14) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.15) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.16) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.17) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.18) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.19) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.20) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.21) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.22) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.23) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('584') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('584') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): de waarde van Item MOET '584' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('XCN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Responsible Observer') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): de waarde van LongName MOET 'Responsible Observer' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="1239"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="1238"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('FN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="1236"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="1235"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="1234"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Own Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="1233"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="1232"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="1231"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="1230"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="1229"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="1228"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="1227"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="1226"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="1225"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="1223"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="1222"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="1221"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="1219"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70200') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="1217"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="1216"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="1214"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="1212"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="1210"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="1209"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="1208"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="1206"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="1204"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70448') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Context') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="1202"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="1201"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="1200"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="1198"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="1197"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="1196"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="1194"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="1192"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="1190"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="1189"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="1187"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="1185"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="1184"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="1182"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70444') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Assembly Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="1180"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="1178"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="1177"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="1175"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="1173"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="1172"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="1170"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Professional Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="1169"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="1167"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="1166"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="1165"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="1163"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="1162"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="1161"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="1159"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="1158"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="1157"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="1156"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="1154"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="1153"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="1152"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="1150"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="1149"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="1148"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="1146"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="1145"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="1144"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17"
                 priority="1143"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('936') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('936') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): de waarde van Item MOET '936' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Observation Method') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): de waarde van LongName MOET 'Observation Method' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="1141"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="1140"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="1139"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="1137"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="1136"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="1135"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18"
                 priority="1133"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1479') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1479') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): de waarde van Item MOET '1479' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Equipment Instance Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): de waarde van LongName MOET 'Equipment Instance Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="1131"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="1130"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="1129"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="1128"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.19"
                 priority="1126"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1480') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1480') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): de waarde van Item MOET '1480' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Date/Time of the Analysis') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2PublicHealth): de waarde van LongName MOET 'Date/Time of the Analysis' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="1124"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="1123"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD"
                 priority="1121"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD.1) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TCD.1) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): element hl7v2:TCD.1 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TCD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): element hl7v2:TCD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TCD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): element hl7v2:TCD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TCD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): element hl7v2:TCD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TCD.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): element hl7v2:TCD.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TCD.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): element hl7v2:TCD.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TCD.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): element hl7v2:TCD.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TCD.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): element hl7v2:TCD.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TCD.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): element hl7v2:TCD.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.1"
                 priority="1120"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('238') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('238') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): de waarde van Item MOET '238' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal Service Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal Service Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): de waarde van LongName MOET 'Universal Service Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.1/hl7v2:CE.1"
                 priority="1118"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.1/hl7v2:CE.2"
                 priority="1117"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.1/hl7v2:CE.3"
                 priority="1116"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.1/hl7v2:CE.4"
                 priority="1114"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.1/hl7v2:CE.5"
                 priority="1113"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.1/hl7v2:CE.6"
                 priority="1112"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.2"
                 priority="1110"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): element hl7v2:SN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): element hl7v2:SN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): element hl7v2:SN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): element hl7v2:SN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1420') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1420') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): de waarde van Item MOET '1420' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('SN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): de waarde van Type MOET 'SN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Auto-Dilution Factor') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Auto-Dilution Factor') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): de waarde van LongName MOET 'Auto-Dilution Factor' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.2/hl7v2:SN.1"
                 priority="1108"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Comparator') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Comparator') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van LongName MOET 'Comparator' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.2/hl7v2:SN.2"
                 priority="1107"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Num1') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Num1') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van LongName MOET 'Num1' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.2/hl7v2:SN.3"
                 priority="1106"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Separator/Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Separator/Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van LongName MOET 'Separator/Suffix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.2/hl7v2:SN.4"
                 priority="1105"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Num2') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Num2') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van LongName MOET 'Num2' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.3"
                 priority="1104"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): element hl7v2:SN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): element hl7v2:SN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): element hl7v2:SN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): element hl7v2:SN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1421') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1421') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): de waarde van Item MOET '1421' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('SN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): de waarde van Type MOET 'SN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Rerun Dilution Factor') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Rerun Dilution Factor') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): de waarde van LongName MOET 'Rerun Dilution Factor' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.3/hl7v2:SN.1"
                 priority="1102"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Comparator') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Comparator') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van LongName MOET 'Comparator' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.3/hl7v2:SN.2"
                 priority="1101"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Num1') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Num1') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van LongName MOET 'Num1' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.3/hl7v2:SN.3"
                 priority="1100"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Separator/Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Separator/Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van LongName MOET 'Separator/Suffix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.3/hl7v2:SN.4"
                 priority="1099"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Num2') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Num2') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van LongName MOET 'Num2' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.4"
                 priority="1098"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): element hl7v2:SN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): element hl7v2:SN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): element hl7v2:SN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): element hl7v2:SN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1422') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1422') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): de waarde van Item MOET '1422' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('SN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): de waarde van Type MOET 'SN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Pre-Dilution Factor') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Pre-Dilution Factor') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): de waarde van LongName MOET 'Pre-Dilution Factor' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.4/hl7v2:SN.1"
                 priority="1096"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Comparator') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Comparator') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van LongName MOET 'Comparator' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.4/hl7v2:SN.2"
                 priority="1095"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Num1') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Num1') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van LongName MOET 'Num1' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.4/hl7v2:SN.3"
                 priority="1094"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Separator/Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Separator/Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van LongName MOET 'Separator/Suffix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.4/hl7v2:SN.4"
                 priority="1093"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Num2') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Num2') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van LongName MOET 'Num2' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.5"
                 priority="1092"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): element hl7v2:SN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): element hl7v2:SN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): element hl7v2:SN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): element hl7v2:SN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1413') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1413') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): de waarde van Item MOET '1413' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('SN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): de waarde van Type MOET 'SN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Endogenous Content of Pre-Dilution Diluent') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Endogenous Content of Pre-Dilution Diluent') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): de waarde van LongName MOET 'Endogenous Content of Pre-Dilution Diluent' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.5/hl7v2:SN.1"
                 priority="1090"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Comparator') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Comparator') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van LongName MOET 'Comparator' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.5/hl7v2:SN.2"
                 priority="1089"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Num1') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Num1') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van LongName MOET 'Num1' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.5/hl7v2:SN.3"
                 priority="1088"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Separator/Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Separator/Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van LongName MOET 'Separator/Suffix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.5/hl7v2:SN.4"
                 priority="1087"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Num2') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Num2') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van LongName MOET 'Num2' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.6"
                 priority="1086"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1416') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1416') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): de waarde van Item MOET '1416' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70136') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Automatic Repeat Allowed') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Automatic Repeat Allowed') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): de waarde van LongName MOET 'Automatic Repeat Allowed' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.7"
                 priority="1084"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1424') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1424') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): de waarde van Item MOET '1424' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70136') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Reflex Allowed') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Reflex Allowed') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): de waarde van LongName MOET 'Reflex Allowed' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.8"
                 priority="1082"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1425') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1425') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): de waarde van Item MOET '1425' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70389') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70389') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): de waarde van Table MOET 'HL70389' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Analyte Repeat Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Analyte Repeat Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): de waarde van LongName MOET 'Analyte Repeat Status' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.8/hl7v2:CE.1"
                 priority="1080"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.8/hl7v2:CE.2"
                 priority="1079"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.8/hl7v2:CE.3"
                 priority="1078"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.8/hl7v2:CE.4"
                 priority="1076"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.8/hl7v2:CE.5"
                 priority="1075"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.8/hl7v2:CE.6"
                 priority="1074"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:SID"
                 priority="1072"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SID.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SID.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.136-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SID_segment): element hl7v2:SID.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SID.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SID.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.136-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SID_segment): element hl7v2:SID.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SID.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SID.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.136-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SID_segment): element hl7v2:SID.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SID.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SID.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.136-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SID_segment): element hl7v2:SID.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:SID/hl7v2:SID.1"
                 priority="1071"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1426') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1426') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.136-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SID_segment): de waarde van Item MOET '1426' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.136-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SID_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Application / Method Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Application / Method Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.136-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SID_segment): de waarde van LongName MOET 'Application / Method Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:SID/hl7v2:SID.1/hl7v2:CE.1"
                 priority="1069"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:SID/hl7v2:SID.1/hl7v2:CE.2"
                 priority="1068"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:SID/hl7v2:SID.1/hl7v2:CE.3"
                 priority="1067"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:SID/hl7v2:SID.1/hl7v2:CE.4"
                 priority="1065"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:SID/hl7v2:SID.1/hl7v2:CE.5"
                 priority="1064"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:SID/hl7v2:SID.1/hl7v2:CE.6"
                 priority="1063"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:SID/hl7v2:SID.2"
                 priority="1061"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1129') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1129') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.136-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SID_segment): de waarde van Item MOET '1129' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.136-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SID_segment): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Substance Lot Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Substance Lot Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.136-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SID_segment): de waarde van LongName MOET 'Substance Lot Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:SID/hl7v2:SID.3"
                 priority="1060"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1428') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1428') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.136-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SID_segment): de waarde van Item MOET '1428' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.136-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SID_segment): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Substance Container Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Substance Container Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.136-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SID_segment): de waarde van LongName MOET 'Substance Container Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:SID/hl7v2:SID.4"
                 priority="1059"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1429') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1429') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.136-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SID_segment): de waarde van Item MOET '1429' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.136-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SID_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70385') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70385') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.136-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SID_segment): de waarde van Table MOET 'HL70385' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Substance Manufacturer Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Substance Manufacturer Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.136-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SID_segment): de waarde van LongName MOET 'Substance Manufacturer Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:SID/hl7v2:SID.4/hl7v2:CE.1"
                 priority="1057"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:SID/hl7v2:SID.4/hl7v2:CE.2"
                 priority="1056"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:SID/hl7v2:SID.4/hl7v2:CE.3"
                 priority="1055"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:SID/hl7v2:SID.4/hl7v2:CE.4"
                 priority="1053"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:SID/hl7v2:SID.4/hl7v2:CE.5"
                 priority="1052"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:SID/hl7v2:SID.4/hl7v2:CE.6"
                 priority="1051"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:NTE"
                 priority="1049"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NTE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): element hl7v2:NTE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NTE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): element hl7v2:NTE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.3) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NTE.3) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): element hl7v2:NTE.3 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NTE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): element hl7v2:NTE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:NTE/hl7v2:NTE.1"
                 priority="1048"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('96') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('96') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van Item MOET '96' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('SI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van Type MOET 'SI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Set ID - NTE') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Set ID - NTE') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van LongName MOET 'Set ID - NTE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:NTE/hl7v2:NTE.2"
                 priority="1047"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('97') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('97') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van Item MOET '97' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70105') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70105') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van Table MOET 'HL70105' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source of Comment') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Source of Comment') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van LongName MOET 'Source of Comment' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:NTE/hl7v2:NTE.3"
                 priority="1045"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('98') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('98') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van Item MOET '98' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('FT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van Type MOET 'FT' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Comment') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Comment') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van LongName MOET 'Comment' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape"
                 priority="1044"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.27-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FT_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/hl7v2:escape"
                 priority="1043"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="1042"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:NTE/hl7v2:NTE.4"
                 priority="1041"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1318') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1318') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van Item MOET '1318' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70364') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70364') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van Table MOET 'HL70364' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Comment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Comment Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van LongName MOET 'Comment Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.1"
                 priority="1039"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.2"
                 priority="1038"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.3"
                 priority="1037"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.4"
                 priority="1035"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.5"
                 priority="1034"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.6"
                 priority="1033"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:CTI"
                 priority="1031"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CTI.1) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CTI.1) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.31-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CTI_segment): element hl7v2:CTI.1 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CTI.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CTI.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.31-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CTI_segment): element hl7v2:CTI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CTI.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CTI.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.31-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CTI_segment): element hl7v2:CTI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CTI.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CTI.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.31-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CTI_segment): element hl7v2:CTI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:CTI/hl7v2:CTI.1"
                 priority="1030"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1011') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1011') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.31-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CTI_segment): de waarde van Item MOET '1011' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.31-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CTI_segment): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Sponsor Study ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Sponsor Study ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.31-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CTI_segment): de waarde van LongName MOET 'Sponsor Study ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:CTI/hl7v2:CTI.1/hl7v2:EI.1"
                 priority="1028"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:CTI/hl7v2:CTI.1/hl7v2:EI.2"
                 priority="1027"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:CTI/hl7v2:CTI.1/hl7v2:EI.3"
                 priority="1026"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:CTI/hl7v2:CTI.1/hl7v2:EI.4"
                 priority="1025"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:CTI/hl7v2:CTI.2"
                 priority="1023"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1022') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1022') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.31-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CTI_segment): de waarde van Item MOET '1022' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.31-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CTI_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Study Phase Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Study Phase Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.31-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CTI_segment): de waarde van LongName MOET 'Study Phase Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:CTI/hl7v2:CTI.2/hl7v2:CE.1"
                 priority="1021"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:CTI/hl7v2:CTI.2/hl7v2:CE.2"
                 priority="1020"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:CTI/hl7v2:CTI.2/hl7v2:CE.3"
                 priority="1019"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:CTI/hl7v2:CTI.2/hl7v2:CE.4"
                 priority="1017"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:CTI/hl7v2:CTI.2/hl7v2:CE.5"
                 priority="1016"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:CTI/hl7v2:CTI.2/hl7v2:CE.6"
                 priority="1015"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:CTI/hl7v2:CTI.3"
                 priority="1013"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1055') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1055') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.31-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CTI_segment): de waarde van Item MOET '1055' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.31-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CTI_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Study Scheduled Time Point') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Study Scheduled Time Point') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.31-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CTI_segment): de waarde van LongName MOET 'Study Scheduled Time Point' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:CTI/hl7v2:CTI.3/hl7v2:CE.1"
                 priority="1011"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:CTI/hl7v2:CTI.3/hl7v2:CE.2"
                 priority="1010"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:CTI/hl7v2:CTI.3/hl7v2:CE.3"
                 priority="1009"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:CTI/hl7v2:CTI.3/hl7v2:CE.4"
                 priority="1007"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:CTI/hl7v2:CTI.3/hl7v2:CE.5"
                 priority="1006"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:CTI/hl7v2:CTI.3/hl7v2:CE.6"
                 priority="1005"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:DSC" priority="1003" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DSC.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DSC.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.35-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DSC_segment): element hl7v2:DSC.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DSC.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DSC.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.35-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DSC_segment): element hl7v2:DSC.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:DSC/hl7v2:DSC.1"
                 priority="1002"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('14') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('14') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.35-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DSC_segment): de waarde van Item MOET '14' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.35-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DSC_segment): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Continuation Pointer') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Continuation Pointer') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.35-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DSC_segment): de waarde van LongName MOET 'Continuation Pointer' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:DSC/hl7v2:DSC.2"
                 priority="1001"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1354') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1354') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.35-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DSC_segment): de waarde van Item MOET '1354' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.35-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DSC_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70398') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70398') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.35-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DSC_segment): de waarde van Table MOET 'HL70398' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Continuation Style') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Continuation Style') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.35-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DSC_segment): de waarde van LongName MOET 'Continuation Style' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M14"/>
   <xsl:template match="@*|node()" priority="-2" mode="M14">
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000-closedLab2PublicHealth Resultaatbericht (OUL^R22)-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">Lab2PublicHealth Resultaatbericht (OUL^R22)</svrl:text>

	  <!--RULE d20e13342-true-d866981e0-->
   <xsl:template match="/hl7v2:OUL_R22/*[not(self::hl7v2:MSH | self::hl7v2:NTE | self::hl7v2:OUL_R22.PATIENT | self::hl7v2:OUL_R22.VISIT | self::hl7v2:OUL_R22.SPECIMEN | self::hl7v2:DSC)]"
                 priority="1680"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d20e13342-true-d866981e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:MSH | hl7v2:NTE | hl7v2:OUL_R22.PATIENT | hl7v2:OUL_R22.VISIT | hl7v2:OUL_R22.SPECIMEN | hl7v2:DSC (rule-reference: d20e13342-true-d866981e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e13488-true-d867011e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/*[not(self::hl7v2:MSH.1 | self::hl7v2:MSH.2 | self::hl7v2:MSH.3 | self::hl7v2:MSH.4 | self::hl7v2:MSH.5 | self::hl7v2:MSH.6 | self::hl7v2:MSH.7 | self::hl7v2:MSH.8 | self::hl7v2:MSH.9 | self::hl7v2:MSH.10 | self::hl7v2:MSH.11 | self::hl7v2:MSH.12 | self::hl7v2:MSH.13 | self::hl7v2:MSH.14 | self::hl7v2:MSH.15 | self::hl7v2:MSH.16 | self::hl7v2:MSH.17 | self::hl7v2:MSH.18 | self::hl7v2:MSH.19 | self::hl7v2:MSH.20 | self::hl7v2:MSH.21)]"
                 priority="1679"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d20e13488-true-d867011e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:MSH.1 | hl7v2:MSH.2 | hl7v2:MSH.3 | hl7v2:MSH.4 | hl7v2:MSH.5 | hl7v2:MSH.6 | hl7v2:MSH.7 | hl7v2:MSH.8 | hl7v2:MSH.9 | hl7v2:MSH.10 | hl7v2:MSH.11 | hl7v2:MSH.12 | hl7v2:MSH.13 | hl7v2:MSH.14 | hl7v2:MSH.15 | hl7v2:MSH.16 | hl7v2:MSH.17 | hl7v2:MSH.18 | hl7v2:MSH.19 | hl7v2:MSH.20 | hl7v2:MSH.21 (rule-reference: d20e13488-true-d867011e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d866986e35-true-d867035e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.3/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1678"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d866986e35-true-d867035e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d866986e35-true-d867035e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d866986e64-true-d867065e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.4/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1677"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d866986e64-true-d867065e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d866986e64-true-d867065e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d866986e99-true-d867095e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.5/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1676"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d866986e99-true-d867095e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d866986e99-true-d867095e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d866986e128-true-d867125e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.6/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1675"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d866986e128-true-d867125e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d866986e128-true-d867125e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d866986e163-true-d867154e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.7/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1674"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d866986e163-true-d867154e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d866986e163-true-d867154e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d866986e209-true-d867184e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.9/*[not(self::hl7v2:MSG.1 | self::hl7v2:MSG.2 | self::hl7v2:MSG.3)]"
                 priority="1673"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d866986e209-true-d867184e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:MSG.1 | hl7v2:MSG.2 | hl7v2:MSG.3 (rule-reference: d866986e209-true-d867184e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d866986e256-true-d867219e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.11/*[not(self::hl7v2:PT.1 | self::hl7v2:PT.2)]"
                 priority="1672"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d866986e256-true-d867219e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:PT.1 | hl7v2:PT.2 (rule-reference: d866986e256-true-d867219e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d866986e283-true-d867243e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.12/*[not(self::hl7v2:VID.1 | self::hl7v2:VID.2 | self::hl7v2:VID.3)]"
                 priority="1671"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d866986e283-true-d867243e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:VID.1 | hl7v2:VID.2 | hl7v2:VID.3 (rule-reference: d866986e283-true-d867243e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d867235e36-true-d867264e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.2/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1670"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d867235e36-true-d867264e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d867235e36-true-d867264e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d867235e55-true-d867315e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.3/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1669"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d867235e55-true-d867315e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d867235e55-true-d867315e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d866986e464-true-d867402e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.19/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1668"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d866986e464-true-d867402e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d866986e464-true-d867402e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d866986e499-true-d867457e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.21/*[not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1667"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d866986e499-true-d867457e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d866986e499-true-d867457e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e13490-true-d867494e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:NTE/*[not(self::hl7v2:NTE.1 | self::hl7v2:NTE.2 | self::hl7v2:NTE.3 | self::hl7v2:NTE.4)]"
                 priority="1666"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d20e13490-true-d867494e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:NTE.1 | hl7v2:NTE.2 | hl7v2:NTE.3 | hl7v2:NTE.4 (rule-reference: d20e13490-true-d867494e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d867486e110-true-d867516e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:NTE/hl7v2:NTE.3/*[not(self::hl7v2:escape)]"
                 priority="1665"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d867486e110-true-d867516e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d867486e110-true-d867516e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d867510e36-true-d867526e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/*[not(self::hl7v2:escape)]"
                 priority="1664"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d867510e36-true-d867526e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d867510e36-true-d867526e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d867520e5-true-d867536e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/hl7v2:escape/*[not(self::hl7v2:escape)]"
                 priority="1663"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d867520e5-true-d867536e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d867520e5-true-d867536e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d867486e142-true-d867555e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:NTE/hl7v2:NTE.4/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1662"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d867486e142-true-d867555e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d867486e142-true-d867555e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e13492-true-d867600e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/*[not(self::hl7v2:PID | self::hl7v2:PD1 | self::hl7v2:NTE)]"
                 priority="1661"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d20e13492-true-d867600e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:PID | hl7v2:PD1 | hl7v2:NTE (rule-reference: d20e13492-true-d867600e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e13494-true-d867648e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/*[not(self::hl7v2:PID.1 | self::hl7v2:PID.2 | self::hl7v2:PID.3 | self::hl7v2:PID.4 | self::hl7v2:PID.5 | self::hl7v2:PID.6 | self::hl7v2:PID.7 | self::hl7v2:PID.8 | self::hl7v2:PID.9 | self::hl7v2:PID.10 | self::hl7v2:PID.11 | self::hl7v2:PID.12 | self::hl7v2:PID.13 | self::hl7v2:PID.14 | self::hl7v2:PID.15 | self::hl7v2:PID.16 | self::hl7v2:PID.17 | self::hl7v2:PID.18 | self::hl7v2:PID.19 | self::hl7v2:PID.20 | self::hl7v2:PID.21 | self::hl7v2:PID.22 | self::hl7v2:PID.23 | self::hl7v2:PID.24 | self::hl7v2:PID.25 | self::hl7v2:PID.26 | self::hl7v2:PID.27 | self::hl7v2:PID.28 | self::hl7v2:PID.29 | self::hl7v2:PID.30 | self::hl7v2:PID.31 | self::hl7v2:PID.32 | self::hl7v2:PID.33 | self::hl7v2:PID.34 | self::hl7v2:PID.35 | self::hl7v2:PID.36 | self::hl7v2:PID.37 | self::hl7v2:PID.38 | self::hl7v2:PID.39)]"
                 priority="1660"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d20e13494-true-d867648e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:PID.1 | hl7v2:PID.2 | hl7v2:PID.3 | hl7v2:PID.4 | hl7v2:PID.5 | hl7v2:PID.6 | hl7v2:PID.7 | hl7v2:PID.8 | hl7v2:PID.9 | hl7v2:PID.10 | hl7v2:PID.11 | hl7v2:PID.12 | hl7v2:PID.13 | hl7v2:PID.14 | hl7v2:PID.15 | hl7v2:PID.16 | hl7v2:PID.17 | hl7v2:PID.18 | hl7v2:PID.19 | hl7v2:PID.20 | hl7v2:PID.21 | hl7v2:PID.22 | hl7v2:PID.23 | hl7v2:PID.24 | hl7v2:PID.25 | hl7v2:PID.26 | hl7v2:PID.27 | hl7v2:PID.28 | hl7v2:PID.29 | hl7v2:PID.30 | hl7v2:PID.31 | hl7v2:PID.32 | hl7v2:PID.33 | hl7v2:PID.34 | hl7v2:PID.35 | hl7v2:PID.36 | hl7v2:PID.37 | hl7v2:PID.38 | hl7v2:PID.39 (rule-reference: d20e13494-true-d867648e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d867605e15-true-d867673e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/*[not(self::hl7v2:CX.1 | self::hl7v2:CX.2 | self::hl7v2:CX.3 | self::hl7v2:CX.4 | self::hl7v2:CX.5 | self::hl7v2:CX.6 | self::hl7v2:CX.7 | self::hl7v2:CX.8 | self::hl7v2:CX.9 | self::hl7v2:CX.10)]"
                 priority="1659"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d867605e15-true-d867673e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CX.1 | hl7v2:CX.2 | hl7v2:CX.3 | hl7v2:CX.4 | hl7v2:CX.5 | hl7v2:CX.6 | hl7v2:CX.7 | hl7v2:CX.8 | hl7v2:CX.9 | hl7v2:CX.10 (rule-reference: d867605e15-true-d867673e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d867658e221-true-d867703e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.4/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1658"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d867658e221-true-d867703e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d867658e221-true-d867703e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d867658e263-true-d867739e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.6/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1657"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d867658e263-true-d867739e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d867658e263-true-d867739e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d867658e305-true-d867787e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1656"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d867658e305-true-d867787e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d867658e305-true-d867787e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d867658e334-true-d867859e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1655"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d867658e334-true-d867859e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d867658e334-true-d867859e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d867605e26-true-d867932e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/*[not(self::hl7v2:CX.1 | self::hl7v2:CX.2 | self::hl7v2:CX.3 | self::hl7v2:CX.4 | self::hl7v2:CX.5 | self::hl7v2:CX.6 | self::hl7v2:CX.7 | self::hl7v2:CX.8 | self::hl7v2:CX.9 | self::hl7v2:CX.10)]"
                 priority="1654"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d867605e26-true-d867932e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CX.1 | hl7v2:CX.2 | hl7v2:CX.3 | hl7v2:CX.4 | hl7v2:CX.5 | hl7v2:CX.6 | hl7v2:CX.7 | hl7v2:CX.8 | hl7v2:CX.9 | hl7v2:CX.10 (rule-reference: d867605e26-true-d867932e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d867917e245-true-d867962e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.4/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1653"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d867917e245-true-d867962e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d867917e245-true-d867962e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d867917e287-true-d867998e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.6/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1652"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d867917e287-true-d867998e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d867917e287-true-d867998e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d867917e329-true-d868046e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1651"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d867917e329-true-d868046e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d867917e329-true-d868046e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d867917e358-true-d868118e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1650"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d867917e358-true-d868118e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d867917e358-true-d868118e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d867605e61-true-d868191e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/*[not(self::hl7v2:CX.1 | self::hl7v2:CX.2 | self::hl7v2:CX.3 | self::hl7v2:CX.4 | self::hl7v2:CX.5 | self::hl7v2:CX.6 | self::hl7v2:CX.7 | self::hl7v2:CX.8 | self::hl7v2:CX.9 | self::hl7v2:CX.10)]"
                 priority="1649"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d867605e61-true-d868191e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CX.1 | hl7v2:CX.2 | hl7v2:CX.3 | hl7v2:CX.4 | hl7v2:CX.5 | hl7v2:CX.6 | hl7v2:CX.7 | hl7v2:CX.8 | hl7v2:CX.9 | hl7v2:CX.10 (rule-reference: d867605e61-true-d868191e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d868176e221-true-d868221e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.4/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1648"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d868176e221-true-d868221e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d868176e221-true-d868221e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d868176e263-true-d868257e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.6/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1647"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d868176e263-true-d868257e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d868176e263-true-d868257e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d868176e305-true-d868305e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1646"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d868176e305-true-d868305e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d868176e305-true-d868305e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d868176e334-true-d868377e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1645"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d868176e334-true-d868377e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d868176e334-true-d868377e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d867605e72-true-d868454e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/*[not(self::hl7v2:XPN.1 | self::hl7v2:XPN.2 | self::hl7v2:XPN.3 | self::hl7v2:XPN.4 | self::hl7v2:XPN.5 | self::hl7v2:XPN.6 | self::hl7v2:XPN.7 | self::hl7v2:XPN.8 | self::hl7v2:XPN.9 | self::hl7v2:XPN.10 | self::hl7v2:XPN.11 | self::hl7v2:XPN.12 | self::hl7v2:XPN.13 | self::hl7v2:XPN.14)]"
                 priority="1644"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d867605e72-true-d868454e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XPN.1 | hl7v2:XPN.2 | hl7v2:XPN.3 | hl7v2:XPN.4 | hl7v2:XPN.5 | hl7v2:XPN.6 | hl7v2:XPN.7 | hl7v2:XPN.8 | hl7v2:XPN.9 | hl7v2:XPN.10 | hl7v2:XPN.11 | hl7v2:XPN.12 | hl7v2:XPN.13 | hl7v2:XPN.14 (rule-reference: d867605e72-true-d868454e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d868435e23-true-d868468e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.1/*[not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="1643"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d868435e23-true-d868468e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d868435e23-true-d868468e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d868435e151-true-d868555e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.9/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1642"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d868435e151-true-d868555e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d868435e151-true-d868555e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d868435e164-true-d868602e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.10/*[not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1641"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d868435e164-true-d868602e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d868435e164-true-d868602e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d868595e17-true-d868613e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.10/hl7v2:DR.1/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1640"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d868595e17-true-d868613e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d868595e17-true-d868613e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d868595e28-true-d868636e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.10/hl7v2:DR.2/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1639"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d868595e28-true-d868636e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d868595e28-true-d868636e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d868435e194-true-d868665e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.12/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1638"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d868435e194-true-d868665e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d868435e194-true-d868665e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d868435e205-true-d868688e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.13/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1637"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d868435e205-true-d868688e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d868435e205-true-d868688e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d867605e92-true-d868729e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/*[not(self::hl7v2:XPN.1 | self::hl7v2:XPN.2 | self::hl7v2:XPN.3 | self::hl7v2:XPN.4 | self::hl7v2:XPN.5 | self::hl7v2:XPN.6 | self::hl7v2:XPN.7 | self::hl7v2:XPN.8 | self::hl7v2:XPN.9 | self::hl7v2:XPN.10 | self::hl7v2:XPN.11 | self::hl7v2:XPN.12 | self::hl7v2:XPN.13 | self::hl7v2:XPN.14)]"
                 priority="1636"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d867605e92-true-d868729e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XPN.1 | hl7v2:XPN.2 | hl7v2:XPN.3 | hl7v2:XPN.4 | hl7v2:XPN.5 | hl7v2:XPN.6 | hl7v2:XPN.7 | hl7v2:XPN.8 | hl7v2:XPN.9 | hl7v2:XPN.10 | hl7v2:XPN.11 | hl7v2:XPN.12 | hl7v2:XPN.13 | hl7v2:XPN.14 (rule-reference: d867605e92-true-d868729e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d868710e15-true-d868743e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.1/*[not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="1635"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d868710e15-true-d868743e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d868710e15-true-d868743e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d868710e142-true-d868830e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.9/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1634"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d868710e142-true-d868830e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d868710e142-true-d868830e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d868710e155-true-d868877e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.10/*[not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1633"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d868710e155-true-d868877e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d868710e155-true-d868877e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d868870e17-true-d868888e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.10/hl7v2:DR.1/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1632"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d868870e17-true-d868888e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d868870e17-true-d868888e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d868870e28-true-d868911e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.10/hl7v2:DR.2/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1631"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d868870e28-true-d868911e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d868870e28-true-d868911e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d868710e186-true-d868940e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.12/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1630"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d868710e186-true-d868940e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d868710e186-true-d868940e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d868710e197-true-d868963e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.13/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1629"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d868710e197-true-d868963e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d868710e197-true-d868963e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d867605e103-true-d868992e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.7/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1628"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d867605e103-true-d868992e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d867605e103-true-d868992e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d867605e145-true-d869033e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/*[not(self::hl7v2:XPN.1 | self::hl7v2:XPN.2 | self::hl7v2:XPN.3 | self::hl7v2:XPN.4 | self::hl7v2:XPN.5 | self::hl7v2:XPN.6 | self::hl7v2:XPN.7 | self::hl7v2:XPN.8 | self::hl7v2:XPN.9 | self::hl7v2:XPN.10 | self::hl7v2:XPN.11 | self::hl7v2:XPN.12 | self::hl7v2:XPN.13 | self::hl7v2:XPN.14)]"
                 priority="1627"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d867605e145-true-d869033e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XPN.1 | hl7v2:XPN.2 | hl7v2:XPN.3 | hl7v2:XPN.4 | hl7v2:XPN.5 | hl7v2:XPN.6 | hl7v2:XPN.7 | hl7v2:XPN.8 | hl7v2:XPN.9 | hl7v2:XPN.10 | hl7v2:XPN.11 | hl7v2:XPN.12 | hl7v2:XPN.13 | hl7v2:XPN.14 (rule-reference: d867605e145-true-d869033e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d869014e15-true-d869047e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.1/*[not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="1626"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d869014e15-true-d869047e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d869014e15-true-d869047e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d869014e142-true-d869134e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.9/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1625"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d869014e142-true-d869134e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d869014e142-true-d869134e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d869014e155-true-d869181e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.10/*[not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1624"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d869014e155-true-d869181e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d869014e155-true-d869181e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d869174e17-true-d869192e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.10/hl7v2:DR.1/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1623"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d869174e17-true-d869192e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d869174e17-true-d869192e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d869174e28-true-d869215e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.10/hl7v2:DR.2/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1622"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d869174e28-true-d869215e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d869174e28-true-d869215e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d869014e186-true-d869244e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.12/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1621"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d869014e186-true-d869244e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d869014e186-true-d869244e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d869014e197-true-d869267e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.13/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1620"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d869014e197-true-d869267e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d869014e197-true-d869267e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d867605e156-true-d869300e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.10/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1619"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d867605e156-true-d869300e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d867605e156-true-d869300e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d867605e169-true-d869359e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/*[not(self::hl7v2:XAD.1 | self::hl7v2:XAD.2 | self::hl7v2:XAD.3 | self::hl7v2:XAD.4 | self::hl7v2:XAD.5 | self::hl7v2:XAD.6 | self::hl7v2:XAD.7 | self::hl7v2:XAD.8 | self::hl7v2:XAD.9 | self::hl7v2:XAD.10 | self::hl7v2:XAD.11 | self::hl7v2:XAD.12 | self::hl7v2:XAD.13 | self::hl7v2:XAD.14)]"
                 priority="1618"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d867605e169-true-d869359e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XAD.1 | hl7v2:XAD.2 | hl7v2:XAD.3 | hl7v2:XAD.4 | hl7v2:XAD.5 | hl7v2:XAD.6 | hl7v2:XAD.7 | hl7v2:XAD.8 | hl7v2:XAD.9 | hl7v2:XAD.10 | hl7v2:XAD.11 | hl7v2:XAD.12 | hl7v2:XAD.13 | hl7v2:XAD.14 (rule-reference: d867605e169-true-d869359e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d869340e26-true-d869371e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.1/*[not(self::hl7v2:SAD.1 | self::hl7v2:SAD.2 | self::hl7v2:SAD.3)]"
                 priority="1617"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d869340e26-true-d869371e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:SAD.1 | hl7v2:SAD.2 | hl7v2:SAD.3 (rule-reference: d869340e26-true-d869371e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d869340e225-true-d869460e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.12/*[not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1616"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d869340e225-true-d869460e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d869340e225-true-d869460e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d869453e23-true-d869471e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.12/hl7v2:DR.1/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1615"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d869453e23-true-d869471e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d869453e23-true-d869471e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d869453e34-true-d869494e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.12/hl7v2:DR.2/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1614"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d869453e34-true-d869494e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d869453e34-true-d869494e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d869340e245-true-d869517e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.13/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1613"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d869340e245-true-d869517e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d869340e245-true-d869517e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d869340e259-true-d869540e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.14/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1612"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d869340e259-true-d869540e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d869340e259-true-d869540e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d867605e206-true-d869579e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.13/*[not(self::hl7v2:XTN.1 | self::hl7v2:XTN.2 | self::hl7v2:XTN.3 | self::hl7v2:XTN.4 | self::hl7v2:XTN.5 | self::hl7v2:XTN.6 | self::hl7v2:XTN.7 | self::hl7v2:XTN.8 | self::hl7v2:XTN.9 | self::hl7v2:XTN.10 | self::hl7v2:XTN.11 | self::hl7v2:XTN.12)]"
                 priority="1611"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d867605e206-true-d869579e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XTN.1 | hl7v2:XTN.2 | hl7v2:XTN.3 | hl7v2:XTN.4 | hl7v2:XTN.5 | hl7v2:XTN.6 | hl7v2:XTN.7 | hl7v2:XTN.8 | hl7v2:XTN.9 | hl7v2:XTN.10 | hl7v2:XTN.11 | hl7v2:XTN.12 (rule-reference: d867605e206-true-d869579e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d867605e220-true-d869672e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.14/*[not(self::hl7v2:XTN.1 | self::hl7v2:XTN.2 | self::hl7v2:XTN.3 | self::hl7v2:XTN.4 | self::hl7v2:XTN.5 | self::hl7v2:XTN.6 | self::hl7v2:XTN.7 | self::hl7v2:XTN.8 | self::hl7v2:XTN.9 | self::hl7v2:XTN.10 | self::hl7v2:XTN.11 | self::hl7v2:XTN.12)]"
                 priority="1610"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d867605e220-true-d869672e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XTN.1 | hl7v2:XTN.2 | hl7v2:XTN.3 | hl7v2:XTN.4 | hl7v2:XTN.5 | hl7v2:XTN.6 | hl7v2:XTN.7 | hl7v2:XTN.8 | hl7v2:XTN.9 | hl7v2:XTN.10 | hl7v2:XTN.11 | hl7v2:XTN.12 (rule-reference: d867605e220-true-d869672e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d867605e234-true-d869759e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.15/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1609"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d867605e234-true-d869759e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d867605e234-true-d869759e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d867605e247-true-d869810e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.16/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1608"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d867605e247-true-d869810e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d867605e247-true-d869810e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d867605e264-true-d869861e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.17/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1607"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d867605e264-true-d869861e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d867605e264-true-d869861e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d867605e277-true-d869916e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/*[not(self::hl7v2:CX.1 | self::hl7v2:CX.2 | self::hl7v2:CX.3 | self::hl7v2:CX.4 | self::hl7v2:CX.5 | self::hl7v2:CX.6 | self::hl7v2:CX.7 | self::hl7v2:CX.8 | self::hl7v2:CX.9 | self::hl7v2:CX.10)]"
                 priority="1606"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d867605e277-true-d869916e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CX.1 | hl7v2:CX.2 | hl7v2:CX.3 | hl7v2:CX.4 | hl7v2:CX.5 | hl7v2:CX.6 | hl7v2:CX.7 | hl7v2:CX.8 | hl7v2:CX.9 | hl7v2:CX.10 (rule-reference: d867605e277-true-d869916e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d869901e221-true-d869946e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.4/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1605"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d869901e221-true-d869946e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d869901e221-true-d869946e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d869901e263-true-d869982e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.6/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1604"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d869901e263-true-d869982e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d869901e263-true-d869982e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d869901e305-true-d870030e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1603"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d869901e305-true-d870030e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d869901e305-true-d870030e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d869901e334-true-d870102e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1602"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d869901e334-true-d870102e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d869901e334-true-d870102e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d867605e299-true-d870174e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.20/*[not(self::hl7v2:DLN.1 | self::hl7v2:DLN.2 | self::hl7v2:DLN.3)]"
                 priority="1601"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d867605e299-true-d870174e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DLN.1 | hl7v2:DLN.2 | hl7v2:DLN.3 (rule-reference: d867605e299-true-d870174e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d867605e310-true-d870211e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/*[not(self::hl7v2:CX.1 | self::hl7v2:CX.2 | self::hl7v2:CX.3 | self::hl7v2:CX.4 | self::hl7v2:CX.5 | self::hl7v2:CX.6 | self::hl7v2:CX.7 | self::hl7v2:CX.8 | self::hl7v2:CX.9 | self::hl7v2:CX.10)]"
                 priority="1600"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d867605e310-true-d870211e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CX.1 | hl7v2:CX.2 | hl7v2:CX.3 | hl7v2:CX.4 | hl7v2:CX.5 | hl7v2:CX.6 | hl7v2:CX.7 | hl7v2:CX.8 | hl7v2:CX.9 | hl7v2:CX.10 (rule-reference: d867605e310-true-d870211e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d870196e221-true-d870241e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.4/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1599"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d870196e221-true-d870241e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d870196e221-true-d870241e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d870196e263-true-d870277e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.6/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1598"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d870196e263-true-d870277e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d870196e263-true-d870277e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d870196e305-true-d870325e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1597"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d870196e305-true-d870325e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d870196e305-true-d870325e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d870196e334-true-d870397e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1596"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d870196e334-true-d870397e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d870196e334-true-d870397e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d867605e321-true-d870466e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.22/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1595"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d867605e321-true-d870466e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d867605e321-true-d870466e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d867605e370-true-d870535e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.26/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1594"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d867605e370-true-d870535e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d867605e370-true-d870535e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d867605e383-true-d870586e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.27/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1593"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d867605e383-true-d870586e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d867605e383-true-d870586e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d867605e396-true-d870637e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.28/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1592"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d867605e396-true-d870637e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d867605e396-true-d870637e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d867605e409-true-d870684e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.29/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1591"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d867605e409-true-d870684e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d867605e409-true-d870684e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d867605e459-true-d870725e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.33/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1590"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d867605e459-true-d870725e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d867605e459-true-d870725e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d867605e471-true-d870749e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.34/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1589"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d867605e471-true-d870749e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d867605e471-true-d870749e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d867605e482-true-d870782e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.35/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1588"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d867605e482-true-d870782e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d867605e482-true-d870782e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d867605e495-true-d870833e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.36/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1587"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d867605e495-true-d870833e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d867605e495-true-d870833e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d867605e519-true-d870890e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.38/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1586"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d867605e519-true-d870890e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d867605e519-true-d870890e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d867605e532-true-d870944e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.39/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1585"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d867605e532-true-d870944e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d867605e532-true-d870944e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e13496-true-d871028e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/*[not(self::hl7v2:PD1.1 | self::hl7v2:PD1.2 | self::hl7v2:PD1.3 | self::hl7v2:PD1.4 | self::hl7v2:PD1.5 | self::hl7v2:PD1.6 | self::hl7v2:PD1.7 | self::hl7v2:PD1.8 | self::hl7v2:PD1.9 | self::hl7v2:PD1.10 | self::hl7v2:PD1.11 | self::hl7v2:PD1.12 | self::hl7v2:PD1.13 | self::hl7v2:PD1.14 | self::hl7v2:PD1.15 | self::hl7v2:PD1.16 | self::hl7v2:PD1.17 | self::hl7v2:PD1.18 | self::hl7v2:PD1.19 | self::hl7v2:PD1.20 | self::hl7v2:PD1.21)]"
                 priority="1584"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d20e13496-true-d871028e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:PD1.1 | hl7v2:PD1.2 | hl7v2:PD1.3 | hl7v2:PD1.4 | hl7v2:PD1.5 | hl7v2:PD1.6 | hl7v2:PD1.7 | hl7v2:PD1.8 | hl7v2:PD1.9 | hl7v2:PD1.10 | hl7v2:PD1.11 | hl7v2:PD1.12 | hl7v2:PD1.13 | hl7v2:PD1.14 | hl7v2:PD1.15 | hl7v2:PD1.16 | hl7v2:PD1.17 | hl7v2:PD1.18 | hl7v2:PD1.19 | hl7v2:PD1.20 | hl7v2:PD1.21 (rule-reference: d20e13496-true-d871028e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d871003e27-true-d871059e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.3/*[not(self::hl7v2:XON.1 | self::hl7v2:XON.2 | self::hl7v2:XON.3 | self::hl7v2:XON.4 | self::hl7v2:XON.5 | self::hl7v2:XON.6 | self::hl7v2:XON.7 | self::hl7v2:XON.8 | self::hl7v2:XON.9 | self::hl7v2:XON.10)]"
                 priority="1583"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d871003e27-true-d871059e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XON.1 | hl7v2:XON.2 | hl7v2:XON.3 | hl7v2:XON.4 | hl7v2:XON.5 | hl7v2:XON.6 | hl7v2:XON.7 | hl7v2:XON.8 | hl7v2:XON.9 | hl7v2:XON.10 (rule-reference: d871003e27-true-d871059e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d871044e80-true-d871101e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.6/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1582"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d871044e80-true-d871101e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d871044e80-true-d871101e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d871044e119-true-d871137e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.8/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1581"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d871044e119-true-d871137e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d871044e119-true-d871137e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d871003e38-true-d871199e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/*[not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="1580"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d871003e38-true-d871199e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d871003e38-true-d871199e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d871171e32-true-d871219e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.2/*[not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="1579"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d871171e32-true-d871219e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d871171e32-true-d871219e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d871171e123-true-d871297e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.9/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1578"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d871171e123-true-d871297e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d871171e123-true-d871297e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d871171e215-true-d871351e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.14/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1577"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d871171e215-true-d871351e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d871171e215-true-d871351e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d871171e275-true-d871390e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.16/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1576"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d871171e275-true-d871390e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d871171e275-true-d871390e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d871171e288-true-d871437e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.17/*[not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1575"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d871171e288-true-d871437e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d871171e288-true-d871437e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d871430e17-true-d871448e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.17/hl7v2:DR.1/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1574"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d871430e17-true-d871448e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d871430e17-true-d871448e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d871430e28-true-d871471e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.17/hl7v2:DR.2/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1573"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d871430e28-true-d871471e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d871430e28-true-d871471e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d871171e318-true-d871500e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.19/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1572"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d871171e318-true-d871500e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d871171e318-true-d871500e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d871171e329-true-d871523e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.20/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1571"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d871171e329-true-d871523e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d871171e329-true-d871523e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d871171e351-true-d871559e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1570"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d871171e351-true-d871559e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d871171e351-true-d871559e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d871171e369-true-d871631e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1569"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d871171e369-true-d871631e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d871171e369-true-d871631e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d871003e114-true-d871734e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/*[not(self::hl7v2:CX.1 | self::hl7v2:CX.2 | self::hl7v2:CX.3 | self::hl7v2:CX.4 | self::hl7v2:CX.5 | self::hl7v2:CX.6 | self::hl7v2:CX.7 | self::hl7v2:CX.8 | self::hl7v2:CX.9 | self::hl7v2:CX.10)]"
                 priority="1568"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d871003e114-true-d871734e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CX.1 | hl7v2:CX.2 | hl7v2:CX.3 | hl7v2:CX.4 | hl7v2:CX.5 | hl7v2:CX.6 | hl7v2:CX.7 | hl7v2:CX.8 | hl7v2:CX.9 | hl7v2:CX.10 (rule-reference: d871003e114-true-d871734e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d871719e221-true-d871764e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.4/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1567"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d871719e221-true-d871764e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d871719e221-true-d871764e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d871719e263-true-d871800e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.6/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1566"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d871719e263-true-d871800e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d871719e263-true-d871800e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d871719e305-true-d871848e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1565"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d871719e305-true-d871848e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d871719e305-true-d871848e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d871719e334-true-d871920e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1564"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d871719e334-true-d871920e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d871719e334-true-d871920e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d871003e125-true-d871989e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.11/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1563"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d871003e125-true-d871989e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d871003e125-true-d871989e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d871003e163-true-d872056e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.14/*[not(self::hl7v2:XON.1 | self::hl7v2:XON.2 | self::hl7v2:XON.3 | self::hl7v2:XON.4 | self::hl7v2:XON.5 | self::hl7v2:XON.6 | self::hl7v2:XON.7 | self::hl7v2:XON.8 | self::hl7v2:XON.9 | self::hl7v2:XON.10)]"
                 priority="1562"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d871003e163-true-d872056e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XON.1 | hl7v2:XON.2 | hl7v2:XON.3 | hl7v2:XON.4 | hl7v2:XON.5 | hl7v2:XON.6 | hl7v2:XON.7 | hl7v2:XON.8 | hl7v2:XON.9 | hl7v2:XON.10 (rule-reference: d871003e163-true-d872056e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d872041e80-true-d872098e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.6/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1561"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d872041e80-true-d872098e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d872041e80-true-d872098e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d872041e119-true-d872134e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.8/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1560"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d872041e119-true-d872134e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d872041e119-true-d872134e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d871003e174-true-d872179e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.15/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1559"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d871003e174-true-d872179e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d871003e174-true-d872179e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e13498-true-d872264e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:NTE/*[not(self::hl7v2:NTE.1 | self::hl7v2:NTE.2 | self::hl7v2:NTE.3 | self::hl7v2:NTE.4)]"
                 priority="1558"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d20e13498-true-d872264e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:NTE.1 | hl7v2:NTE.2 | hl7v2:NTE.3 | hl7v2:NTE.4 (rule-reference: d20e13498-true-d872264e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d872256e110-true-d872286e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:NTE/hl7v2:NTE.3/*[not(self::hl7v2:escape)]"
                 priority="1557"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d872256e110-true-d872286e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d872256e110-true-d872286e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d872280e36-true-d872296e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/*[not(self::hl7v2:escape)]"
                 priority="1556"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d872280e36-true-d872296e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d872280e36-true-d872296e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d872290e5-true-d872306e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/hl7v2:escape/*[not(self::hl7v2:escape)]"
                 priority="1555"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d872290e5-true-d872306e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d872290e5-true-d872306e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d872256e142-true-d872325e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:NTE/hl7v2:NTE.4/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1554"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d872256e142-true-d872325e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d872256e142-true-d872325e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e13501-true-d872369e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/*[not(self::hl7v2:PV1 | self::hl7v2:PV2)]"
                 priority="1553"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d20e13501-true-d872369e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:PV1 | hl7v2:PV2 (rule-reference: d20e13501-true-d872369e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e13503-true-d872430e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/*[not(self::hl7v2:PV1.1 | self::hl7v2:PV1.2 | self::hl7v2:PV1.3 | self::hl7v2:PV1.4 | self::hl7v2:PV1.5 | self::hl7v2:PV1.6 | self::hl7v2:PV1.7 | self::hl7v2:PV1.8 | self::hl7v2:PV1.9 | self::hl7v2:PV1.10 | self::hl7v2:PV1.11 | self::hl7v2:PV1.12 | self::hl7v2:PV1.13 | self::hl7v2:PV1.14 | self::hl7v2:PV1.15 | self::hl7v2:PV1.16 | self::hl7v2:PV1.17 | self::hl7v2:PV1.18 | self::hl7v2:PV1.19 | self::hl7v2:PV1.20 | self::hl7v2:PV1.21 | self::hl7v2:PV1.22 | self::hl7v2:PV1.23 | self::hl7v2:PV1.24 | self::hl7v2:PV1.25 | self::hl7v2:PV1.26 | self::hl7v2:PV1.27 | self::hl7v2:PV1.28 | self::hl7v2:PV1.29 | self::hl7v2:PV1.30 | self::hl7v2:PV1.31 | self::hl7v2:PV1.32 | self::hl7v2:PV1.33 | self::hl7v2:PV1.34 | self::hl7v2:PV1.35 | self::hl7v2:PV1.36 | self::hl7v2:PV1.37 | self::hl7v2:PV1.38 | self::hl7v2:PV1.39 | self::hl7v2:PV1.40 | self::hl7v2:PV1.41 | self::hl7v2:PV1.42 | self::hl7v2:PV1.43 | self::hl7v2:PV1.44 | self::hl7v2:PV1.45 | self::hl7v2:PV1.46 | self::hl7v2:PV1.47 | self::hl7v2:PV1.48 | self::hl7v2:PV1.49 | self::hl7v2:PV1.50 | self::hl7v2:PV1.51 | self::hl7v2:PV1.52)]"
                 priority="1552"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d20e13503-true-d872430e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:PV1.1 | hl7v2:PV1.2 | hl7v2:PV1.3 | hl7v2:PV1.4 | hl7v2:PV1.5 | hl7v2:PV1.6 | hl7v2:PV1.7 | hl7v2:PV1.8 | hl7v2:PV1.9 | hl7v2:PV1.10 | hl7v2:PV1.11 | hl7v2:PV1.12 | hl7v2:PV1.13 | hl7v2:PV1.14 | hl7v2:PV1.15 | hl7v2:PV1.16 | hl7v2:PV1.17 | hl7v2:PV1.18 | hl7v2:PV1.19 | hl7v2:PV1.20 | hl7v2:PV1.21 | hl7v2:PV1.22 | hl7v2:PV1.23 | hl7v2:PV1.24 | hl7v2:PV1.25 | hl7v2:PV1.26 | hl7v2:PV1.27 | hl7v2:PV1.28 | hl7v2:PV1.29 | hl7v2:PV1.30 | hl7v2:PV1.31 | hl7v2:PV1.32 | hl7v2:PV1.33 | hl7v2:PV1.34 | hl7v2:PV1.35 | hl7v2:PV1.36 | hl7v2:PV1.37 | hl7v2:PV1.38 | hl7v2:PV1.39 | hl7v2:PV1.40 | hl7v2:PV1.41 | hl7v2:PV1.42 | hl7v2:PV1.43 | hl7v2:PV1.44 | hl7v2:PV1.45 | hl7v2:PV1.46 | hl7v2:PV1.47 | hl7v2:PV1.48 | hl7v2:PV1.49 | hl7v2:PV1.50 | hl7v2:PV1.51 | hl7v2:PV1.52 (rule-reference: d20e13503-true-d872430e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d872374e29-true-d872462e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3/*[not(self::hl7v2:PL.1 | self::hl7v2:PL.2 | self::hl7v2:PL.3 | self::hl7v2:PL.4 | self::hl7v2:PL.5 | self::hl7v2:PL.6 | self::hl7v2:PL.7 | self::hl7v2:PL.8 | self::hl7v2:PL.9 | self::hl7v2:PL.10 | self::hl7v2:PL.11)]"
                 priority="1551"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d872374e29-true-d872462e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:PL.1 | hl7v2:PL.2 | hl7v2:PL.3 | hl7v2:PL.4 | hl7v2:PL.5 | hl7v2:PL.6 | hl7v2:PL.7 | hl7v2:PL.8 | hl7v2:PL.9 | hl7v2:PL.10 | hl7v2:PL.11 (rule-reference: d872374e29-true-d872462e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d872446e82-true-d872492e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.4/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1550"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d872446e82-true-d872492e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d872446e82-true-d872492e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d872446e181-true-d872553e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.10/*[not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1549"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d872446e181-true-d872553e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d872446e181-true-d872553e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d872446e193-true-d872589e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.11/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1548"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d872446e193-true-d872589e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d872446e193-true-d872589e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d872374e79-true-d872632e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/*[not(self::hl7v2:CX.1 | self::hl7v2:CX.2 | self::hl7v2:CX.3 | self::hl7v2:CX.4 | self::hl7v2:CX.5 | self::hl7v2:CX.6 | self::hl7v2:CX.7 | self::hl7v2:CX.8 | self::hl7v2:CX.9 | self::hl7v2:CX.10)]"
                 priority="1547"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d872374e79-true-d872632e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CX.1 | hl7v2:CX.2 | hl7v2:CX.3 | hl7v2:CX.4 | hl7v2:CX.5 | hl7v2:CX.6 | hl7v2:CX.7 | hl7v2:CX.8 | hl7v2:CX.9 | hl7v2:CX.10 (rule-reference: d872374e79-true-d872632e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d872617e221-true-d872662e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.4/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1546"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d872617e221-true-d872662e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d872617e221-true-d872662e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d872617e263-true-d872698e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.6/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1545"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d872617e263-true-d872698e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d872617e263-true-d872698e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d872617e305-true-d872746e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1544"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d872617e305-true-d872746e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d872617e305-true-d872746e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d872617e334-true-d872818e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1543"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d872617e334-true-d872818e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d872617e334-true-d872818e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d872374e90-true-d872892e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6/*[not(self::hl7v2:PL.1 | self::hl7v2:PL.2 | self::hl7v2:PL.3 | self::hl7v2:PL.4 | self::hl7v2:PL.5 | self::hl7v2:PL.6 | self::hl7v2:PL.7 | self::hl7v2:PL.8 | self::hl7v2:PL.9 | self::hl7v2:PL.10 | self::hl7v2:PL.11)]"
                 priority="1542"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d872374e90-true-d872892e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:PL.1 | hl7v2:PL.2 | hl7v2:PL.3 | hl7v2:PL.4 | hl7v2:PL.5 | hl7v2:PL.6 | hl7v2:PL.7 | hl7v2:PL.8 | hl7v2:PL.9 | hl7v2:PL.10 | hl7v2:PL.11 (rule-reference: d872374e90-true-d872892e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d872876e48-true-d872922e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.4/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1541"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d872876e48-true-d872922e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d872876e48-true-d872922e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d872876e125-true-d872983e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.10/*[not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1540"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d872876e125-true-d872983e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d872876e125-true-d872983e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d872876e134-true-d873019e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.11/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1539"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d872876e134-true-d873019e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d872876e134-true-d873019e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d872374e101-true-d873069e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/*[not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="1538"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d872374e101-true-d873069e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d872374e101-true-d873069e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d873041e35-true-d873089e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.2/*[not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="1537"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d873041e35-true-d873089e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d873041e35-true-d873089e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d873041e127-true-d873167e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.9/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1536"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d873041e127-true-d873167e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d873041e127-true-d873167e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d873041e218-true-d873221e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.14/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1535"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d873041e218-true-d873221e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d873041e218-true-d873221e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d873041e278-true-d873260e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.16/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1534"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d873041e278-true-d873260e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d873041e278-true-d873260e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d873041e291-true-d873307e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.17/*[not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1533"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d873041e291-true-d873307e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d873041e291-true-d873307e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d873300e17-true-d873318e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.17/hl7v2:DR.1/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1532"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d873300e17-true-d873318e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d873300e17-true-d873318e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d873300e28-true-d873341e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.17/hl7v2:DR.2/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1531"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d873300e28-true-d873341e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d873300e28-true-d873341e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d873041e322-true-d873370e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.19/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1530"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d873041e322-true-d873370e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d873041e322-true-d873370e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d873041e333-true-d873393e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.20/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1529"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d873041e333-true-d873393e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d873041e333-true-d873393e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d873041e355-true-d873429e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1528"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d873041e355-true-d873429e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d873041e355-true-d873429e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d873041e372-true-d873501e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1527"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d873041e372-true-d873501e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d873041e372-true-d873501e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d872374e114-true-d873587e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/*[not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="1526"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d872374e114-true-d873587e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d872374e114-true-d873587e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d873559e35-true-d873607e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.2/*[not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="1525"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d873559e35-true-d873607e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d873559e35-true-d873607e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d873559e127-true-d873685e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.9/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1524"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d873559e127-true-d873685e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d873559e127-true-d873685e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d873559e218-true-d873739e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.14/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1523"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d873559e218-true-d873739e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d873559e218-true-d873739e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d873559e278-true-d873778e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.16/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1522"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d873559e278-true-d873778e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d873559e278-true-d873778e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d873559e291-true-d873825e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.17/*[not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1521"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d873559e291-true-d873825e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d873559e291-true-d873825e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d873818e17-true-d873836e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.17/hl7v2:DR.1/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1520"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d873818e17-true-d873836e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d873818e17-true-d873836e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d873818e28-true-d873859e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.17/hl7v2:DR.2/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1519"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d873818e28-true-d873859e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d873818e28-true-d873859e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d873559e322-true-d873888e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.19/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1518"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d873559e322-true-d873888e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d873559e322-true-d873888e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d873559e333-true-d873911e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.20/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1517"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d873559e333-true-d873911e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d873559e333-true-d873911e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d873559e355-true-d873947e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1516"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d873559e355-true-d873947e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d873559e355-true-d873947e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d873559e372-true-d874019e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1515"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d873559e372-true-d874019e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d873559e372-true-d874019e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d872374e127-true-d874105e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/*[not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="1514"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d872374e127-true-d874105e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d872374e127-true-d874105e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d874077e35-true-d874125e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.2/*[not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="1513"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d874077e35-true-d874125e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d874077e35-true-d874125e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d874077e127-true-d874203e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.9/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1512"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d874077e127-true-d874203e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d874077e127-true-d874203e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d874077e218-true-d874257e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.14/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1511"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d874077e218-true-d874257e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d874077e218-true-d874257e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d874077e278-true-d874296e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.16/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1510"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d874077e278-true-d874296e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d874077e278-true-d874296e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d874077e291-true-d874343e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.17/*[not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1509"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d874077e291-true-d874343e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d874077e291-true-d874343e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d874336e17-true-d874354e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.17/hl7v2:DR.1/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1508"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d874336e17-true-d874354e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d874336e17-true-d874354e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d874336e28-true-d874377e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.17/hl7v2:DR.2/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1507"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d874336e28-true-d874377e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d874336e28-true-d874377e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d874077e322-true-d874406e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.19/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1506"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d874077e322-true-d874406e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d874077e322-true-d874406e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d874077e333-true-d874429e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.20/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1505"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d874077e333-true-d874429e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d874077e333-true-d874429e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d874077e355-true-d874465e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1504"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d874077e355-true-d874465e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d874077e355-true-d874465e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d874077e372-true-d874537e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1503"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d874077e372-true-d874537e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d874077e372-true-d874537e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d872374e162-true-d874617e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11/*[not(self::hl7v2:PL.1 | self::hl7v2:PL.2 | self::hl7v2:PL.3 | self::hl7v2:PL.4 | self::hl7v2:PL.5 | self::hl7v2:PL.6 | self::hl7v2:PL.7 | self::hl7v2:PL.8 | self::hl7v2:PL.9 | self::hl7v2:PL.10 | self::hl7v2:PL.11)]"
                 priority="1502"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d872374e162-true-d874617e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:PL.1 | hl7v2:PL.2 | hl7v2:PL.3 | hl7v2:PL.4 | hl7v2:PL.5 | hl7v2:PL.6 | hl7v2:PL.7 | hl7v2:PL.8 | hl7v2:PL.9 | hl7v2:PL.10 | hl7v2:PL.11 (rule-reference: d872374e162-true-d874617e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d874601e48-true-d874647e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.4/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1501"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d874601e48-true-d874647e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d874601e48-true-d874647e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d874601e125-true-d874708e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.10/*[not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1500"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d874601e125-true-d874708e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d874601e125-true-d874708e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d874601e134-true-d874744e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.11/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1499"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d874601e134-true-d874744e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d874601e134-true-d874744e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d872374e239-true-d874824e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/*[not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="1498"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d872374e239-true-d874824e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d872374e239-true-d874824e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d874796e35-true-d874844e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.2/*[not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="1497"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d874796e35-true-d874844e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d874796e35-true-d874844e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d874796e127-true-d874922e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.9/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1496"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d874796e127-true-d874922e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d874796e127-true-d874922e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d874796e218-true-d874976e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.14/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1495"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d874796e218-true-d874976e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d874796e218-true-d874976e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d874796e278-true-d875015e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.16/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1494"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d874796e278-true-d875015e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d874796e278-true-d875015e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d874796e291-true-d875062e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.17/*[not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1493"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d874796e291-true-d875062e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d874796e291-true-d875062e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d875055e17-true-d875073e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.17/hl7v2:DR.1/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1492"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d875055e17-true-d875073e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d875055e17-true-d875073e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d875055e28-true-d875096e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.17/hl7v2:DR.2/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1491"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d875055e28-true-d875096e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d875055e28-true-d875096e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d874796e322-true-d875125e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.19/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1490"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d874796e322-true-d875125e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d874796e322-true-d875125e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d874796e333-true-d875148e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.20/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1489"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d874796e333-true-d875148e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d874796e333-true-d875148e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d874796e355-true-d875184e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1488"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d874796e355-true-d875184e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d874796e355-true-d875184e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d874796e372-true-d875256e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1487"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d874796e372-true-d875256e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d874796e372-true-d875256e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d872374e265-true-d875335e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/*[not(self::hl7v2:CX.1 | self::hl7v2:CX.2 | self::hl7v2:CX.3 | self::hl7v2:CX.4 | self::hl7v2:CX.5 | self::hl7v2:CX.6 | self::hl7v2:CX.7 | self::hl7v2:CX.8 | self::hl7v2:CX.9 | self::hl7v2:CX.10)]"
                 priority="1486"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d872374e265-true-d875335e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CX.1 | hl7v2:CX.2 | hl7v2:CX.3 | hl7v2:CX.4 | hl7v2:CX.5 | hl7v2:CX.6 | hl7v2:CX.7 | hl7v2:CX.8 | hl7v2:CX.9 | hl7v2:CX.10 (rule-reference: d872374e265-true-d875335e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d875320e221-true-d875365e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.4/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1485"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d875320e221-true-d875365e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d875320e221-true-d875365e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d875320e263-true-d875401e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.6/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1484"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d875320e263-true-d875401e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d875320e263-true-d875401e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d875320e305-true-d875449e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1483"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d875320e305-true-d875449e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d875320e305-true-d875449e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d875320e334-true-d875521e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1482"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d875320e334-true-d875521e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d875320e334-true-d875521e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d872374e276-true-d875586e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.20/*[not(self::hl7v2:FC.1 | self::hl7v2:FC.2)]"
                 priority="1481"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d872374e276-true-d875586e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FC.1 | hl7v2:FC.2 (rule-reference: d872374e276-true-d875586e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d875579e31-true-d875603e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.20/hl7v2:FC.2/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1480"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d875579e31-true-d875603e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d875579e31-true-d875603e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d872374e485-true-d875722e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.37/*[not(self::hl7v2:DLD.1 | self::hl7v2:DLD.2)]"
                 priority="1479"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d872374e485-true-d875722e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DLD.1 | hl7v2:DLD.2 (rule-reference: d872374e485-true-d875722e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d875715e31-true-d875739e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.37/hl7v2:DLD.2/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1478"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d875715e31-true-d875739e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d875715e31-true-d875739e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d872374e498-true-d875766e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.38/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1477"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d872374e498-true-d875766e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d872374e498-true-d875766e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d872374e559-true-d875840e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42/*[not(self::hl7v2:PL.1 | self::hl7v2:PL.2 | self::hl7v2:PL.3 | self::hl7v2:PL.4 | self::hl7v2:PL.5 | self::hl7v2:PL.6 | self::hl7v2:PL.7 | self::hl7v2:PL.8 | self::hl7v2:PL.9 | self::hl7v2:PL.10 | self::hl7v2:PL.11)]"
                 priority="1476"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d872374e559-true-d875840e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:PL.1 | hl7v2:PL.2 | hl7v2:PL.3 | hl7v2:PL.4 | hl7v2:PL.5 | hl7v2:PL.6 | hl7v2:PL.7 | hl7v2:PL.8 | hl7v2:PL.9 | hl7v2:PL.10 | hl7v2:PL.11 (rule-reference: d872374e559-true-d875840e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d875824e48-true-d875870e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.4/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1475"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d875824e48-true-d875870e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d875824e48-true-d875870e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d875824e125-true-d875931e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.10/*[not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1474"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d875824e125-true-d875931e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d875824e125-true-d875931e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d875824e134-true-d875967e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.11/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1473"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d875824e134-true-d875967e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d875824e134-true-d875967e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d872374e570-true-d876005e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43/*[not(self::hl7v2:PL.1 | self::hl7v2:PL.2 | self::hl7v2:PL.3 | self::hl7v2:PL.4 | self::hl7v2:PL.5 | self::hl7v2:PL.6 | self::hl7v2:PL.7 | self::hl7v2:PL.8 | self::hl7v2:PL.9 | self::hl7v2:PL.10 | self::hl7v2:PL.11)]"
                 priority="1472"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d872374e570-true-d876005e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:PL.1 | hl7v2:PL.2 | hl7v2:PL.3 | hl7v2:PL.4 | hl7v2:PL.5 | hl7v2:PL.6 | hl7v2:PL.7 | hl7v2:PL.8 | hl7v2:PL.9 | hl7v2:PL.10 | hl7v2:PL.11 (rule-reference: d872374e570-true-d876005e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d875989e48-true-d876035e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.4/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1471"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d875989e48-true-d876035e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d875989e48-true-d876035e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d875989e125-true-d876096e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.10/*[not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1470"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d875989e125-true-d876096e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d875989e125-true-d876096e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d875989e134-true-d876132e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.11/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1469"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d875989e134-true-d876132e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d875989e134-true-d876132e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d872374e581-true-d876161e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.44/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1468"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d872374e581-true-d876161e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d872374e581-true-d876161e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d872374e603-true-d876184e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.45/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1467"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d872374e603-true-d876184e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d872374e603-true-d876184e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d872374e658-true-d876239e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/*[not(self::hl7v2:CX.1 | self::hl7v2:CX.2 | self::hl7v2:CX.3 | self::hl7v2:CX.4 | self::hl7v2:CX.5 | self::hl7v2:CX.6 | self::hl7v2:CX.7 | self::hl7v2:CX.8 | self::hl7v2:CX.9 | self::hl7v2:CX.10)]"
                 priority="1466"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d872374e658-true-d876239e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CX.1 | hl7v2:CX.2 | hl7v2:CX.3 | hl7v2:CX.4 | hl7v2:CX.5 | hl7v2:CX.6 | hl7v2:CX.7 | hl7v2:CX.8 | hl7v2:CX.9 | hl7v2:CX.10 (rule-reference: d872374e658-true-d876239e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d876224e224-true-d876269e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.4/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1465"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d876224e224-true-d876269e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d876224e224-true-d876269e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d876224e266-true-d876305e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.6/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1464"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d876224e266-true-d876305e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d876224e266-true-d876305e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d876224e309-true-d876353e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1463"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d876224e309-true-d876353e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d876224e309-true-d876353e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d876224e338-true-d876425e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1462"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d876224e338-true-d876425e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d876224e338-true-d876425e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d872374e684-true-d876517e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/*[not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="1461"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d872374e684-true-d876517e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d872374e684-true-d876517e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d876489e35-true-d876537e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.2/*[not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="1460"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d876489e35-true-d876537e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d876489e35-true-d876537e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d876489e127-true-d876615e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.9/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1459"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d876489e127-true-d876615e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d876489e127-true-d876615e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d876489e218-true-d876669e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.14/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1458"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d876489e218-true-d876669e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d876489e218-true-d876669e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d876489e278-true-d876708e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.16/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1457"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d876489e278-true-d876708e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d876489e278-true-d876708e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d876489e291-true-d876755e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.17/*[not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1456"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d876489e291-true-d876755e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d876489e291-true-d876755e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d876748e17-true-d876766e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.17/hl7v2:DR.1/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1455"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d876748e17-true-d876766e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d876748e17-true-d876766e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d876748e28-true-d876789e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.17/hl7v2:DR.2/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1454"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d876748e28-true-d876789e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d876748e28-true-d876789e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d876489e322-true-d876818e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.19/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1453"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d876489e322-true-d876818e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d876489e322-true-d876818e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d876489e333-true-d876841e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.20/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1452"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d876489e333-true-d876841e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d876489e333-true-d876841e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d876489e355-true-d876877e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1451"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d876489e355-true-d876877e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d876489e355-true-d876877e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d876489e372-true-d876949e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1450"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d876489e372-true-d876949e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d876489e372-true-d876949e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e13505-true-d877061e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/*[not(self::hl7v2:PV2.1 | self::hl7v2:PV2.2 | self::hl7v2:PV2.3 | self::hl7v2:PV2.4 | self::hl7v2:PV2.5 | self::hl7v2:PV2.6 | self::hl7v2:PV2.7 | self::hl7v2:PV2.8 | self::hl7v2:PV2.9 | self::hl7v2:PV2.10 | self::hl7v2:PV2.11 | self::hl7v2:PV2.12 | self::hl7v2:PV2.13 | self::hl7v2:PV2.14 | self::hl7v2:PV2.15 | self::hl7v2:PV2.16 | self::hl7v2:PV2.17 | self::hl7v2:PV2.18 | self::hl7v2:PV2.19 | self::hl7v2:PV2.20 | self::hl7v2:PV2.21 | self::hl7v2:PV2.22 | self::hl7v2:PV2.23 | self::hl7v2:PV2.24 | self::hl7v2:PV2.25 | self::hl7v2:PV2.26 | self::hl7v2:PV2.27 | self::hl7v2:PV2.28 | self::hl7v2:PV2.29 | self::hl7v2:PV2.30 | self::hl7v2:PV2.31 | self::hl7v2:PV2.32 | self::hl7v2:PV2.33 | self::hl7v2:PV2.34 | self::hl7v2:PV2.35 | self::hl7v2:PV2.36 | self::hl7v2:PV2.37 | self::hl7v2:PV2.38 | self::hl7v2:PV2.39 | self::hl7v2:PV2.40 | self::hl7v2:PV2.41 | self::hl7v2:PV2.42 | self::hl7v2:PV2.43 | self::hl7v2:PV2.44 | self::hl7v2:PV2.45 | self::hl7v2:PV2.46 | self::hl7v2:PV2.47 | self::hl7v2:PV2.48 | self::hl7v2:PV2.49)]"
                 priority="1449"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d20e13505-true-d877061e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:PV2.1 | hl7v2:PV2.2 | hl7v2:PV2.3 | hl7v2:PV2.4 | hl7v2:PV2.5 | hl7v2:PV2.6 | hl7v2:PV2.7 | hl7v2:PV2.8 | hl7v2:PV2.9 | hl7v2:PV2.10 | hl7v2:PV2.11 | hl7v2:PV2.12 | hl7v2:PV2.13 | hl7v2:PV2.14 | hl7v2:PV2.15 | hl7v2:PV2.16 | hl7v2:PV2.17 | hl7v2:PV2.18 | hl7v2:PV2.19 | hl7v2:PV2.20 | hl7v2:PV2.21 | hl7v2:PV2.22 | hl7v2:PV2.23 | hl7v2:PV2.24 | hl7v2:PV2.25 | hl7v2:PV2.26 | hl7v2:PV2.27 | hl7v2:PV2.28 | hl7v2:PV2.29 | hl7v2:PV2.30 | hl7v2:PV2.31 | hl7v2:PV2.32 | hl7v2:PV2.33 | hl7v2:PV2.34 | hl7v2:PV2.35 | hl7v2:PV2.36 | hl7v2:PV2.37 | hl7v2:PV2.38 | hl7v2:PV2.39 | hl7v2:PV2.40 | hl7v2:PV2.41 | hl7v2:PV2.42 | hl7v2:PV2.43 | hl7v2:PV2.44 | hl7v2:PV2.45 | hl7v2:PV2.46 | hl7v2:PV2.47 | hl7v2:PV2.48 | hl7v2:PV2.49 (rule-reference: d20e13505-true-d877061e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d877008e1-true-d877081e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1/*[not(self::hl7v2:PL.1 | self::hl7v2:PL.2 | self::hl7v2:PL.3 | self::hl7v2:PL.4 | self::hl7v2:PL.5 | self::hl7v2:PL.6 | self::hl7v2:PL.7 | self::hl7v2:PL.8 | self::hl7v2:PL.9 | self::hl7v2:PL.10 | self::hl7v2:PL.11)]"
                 priority="1448"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d877008e1-true-d877081e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:PL.1 | hl7v2:PL.2 | hl7v2:PL.3 | hl7v2:PL.4 | hl7v2:PL.5 | hl7v2:PL.6 | hl7v2:PL.7 | hl7v2:PL.8 | hl7v2:PL.9 | hl7v2:PL.10 | hl7v2:PL.11 (rule-reference: d877008e1-true-d877081e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d877065e48-true-d877111e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.4/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1447"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d877065e48-true-d877111e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d877065e48-true-d877111e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d877065e125-true-d877172e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.10/*[not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1446"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d877065e125-true-d877172e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d877065e125-true-d877172e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d877065e134-true-d877208e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.11/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1445"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d877065e134-true-d877208e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d877065e134-true-d877208e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d877008e12-true-d877241e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.2/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1444"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d877008e12-true-d877241e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d877008e12-true-d877241e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d877008e25-true-d877292e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.3/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1443"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d877008e25-true-d877292e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d877008e25-true-d877292e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d877008e36-true-d877343e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.4/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1442"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d877008e36-true-d877343e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d877008e36-true-d877343e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d877008e82-true-d877408e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.8/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1441"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d877008e82-true-d877408e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d877008e82-true-d877408e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d877008e93-true-d877431e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.9/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1440"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d877008e93-true-d877431e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d877008e93-true-d877431e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d877008e138-true-d877493e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/*[not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="1439"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d877008e138-true-d877493e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d877008e138-true-d877493e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d877465e32-true-d877513e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.2/*[not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="1438"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d877465e32-true-d877513e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d877465e32-true-d877513e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d877465e123-true-d877591e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.9/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1437"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d877465e123-true-d877591e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d877465e123-true-d877591e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d877465e215-true-d877645e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.14/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1436"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d877465e215-true-d877645e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d877465e215-true-d877645e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d877465e275-true-d877684e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.16/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1435"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d877465e275-true-d877684e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d877465e275-true-d877684e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d877465e288-true-d877731e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.17/*[not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1434"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d877465e288-true-d877731e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d877465e288-true-d877731e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d877724e17-true-d877742e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.17/hl7v2:DR.1/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1433"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d877724e17-true-d877742e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d877724e17-true-d877742e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d877724e28-true-d877765e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.17/hl7v2:DR.2/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1432"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d877724e28-true-d877765e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d877724e28-true-d877765e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d877465e318-true-d877794e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.19/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1431"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d877465e318-true-d877794e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d877465e318-true-d877794e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d877465e329-true-d877817e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.20/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1430"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d877465e329-true-d877817e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d877465e329-true-d877817e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d877465e351-true-d877853e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1429"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d877465e351-true-d877853e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d877465e351-true-d877853e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d877465e369-true-d877925e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1428"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d877465e369-true-d877925e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d877465e369-true-d877925e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d877008e261-true-d878052e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.23/*[not(self::hl7v2:XON.1 | self::hl7v2:XON.2 | self::hl7v2:XON.3 | self::hl7v2:XON.4 | self::hl7v2:XON.5 | self::hl7v2:XON.6 | self::hl7v2:XON.7 | self::hl7v2:XON.8 | self::hl7v2:XON.9 | self::hl7v2:XON.10)]"
                 priority="1427"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d877008e261-true-d878052e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XON.1 | hl7v2:XON.2 | hl7v2:XON.3 | hl7v2:XON.4 | hl7v2:XON.5 | hl7v2:XON.6 | hl7v2:XON.7 | hl7v2:XON.8 | hl7v2:XON.9 | hl7v2:XON.10 (rule-reference: d877008e261-true-d878052e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d878037e80-true-d878094e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.6/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1426"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d878037e80-true-d878094e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d878037e80-true-d878094e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d878037e119-true-d878130e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.8/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1425"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d878037e119-true-d878130e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d878037e119-true-d878130e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d877008e344-true-d878211e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.30/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1424"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d877008e344-true-d878211e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d877008e344-true-d878211e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d877008e383-true-d878270e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.33/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1423"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d877008e383-true-d878270e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d877008e383-true-d878270e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d877008e447-true-d878321e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.38/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1422"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d877008e447-true-d878321e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d877008e447-true-d878321e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d877008e460-true-d878372e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.39/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1421"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d877008e460-true-d878372e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d877008e460-true-d878372e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d877008e473-true-d878423e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.40/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1420"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d877008e473-true-d878423e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d877008e473-true-d878423e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d877008e486-true-d878474e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.41/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1419"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d877008e486-true-d878474e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d877008e486-true-d878474e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d877008e499-true-d878525e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.42/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1418"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d877008e499-true-d878525e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d877008e499-true-d878525e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d877008e539-true-d878588e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.45/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1417"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d877008e539-true-d878588e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d877008e539-true-d878588e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d877008e563-true-d878641e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.47/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1416"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d877008e563-true-d878641e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d877008e563-true-d878641e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d877008e574-true-d878664e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.48/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1415"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d877008e574-true-d878664e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d877008e574-true-d878664e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e13508-true-d878692e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/*[not(self::hl7v2:SPM | self::hl7v2:OBX | self::hl7v2:OUL_R22.CONTAINER | self::hl7v2:OUL_R22.ORDER)]"
                 priority="1414"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d20e13508-true-d878692e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:SPM | hl7v2:OBX | hl7v2:OUL_R22.CONTAINER | hl7v2:OUL_R22.ORDER (rule-reference: d20e13508-true-d878692e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e13510-true-d878730e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/*[not(self::hl7v2:SPM.1 | self::hl7v2:SPM.2 | self::hl7v2:SPM.3 | self::hl7v2:SPM.4 | self::hl7v2:SPM.5 | self::hl7v2:SPM.6 | self::hl7v2:SPM.7 | self::hl7v2:SPM.8 | self::hl7v2:SPM.9 | self::hl7v2:SPM.10 | self::hl7v2:SPM.11 | self::hl7v2:SPM.12 | self::hl7v2:SPM.13 | self::hl7v2:SPM.14 | self::hl7v2:SPM.15 | self::hl7v2:SPM.16 | self::hl7v2:SPM.17 | self::hl7v2:SPM.18 | self::hl7v2:SPM.19 | self::hl7v2:SPM.20 | self::hl7v2:SPM.21 | self::hl7v2:SPM.22 | self::hl7v2:SPM.23 | self::hl7v2:SPM.24 | self::hl7v2:SPM.25 | self::hl7v2:SPM.26 | self::hl7v2:SPM.27 | self::hl7v2:SPM.28 | self::hl7v2:SPM.29)]"
                 priority="1413"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d20e13510-true-d878730e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:SPM.1 | hl7v2:SPM.2 | hl7v2:SPM.3 | hl7v2:SPM.4 | hl7v2:SPM.5 | hl7v2:SPM.6 | hl7v2:SPM.7 | hl7v2:SPM.8 | hl7v2:SPM.9 | hl7v2:SPM.10 | hl7v2:SPM.11 | hl7v2:SPM.12 | hl7v2:SPM.13 | hl7v2:SPM.14 | hl7v2:SPM.15 | hl7v2:SPM.16 | hl7v2:SPM.17 | hl7v2:SPM.18 | hl7v2:SPM.19 | hl7v2:SPM.20 | hl7v2:SPM.21 | hl7v2:SPM.22 | hl7v2:SPM.23 | hl7v2:SPM.24 | hl7v2:SPM.25 | hl7v2:SPM.26 | hl7v2:SPM.27 | hl7v2:SPM.28 | hl7v2:SPM.29 (rule-reference: d20e13510-true-d878730e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d878696e16-true-d878747e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2/*[not(self::hl7v2:EIP.1 | self::hl7v2:EIP.2)]"
                 priority="1412"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d878696e16-true-d878747e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EIP.1 | hl7v2:EIP.2 (rule-reference: d878696e16-true-d878747e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d878740e18-true-d878760e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2/hl7v2:EIP.1/*[not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1411"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d878740e18-true-d878760e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d878740e18-true-d878760e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d878740e47-true-d878797e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2/hl7v2:EIP.2/*[not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1410"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d878740e47-true-d878797e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d878740e47-true-d878797e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d878696e30-true-d878832e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3/*[not(self::hl7v2:EIP.1 | self::hl7v2:EIP.2)]"
                 priority="1409"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d878696e30-true-d878832e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EIP.1 | hl7v2:EIP.2 (rule-reference: d878696e30-true-d878832e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d878825e39-true-d878845e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3/hl7v2:EIP.1/*[not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1408"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d878825e39-true-d878845e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d878825e39-true-d878845e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d878825e68-true-d878882e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3/hl7v2:EIP.2/*[not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1407"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d878825e68-true-d878882e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d878825e68-true-d878882e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d878696e66-true-d878924e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.4/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1406"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d878696e66-true-d878924e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d878696e66-true-d878924e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d878696e92-true-d878996e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.5/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1405"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d878696e92-true-d878996e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d878696e92-true-d878996e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d878696e115-true-d879068e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.6/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1404"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d878696e115-true-d879068e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d878696e115-true-d879068e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d878696e128-true-d879140e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.7/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1403"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d878696e128-true-d879140e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d878696e128-true-d879140e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d878696e154-true-d879212e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.8/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1402"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d878696e154-true-d879212e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d878696e154-true-d879212e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d878696e179-true-d879284e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.9/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1401"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d878696e179-true-d879284e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d878696e179-true-d879284e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d878696e192-true-d879356e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.10/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1400"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d878696e192-true-d879356e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d878696e192-true-d879356e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d878696e215-true-d879428e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.11/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1399"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d878696e215-true-d879428e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d878696e215-true-d879428e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d878696e228-true-d879493e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.12/*[not(self::hl7v2:CQ.1 | self::hl7v2:CQ.2)]"
                 priority="1398"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d878696e228-true-d879493e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CQ.1 | hl7v2:CQ.2 (rule-reference: d878696e228-true-d879493e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d879486e29-true-d879514e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.12/hl7v2:CQ.2/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1397"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d879486e29-true-d879514e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d879486e29-true-d879514e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d878696e264-true-d879580e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.15/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1396"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d878696e264-true-d879580e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d878696e264-true-d879580e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d878696e277-true-d879652e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.16/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1395"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d878696e277-true-d879652e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d878696e277-true-d879652e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d878696e290-true-d879717e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.17/*[not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1394"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d878696e290-true-d879717e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d878696e290-true-d879717e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d879710e21-true-d879728e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.17/hl7v2:DR.1/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1393"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d879710e21-true-d879728e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d879710e21-true-d879728e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d879710e32-true-d879751e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.17/hl7v2:DR.2/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1392"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d879710e32-true-d879751e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d879710e32-true-d879751e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d878696e308-true-d879774e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.18/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1391"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d878696e308-true-d879774e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d878696e308-true-d879774e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d878696e322-true-d879797e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.19/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1390"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d878696e322-true-d879797e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d878696e322-true-d879797e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d878696e347-true-d879833e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.21/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1389"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d878696e347-true-d879833e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d878696e347-true-d879833e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d878696e360-true-d879905e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.22/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1388"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d878696e360-true-d879905e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d878696e360-true-d879905e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d878696e373-true-d879977e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.23/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1387"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d878696e373-true-d879977e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d878696e373-true-d879977e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d878696e386-true-d880049e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.24/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1386"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d878696e386-true-d880049e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d878696e386-true-d880049e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d878696e399-true-d880114e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.25/*[not(self::hl7v2:CQ.1 | self::hl7v2:CQ.2)]"
                 priority="1385"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d878696e399-true-d880114e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CQ.1 | hl7v2:CQ.2 (rule-reference: d878696e399-true-d880114e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d880107e26-true-d880135e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.25/hl7v2:CQ.2/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1384"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d880107e26-true-d880135e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d880107e26-true-d880135e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d878696e421-true-d880195e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.27/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1383"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d878696e421-true-d880195e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d878696e421-true-d880195e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d878696e432-true-d880267e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.28/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1382"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d878696e432-true-d880267e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d878696e432-true-d880267e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d878696e445-true-d880339e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.29/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1381"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d878696e445-true-d880339e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d878696e445-true-d880339e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e13518-true-d880421e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/*[not(self::hl7v2:OBX.1 | self::hl7v2:OBX.2 | self::hl7v2:OBX.3 | self::hl7v2:OBX.4 | self::hl7v2:OBX.5 | self::hl7v2:OBX.6 | self::hl7v2:OBX.7 | self::hl7v2:OBX.8 | self::hl7v2:OBX.9 | self::hl7v2:OBX.10 | self::hl7v2:OBX.11 | self::hl7v2:OBX.12 | self::hl7v2:OBX.13 | self::hl7v2:OBX.14 | self::hl7v2:OBX.15 | self::hl7v2:OBX.16 | self::hl7v2:OBX.17 | self::hl7v2:OBX.18 | self::hl7v2:OBX.19)]"
                 priority="1380"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d20e13518-true-d880421e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:OBX.1 | hl7v2:OBX.2 | hl7v2:OBX.3 | hl7v2:OBX.4 | hl7v2:OBX.5 | hl7v2:OBX.6 | hl7v2:OBX.7 | hl7v2:OBX.8 | hl7v2:OBX.9 | hl7v2:OBX.10 | hl7v2:OBX.11 | hl7v2:OBX.12 | hl7v2:OBX.13 | hl7v2:OBX.14 | hl7v2:OBX.15 | hl7v2:OBX.16 | hl7v2:OBX.17 | hl7v2:OBX.18 | hl7v2:OBX.19 (rule-reference: d20e13518-true-d880421e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d880398e35-true-d880448e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.3/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1379"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d880398e35-true-d880448e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d880398e35-true-d880448e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d880398e74-true-d880511e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.6/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1378"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d880398e74-true-d880511e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d880398e74-true-d880511e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d880398e151-true-d880588e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.12/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1377"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d880398e151-true-d880588e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d880398e151-true-d880588e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d880398e173-true-d880617e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.14/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1376"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d880398e173-true-d880617e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d880398e173-true-d880617e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d880398e184-true-d880644e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.15/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1375"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d880398e184-true-d880644e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d880398e184-true-d880644e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d880398e195-true-d880712e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/*[not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="1374"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d880398e195-true-d880712e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d880398e195-true-d880712e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d880684e32-true-d880732e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/*[not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="1373"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d880684e32-true-d880732e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d880684e32-true-d880732e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d880684e123-true-d880810e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1372"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d880684e123-true-d880810e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d880684e123-true-d880810e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d880684e215-true-d880864e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1371"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d880684e215-true-d880864e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d880684e215-true-d880864e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d880684e275-true-d880903e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1370"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d880684e275-true-d880903e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d880684e275-true-d880903e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d880684e288-true-d880950e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/*[not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1369"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d880684e288-true-d880950e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d880684e288-true-d880950e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d880943e17-true-d880961e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1368"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d880943e17-true-d880961e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d880943e17-true-d880961e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d880943e28-true-d880984e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1367"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d880943e28-true-d880984e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d880943e28-true-d880984e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d880684e318-true-d881013e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1366"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d880684e318-true-d881013e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d880684e318-true-d881013e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d880684e329-true-d881036e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1365"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d880684e329-true-d881036e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d880684e329-true-d881036e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d880684e351-true-d881072e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1364"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d880684e351-true-d881072e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d880684e351-true-d881072e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d880684e369-true-d881144e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1363"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d880684e369-true-d881144e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d880684e369-true-d881144e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d880398e206-true-d881213e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.17/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1362"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d880398e206-true-d881213e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d880398e206-true-d881213e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d880398e217-true-d881262e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.18/*[not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1361"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d880398e217-true-d881262e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d880398e217-true-d881262e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d880398e228-true-d881297e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.19/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1360"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d880398e228-true-d881297e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d880398e228-true-d881297e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e13520-true-d881317e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/*[not(self::hl7v2:SAC | self::hl7v2:INV)]"
                 priority="1359"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d20e13520-true-d881317e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:SAC | hl7v2:INV (rule-reference: d20e13520-true-d881317e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e13522-true-d881370e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/*[not(self::hl7v2:SAC.1 | self::hl7v2:SAC.2 | self::hl7v2:SAC.3 | self::hl7v2:SAC.4 | self::hl7v2:SAC.5 | self::hl7v2:SAC.6 | self::hl7v2:SAC.7 | self::hl7v2:SAC.8 | self::hl7v2:SAC.9 | self::hl7v2:SAC.10 | self::hl7v2:SAC.11 | self::hl7v2:SAC.12 | self::hl7v2:SAC.13 | self::hl7v2:SAC.14 | self::hl7v2:SAC.15 | self::hl7v2:SAC.16 | self::hl7v2:SAC.17 | self::hl7v2:SAC.18 | self::hl7v2:SAC.19 | self::hl7v2:SAC.20 | self::hl7v2:SAC.21 | self::hl7v2:SAC.22 | self::hl7v2:SAC.23 | self::hl7v2:SAC.24 | self::hl7v2:SAC.25 | self::hl7v2:SAC.26 | self::hl7v2:SAC.27 | self::hl7v2:SAC.28 | self::hl7v2:SAC.29 | self::hl7v2:SAC.30 | self::hl7v2:SAC.31 | self::hl7v2:SAC.32 | self::hl7v2:SAC.33 | self::hl7v2:SAC.34 | self::hl7v2:SAC.35 | self::hl7v2:SAC.36 | self::hl7v2:SAC.37 | self::hl7v2:SAC.38 | self::hl7v2:SAC.39 | self::hl7v2:SAC.40 | self::hl7v2:SAC.41 | self::hl7v2:SAC.42 | self::hl7v2:SAC.43 | self::hl7v2:SAC.44)]"
                 priority="1358"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d20e13522-true-d881370e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:SAC.1 | hl7v2:SAC.2 | hl7v2:SAC.3 | hl7v2:SAC.4 | hl7v2:SAC.5 | hl7v2:SAC.6 | hl7v2:SAC.7 | hl7v2:SAC.8 | hl7v2:SAC.9 | hl7v2:SAC.10 | hl7v2:SAC.11 | hl7v2:SAC.12 | hl7v2:SAC.13 | hl7v2:SAC.14 | hl7v2:SAC.15 | hl7v2:SAC.16 | hl7v2:SAC.17 | hl7v2:SAC.18 | hl7v2:SAC.19 | hl7v2:SAC.20 | hl7v2:SAC.21 | hl7v2:SAC.22 | hl7v2:SAC.23 | hl7v2:SAC.24 | hl7v2:SAC.25 | hl7v2:SAC.26 | hl7v2:SAC.27 | hl7v2:SAC.28 | hl7v2:SAC.29 | hl7v2:SAC.30 | hl7v2:SAC.31 | hl7v2:SAC.32 | hl7v2:SAC.33 | hl7v2:SAC.34 | hl7v2:SAC.35 | hl7v2:SAC.36 | hl7v2:SAC.37 | hl7v2:SAC.38 | hl7v2:SAC.39 | hl7v2:SAC.40 | hl7v2:SAC.41 | hl7v2:SAC.42 | hl7v2:SAC.43 | hl7v2:SAC.44 (rule-reference: d20e13522-true-d881370e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d881322e1-true-d881383e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.1/*[not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1357"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d881322e1-true-d881383e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d881322e1-true-d881383e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d881322e12-true-d881420e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.2/*[not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1356"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d881322e12-true-d881420e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d881322e12-true-d881420e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d881322e23-true-d881457e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.3/*[not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1355"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d881322e23-true-d881457e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d881322e23-true-d881457e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d881322e34-true-d881494e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.4/*[not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1354"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d881322e34-true-d881494e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d881322e34-true-d881494e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d881322e45-true-d881531e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.5/*[not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1353"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d881322e45-true-d881531e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d881322e45-true-d881531e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d881322e56-true-d881571e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/*[not(self::hl7v2:SPS.1 | self::hl7v2:SPS.2 | self::hl7v2:SPS.3 | self::hl7v2:SPS.4 | self::hl7v2:SPS.5 | self::hl7v2:SPS.6 | self::hl7v2:SPS.7)]"
                 priority="1352"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d881322e56-true-d881571e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:SPS.1 | hl7v2:SPS.2 | hl7v2:SPS.3 | hl7v2:SPS.4 | hl7v2:SPS.5 | hl7v2:SPS.6 | hl7v2:SPS.7 (rule-reference: d881322e56-true-d881571e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d881559e15-true-d881589e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.1/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1351"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d881559e15-true-d881589e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d881559e15-true-d881589e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d881559e44-true-d881661e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.2/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1350"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d881559e44-true-d881661e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d881559e44-true-d881661e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d881559e57-true-d881725e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.3/*[not(self::hl7v2:escape)]"
                 priority="1349"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d881559e57-true-d881725e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d881559e57-true-d881725e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d881719e11-true-d881735e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.3/hl7v2:escape/*[not(self::hl7v2:escape)]"
                 priority="1348"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d881719e11-true-d881735e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d881719e11-true-d881735e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d881729e5-true-d881745e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.3/hl7v2:escape/hl7v2:escape/*[not(self::hl7v2:escape)]"
                 priority="1347"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d881729e5-true-d881745e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d881729e5-true-d881745e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d881559e68-true-d881767e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.4/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1346"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d881559e68-true-d881767e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d881559e68-true-d881767e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d881559e93-true-d881839e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.5/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1345"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d881559e93-true-d881839e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d881559e93-true-d881839e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d881559e106-true-d881911e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.6/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1344"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d881559e106-true-d881911e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d881559e106-true-d881911e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d881559e117-true-d881983e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.7/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1343"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d881559e117-true-d881983e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d881559e117-true-d881983e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d881322e67-true-d882048e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.7/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1342"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d881322e67-true-d882048e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d881322e67-true-d882048e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d881322e78-true-d882075e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.8/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1341"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d881322e78-true-d882075e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d881322e78-true-d882075e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d881322e91-true-d882126e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.9/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1340"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d881322e91-true-d882126e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d881322e91-true-d882126e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d881322e104-true-d882175e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.10/*[not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1339"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d881322e104-true-d882175e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d881322e104-true-d882175e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d881322e115-true-d882212e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.11/*[not(self::hl7v2:NA.1 | self::hl7v2:NA.2 | self::hl7v2:NA.3 | self::hl7v2:NA.4)]"
                 priority="1338"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d881322e115-true-d882212e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:NA.1 | hl7v2:NA.2 | hl7v2:NA.3 | hl7v2:NA.4 (rule-reference: d881322e115-true-d882212e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d881322e127-true-d882251e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.12/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1337"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d881322e127-true-d882251e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d881322e127-true-d882251e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d881322e140-true-d882300e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.13/*[not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1336"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d881322e140-true-d882300e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d881322e140-true-d882300e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d881322e151-true-d882337e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.14/*[not(self::hl7v2:NA.1 | self::hl7v2:NA.2 | self::hl7v2:NA.3 | self::hl7v2:NA.4)]"
                 priority="1335"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d881322e151-true-d882337e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:NA.1 | hl7v2:NA.2 | hl7v2:NA.3 | hl7v2:NA.4 (rule-reference: d881322e151-true-d882337e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d881322e162-true-d882376e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.15/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1334"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d881322e162-true-d882376e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d881322e162-true-d882376e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d881322e217-true-d882451e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.20/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1333"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d881322e217-true-d882451e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d881322e217-true-d882451e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d881322e262-true-d882520e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.24/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1332"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d881322e262-true-d882520e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d881322e262-true-d882520e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d881322e273-true-d882571e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.25/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1331"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d881322e273-true-d882571e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d881322e273-true-d882571e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d881322e286-true-d882622e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.26/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1330"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d881322e286-true-d882622e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d881322e286-true-d882622e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d881322e299-true-d882676e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.27/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1329"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d881322e299-true-d882676e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d881322e299-true-d882676e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d881322e312-true-d882745e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.28/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1328"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d881322e312-true-d882745e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d881322e312-true-d882745e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d881322e323-true-d882794e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.29/*[not(self::hl7v2:SN.1 | self::hl7v2:SN.2 | self::hl7v2:SN.3 | self::hl7v2:SN.4)]"
                 priority="1327"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d881322e323-true-d882794e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:SN.1 | hl7v2:SN.2 | hl7v2:SN.3 | hl7v2:SN.4 (rule-reference: d881322e323-true-d882794e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d881322e334-true-d882833e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.30/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1326"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d881322e334-true-d882833e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d881322e334-true-d882833e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d881322e347-true-d882882e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.31/*[not(self::hl7v2:SN.1 | self::hl7v2:SN.2 | self::hl7v2:SN.3 | self::hl7v2:SN.4)]"
                 priority="1325"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d881322e347-true-d882882e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:SN.1 | hl7v2:SN.2 | hl7v2:SN.3 | hl7v2:SN.4 (rule-reference: d881322e347-true-d882882e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d881322e369-true-d882927e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.33/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1324"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d881322e369-true-d882927e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d881322e369-true-d882927e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d881322e392-true-d882984e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.35/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1323"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d881322e392-true-d882984e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d881322e392-true-d882984e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d881322e414-true-d883041e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.37/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1322"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d881322e414-true-d883041e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d881322e414-true-d883041e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d881322e436-true-d883098e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.39/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1321"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d881322e436-true-d883098e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d881322e436-true-d883098e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d881322e447-true-d883149e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.40/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1320"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d881322e447-true-d883149e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d881322e447-true-d883149e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d881322e460-true-d883200e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.41/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1319"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d881322e460-true-d883200e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d881322e460-true-d883200e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d881322e473-true-d883251e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.42/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1318"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d881322e473-true-d883251e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d881322e473-true-d883251e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d881322e486-true-d883305e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.43/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1317"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d881322e486-true-d883305e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d881322e486-true-d883305e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d881322e499-true-d883374e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.44/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1316"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d881322e499-true-d883374e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d881322e499-true-d883374e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e13524-true-d883439e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/*[not(self::hl7v2:INV.1 | self::hl7v2:INV.2 | self::hl7v2:INV.3 | self::hl7v2:INV.4 | self::hl7v2:INV.5 | self::hl7v2:INV.6 | self::hl7v2:INV.7 | self::hl7v2:INV.8 | self::hl7v2:INV.9 | self::hl7v2:INV.10 | self::hl7v2:INV.11 | self::hl7v2:INV.12 | self::hl7v2:INV.13 | self::hl7v2:INV.14 | self::hl7v2:INV.15 | self::hl7v2:INV.16 | self::hl7v2:INV.17 | self::hl7v2:INV.18 | self::hl7v2:INV.19 | self::hl7v2:INV.20)]"
                 priority="1315"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d20e13524-true-d883439e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:INV.1 | hl7v2:INV.2 | hl7v2:INV.3 | hl7v2:INV.4 | hl7v2:INV.5 | hl7v2:INV.6 | hl7v2:INV.7 | hl7v2:INV.8 | hl7v2:INV.9 | hl7v2:INV.10 | hl7v2:INV.11 | hl7v2:INV.12 | hl7v2:INV.13 | hl7v2:INV.14 | hl7v2:INV.15 | hl7v2:INV.16 | hl7v2:INV.17 | hl7v2:INV.18 | hl7v2:INV.19 | hl7v2:INV.20 (rule-reference: d20e13524-true-d883439e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d883415e1-true-d883454e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.1/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1314"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d883415e1-true-d883454e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d883415e1-true-d883454e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d883415e14-true-d883505e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.2/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1313"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d883415e14-true-d883505e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d883415e14-true-d883505e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d883415e27-true-d883556e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.3/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1312"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d883415e27-true-d883556e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d883415e27-true-d883556e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d883415e40-true-d883607e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.4/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1311"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d883415e40-true-d883607e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d883415e40-true-d883607e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d883415e51-true-d883658e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.5/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1310"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d883415e51-true-d883658e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d883415e51-true-d883658e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d883415e62-true-d883709e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.6/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1309"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d883415e62-true-d883709e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d883415e62-true-d883709e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d883415e117-true-d883784e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.11/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1308"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d883415e117-true-d883784e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d883415e117-true-d883784e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d883415e129-true-d883831e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.12/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1307"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d883415e129-true-d883831e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d883415e129-true-d883831e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d883415e140-true-d883854e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.13/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1306"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d883415e140-true-d883854e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d883415e140-true-d883854e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d883415e151-true-d883887e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/*[not(self::hl7v2:TQ.1 | self::hl7v2:TQ.2 | self::hl7v2:TQ.3 | self::hl7v2:TQ.4 | self::hl7v2:TQ.5 | self::hl7v2:TQ.6 | self::hl7v2:TQ.7 | self::hl7v2:TQ.8 | self::hl7v2:TQ.9 | self::hl7v2:TQ.10 | self::hl7v2:TQ.11 | self::hl7v2:TQ.12)]"
                 priority="1305"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d883415e151-true-d883887e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TQ.1 | hl7v2:TQ.2 | hl7v2:TQ.3 | hl7v2:TQ.4 | hl7v2:TQ.5 | hl7v2:TQ.6 | hl7v2:TQ.7 | hl7v2:TQ.8 | hl7v2:TQ.9 | hl7v2:TQ.10 | hl7v2:TQ.11 | hl7v2:TQ.12 (rule-reference: d883415e151-true-d883887e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d883870e15-true-d883898e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.1/*[not(self::hl7v2:CQ.1 | self::hl7v2:CQ.2)]"
                 priority="1304"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d883870e15-true-d883898e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CQ.1 | hl7v2:CQ.2 (rule-reference: d883870e15-true-d883898e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d883891e31-true-d883919e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.1/hl7v2:CQ.2/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1303"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d883891e31-true-d883919e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d883891e31-true-d883919e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d883870e35-true-d883966e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.2/*[not(self::hl7v2:RI.1 | self::hl7v2:RI.2)]"
                 priority="1302"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d883870e35-true-d883966e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:RI.1 | hl7v2:RI.2 (rule-reference: d883870e35-true-d883966e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d883870e189-true-d883995e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.4/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1301"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d883870e189-true-d883995e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d883870e189-true-d883995e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d883870e206-true-d884018e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.5/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1300"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d883870e206-true-d884018e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d883870e206-true-d884018e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d883870e461-true-d884052e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.8/*[not(self::hl7v2:escape)]"
                 priority="1299"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d883870e461-true-d884052e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d883870e461-true-d884052e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d884046e11-true-d884062e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.8/hl7v2:escape/*[not(self::hl7v2:escape)]"
                 priority="1298"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d884046e11-true-d884062e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d884046e11-true-d884062e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d884056e5-true-d884072e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.8/hl7v2:escape/hl7v2:escape/*[not(self::hl7v2:escape)]"
                 priority="1297"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d884056e5-true-d884072e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d884056e5-true-d884072e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d883870e485-true-d884102e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.10/*[not(self::hl7v2:OSD.1 | self::hl7v2:OSD.2 | self::hl7v2:OSD.3 | self::hl7v2:OSD.4 | self::hl7v2:OSD.5 | self::hl7v2:OSD.6 | self::hl7v2:OSD.7 | self::hl7v2:OSD.8 | self::hl7v2:OSD.9 | self::hl7v2:OSD.10 | self::hl7v2:OSD.11)]"
                 priority="1296"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d883870e485-true-d884102e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:OSD.1 | hl7v2:OSD.2 | hl7v2:OSD.3 | hl7v2:OSD.4 | hl7v2:OSD.5 | hl7v2:OSD.6 | hl7v2:OSD.7 | hl7v2:OSD.8 | hl7v2:OSD.9 | hl7v2:OSD.10 | hl7v2:OSD.11 (rule-reference: d883870e485-true-d884102e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d883870e505-true-d884183e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.11/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1295"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d883870e505-true-d884183e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d883870e505-true-d884183e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d883415e162-true-d884240e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.15/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1294"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d883415e162-true-d884240e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d883415e162-true-d884240e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d883415e184-true-d884297e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.17/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1293"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d883415e184-true-d884297e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d883415e184-true-d884297e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d883415e197-true-d884348e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.18/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1292"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d883415e197-true-d884348e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d883415e197-true-d884348e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d883415e210-true-d884395e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.19/*[not(self::hl7v2:CQ.1 | self::hl7v2:CQ.2)]"
                 priority="1291"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d883415e210-true-d884395e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CQ.1 | hl7v2:CQ.2 (rule-reference: d883415e210-true-d884395e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d884388e26-true-d884416e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.19/hl7v2:CQ.2/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1290"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d884388e26-true-d884416e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d884388e26-true-d884416e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d883415e221-true-d884463e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.20/*[not(self::hl7v2:CQ.1 | self::hl7v2:CQ.2)]"
                 priority="1289"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d883415e221-true-d884463e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CQ.1 | hl7v2:CQ.2 (rule-reference: d883415e221-true-d884463e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d884456e26-true-d884484e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.20/hl7v2:CQ.2/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1288"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d884456e26-true-d884484e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d884456e26-true-d884484e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e13527-true-d884532e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/*[not(self::hl7v2:OBR | self::hl7v2:ORC | self::hl7v2:NTE | self::hl7v2:OUL_R22.TIMING_QTY | self::hl7v2:OUL_R22.RESULT | self::hl7v2:CTI)]"
                 priority="1287"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d20e13527-true-d884532e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:OBR | hl7v2:ORC | hl7v2:NTE | hl7v2:OUL_R22.TIMING_QTY | hl7v2:OUL_R22.RESULT | hl7v2:CTI (rule-reference: d20e13527-true-d884532e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e13529-true-d884590e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/*[not(self::hl7v2:OBR.1 | self::hl7v2:OBR.2 | self::hl7v2:OBR.3 | self::hl7v2:OBR.4 | self::hl7v2:OBR.5 | self::hl7v2:OBR.6 | self::hl7v2:OBR.7 | self::hl7v2:OBR.8 | self::hl7v2:OBR.9 | self::hl7v2:OBR.10 | self::hl7v2:OBR.11 | self::hl7v2:OBR.12 | self::hl7v2:OBR.13 | self::hl7v2:OBR.14 | self::hl7v2:OBR.15 | self::hl7v2:OBR.16 | self::hl7v2:OBR.17 | self::hl7v2:OBR.18 | self::hl7v2:OBR.19 | self::hl7v2:OBR.20 | self::hl7v2:OBR.21 | self::hl7v2:OBR.22 | self::hl7v2:OBR.23 | self::hl7v2:OBR.24 | self::hl7v2:OBR.25 | self::hl7v2:OBR.26 | self::hl7v2:OBR.27 | self::hl7v2:OBR.28 | self::hl7v2:OBR.29 | self::hl7v2:OBR.30 | self::hl7v2:OBR.31 | self::hl7v2:OBR.32 | self::hl7v2:OBR.33 | self::hl7v2:OBR.34 | self::hl7v2:OBR.35 | self::hl7v2:OBR.36 | self::hl7v2:OBR.37 | self::hl7v2:OBR.38 | self::hl7v2:OBR.39 | self::hl7v2:OBR.40 | self::hl7v2:OBR.41 | self::hl7v2:OBR.42 | self::hl7v2:OBR.43 | self::hl7v2:OBR.44 | self::hl7v2:OBR.45 | self::hl7v2:OBR.46 | self::hl7v2:OBR.47 | self::hl7v2:OBR.48 | self::hl7v2:OBR.49)]"
                 priority="1286"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d20e13529-true-d884590e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:OBR.1 | hl7v2:OBR.2 | hl7v2:OBR.3 | hl7v2:OBR.4 | hl7v2:OBR.5 | hl7v2:OBR.6 | hl7v2:OBR.7 | hl7v2:OBR.8 | hl7v2:OBR.9 | hl7v2:OBR.10 | hl7v2:OBR.11 | hl7v2:OBR.12 | hl7v2:OBR.13 | hl7v2:OBR.14 | hl7v2:OBR.15 | hl7v2:OBR.16 | hl7v2:OBR.17 | hl7v2:OBR.18 | hl7v2:OBR.19 | hl7v2:OBR.20 | hl7v2:OBR.21 | hl7v2:OBR.22 | hl7v2:OBR.23 | hl7v2:OBR.24 | hl7v2:OBR.25 | hl7v2:OBR.26 | hl7v2:OBR.27 | hl7v2:OBR.28 | hl7v2:OBR.29 | hl7v2:OBR.30 | hl7v2:OBR.31 | hl7v2:OBR.32 | hl7v2:OBR.33 | hl7v2:OBR.34 | hl7v2:OBR.35 | hl7v2:OBR.36 | hl7v2:OBR.37 | hl7v2:OBR.38 | hl7v2:OBR.39 | hl7v2:OBR.40 | hl7v2:OBR.41 | hl7v2:OBR.42 | hl7v2:OBR.43 | hl7v2:OBR.44 | hl7v2:OBR.45 | hl7v2:OBR.46 | hl7v2:OBR.47 | hl7v2:OBR.48 | hl7v2:OBR.49 (rule-reference: d20e13529-true-d884590e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d884536e19-true-d884609e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.2/*[not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1285"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d884536e19-true-d884609e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d884536e19-true-d884609e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d884536e33-true-d884646e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.3/*[not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1284"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d884536e33-true-d884646e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d884536e33-true-d884646e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d884536e47-true-d884685e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.4/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1283"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d884536e47-true-d884685e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d884536e47-true-d884685e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d884536e81-true-d884738e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.6/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1282"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d884536e81-true-d884738e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d884536e81-true-d884738e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d884536e101-true-d884761e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.7/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1281"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d884536e101-true-d884761e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d884536e101-true-d884761e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d884536e112-true-d884784e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.8/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1280"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d884536e112-true-d884784e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d884536e112-true-d884784e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d884536e124-true-d884807e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.9/*[not(self::hl7v2:CQ.1 | self::hl7v2:CQ.2)]"
                 priority="1279"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d884536e124-true-d884807e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CQ.1 | hl7v2:CQ.2 (rule-reference: d884536e124-true-d884807e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d884800e26-true-d884828e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.9/hl7v2:CQ.2/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1278"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d884800e26-true-d884828e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d884800e26-true-d884828e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d884536e135-true-d884896e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/*[not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="1277"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d884536e135-true-d884896e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d884536e135-true-d884896e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d884868e32-true-d884916e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.2/*[not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="1276"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d884868e32-true-d884916e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d884868e32-true-d884916e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d884868e123-true-d884994e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.9/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1275"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d884868e123-true-d884994e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d884868e123-true-d884994e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d884868e215-true-d885048e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.14/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1274"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d884868e215-true-d885048e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d884868e215-true-d885048e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d884868e275-true-d885087e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.16/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1273"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d884868e275-true-d885087e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d884868e275-true-d885087e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d884868e288-true-d885134e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.17/*[not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1272"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d884868e288-true-d885134e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d884868e288-true-d885134e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d885127e17-true-d885145e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.17/hl7v2:DR.1/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1271"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d885127e17-true-d885145e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d885127e17-true-d885145e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d885127e28-true-d885168e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.17/hl7v2:DR.2/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1270"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d885127e28-true-d885168e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d885127e28-true-d885168e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d884868e318-true-d885197e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.19/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1269"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d884868e318-true-d885197e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d884868e318-true-d885197e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d884868e329-true-d885220e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.20/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1268"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d884868e329-true-d885220e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d884868e329-true-d885220e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d884868e351-true-d885256e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1267"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d884868e351-true-d885256e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d884868e351-true-d885256e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d884868e369-true-d885328e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1266"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d884868e369-true-d885328e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d884868e369-true-d885328e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d884536e159-true-d885403e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.12/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1265"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d884536e159-true-d885403e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d884536e159-true-d885403e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d884536e181-true-d885456e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.14/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1264"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d884536e181-true-d885456e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d884536e181-true-d885456e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d884536e213-true-d885484e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/*[not(self::hl7v2:SPS.1 | self::hl7v2:SPS.2 | self::hl7v2:SPS.3 | self::hl7v2:SPS.4 | self::hl7v2:SPS.5 | self::hl7v2:SPS.6 | self::hl7v2:SPS.7)]"
                 priority="1263"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d884536e213-true-d885484e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:SPS.1 | hl7v2:SPS.2 | hl7v2:SPS.3 | hl7v2:SPS.4 | hl7v2:SPS.5 | hl7v2:SPS.6 | hl7v2:SPS.7 (rule-reference: d884536e213-true-d885484e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d885472e24-true-d885502e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1262"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d885472e24-true-d885502e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d885472e24-true-d885502e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d885472e53-true-d885574e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1261"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d885472e53-true-d885574e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d885472e53-true-d885574e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d885472e66-true-d885638e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.3/*[not(self::hl7v2:escape)]"
                 priority="1260"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d885472e66-true-d885638e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d885472e66-true-d885638e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d885632e11-true-d885648e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.3/hl7v2:escape/*[not(self::hl7v2:escape)]"
                 priority="1259"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d885632e11-true-d885648e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d885632e11-true-d885648e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d885642e5-true-d885658e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.3/hl7v2:escape/hl7v2:escape/*[not(self::hl7v2:escape)]"
                 priority="1258"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d885642e5-true-d885658e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d885642e5-true-d885658e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d885472e77-true-d885680e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1257"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d885472e77-true-d885680e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d885472e77-true-d885680e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d885472e102-true-d885752e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1256"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d885472e102-true-d885752e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d885472e102-true-d885752e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d885472e115-true-d885824e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1255"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d885472e115-true-d885824e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d885472e115-true-d885824e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d885472e126-true-d885896e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1254"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d885472e126-true-d885896e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d885472e126-true-d885896e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d884536e233-true-d885982e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/*[not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="1253"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d884536e233-true-d885982e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d884536e233-true-d885982e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d885954e35-true-d886002e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.2/*[not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="1252"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d885954e35-true-d886002e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d885954e35-true-d886002e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d885954e126-true-d886080e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.9/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1251"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d885954e126-true-d886080e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d885954e126-true-d886080e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d885954e218-true-d886134e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.14/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1250"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d885954e218-true-d886134e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d885954e218-true-d886134e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d885954e278-true-d886173e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.16/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1249"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d885954e278-true-d886173e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d885954e278-true-d886173e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d885954e291-true-d886220e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.17/*[not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1248"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d885954e291-true-d886220e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d885954e291-true-d886220e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d886213e17-true-d886231e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.17/hl7v2:DR.1/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1247"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d886213e17-true-d886231e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d886213e17-true-d886231e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d886213e28-true-d886254e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.17/hl7v2:DR.2/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1246"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d886213e28-true-d886254e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d886213e28-true-d886254e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d885954e321-true-d886283e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.19/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1245"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d885954e321-true-d886283e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d885954e321-true-d886283e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d885954e332-true-d886306e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.20/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1244"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d885954e332-true-d886306e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d885954e332-true-d886306e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d885954e355-true-d886342e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1243"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d885954e355-true-d886342e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d885954e355-true-d886342e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d885954e372-true-d886414e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1242"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d885954e372-true-d886414e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d885954e372-true-d886414e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d884536e247-true-d886489e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.17/*[not(self::hl7v2:XTN.1 | self::hl7v2:XTN.2 | self::hl7v2:XTN.3 | self::hl7v2:XTN.4 | self::hl7v2:XTN.5 | self::hl7v2:XTN.6 | self::hl7v2:XTN.7 | self::hl7v2:XTN.8 | self::hl7v2:XTN.9 | self::hl7v2:XTN.10 | self::hl7v2:XTN.11 | self::hl7v2:XTN.12)]"
                 priority="1241"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d884536e247-true-d886489e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XTN.1 | hl7v2:XTN.2 | hl7v2:XTN.3 | hl7v2:XTN.4 | hl7v2:XTN.5 | hl7v2:XTN.6 | hl7v2:XTN.7 | hl7v2:XTN.8 | hl7v2:XTN.9 | hl7v2:XTN.10 | hl7v2:XTN.11 | hl7v2:XTN.12 (rule-reference: d884536e247-true-d886489e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d884536e306-true-d886596e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.22/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1240"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d884536e306-true-d886596e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d884536e306-true-d886596e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d884536e317-true-d886619e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.23/*[not(self::hl7v2:MOC.1 | self::hl7v2:MOC.2)]"
                 priority="1239"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d884536e317-true-d886619e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:MOC.1 | hl7v2:MOC.2 (rule-reference: d884536e317-true-d886619e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d886612e15-true-d886630e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.1/*[not(self::hl7v2:MO.1 | self::hl7v2:MO.2)]"
                 priority="1238"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d886612e15-true-d886630e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:MO.1 | hl7v2:MO.2 (rule-reference: d886612e15-true-d886630e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d886612e26-true-d886657e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.2/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1237"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d886612e26-true-d886657e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d886612e26-true-d886657e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d884536e361-true-d886717e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.26/*[not(self::hl7v2:PRL.1 | self::hl7v2:PRL.2 | self::hl7v2:PRL.3)]"
                 priority="1236"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d884536e361-true-d886717e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:PRL.1 | hl7v2:PRL.2 | hl7v2:PRL.3 (rule-reference: d884536e361-true-d886717e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d886709e48-true-d886732e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.1/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1235"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d886709e48-true-d886732e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d886709e48-true-d886732e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d886709e70-true-d886784e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.3/*[not(self::hl7v2:escape)]"
                 priority="1234"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d886709e70-true-d886784e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d886709e70-true-d886784e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d886778e17-true-d886794e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.3/hl7v2:escape/*[not(self::hl7v2:escape)]"
                 priority="1233"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d886778e17-true-d886794e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d886778e17-true-d886794e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d886788e5-true-d886804e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.3/hl7v2:escape/hl7v2:escape/*[not(self::hl7v2:escape)]"
                 priority="1232"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d886788e5-true-d886804e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d886788e5-true-d886804e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d884536e406-true-d886829e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/*[not(self::hl7v2:TQ.1 | self::hl7v2:TQ.2 | self::hl7v2:TQ.3 | self::hl7v2:TQ.4 | self::hl7v2:TQ.5 | self::hl7v2:TQ.6 | self::hl7v2:TQ.7 | self::hl7v2:TQ.8 | self::hl7v2:TQ.9 | self::hl7v2:TQ.10 | self::hl7v2:TQ.11 | self::hl7v2:TQ.12)]"
                 priority="1231"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d884536e406-true-d886829e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TQ.1 | hl7v2:TQ.2 | hl7v2:TQ.3 | hl7v2:TQ.4 | hl7v2:TQ.5 | hl7v2:TQ.6 | hl7v2:TQ.7 | hl7v2:TQ.8 | hl7v2:TQ.9 | hl7v2:TQ.10 | hl7v2:TQ.11 | hl7v2:TQ.12 (rule-reference: d884536e406-true-d886829e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d886812e36-true-d886840e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/*[not(self::hl7v2:CQ.1 | self::hl7v2:CQ.2)]"
                 priority="1230"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d886812e36-true-d886840e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CQ.1 | hl7v2:CQ.2 (rule-reference: d886812e36-true-d886840e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d886833e31-true-d886861e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/hl7v2:CQ.2/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1229"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d886833e31-true-d886861e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d886833e31-true-d886861e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d886812e56-true-d886908e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.2/*[not(self::hl7v2:RI.1 | self::hl7v2:RI.2)]"
                 priority="1228"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d886812e56-true-d886908e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:RI.1 | hl7v2:RI.2 (rule-reference: d886812e56-true-d886908e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d886812e210-true-d886937e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.4/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1227"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d886812e210-true-d886937e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d886812e210-true-d886937e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d886812e227-true-d886960e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.5/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1226"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d886812e227-true-d886960e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d886812e227-true-d886960e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d886812e482-true-d886994e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.8/*[not(self::hl7v2:escape)]"
                 priority="1225"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d886812e482-true-d886994e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d886812e482-true-d886994e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d886988e11-true-d887004e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.8/hl7v2:escape/*[not(self::hl7v2:escape)]"
                 priority="1224"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d886988e11-true-d887004e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d886988e11-true-d887004e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d886998e5-true-d887014e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.8/hl7v2:escape/hl7v2:escape/*[not(self::hl7v2:escape)]"
                 priority="1223"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d886998e5-true-d887014e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d886998e5-true-d887014e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d886812e507-true-d887044e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/*[not(self::hl7v2:OSD.1 | self::hl7v2:OSD.2 | self::hl7v2:OSD.3 | self::hl7v2:OSD.4 | self::hl7v2:OSD.5 | self::hl7v2:OSD.6 | self::hl7v2:OSD.7 | self::hl7v2:OSD.8 | self::hl7v2:OSD.9 | self::hl7v2:OSD.10 | self::hl7v2:OSD.11)]"
                 priority="1222"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d886812e507-true-d887044e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:OSD.1 | hl7v2:OSD.2 | hl7v2:OSD.3 | hl7v2:OSD.4 | hl7v2:OSD.5 | hl7v2:OSD.6 | hl7v2:OSD.7 | hl7v2:OSD.8 | hl7v2:OSD.9 | hl7v2:OSD.10 | hl7v2:OSD.11 (rule-reference: d886812e507-true-d887044e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d886812e527-true-d887125e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.11/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1221"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d886812e527-true-d887125e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d886812e527-true-d887125e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d884536e438-true-d887199e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/*[not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="1220"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d884536e438-true-d887199e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d884536e438-true-d887199e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d887171e32-true-d887219e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.2/*[not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="1219"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d887171e32-true-d887219e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d887171e32-true-d887219e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d887171e123-true-d887297e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.9/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1218"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d887171e123-true-d887297e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d887171e123-true-d887297e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d887171e215-true-d887351e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.14/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1217"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d887171e215-true-d887351e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d887171e215-true-d887351e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d887171e275-true-d887390e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.16/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1216"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d887171e275-true-d887390e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d887171e275-true-d887390e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d887171e288-true-d887437e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.17/*[not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1215"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d887171e288-true-d887437e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d887171e288-true-d887437e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d887430e17-true-d887448e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.17/hl7v2:DR.1/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1214"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d887430e17-true-d887448e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d887430e17-true-d887448e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d887430e28-true-d887471e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.17/hl7v2:DR.2/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1213"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d887430e28-true-d887471e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d887430e28-true-d887471e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d887171e318-true-d887500e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.19/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1212"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d887171e318-true-d887500e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d887171e318-true-d887500e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d887171e329-true-d887523e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.20/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1211"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d887171e329-true-d887523e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d887171e329-true-d887523e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d887171e351-true-d887559e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1210"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d887171e351-true-d887559e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d887171e351-true-d887559e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d887171e369-true-d887631e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1209"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d887171e369-true-d887631e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d887171e369-true-d887631e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d884536e449-true-d887696e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.29/*[not(self::hl7v2:EIP.1 | self::hl7v2:EIP.2)]"
                 priority="1208"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d884536e449-true-d887696e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EIP.1 | hl7v2:EIP.2 (rule-reference: d884536e449-true-d887696e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d887689e21-true-d887709e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.1/*[not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1207"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d887689e21-true-d887709e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d887689e21-true-d887709e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d887689e50-true-d887746e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.2/*[not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1206"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d887689e50-true-d887746e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d887689e50-true-d887746e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d884536e481-true-d887791e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.31/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1205"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d884536e481-true-d887791e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d884536e481-true-d887791e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d884536e498-true-d887847e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/*[not(self::hl7v2:NDL.1 | self::hl7v2:NDL.2 | self::hl7v2:NDL.3 | self::hl7v2:NDL.4 | self::hl7v2:NDL.5 | self::hl7v2:NDL.6 | self::hl7v2:NDL.7 | self::hl7v2:NDL.8 | self::hl7v2:NDL.9 | self::hl7v2:NDL.10 | self::hl7v2:NDL.11)]"
                 priority="1204"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d884536e498-true-d887847e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:NDL.1 | hl7v2:NDL.2 | hl7v2:NDL.3 | hl7v2:NDL.4 | hl7v2:NDL.5 | hl7v2:NDL.6 | hl7v2:NDL.7 | hl7v2:NDL.8 | hl7v2:NDL.9 | hl7v2:NDL.10 | hl7v2:NDL.11 (rule-reference: d884536e498-true-d887847e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d887831e15-true-d887867e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/*[not(self::hl7v2:CNN.1 | self::hl7v2:CNN.2 | self::hl7v2:CNN.3 | self::hl7v2:CNN.4 | self::hl7v2:CNN.5 | self::hl7v2:CNN.6 | self::hl7v2:CNN.7 | self::hl7v2:CNN.8 | self::hl7v2:CNN.9 | self::hl7v2:CNN.10 | self::hl7v2:CNN.11)]"
                 priority="1203"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d887831e15-true-d887867e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CNN.1 | hl7v2:CNN.2 | hl7v2:CNN.3 | hl7v2:CNN.4 | hl7v2:CNN.5 | hl7v2:CNN.6 | hl7v2:CNN.7 | hl7v2:CNN.8 | hl7v2:CNN.9 | hl7v2:CNN.10 | hl7v2:CNN.11 (rule-reference: d887831e15-true-d887867e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d887831e26-true-d887944e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.2/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1202"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d887831e26-true-d887944e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d887831e26-true-d887944e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d887831e37-true-d887967e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.3/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1201"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d887831e37-true-d887967e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d887831e37-true-d887967e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d887831e87-true-d888009e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.7/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1200"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d887831e87-true-d888009e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d887831e87-true-d888009e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d884536e509-true-d888071e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/*[not(self::hl7v2:NDL.1 | self::hl7v2:NDL.2 | self::hl7v2:NDL.3 | self::hl7v2:NDL.4 | self::hl7v2:NDL.5 | self::hl7v2:NDL.6 | self::hl7v2:NDL.7 | self::hl7v2:NDL.8 | self::hl7v2:NDL.9 | self::hl7v2:NDL.10 | self::hl7v2:NDL.11)]"
                 priority="1199"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d884536e509-true-d888071e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:NDL.1 | hl7v2:NDL.2 | hl7v2:NDL.3 | hl7v2:NDL.4 | hl7v2:NDL.5 | hl7v2:NDL.6 | hl7v2:NDL.7 | hl7v2:NDL.8 | hl7v2:NDL.9 | hl7v2:NDL.10 | hl7v2:NDL.11 (rule-reference: d884536e509-true-d888071e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d888055e15-true-d888091e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/*[not(self::hl7v2:CNN.1 | self::hl7v2:CNN.2 | self::hl7v2:CNN.3 | self::hl7v2:CNN.4 | self::hl7v2:CNN.5 | self::hl7v2:CNN.6 | self::hl7v2:CNN.7 | self::hl7v2:CNN.8 | self::hl7v2:CNN.9 | self::hl7v2:CNN.10 | self::hl7v2:CNN.11)]"
                 priority="1198"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d888055e15-true-d888091e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CNN.1 | hl7v2:CNN.2 | hl7v2:CNN.3 | hl7v2:CNN.4 | hl7v2:CNN.5 | hl7v2:CNN.6 | hl7v2:CNN.7 | hl7v2:CNN.8 | hl7v2:CNN.9 | hl7v2:CNN.10 | hl7v2:CNN.11 (rule-reference: d888055e15-true-d888091e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d888055e26-true-d888168e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.2/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1197"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d888055e26-true-d888168e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d888055e26-true-d888168e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d888055e37-true-d888191e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.3/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1196"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d888055e37-true-d888191e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d888055e37-true-d888191e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d888055e87-true-d888233e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.7/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1195"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d888055e87-true-d888233e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d888055e87-true-d888233e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d884536e520-true-d888295e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/*[not(self::hl7v2:NDL.1 | self::hl7v2:NDL.2 | self::hl7v2:NDL.3 | self::hl7v2:NDL.4 | self::hl7v2:NDL.5 | self::hl7v2:NDL.6 | self::hl7v2:NDL.7 | self::hl7v2:NDL.8 | self::hl7v2:NDL.9 | self::hl7v2:NDL.10 | self::hl7v2:NDL.11)]"
                 priority="1194"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d884536e520-true-d888295e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:NDL.1 | hl7v2:NDL.2 | hl7v2:NDL.3 | hl7v2:NDL.4 | hl7v2:NDL.5 | hl7v2:NDL.6 | hl7v2:NDL.7 | hl7v2:NDL.8 | hl7v2:NDL.9 | hl7v2:NDL.10 | hl7v2:NDL.11 (rule-reference: d884536e520-true-d888295e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d888279e15-true-d888315e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/*[not(self::hl7v2:CNN.1 | self::hl7v2:CNN.2 | self::hl7v2:CNN.3 | self::hl7v2:CNN.4 | self::hl7v2:CNN.5 | self::hl7v2:CNN.6 | self::hl7v2:CNN.7 | self::hl7v2:CNN.8 | self::hl7v2:CNN.9 | self::hl7v2:CNN.10 | self::hl7v2:CNN.11)]"
                 priority="1193"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d888279e15-true-d888315e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CNN.1 | hl7v2:CNN.2 | hl7v2:CNN.3 | hl7v2:CNN.4 | hl7v2:CNN.5 | hl7v2:CNN.6 | hl7v2:CNN.7 | hl7v2:CNN.8 | hl7v2:CNN.9 | hl7v2:CNN.10 | hl7v2:CNN.11 (rule-reference: d888279e15-true-d888315e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d888279e26-true-d888392e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.2/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1192"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d888279e26-true-d888392e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d888279e26-true-d888392e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d888279e37-true-d888415e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.3/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1191"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d888279e37-true-d888415e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d888279e37-true-d888415e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d888279e87-true-d888457e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.7/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1190"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d888279e87-true-d888457e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d888279e87-true-d888457e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d884536e531-true-d888519e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/*[not(self::hl7v2:NDL.1 | self::hl7v2:NDL.2 | self::hl7v2:NDL.3 | self::hl7v2:NDL.4 | self::hl7v2:NDL.5 | self::hl7v2:NDL.6 | self::hl7v2:NDL.7 | self::hl7v2:NDL.8 | self::hl7v2:NDL.9 | self::hl7v2:NDL.10 | self::hl7v2:NDL.11)]"
                 priority="1189"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d884536e531-true-d888519e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:NDL.1 | hl7v2:NDL.2 | hl7v2:NDL.3 | hl7v2:NDL.4 | hl7v2:NDL.5 | hl7v2:NDL.6 | hl7v2:NDL.7 | hl7v2:NDL.8 | hl7v2:NDL.9 | hl7v2:NDL.10 | hl7v2:NDL.11 (rule-reference: d884536e531-true-d888519e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d888503e15-true-d888539e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/*[not(self::hl7v2:CNN.1 | self::hl7v2:CNN.2 | self::hl7v2:CNN.3 | self::hl7v2:CNN.4 | self::hl7v2:CNN.5 | self::hl7v2:CNN.6 | self::hl7v2:CNN.7 | self::hl7v2:CNN.8 | self::hl7v2:CNN.9 | self::hl7v2:CNN.10 | self::hl7v2:CNN.11)]"
                 priority="1188"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d888503e15-true-d888539e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CNN.1 | hl7v2:CNN.2 | hl7v2:CNN.3 | hl7v2:CNN.4 | hl7v2:CNN.5 | hl7v2:CNN.6 | hl7v2:CNN.7 | hl7v2:CNN.8 | hl7v2:CNN.9 | hl7v2:CNN.10 | hl7v2:CNN.11 (rule-reference: d888503e15-true-d888539e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d888503e26-true-d888616e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.2/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1187"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d888503e26-true-d888616e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d888503e26-true-d888616e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d888503e37-true-d888639e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.3/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1186"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d888503e37-true-d888639e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d888503e37-true-d888639e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d888503e87-true-d888681e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.7/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1185"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d888503e87-true-d888681e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d888503e87-true-d888681e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d884536e542-true-d888734e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.36/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1184"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d884536e542-true-d888734e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d884536e542-true-d888734e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d884536e564-true-d888767e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.38/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1183"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d884536e564-true-d888767e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d884536e564-true-d888767e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d884536e575-true-d888818e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.39/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1182"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d884536e575-true-d888818e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d884536e575-true-d888818e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d884536e586-true-d888869e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.40/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1181"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d884536e586-true-d888869e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d884536e586-true-d888869e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d884536e624-true-d888932e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.43/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1180"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d884536e624-true-d888932e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d884536e624-true-d888932e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d884536e635-true-d888983e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.44/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1179"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d884536e635-true-d888983e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d884536e635-true-d888983e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d884536e648-true-d889034e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.45/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1178"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d884536e648-true-d889034e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d884536e648-true-d889034e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d884536e661-true-d889085e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.46/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1177"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d884536e661-true-d889085e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d884536e661-true-d889085e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d884536e674-true-d889136e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.47/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1176"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d884536e674-true-d889136e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d884536e674-true-d889136e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d884536e687-true-d889190e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.48/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1175"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d884536e687-true-d889190e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d884536e687-true-d889190e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e13535-true-d889289e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/*[not(self::hl7v2:ORC.1 | self::hl7v2:ORC.2 | self::hl7v2:ORC.3 | self::hl7v2:ORC.4 | self::hl7v2:ORC.5 | self::hl7v2:ORC.6 | self::hl7v2:ORC.7 | self::hl7v2:ORC.8 | self::hl7v2:ORC.9 | self::hl7v2:ORC.10 | self::hl7v2:ORC.11 | self::hl7v2:ORC.12 | self::hl7v2:ORC.13 | self::hl7v2:ORC.14 | self::hl7v2:ORC.15 | self::hl7v2:ORC.16 | self::hl7v2:ORC.17 | self::hl7v2:ORC.18 | self::hl7v2:ORC.19 | self::hl7v2:ORC.20 | self::hl7v2:ORC.21 | self::hl7v2:ORC.22 | self::hl7v2:ORC.23 | self::hl7v2:ORC.24 | self::hl7v2:ORC.25 | self::hl7v2:ORC.26 | self::hl7v2:ORC.27 | self::hl7v2:ORC.28 | self::hl7v2:ORC.29 | self::hl7v2:ORC.30)]"
                 priority="1174"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d20e13535-true-d889289e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:ORC.1 | hl7v2:ORC.2 | hl7v2:ORC.3 | hl7v2:ORC.4 | hl7v2:ORC.5 | hl7v2:ORC.6 | hl7v2:ORC.7 | hl7v2:ORC.8 | hl7v2:ORC.9 | hl7v2:ORC.10 | hl7v2:ORC.11 | hl7v2:ORC.12 | hl7v2:ORC.13 | hl7v2:ORC.14 | hl7v2:ORC.15 | hl7v2:ORC.16 | hl7v2:ORC.17 | hl7v2:ORC.18 | hl7v2:ORC.19 | hl7v2:ORC.20 | hl7v2:ORC.21 | hl7v2:ORC.22 | hl7v2:ORC.23 | hl7v2:ORC.24 | hl7v2:ORC.25 | hl7v2:ORC.26 | hl7v2:ORC.27 | hl7v2:ORC.28 | hl7v2:ORC.29 | hl7v2:ORC.30 (rule-reference: d20e13535-true-d889289e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d889255e18-true-d889308e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.2/*[not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1173"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d889255e18-true-d889308e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d889255e18-true-d889308e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d889255e32-true-d889345e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.3/*[not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1172"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d889255e32-true-d889345e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d889255e32-true-d889345e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d889255e46-true-d889382e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.4/*[not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1171"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d889255e46-true-d889382e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d889255e46-true-d889382e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d889255e83-true-d889439e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/*[not(self::hl7v2:TQ.1 | self::hl7v2:TQ.2 | self::hl7v2:TQ.3 | self::hl7v2:TQ.4 | self::hl7v2:TQ.5 | self::hl7v2:TQ.6 | self::hl7v2:TQ.7 | self::hl7v2:TQ.8 | self::hl7v2:TQ.9 | self::hl7v2:TQ.10 | self::hl7v2:TQ.11 | self::hl7v2:TQ.12)]"
                 priority="1170"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d889255e83-true-d889439e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TQ.1 | hl7v2:TQ.2 | hl7v2:TQ.3 | hl7v2:TQ.4 | hl7v2:TQ.5 | hl7v2:TQ.6 | hl7v2:TQ.7 | hl7v2:TQ.8 | hl7v2:TQ.9 | hl7v2:TQ.10 | hl7v2:TQ.11 | hl7v2:TQ.12 (rule-reference: d889255e83-true-d889439e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d889422e15-true-d889450e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/*[not(self::hl7v2:CQ.1 | self::hl7v2:CQ.2)]"
                 priority="1169"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d889422e15-true-d889450e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CQ.1 | hl7v2:CQ.2 (rule-reference: d889422e15-true-d889450e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d889443e31-true-d889471e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/hl7v2:CQ.2/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1168"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d889443e31-true-d889471e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d889443e31-true-d889471e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d889422e35-true-d889518e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.2/*[not(self::hl7v2:RI.1 | self::hl7v2:RI.2)]"
                 priority="1167"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d889422e35-true-d889518e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:RI.1 | hl7v2:RI.2 (rule-reference: d889422e35-true-d889518e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d889422e189-true-d889547e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.4/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1166"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d889422e189-true-d889547e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d889422e189-true-d889547e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d889422e206-true-d889570e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.5/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1165"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d889422e206-true-d889570e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d889422e206-true-d889570e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d889422e461-true-d889604e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.8/*[not(self::hl7v2:escape)]"
                 priority="1164"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d889422e461-true-d889604e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d889422e461-true-d889604e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d889598e11-true-d889614e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.8/hl7v2:escape/*[not(self::hl7v2:escape)]"
                 priority="1163"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d889598e11-true-d889614e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d889598e11-true-d889614e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d889608e5-true-d889624e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.8/hl7v2:escape/hl7v2:escape/*[not(self::hl7v2:escape)]"
                 priority="1162"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d889608e5-true-d889624e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d889608e5-true-d889624e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d889422e485-true-d889654e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/*[not(self::hl7v2:OSD.1 | self::hl7v2:OSD.2 | self::hl7v2:OSD.3 | self::hl7v2:OSD.4 | self::hl7v2:OSD.5 | self::hl7v2:OSD.6 | self::hl7v2:OSD.7 | self::hl7v2:OSD.8 | self::hl7v2:OSD.9 | self::hl7v2:OSD.10 | self::hl7v2:OSD.11)]"
                 priority="1161"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d889422e485-true-d889654e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:OSD.1 | hl7v2:OSD.2 | hl7v2:OSD.3 | hl7v2:OSD.4 | hl7v2:OSD.5 | hl7v2:OSD.6 | hl7v2:OSD.7 | hl7v2:OSD.8 | hl7v2:OSD.9 | hl7v2:OSD.10 | hl7v2:OSD.11 (rule-reference: d889422e485-true-d889654e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d889422e505-true-d889735e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.11/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1160"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d889422e505-true-d889735e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d889422e505-true-d889735e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d889255e94-true-d889788e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.8/*[not(self::hl7v2:EIP.1 | self::hl7v2:EIP.2)]"
                 priority="1159"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d889255e94-true-d889788e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EIP.1 | hl7v2:EIP.2 (rule-reference: d889255e94-true-d889788e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d889781e18-true-d889801e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.1/*[not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1158"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d889781e18-true-d889801e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d889781e18-true-d889801e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d889781e47-true-d889838e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.2/*[not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1157"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d889781e47-true-d889838e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d889781e47-true-d889838e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d889255e108-true-d889873e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.9/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1156"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d889255e108-true-d889873e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d889255e108-true-d889873e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d889255e119-true-d889917e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/*[not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="1155"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d889255e119-true-d889917e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d889255e119-true-d889917e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d889889e32-true-d889937e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.2/*[not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="1154"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d889889e32-true-d889937e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d889889e32-true-d889937e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d889889e123-true-d890015e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.9/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1153"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d889889e123-true-d890015e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d889889e123-true-d890015e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d889889e215-true-d890069e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.14/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1152"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d889889e215-true-d890069e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d889889e215-true-d890069e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d889889e275-true-d890108e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.16/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1151"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d889889e275-true-d890108e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d889889e275-true-d890108e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d889889e288-true-d890155e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.17/*[not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1150"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d889889e288-true-d890155e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d889889e288-true-d890155e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d890148e17-true-d890166e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.17/hl7v2:DR.1/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1149"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d890148e17-true-d890166e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d890148e17-true-d890166e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d890148e28-true-d890189e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.17/hl7v2:DR.2/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1148"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d890148e28-true-d890189e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d890148e28-true-d890189e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d889889e318-true-d890218e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.19/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1147"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d889889e318-true-d890218e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d889889e318-true-d890218e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d889889e329-true-d890241e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.20/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1146"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d889889e329-true-d890241e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d889889e329-true-d890241e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d889889e351-true-d890277e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1145"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d889889e351-true-d890277e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d889889e351-true-d890277e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d889889e369-true-d890349e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1144"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d889889e369-true-d890349e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d889889e369-true-d890349e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d889255e130-true-d890435e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/*[not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="1143"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d889255e130-true-d890435e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d889255e130-true-d890435e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d890407e32-true-d890455e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.2/*[not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="1142"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d890407e32-true-d890455e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d890407e32-true-d890455e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d890407e123-true-d890533e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.9/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1141"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d890407e123-true-d890533e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d890407e123-true-d890533e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d890407e215-true-d890587e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.14/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1140"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d890407e215-true-d890587e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d890407e215-true-d890587e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d890407e275-true-d890626e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.16/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1139"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d890407e275-true-d890626e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d890407e275-true-d890626e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d890407e288-true-d890673e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.17/*[not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1138"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d890407e288-true-d890673e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d890407e288-true-d890673e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d890666e17-true-d890684e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.17/hl7v2:DR.1/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1137"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d890666e17-true-d890684e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d890666e17-true-d890684e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d890666e28-true-d890707e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.17/hl7v2:DR.2/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1136"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d890666e28-true-d890707e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d890666e28-true-d890707e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d890407e318-true-d890736e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.19/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1135"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d890407e318-true-d890736e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d890407e318-true-d890736e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d890407e329-true-d890759e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.20/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1134"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d890407e329-true-d890759e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d890407e329-true-d890759e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d890407e351-true-d890795e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1133"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d890407e351-true-d890795e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d890407e351-true-d890795e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d890407e369-true-d890867e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1132"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d890407e369-true-d890867e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d890407e369-true-d890867e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d889255e142-true-d890953e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/*[not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="1131"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d889255e142-true-d890953e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d889255e142-true-d890953e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d890925e32-true-d890973e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.2/*[not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="1130"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d890925e32-true-d890973e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d890925e32-true-d890973e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d890925e123-true-d891051e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.9/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1129"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d890925e123-true-d891051e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d890925e123-true-d891051e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d890925e215-true-d891105e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.14/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1128"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d890925e215-true-d891105e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d890925e215-true-d891105e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d890925e275-true-d891144e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.16/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1127"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d890925e275-true-d891144e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d890925e275-true-d891144e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d890925e288-true-d891191e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.17/*[not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1126"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d890925e288-true-d891191e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d890925e288-true-d891191e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d891184e17-true-d891202e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.17/hl7v2:DR.1/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1125"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d891184e17-true-d891202e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d891184e17-true-d891202e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d891184e28-true-d891225e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.17/hl7v2:DR.2/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1124"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d891184e28-true-d891225e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d891184e28-true-d891225e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d890925e318-true-d891254e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.19/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1123"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d890925e318-true-d891254e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d890925e318-true-d891254e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d890925e329-true-d891277e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.20/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1122"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d890925e329-true-d891277e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d890925e329-true-d891277e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d890925e351-true-d891313e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1121"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d890925e351-true-d891313e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d890925e351-true-d891313e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d890925e369-true-d891385e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1120"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d890925e369-true-d891385e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d890925e369-true-d891385e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d889255e153-true-d891459e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13/*[not(self::hl7v2:PL.1 | self::hl7v2:PL.2 | self::hl7v2:PL.3 | self::hl7v2:PL.4 | self::hl7v2:PL.5 | self::hl7v2:PL.6 | self::hl7v2:PL.7 | self::hl7v2:PL.8 | self::hl7v2:PL.9 | self::hl7v2:PL.10 | self::hl7v2:PL.11)]"
                 priority="1119"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d889255e153-true-d891459e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:PL.1 | hl7v2:PL.2 | hl7v2:PL.3 | hl7v2:PL.4 | hl7v2:PL.5 | hl7v2:PL.6 | hl7v2:PL.7 | hl7v2:PL.8 | hl7v2:PL.9 | hl7v2:PL.10 | hl7v2:PL.11 (rule-reference: d889255e153-true-d891459e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d891443e48-true-d891489e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.4/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1118"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d891443e48-true-d891489e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d891443e48-true-d891489e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d891443e125-true-d891550e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.10/*[not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1117"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d891443e125-true-d891550e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d891443e125-true-d891550e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d891443e134-true-d891586e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.11/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1116"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d891443e134-true-d891586e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d891443e134-true-d891586e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d889255e164-true-d891625e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.14/*[not(self::hl7v2:XTN.1 | self::hl7v2:XTN.2 | self::hl7v2:XTN.3 | self::hl7v2:XTN.4 | self::hl7v2:XTN.5 | self::hl7v2:XTN.6 | self::hl7v2:XTN.7 | self::hl7v2:XTN.8 | self::hl7v2:XTN.9 | self::hl7v2:XTN.10 | self::hl7v2:XTN.11 | self::hl7v2:XTN.12)]"
                 priority="1115"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d889255e164-true-d891625e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XTN.1 | hl7v2:XTN.2 | hl7v2:XTN.3 | hl7v2:XTN.4 | hl7v2:XTN.5 | hl7v2:XTN.6 | hl7v2:XTN.7 | hl7v2:XTN.8 | hl7v2:XTN.9 | hl7v2:XTN.10 | hl7v2:XTN.11 | hl7v2:XTN.12 (rule-reference: d889255e164-true-d891625e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d889255e175-true-d891708e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.15/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1114"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d889255e175-true-d891708e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d889255e175-true-d891708e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d889255e186-true-d891735e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.16/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1113"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d889255e186-true-d891735e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d889255e186-true-d891735e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d889255e197-true-d891786e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.17/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1112"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d889255e197-true-d891786e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d889255e197-true-d891786e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d889255e208-true-d891837e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.18/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1111"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d889255e208-true-d891837e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d889255e208-true-d891837e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d889255e219-true-d891905e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/*[not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="1110"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d889255e219-true-d891905e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d889255e219-true-d891905e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d891877e32-true-d891925e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.2/*[not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="1109"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d891877e32-true-d891925e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d891877e32-true-d891925e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d891877e123-true-d892003e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.9/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1108"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d891877e123-true-d892003e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d891877e123-true-d892003e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d891877e215-true-d892057e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.14/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1107"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d891877e215-true-d892057e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d891877e215-true-d892057e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d891877e275-true-d892096e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.16/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1106"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d891877e275-true-d892096e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d891877e275-true-d892096e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d891877e288-true-d892143e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.17/*[not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1105"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d891877e288-true-d892143e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d891877e288-true-d892143e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d892136e17-true-d892154e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.17/hl7v2:DR.1/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1104"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d892136e17-true-d892154e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d892136e17-true-d892154e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d892136e28-true-d892177e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.17/hl7v2:DR.2/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1103"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d892136e28-true-d892177e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d892136e28-true-d892177e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d891877e318-true-d892206e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.19/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1102"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d891877e318-true-d892206e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d891877e318-true-d892206e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d891877e329-true-d892229e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.20/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1101"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d891877e329-true-d892229e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d891877e329-true-d892229e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d891877e351-true-d892265e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1100"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d891877e351-true-d892265e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d891877e351-true-d892265e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d891877e369-true-d892337e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1099"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d891877e369-true-d892337e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d891877e369-true-d892337e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d889255e230-true-d892406e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.20/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1098"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d889255e230-true-d892406e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d889255e230-true-d892406e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d889255e243-true-d892461e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.21/*[not(self::hl7v2:XON.1 | self::hl7v2:XON.2 | self::hl7v2:XON.3 | self::hl7v2:XON.4 | self::hl7v2:XON.5 | self::hl7v2:XON.6 | self::hl7v2:XON.7 | self::hl7v2:XON.8 | self::hl7v2:XON.9 | self::hl7v2:XON.10)]"
                 priority="1097"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d889255e243-true-d892461e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XON.1 | hl7v2:XON.2 | hl7v2:XON.3 | hl7v2:XON.4 | hl7v2:XON.5 | hl7v2:XON.6 | hl7v2:XON.7 | hl7v2:XON.8 | hl7v2:XON.9 | hl7v2:XON.10 (rule-reference: d889255e243-true-d892461e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d892446e80-true-d892503e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.6/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1096"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d892446e80-true-d892503e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d892446e80-true-d892503e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d892446e119-true-d892539e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.8/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1095"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d892446e119-true-d892539e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d892446e119-true-d892539e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d889255e254-true-d892592e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/*[not(self::hl7v2:XAD.1 | self::hl7v2:XAD.2 | self::hl7v2:XAD.3 | self::hl7v2:XAD.4 | self::hl7v2:XAD.5 | self::hl7v2:XAD.6 | self::hl7v2:XAD.7 | self::hl7v2:XAD.8 | self::hl7v2:XAD.9 | self::hl7v2:XAD.10 | self::hl7v2:XAD.11 | self::hl7v2:XAD.12 | self::hl7v2:XAD.13 | self::hl7v2:XAD.14)]"
                 priority="1094"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d889255e254-true-d892592e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XAD.1 | hl7v2:XAD.2 | hl7v2:XAD.3 | hl7v2:XAD.4 | hl7v2:XAD.5 | hl7v2:XAD.6 | hl7v2:XAD.7 | hl7v2:XAD.8 | hl7v2:XAD.9 | hl7v2:XAD.10 | hl7v2:XAD.11 | hl7v2:XAD.12 | hl7v2:XAD.13 | hl7v2:XAD.14 (rule-reference: d889255e254-true-d892592e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d892573e15-true-d892604e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.1/*[not(self::hl7v2:SAD.1 | self::hl7v2:SAD.2 | self::hl7v2:SAD.3)]"
                 priority="1093"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d892573e15-true-d892604e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:SAD.1 | hl7v2:SAD.2 | hl7v2:SAD.3 (rule-reference: d892573e15-true-d892604e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d892573e214-true-d892693e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.12/*[not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1092"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d892573e214-true-d892693e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d892573e214-true-d892693e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d892686e23-true-d892704e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.12/hl7v2:DR.1/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1091"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d892686e23-true-d892704e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d892686e23-true-d892704e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d892686e34-true-d892727e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.12/hl7v2:DR.2/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1090"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d892686e34-true-d892727e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d892686e34-true-d892727e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d892573e234-true-d892750e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.13/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1089"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d892573e234-true-d892750e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d892573e234-true-d892750e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d892573e248-true-d892773e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.14/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1088"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d892573e248-true-d892773e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d892573e248-true-d892773e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d889255e266-true-d892806e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.23/*[not(self::hl7v2:XTN.1 | self::hl7v2:XTN.2 | self::hl7v2:XTN.3 | self::hl7v2:XTN.4 | self::hl7v2:XTN.5 | self::hl7v2:XTN.6 | self::hl7v2:XTN.7 | self::hl7v2:XTN.8 | self::hl7v2:XTN.9 | self::hl7v2:XTN.10 | self::hl7v2:XTN.11 | self::hl7v2:XTN.12)]"
                 priority="1087"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d889255e266-true-d892806e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XTN.1 | hl7v2:XTN.2 | hl7v2:XTN.3 | hl7v2:XTN.4 | hl7v2:XTN.5 | hl7v2:XTN.6 | hl7v2:XTN.7 | hl7v2:XTN.8 | hl7v2:XTN.9 | hl7v2:XTN.10 | hl7v2:XTN.11 | hl7v2:XTN.12 (rule-reference: d889255e266-true-d892806e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d889255e277-true-d892901e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/*[not(self::hl7v2:XAD.1 | self::hl7v2:XAD.2 | self::hl7v2:XAD.3 | self::hl7v2:XAD.4 | self::hl7v2:XAD.5 | self::hl7v2:XAD.6 | self::hl7v2:XAD.7 | self::hl7v2:XAD.8 | self::hl7v2:XAD.9 | self::hl7v2:XAD.10 | self::hl7v2:XAD.11 | self::hl7v2:XAD.12 | self::hl7v2:XAD.13 | self::hl7v2:XAD.14)]"
                 priority="1086"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d889255e277-true-d892901e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XAD.1 | hl7v2:XAD.2 | hl7v2:XAD.3 | hl7v2:XAD.4 | hl7v2:XAD.5 | hl7v2:XAD.6 | hl7v2:XAD.7 | hl7v2:XAD.8 | hl7v2:XAD.9 | hl7v2:XAD.10 | hl7v2:XAD.11 | hl7v2:XAD.12 | hl7v2:XAD.13 | hl7v2:XAD.14 (rule-reference: d889255e277-true-d892901e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d892882e15-true-d892913e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.1/*[not(self::hl7v2:SAD.1 | self::hl7v2:SAD.2 | self::hl7v2:SAD.3)]"
                 priority="1085"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d892882e15-true-d892913e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:SAD.1 | hl7v2:SAD.2 | hl7v2:SAD.3 (rule-reference: d892882e15-true-d892913e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d892882e214-true-d893002e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.12/*[not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1084"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d892882e214-true-d893002e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d892882e214-true-d893002e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d892995e23-true-d893013e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.12/hl7v2:DR.1/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1083"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d892995e23-true-d893013e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d892995e23-true-d893013e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d892995e34-true-d893036e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.12/hl7v2:DR.2/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1082"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d892995e34-true-d893036e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d892995e34-true-d893036e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d892882e234-true-d893059e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.13/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1081"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d892882e234-true-d893059e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d892882e234-true-d893059e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d892882e248-true-d893082e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.14/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1080"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d892882e248-true-d893082e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d892882e248-true-d893082e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d889255e288-true-d893112e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.25/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1079"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d889255e288-true-d893112e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d889255e288-true-d893112e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d889255e299-true-d893184e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.26/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1078"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d889255e299-true-d893184e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d889255e299-true-d893184e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d889255e312-true-d893249e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.27/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1077"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d889255e312-true-d893249e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d889255e312-true-d893249e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d889255e323-true-d893279e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.28/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1076"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d889255e323-true-d893279e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d889255e323-true-d893279e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d889255e336-true-d893351e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.29/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1075"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d889255e336-true-d893351e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d889255e336-true-d893351e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d889255e349-true-d893423e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.30/*[not(self::hl7v2:CNE.1 | self::hl7v2:CNE.2 | self::hl7v2:CNE.3 | self::hl7v2:CNE.4 | self::hl7v2:CNE.5 | self::hl7v2:CNE.6 | self::hl7v2:CNE.7 | self::hl7v2:CNE.8 | self::hl7v2:CNE.9)]"
                 priority="1074"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d889255e349-true-d893423e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CNE.1 | hl7v2:CNE.2 | hl7v2:CNE.3 | hl7v2:CNE.4 | hl7v2:CNE.5 | hl7v2:CNE.6 | hl7v2:CNE.7 | hl7v2:CNE.8 | hl7v2:CNE.9 (rule-reference: d889255e349-true-d893423e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e13537-true-d893490e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:NTE/*[not(self::hl7v2:NTE.1 | self::hl7v2:NTE.2 | self::hl7v2:NTE.3 | self::hl7v2:NTE.4)]"
                 priority="1073"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d20e13537-true-d893490e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:NTE.1 | hl7v2:NTE.2 | hl7v2:NTE.3 | hl7v2:NTE.4 (rule-reference: d20e13537-true-d893490e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d893482e110-true-d893512e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:NTE/hl7v2:NTE.3/*[not(self::hl7v2:escape)]"
                 priority="1072"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d893482e110-true-d893512e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d893482e110-true-d893512e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d893506e36-true-d893522e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/*[not(self::hl7v2:escape)]"
                 priority="1071"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d893506e36-true-d893522e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d893506e36-true-d893522e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d893516e5-true-d893532e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/hl7v2:escape/*[not(self::hl7v2:escape)]"
                 priority="1070"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d893516e5-true-d893532e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d893516e5-true-d893532e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d893482e142-true-d893551e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:NTE/hl7v2:NTE.4/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1069"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d893482e142-true-d893551e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d893482e142-true-d893551e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e13539-true-d893595e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/*[not(self::hl7v2:TQ1 | self::hl7v2:TQ2)]"
                 priority="1068"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d20e13539-true-d893595e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TQ1 | hl7v2:TQ2 (rule-reference: d20e13539-true-d893595e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e13541-true-d893618e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/*[not(self::hl7v2:TQ1.1 | self::hl7v2:TQ1.2 | self::hl7v2:TQ1.3 | self::hl7v2:TQ1.4 | self::hl7v2:TQ1.5 | self::hl7v2:TQ1.6 | self::hl7v2:TQ1.7 | self::hl7v2:TQ1.8 | self::hl7v2:TQ1.9 | self::hl7v2:TQ1.10 | self::hl7v2:TQ1.11 | self::hl7v2:TQ1.12 | self::hl7v2:TQ1.13 | self::hl7v2:TQ1.14)]"
                 priority="1067"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d20e13541-true-d893618e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TQ1.1 | hl7v2:TQ1.2 | hl7v2:TQ1.3 | hl7v2:TQ1.4 | hl7v2:TQ1.5 | hl7v2:TQ1.6 | hl7v2:TQ1.7 | hl7v2:TQ1.8 | hl7v2:TQ1.9 | hl7v2:TQ1.10 | hl7v2:TQ1.11 | hl7v2:TQ1.12 | hl7v2:TQ1.13 | hl7v2:TQ1.14 (rule-reference: d20e13541-true-d893618e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d893600e15-true-d893635e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.2/*[not(self::hl7v2:CQ.1 | self::hl7v2:CQ.2)]"
                 priority="1066"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d893600e15-true-d893635e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CQ.1 | hl7v2:CQ.2 (rule-reference: d893600e15-true-d893635e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d893628e26-true-d893656e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.2/hl7v2:CQ.2/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1065"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d893628e26-true-d893656e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d893628e26-true-d893656e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d893600e26-true-d893712e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.3/*[not(self::hl7v2:RPT.1 | self::hl7v2:RPT.2 | self::hl7v2:RPT.3 | self::hl7v2:RPT.4 | self::hl7v2:RPT.5 | self::hl7v2:RPT.6 | self::hl7v2:RPT.7 | self::hl7v2:RPT.8 | self::hl7v2:RPT.9 | self::hl7v2:RPT.10 | self::hl7v2:RPT.11)]"
                 priority="1064"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d893600e26-true-d893712e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:RPT.1 | hl7v2:RPT.2 | hl7v2:RPT.3 | hl7v2:RPT.4 | hl7v2:RPT.5 | hl7v2:RPT.6 | hl7v2:RPT.7 | hl7v2:RPT.8 | hl7v2:RPT.9 | hl7v2:RPT.10 | hl7v2:RPT.11 (rule-reference: d893600e26-true-d893712e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d893696e18-true-d893730e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1063"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d893696e18-true-d893730e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d893696e18-true-d893730e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d893600e50-true-d893861e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.5/*[not(self::hl7v2:CQ.1 | self::hl7v2:CQ.2)]"
                 priority="1062"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d893600e50-true-d893861e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CQ.1 | hl7v2:CQ.2 (rule-reference: d893600e50-true-d893861e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d893854e26-true-d893882e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.5/hl7v2:CQ.2/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1061"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d893854e26-true-d893882e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d893854e26-true-d893882e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d893600e61-true-d893929e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.6/*[not(self::hl7v2:CQ.1 | self::hl7v2:CQ.2)]"
                 priority="1060"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d893600e61-true-d893929e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CQ.1 | hl7v2:CQ.2 (rule-reference: d893600e61-true-d893929e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d893922e26-true-d893950e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.6/hl7v2:CQ.2/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1059"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d893922e26-true-d893950e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d893922e26-true-d893950e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d893600e72-true-d893997e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.7/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1058"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d893600e72-true-d893997e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d893600e72-true-d893997e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d893600e86-true-d894020e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.8/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1057"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d893600e86-true-d894020e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d893600e86-true-d894020e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d893600e100-true-d894050e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.9/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1056"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d893600e100-true-d894050e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d893600e100-true-d894050e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d893600e117-true-d894114e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.10/*[not(self::hl7v2:escape)]"
                 priority="1055"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d893600e117-true-d894114e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d893600e117-true-d894114e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d894108e15-true-d894124e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.10/hl7v2:escape/*[not(self::hl7v2:escape)]"
                 priority="1054"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d894108e15-true-d894124e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d894108e15-true-d894124e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d894118e5-true-d894134e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.10/hl7v2:escape/hl7v2:escape/*[not(self::hl7v2:escape)]"
                 priority="1053"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d894118e5-true-d894134e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d894118e5-true-d894134e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d893600e128-true-d894148e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.11/*[not(self::hl7v2:escape)]"
                 priority="1052"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d893600e128-true-d894148e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d893600e128-true-d894148e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d894142e15-true-d894158e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.11/hl7v2:escape/*[not(self::hl7v2:escape)]"
                 priority="1051"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d894142e15-true-d894158e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d894142e15-true-d894158e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d894152e5-true-d894168e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.11/hl7v2:escape/hl7v2:escape/*[not(self::hl7v2:escape)]"
                 priority="1050"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d894152e5-true-d894168e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d894152e5-true-d894168e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d893600e153-true-d894189e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.13/*[not(self::hl7v2:CQ.1 | self::hl7v2:CQ.2)]"
                 priority="1049"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d893600e153-true-d894189e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CQ.1 | hl7v2:CQ.2 (rule-reference: d893600e153-true-d894189e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d894182e26-true-d894210e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.13/hl7v2:CQ.2/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1048"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d894182e26-true-d894210e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d894182e26-true-d894210e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e13543-true-d894271e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/*[not(self::hl7v2:TQ2.1 | self::hl7v2:TQ2.2 | self::hl7v2:TQ2.3 | self::hl7v2:TQ2.4 | self::hl7v2:TQ2.5 | self::hl7v2:TQ2.6 | self::hl7v2:TQ2.7 | self::hl7v2:TQ2.8 | self::hl7v2:TQ2.9 | self::hl7v2:TQ2.10)]"
                 priority="1047"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d20e13543-true-d894271e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TQ2.1 | hl7v2:TQ2.2 | hl7v2:TQ2.3 | hl7v2:TQ2.4 | hl7v2:TQ2.5 | hl7v2:TQ2.6 | hl7v2:TQ2.7 | hl7v2:TQ2.8 | hl7v2:TQ2.9 | hl7v2:TQ2.10 (rule-reference: d20e13543-true-d894271e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d894257e25-true-d894296e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.3/*[not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1046"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d894257e25-true-d894296e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d894257e25-true-d894296e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d894257e36-true-d894333e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.4/*[not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1045"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d894257e36-true-d894333e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d894257e36-true-d894333e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d894257e47-true-d894370e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.5/*[not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1044"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d894257e47-true-d894370e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d894257e47-true-d894370e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d894257e84-true-d894417e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.8/*[not(self::hl7v2:CQ.1 | self::hl7v2:CQ.2)]"
                 priority="1043"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d894257e84-true-d894417e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CQ.1 | hl7v2:CQ.2 (rule-reference: d894257e84-true-d894417e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d894410e26-true-d894438e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.8/hl7v2:CQ.2/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1042"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d894410e26-true-d894438e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d894410e26-true-d894438e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e13549-true-d894496e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/*[not(self::hl7v2:OBX | self::hl7v2:TCD | self::hl7v2:SID | self::hl7v2:NTE)]"
                 priority="1041"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d20e13549-true-d894496e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:OBX | hl7v2:TCD | hl7v2:SID | hl7v2:NTE (rule-reference: d20e13549-true-d894496e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e13554-true-d894524e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/*[not(self::hl7v2:OBX.1 | self::hl7v2:OBX.2 | self::hl7v2:OBX.3 | self::hl7v2:OBX.4 | self::hl7v2:OBX.5 | self::hl7v2:OBX.6 | self::hl7v2:OBX.7 | self::hl7v2:OBX.8 | self::hl7v2:OBX.9 | self::hl7v2:OBX.10 | self::hl7v2:OBX.11 | self::hl7v2:OBX.12 | self::hl7v2:OBX.13 | self::hl7v2:OBX.14 | self::hl7v2:OBX.15 | self::hl7v2:OBX.16 | self::hl7v2:OBX.17 | self::hl7v2:OBX.18 | self::hl7v2:OBX.19)]"
                 priority="1040"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d20e13554-true-d894524e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:OBX.1 | hl7v2:OBX.2 | hl7v2:OBX.3 | hl7v2:OBX.4 | hl7v2:OBX.5 | hl7v2:OBX.6 | hl7v2:OBX.7 | hl7v2:OBX.8 | hl7v2:OBX.9 | hl7v2:OBX.10 | hl7v2:OBX.11 | hl7v2:OBX.12 | hl7v2:OBX.13 | hl7v2:OBX.14 | hl7v2:OBX.15 | hl7v2:OBX.16 | hl7v2:OBX.17 | hl7v2:OBX.18 | hl7v2:OBX.19 (rule-reference: d20e13554-true-d894524e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d894501e65-true-d894551e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1039"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d894501e65-true-d894551e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d894501e65-true-d894551e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d894501e152-true-d894614e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1038"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d894501e152-true-d894614e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d894501e152-true-d894614e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d894501e282-true-d894691e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.12/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1037"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d894501e282-true-d894691e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d894501e282-true-d894691e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d894501e304-true-d894720e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.14/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1036"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d894501e304-true-d894720e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d894501e304-true-d894720e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d894501e322-true-d894747e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1035"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d894501e322-true-d894747e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d894501e322-true-d894747e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d894501e333-true-d894815e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/*[not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="1034"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d894501e333-true-d894815e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d894501e333-true-d894815e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d894787e32-true-d894835e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/*[not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="1033"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d894787e32-true-d894835e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d894787e32-true-d894835e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d894787e123-true-d894913e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1032"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d894787e123-true-d894913e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d894787e123-true-d894913e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d894787e215-true-d894967e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1031"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d894787e215-true-d894967e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d894787e215-true-d894967e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d894787e275-true-d895006e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1030"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d894787e275-true-d895006e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d894787e275-true-d895006e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d894787e288-true-d895053e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/*[not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1029"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d894787e288-true-d895053e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d894787e288-true-d895053e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d895046e17-true-d895064e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1028"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d895046e17-true-d895064e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d895046e17-true-d895064e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d895046e28-true-d895087e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1027"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d895046e28-true-d895087e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d895046e28-true-d895087e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d894787e318-true-d895116e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1026"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d894787e318-true-d895116e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d894787e318-true-d895116e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d894787e329-true-d895139e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1025"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d894787e329-true-d895139e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d894787e329-true-d895139e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d894787e351-true-d895175e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1024"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d894787e351-true-d895175e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d894787e351-true-d895175e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d894787e369-true-d895247e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1023"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d894787e369-true-d895247e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d894787e369-true-d895247e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d894501e344-true-d895316e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1022"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d894501e344-true-d895316e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d894501e344-true-d895316e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d894501e355-true-d895365e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/*[not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1021"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d894501e355-true-d895365e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d894501e355-true-d895365e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d894501e366-true-d895400e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.19/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1020"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d894501e366-true-d895400e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d894501e366-true-d895400e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e13556-true-d895429e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/*[not(self::hl7v2:TCD.1 | self::hl7v2:TCD.2 | self::hl7v2:TCD.3 | self::hl7v2:TCD.4 | self::hl7v2:TCD.5 | self::hl7v2:TCD.6 | self::hl7v2:TCD.7 | self::hl7v2:TCD.8)]"
                 priority="1019"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d20e13556-true-d895429e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TCD.1 | hl7v2:TCD.2 | hl7v2:TCD.3 | hl7v2:TCD.4 | hl7v2:TCD.5 | hl7v2:TCD.6 | hl7v2:TCD.7 | hl7v2:TCD.8 (rule-reference: d20e13556-true-d895429e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d895417e1-true-d895444e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.1/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1018"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d895417e1-true-d895444e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d895417e1-true-d895444e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d895417e12-true-d895493e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.2/*[not(self::hl7v2:SN.1 | self::hl7v2:SN.2 | self::hl7v2:SN.3 | self::hl7v2:SN.4)]"
                 priority="1017"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d895417e12-true-d895493e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:SN.1 | hl7v2:SN.2 | hl7v2:SN.3 | hl7v2:SN.4 (rule-reference: d895417e12-true-d895493e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d895417e23-true-d895530e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.3/*[not(self::hl7v2:SN.1 | self::hl7v2:SN.2 | self::hl7v2:SN.3 | self::hl7v2:SN.4)]"
                 priority="1016"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d895417e23-true-d895530e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:SN.1 | hl7v2:SN.2 | hl7v2:SN.3 | hl7v2:SN.4 (rule-reference: d895417e23-true-d895530e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d895417e34-true-d895567e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.4/*[not(self::hl7v2:SN.1 | self::hl7v2:SN.2 | self::hl7v2:SN.3 | self::hl7v2:SN.4)]"
                 priority="1015"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d895417e34-true-d895567e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:SN.1 | hl7v2:SN.2 | hl7v2:SN.3 | hl7v2:SN.4 (rule-reference: d895417e34-true-d895567e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d895417e45-true-d895604e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.5/*[not(self::hl7v2:SN.1 | self::hl7v2:SN.2 | self::hl7v2:SN.3 | self::hl7v2:SN.4)]"
                 priority="1014"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d895417e45-true-d895604e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:SN.1 | hl7v2:SN.2 | hl7v2:SN.3 | hl7v2:SN.4 (rule-reference: d895417e45-true-d895604e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d895417e82-true-d895655e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.8/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1013"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d895417e82-true-d895655e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d895417e82-true-d895655e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e13558-true-d895704e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:SID/*[not(self::hl7v2:SID.1 | self::hl7v2:SID.2 | self::hl7v2:SID.3 | self::hl7v2:SID.4)]"
                 priority="1012"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d20e13558-true-d895704e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:SID.1 | hl7v2:SID.2 | hl7v2:SID.3 | hl7v2:SID.4 (rule-reference: d20e13558-true-d895704e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d895696e1-true-d895719e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:SID/hl7v2:SID.1/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1011"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d895696e1-true-d895719e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d895696e1-true-d895719e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d895696e34-true-d895782e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:SID/hl7v2:SID.4/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1010"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d895696e34-true-d895782e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d895696e34-true-d895782e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e13560-true-d895831e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:NTE/*[not(self::hl7v2:NTE.1 | self::hl7v2:NTE.2 | self::hl7v2:NTE.3 | self::hl7v2:NTE.4)]"
                 priority="1009"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d20e13560-true-d895831e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:NTE.1 | hl7v2:NTE.2 | hl7v2:NTE.3 | hl7v2:NTE.4 (rule-reference: d20e13560-true-d895831e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d895823e110-true-d895853e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:NTE/hl7v2:NTE.3/*[not(self::hl7v2:escape)]"
                 priority="1008"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d895823e110-true-d895853e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d895823e110-true-d895853e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d895847e36-true-d895863e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/*[not(self::hl7v2:escape)]"
                 priority="1007"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d895847e36-true-d895863e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d895847e36-true-d895863e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d895857e5-true-d895873e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/hl7v2:escape/*[not(self::hl7v2:escape)]"
                 priority="1006"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d895857e5-true-d895873e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d895857e5-true-d895873e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d895823e142-true-d895892e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:NTE/hl7v2:NTE.4/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1005"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d895823e142-true-d895892e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d895823e142-true-d895892e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e13563-true-d895940e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:CTI/*[not(self::hl7v2:CTI.1 | self::hl7v2:CTI.2 | self::hl7v2:CTI.3)]"
                 priority="1004"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d20e13563-true-d895940e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CTI.1 | hl7v2:CTI.2 | hl7v2:CTI.3 (rule-reference: d20e13563-true-d895940e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d895933e1-true-d895953e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:CTI/hl7v2:CTI.1/*[not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1003"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d895933e1-true-d895953e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d895933e1-true-d895953e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d895933e12-true-d895992e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:CTI/hl7v2:CTI.2/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1002"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d895933e12-true-d895992e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d895933e12-true-d895992e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d895933e23-true-d896043e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:CTI/hl7v2:CTI.3/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1001"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d895933e23-true-d896043e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d895933e23-true-d896043e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e13567-true-d896090e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:DSC/*[not(self::hl7v2:DSC.1 | self::hl7v2:DSC.2)]"
                 priority="1000"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2PublicHealth)/d20e13567-true-d896090e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DSC.1 | hl7v2:DSC.2 (rule-reference: d20e13567-true-d896090e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M15"/>
   <xsl:template match="@*|node()" priority="-2" mode="M15">
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>
</xsl:stylesheet>
